@@ -1,6 +1,6 @@
 /*
  *
- *  (c) COPYRIGHT MIT and INRIA, 1996-2000
+ *  (c) COPYRIGHT MIT and INRIA, 1996-2001
  *  Please first read the full copyright statement in file COPYRIGHT.
  *
  */
@@ -9,7 +9,7 @@
  * Initialization functions and button functions of Amaya application.
  *
  * Authors: V. Quint, I. Vatton
- *          R. Guetari (W3C/INRIA) - Unicode and Windows version.
+ *          R. Guetari (W3C/INRIA) - Windows version.
  */
 
 
@@ -25,7 +25,7 @@ typedef struct _SubDoc
   {
      struct _SubDoc  *SDnext;
      Element          SDel;
-     STRING           SDname;
+     char            *SDname;
   }SubDoc;
 
 /* the structure used for the GetIncludedDocuments_callback function */
@@ -33,8 +33,8 @@ typedef struct _IncludeCtxt
 {
   Element		div; /* enclosing element for the search */
   Element		link; /* current processed link */
-  STRING		url; /* called url */
-  STRING                name; /* the fragment name */
+  char		       *url; /* called url */
+  char                 *name; /* the fragment name */
   struct _IncludeCtxt  *ctxt; /* the previous context */
 } IncludeCtxt;
 
@@ -45,8 +45,9 @@ ThotBool	 WithToC;
 ThotBool         IgnoreCSS;
 
 static struct _SubDoc  *SubDocs;
-static CHAR_T           PSdir[MAX_PATH];
-static CHAR_T           PPrinter[MAX_PATH];
+static char             PSfile[MAX_PATH];
+static char             PPrinter[MAX_PATH];
+static char            *DocPrintURL;
 static Document		DocPrint;
 static int              PaperPrint;
 static int              ManualFeed = PP_OFF;
@@ -70,13 +71,7 @@ static ThotBool GetIncludedDocuments ();
 /*----------------------------------------------------------------------
   RegisterSubDoc adds a new entry in SubDoc table.
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-static void         RegisterSubDoc (Element el, STRING url)
-#else
-static void         RegisterSubDoc (el, url)
-Element             el;
-STRING              url;
-#endif
+static void         RegisterSubDoc (Element el, char *url)
 {
   struct _SubDoc  *entry, *last;
 
@@ -86,7 +81,7 @@ STRING              url;
   entry = TtaGetMemory (sizeof (struct _SubDoc));
   entry->SDnext = NULL;
   entry->SDel = el;
-  entry->SDname = TtaWCSdup (url);
+  entry->SDname = TtaStrdup (url);
 
   if (SubDocs == NULL)
     SubDocs = entry;
@@ -105,12 +100,7 @@ STRING              url;
   within the SubDoc table.
   Return the DIV element that correspond to the sub-document or NULL.
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-static Element      SearchSubDoc (STRING url)
-#else
-static Element      SearchSubDoc (url)
-STRING              url;
-#endif
+static Element      SearchSubDoc (char *url)
 {
   Element          el;
   struct _SubDoc  *entry;
@@ -124,7 +114,7 @@ STRING              url;
   el = NULL;
   while (!docFound && entry != NULL)
     {
-      docFound = (ustrcmp (url, entry->SDname) == 0);
+      docFound = (strcmp (url, entry->SDname) == 0);
       if (!docFound)
 	entry = entry->SDnext;
       else
@@ -161,21 +151,16 @@ static void         FreeSubDocTable ()
   InternalLink is a Thot reference attribute that links a source and a
   target anchor and that allows P schemas to display and print cross-references
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 void             SetInternalLinks (Document document)
-#else
-void             SetInternalLinks (document)
-Document                document;
-#endif
 {
   Element	        el, div, link, target, sibling;
   ElementType		elType, linkType;
   Attribute		HrefAttr, IntLinkAttr;
   Attribute             attr, ExtLinkAttr;
   AttributeType	        attrType;
-  STRING		text, ptr, url; 
-  CHAR_T                  number[10];
-  CHAR_T                  value[MAX_LENGTH];
+  char		       *text, *ptr, *url; 
+  char                  number[10];
+  char                  value[MAX_LENGTH];
   int			length, i, volume;
   int                   status, position;
   ThotBool              split;
@@ -207,7 +192,7 @@ Document                document;
 	  while (sibling != NULL);
 	  el = TtaGetParent (el);
 	}
-      usprintf (number, TEXT("%d"), position*100/volume);
+      sprintf (number, "%d", position*100/volume);
       TtaSetStatus (document, 1, TtaGetMessage (AMAYA, AM_UPDATED_LINK), number);
       TtaHandlePendingEvents ();
       link = TtaSearchTypedElement (elType, SearchForward, link);
@@ -238,13 +223,13 @@ Document                document;
 	    /* this element has an HREF or cite attribute */
 	    {
 	      length = TtaGetTextAttributeLength (HrefAttr);
-	      text = TtaAllocString (length + 1);
+	      text = TtaGetMemory (length + 1);
 	      TtaGiveTextAttributeValue (HrefAttr, text, &length);
 
 	      /* does an external link become an internal link ? */
 	      if (document == DocBook && SubDocs != NULL)
 		{
-		  ptr = ustrrchr (text, '#');
+		  ptr = strrchr (text, '#');
 		  url = text;
 		  split = FALSE;
 		  if (ptr == text)
@@ -279,8 +264,8 @@ Document                document;
 		      if (ptr != NULL)
 			{
 			  /* get the target name */
-			  ustrcpy (value, ptr);
-			  length = ustrlen (value);
+			  strcpy (value, ptr);
+			  length = strlen (value);
 			  /* check whether the name changed */
 			  i = 0;
 			  target = SearchNAMEattribute (document, &value[1], NULL);
@@ -293,7 +278,7 @@ Document                document;
 				{
 				  /* continue the search */
 				  i++;
-				  usprintf (&value[length], TEXT("%d"), i);
+				  sprintf (&value[length], "%d", i);
 				  target = SearchNAMEattribute (document,
 							&value[1], NULL);
 				}
@@ -361,101 +346,83 @@ Document                document;
   CheckPrintingDocument reinitialize printing parameters as soon as
   the printing document changes.
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 static void         CheckPrintingDocument (Document document)
-#else
-static void         CheckPrintingDocument (document)
-Document            document;
-#endif
 {
-   CHAR_T         docName[MAX_LENGTH];
-   CHAR_T*        ptr; 
-   CHAR_T         suffix[MAX_LENGTH];
-   int              lg;
+  char         docName[MAX_LENGTH];
+  char        *ptr; 
+  char         suffix[MAX_LENGTH];
+  int            lg;
 
-   if (DocPrint != document)
-     {
-       /* initialize print parameters */
-       DocPrint = document;
-
-       /* define the new default PS file */
-       ptr = TtaGetEnvString ("APP_TMPDIR");
-       if (ptr != NULL && TtaCheckDirectory (ptr))
-	     ustrcpy (PSdir, ptr);
-       else
-	     ustrcpy (PSdir, TtaGetDefEnvString ("APP_TMPDIR"));
-	   lg = ustrlen (PSdir);
-	   if (PSdir[lg - 1] == WC_DIR_SEP)
-	     PSdir[--lg] = WC_EOS;
-
-       ustrcpy (docName, TtaGetDocumentName (document));
-       ExtractSuffix (docName, suffix);
-       usprintf (&PSdir[lg], TEXT("%c%s.ps"), WC_DIR_SEP, docName);
-       TtaSetPsFile (PSdir);
-       /* define the new default PrintSchema */
-       NumberLinks = FALSE;
-       WithToC = FALSE;
-       IgnoreCSS = FALSE;
-       PrintURL = TRUE;
-       TtaSetPrintSchema (TEXT(""));
-       /* no manual feed */
-       ManualFeed = PP_OFF;
-       TtaSetPrintParameter (PP_ManualFeed, ManualFeed);
-       PagePerSheet = 1;
-       TtaSetPrintParameter (PP_PagesPerSheet, PagePerSheet);
-     }
+  if (DocPrint != document || DocPrintURL == NULL ||
+      strcmp(DocPrintURL, DocumentURLs[document]))
+    {
+      /* initialize print parameters */
+      TtaFreeMemory (DocPrintURL);
+      DocPrint = document;
+      DocPrintURL = TtaStrdup (DocumentURLs[document]);
+      
+      /* define the new default PS file */
+      ptr = TtaGetEnvString ("APP_TMPDIR");
+      if (ptr != NULL && TtaCheckDirectory (ptr))
+	strcpy (PSfile, ptr);
+      else
+	strcpy (PSfile, TtaGetDefEnvString ("APP_TMPDIR"));
+      lg = strlen (PSfile);
+      if (PSfile[lg - 1] == DIR_SEP)
+	PSfile[--lg] = EOS;
+      strcpy (docName, TtaGetDocumentName (document));
+      ExtractSuffix (docName, suffix);
+      sprintf (&PSfile[lg], "%c%s.ps", DIR_SEP, docName);
+      TtaSetPsFile (PSfile);
+    }
 }
 
-
 /*----------------------------------------------------------------------
    PrintDocument prints the document using predefined parameters.
    ----------------------------------------------------------------------*/  
-#ifdef __STDC__
 static void         PrintDocument (Document doc, View view)
-#else  /* __STDC__ */
-static void         PrintDocument (doc, view)
-Document            doc;
-#endif /* __STDC__ */
 {
   AttributeType      attrType;
+  ElementType        elType;
   Attribute          attr;
-  Element            el;
-  STRING             files, dir;
-  CHAR_T             viewsToPrint[MAX_PATH];
+  Element            el, docEl;
+  char              *files, *dir;
+  char               viewsToPrint[MAX_PATH];
   ThotBool           status, textFile;
 
   textFile = (DocumentTypes[doc] == docText ||
               DocumentTypes[doc] == docSource ||
 	      DocumentTypes[doc] == docCSS);
 
+  /* initialize printing information */
   CheckPrintingDocument (doc);
-  ustrcpy (viewsToPrint, TEXT("Formatted_view "));
+  strcpy (viewsToPrint, "Formatted_view ");
   if (DocumentTypes[doc] == docHTML && WithToC)
-    ustrcat (viewsToPrint, TEXT("Table_of_contents "));
+    strcat (viewsToPrint, "Table_of_contents ");
   
   if (textFile)
     {
       if (PageSize == PP_A4)
 	{
 	  if (Orientation == PP_Landscape)
-	    TtaSetPrintSchema (TEXT("TextFilePL"));
+	    TtaSetPrintSchema ("TextFilePL");
 	  else
-	    TtaSetPrintSchema (TEXT("TextFilePP"));
+	    TtaSetPrintSchema ("TextFilePP");
 	}
       else
 	{
 	  if (Orientation == PP_Landscape)
-	    TtaSetPrintSchema (TEXT("TextFileUSL"));
+	    TtaSetPrintSchema ("TextFileUSL");
 	  else
-	    TtaSetPrintSchema (TEXT("TextFilePPUS"));
+	    TtaSetPrintSchema ("TextFilePPUS");
 	}
     }
   else if (DocumentTypes[doc] == docSVG)
-    TtaSetPrintSchema (TEXT("GraphMLP"));
+    TtaSetPrintSchema ("GraphMLP");
   else if (DocumentTypes[doc] == docMath)
-    TtaSetPrintSchema (TEXT("MathMLP"));
+    TtaSetPrintSchema ("MathMLP");
   else if (DocumentTypes[doc] == docAnnot)
-    TtaSetPrintSchema (TEXT("AnnotP"));
+    TtaSetPrintSchema ("AnnotP");
   else if (DocumentTypes[doc] == docHTML && NumberLinks)
     /* display numbered links */
     {
@@ -466,32 +433,32 @@ Document            doc;
       if (PageSize == PP_A4)
 	{
 	  if (Orientation == PP_Landscape)
-	    TtaSetPrintSchema (TEXT("HTMLPLL"));
+	    TtaSetPrintSchema ("HTMLPLL");
 	  else
-	    TtaSetPrintSchema (TEXT("HTMLPLP"));
+	    TtaSetPrintSchema ("HTMLPLP");
 	}
       else
 	{
 	  if (Orientation == PP_Landscape)
-	    TtaSetPrintSchema (TEXT("HTMLUSLL"));
+	    TtaSetPrintSchema ("HTMLUSLL");
 	  else
-	    TtaSetPrintSchema (TEXT("HTMLPLPUS"));
+	    TtaSetPrintSchema ("HTMLPLPUS");
 	}
-      ustrcat (viewsToPrint, TEXT("Links_view "));
+      strcat (viewsToPrint, "Links_view ");
     }
   else if (PageSize == PP_A4)
     {
       if (Orientation == PP_Landscape)
-	TtaSetPrintSchema (TEXT("HTMLPL"));
+	TtaSetPrintSchema ("HTMLPL");
       else
-	TtaSetPrintSchema (TEXT("HTMLPP"));
+	TtaSetPrintSchema ("HTMLPP");
     }
   else
     {
       if (Orientation == PP_Landscape)
-	TtaSetPrintSchema (TEXT("HTMLUSL"));
+	TtaSetPrintSchema ("HTMLUSL");
       else
-	TtaSetPrintSchema (TEXT("HTMLPPUS"));
+	TtaSetPrintSchema ("HTMLPPUS");
     }    
   
   status = TtaIsDocumentModified (doc);
@@ -501,11 +468,19 @@ Document            doc;
     {
       /* post or remove the PrintURL attribute */
       attrType.AttrSSchema = TtaGetDocumentSSchema (doc);
+      elType.ElSSchema = attrType.AttrSSchema;
       if (textFile)
-	attrType.AttrTypeNum = TextFile_ATTR_PrintURL;
+	{
+	  elType. ElTypeNum = TextFile_EL_TextFile;
+	  attrType.AttrTypeNum = TextFile_ATTR_PrintURL;
+	}
       else
-	attrType.AttrTypeNum = HTML_ATTR_PrintURL;
-      el =  TtaGetMainRoot (doc);
+	{
+	  elType. ElTypeNum = HTML_EL_HTML;
+	  attrType.AttrTypeNum = HTML_ATTR_PrintURL;
+	}
+      docEl = TtaGetMainRoot (doc);
+      el = TtaSearchTypedElement (elType, SearchForward, docEl);
       attr = TtaGetAttribute (el, attrType);
       if (!attr && PrintURL)
 	{
@@ -517,7 +492,8 @@ Document            doc;
     }
   
   /* get the path dir where css files have to be stored */
-  if (DocumentTypes[doc] == docHTML && !IgnoreCSS)
+  if ((DocumentTypes[doc] == docHTML || DocumentTypes[doc] == docSVG) &&
+      !IgnoreCSS)
     {
       TtaGetPrintNames (&files, &dir);
       /* store css files and get the list of names */
@@ -535,12 +511,7 @@ Document            doc;
 /*----------------------------------------------------------------------
    PrintAs prints the document using predefined parameters.
    ----------------------------------------------------------------------*/  
-#ifdef __STDC__
 void                PrintAs (Document doc, View view)
-#else  /* __STDC__ */
-void                PrintAs (doc, view)
-Document            doc;
-#endif /* __STDC__ */
 {
 #ifdef _WINDOWS
   DocPrint = doc;
@@ -553,14 +524,7 @@ Document            doc;
 /*----------------------------------------------------------------------
    CallbackImage manage returns of Picture form.                   
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-void                CallbackPrint (int ref, int typedata, STRING data)
-#else  /* __STDC__ */
-void                CallbackPrint (ref, typedata, data)
-int                 ref;
-int                 typedata;
-STRING              data;
-#endif /* __STDC__ */
+void CallbackPrint (int ref, int typedata, char *data)
 {
   int                 val;
 
@@ -572,28 +536,12 @@ STRING              data;
       switch (val)
 	{
 	case 1:
-	  /* confirms the paper print option */
-	  /* the other options are not taken into account without this
-	     confirmation */
-	  TtaSetPrintParameter (PP_Destination, PaperPrint);
-	  TtaSetPrintParameter (PP_ManualFeed, ManualFeed);
-	  TtaSetPrintParameter (PP_PagesPerSheet, PagePerSheet);
-	  TtaSetPrintParameter (PP_Orientation, Orientation);
-	  TtaSetPrintParameter (PP_PaperSize, PageSize);
 	  TtaSetPrintCommand (PPrinter);
-	  TtaSetPsFile (PSdir);
+	  TtaSetPsFile (PSfile);
 	  /* update the environment variable */
 	  TtaSetEnvString ("THOTPRINT", PPrinter, TRUE);
-	  TtaSetEnvInt ("PAPERSIZE", PageSize, TRUE);
 	  PrintDocument (DocPrint, 1);
 	  break;
-	case 0:
-	  PaperPrint = (TtaGetPrintParameter (PP_Destination)) ? PP_PRINTER : PP_PS;
-	  ManualFeed = TtaGetPrintParameter (PP_ManualFeed);
-	  PageSize = TtaGetPrintParameter (PP_PaperSize);	  
-	  TtaGetPrintCommand (PPrinter);
-	  TtaGetPsFile (PSdir);
-	  break;
 	default:
 	  break;
 	}
@@ -607,6 +555,7 @@ STRING              data;
 	    ManualFeed = PP_OFF;
 	  else
 	    ManualFeed = PP_ON;
+	  TtaSetPrintParameter (PP_ManualFeed, ManualFeed);
 	  break;
 	case 1:
 	  /* Toc option */
@@ -636,10 +585,12 @@ STRING              data;
 	  PageSize = PP_US;
 	  break;
 	}
+      TtaSetPrintParameter (PP_PaperSize, PageSize);
       break;
     case PaperOrientation:
       /* orientation submenu */
       Orientation = val;
+      TtaSetPrintParameter (PP_Orientation, Orientation);
       break;
     case PPagesPerSheet:
       /* pages per sheet submenu */
@@ -655,6 +606,7 @@ STRING              data;
 	  PagePerSheet = 4;
 	  break;
 	}
+      TtaSetPrintParameter (PP_PagesPerSheet, PagePerSheet);
       break;
     case PrintSupport:
       /* paper print/save PostScript submenu */
@@ -667,187 +619,181 @@ STRING              data;
 #ifndef _WINDOWS
 	      TtaSetTextForm (BasePrint + PPrinterName, PPrinter);
 #endif /* !_WINDOWS */
+	      TtaSetPrintParameter (PP_Destination, PaperPrint);
 	    }
 	  break;
 	case 1:
 	  if (PaperPrint == PP_PRINTER)
 	    {
 	      PaperPrint = PP_PS;
-#         ifndef _WINDOWS
-	      TtaSetTextForm (BasePrint + PPrinterName, PSdir);
-#         endif /* !_WINDOWS */
+#ifndef _WINDOWS
+	      TtaSetTextForm (BasePrint + PPrinterName, PSfile);
+#endif /* !_WINDOWS */
+	      TtaSetPrintParameter (PP_Destination, PaperPrint);
 	    }
 	  break;
 	}
       break;
     case PPrinterName:
       if (data[0] != '\0')
+	{
 	if (PaperPrint == PP_PRINTER)
 	    /* text capture zone for the printer name */
-	    ustrncpy (PPrinter, data, MAX_PATH);
+	    strncpy (PPrinter, data, MAX_PATH);
 	else
 	  /* text capture zone for the name of the PostScript file */
-	  ustrncpy (PSdir, data, MAX_PATH);
+	  strncpy (PSfile, data, MAX_PATH);
+	}
       break;
     }
 }
 
 /*----------------------------------------------------------------------
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 void                InitPrint (void)
-#else  /* __STDC__ */
-void                InitPrint ()
-#endif /* __STDC__ */
 {
-  CHAR_T* ptr;
+  char* ptr;
 
    BasePrint = TtaSetCallback (CallbackPrint, PRINT_MAX_REF);
    DocPrint = 0;
+   DocPrintURL = NULL;
 
-   /* init printer variables */
    /* read default printer variable */
    ptr = TtaGetEnvString ("THOTPRINT");
    if (ptr == NULL)
-     ustrcpy (PPrinter, TEXT(""));
+     strcpy (PPrinter, "");
    else
-     ustrcpy (PPrinter, ptr);
-   TtaGetEnvInt ("PAPERSIZE", &PageSize);
-   PaperPrint = PP_PRINTER;
-   PrintURL = TRUE;
-   IgnoreCSS = FALSE;
-   TtaSetPrintParameter (PP_Destination, PaperPrint);
-   TtaSetPrintParameter (PP_PaperSize, PageSize);
+     strcpy (PPrinter, ptr);
    TtaSetPrintCommand (PPrinter);
+   PaperPrint = PP_PRINTER;
+   TtaSetPrintParameter (PP_Destination, PaperPrint);
+
+   /* define the new default PrintSchema */
+   NumberLinks = FALSE;
+   WithToC = FALSE;
+   IgnoreCSS = FALSE;
+   PrintURL = TRUE;
+   PageSize = TtaGetPrintParameter (PP_PaperSize);	  
+   TtaSetPrintSchema ("");
+   /* no manual feed */
+   ManualFeed = PP_OFF;
+   TtaSetPrintParameter (PP_ManualFeed, ManualFeed);
+   PagePerSheet = 1;
+   TtaSetPrintParameter (PP_PagesPerSheet, PagePerSheet);
 }
 
 /*----------------------------------------------------------------------
   SetupAndPrint sets printing parameters and starts the printing process
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 void                SetupAndPrint (Document doc, View view)
-#else
-void                SetupAndPrint (doc, view)
-Document            doc;
-View                view;
-#endif
 {
 #ifndef _WINDOWS
-   CHAR_T           bufMenu[MAX_LENGTH];
-   int              i;
+  char           bufMenu[MAX_LENGTH];
+  int              i;
 #endif /* !_WINDOWS */
-   ThotBool           textFile;
+  ThotBool           textFile;
 
-   textFile = (DocumentTypes[doc] == docText ||
-	       DocumentTypes[doc] == docCSS);
-
-   /* Print form */
-   CheckPrintingDocument (doc);
-
-   /* read the values that the user may have changed thru
-      the configuration menu */
-   TtaGetPrintCommand (PPrinter);
-   PageSize = TtaGetPrintParameter (PP_PaperSize);	  
+  textFile = (DocumentTypes[doc] == docText || DocumentTypes[doc] == docCSS);
+  /* Print form */
+  CheckPrintingDocument (doc);
 
 #ifndef _WINDOWS
-   TtaNewSheet (BasePrint + FormPrint, TtaGetViewFrame (doc, view), 
-		TtaGetMessage (LIB, TMSG_LIB_PRINT),
-	   1, TtaGetMessage (AMAYA, AM_BUTTON_PRINT), FALSE, 3, 'L', D_CANCEL);
+  TtaNewSheet (BasePrint + FormPrint, TtaGetViewFrame (doc, view), 
+	       TtaGetMessage (LIB, TMSG_LIB_PRINT), 1,
+	       TtaGetMessage (AMAYA, AM_BUTTON_PRINT), FALSE, 3, 'L', D_CANCEL);
 
-   /* Paper format submenu */
-   i = 0;
-   sprintf (&bufMenu[i], "%s%s", "B", TtaGetMessage (LIB, TMSG_A4));
-   i += ustrlen (&bufMenu[i]) + 1;
-   sprintf (&bufMenu[i], "%s%s", "B", TtaGetMessage (LIB, TMSG_US));
-   TtaNewSubmenu (BasePrint + PaperFormat, BasePrint + FormPrint, 0,
-	     TtaGetMessage (LIB, TMSG_PAPER_SIZE), 2, bufMenu, NULL, FALSE);
-   if (PageSize == PP_US)
-      TtaSetMenuForm (BasePrint + PaperFormat, 1);
-   else
-      TtaSetMenuForm (BasePrint + PaperFormat, 0);
-
-   /* Orientation submenu */
-   i = 0;
-   sprintf (&bufMenu[i], "%s%s", "B", TtaGetMessage (AMAYA, AM_PORTRAIT));
-   i += ustrlen (&bufMenu[i]) + 1;
-   sprintf (&bufMenu[i], "%s%s", "B", TtaGetMessage (AMAYA, AM_LANDSCAPE));
-   TtaNewSubmenu (BasePrint + PaperOrientation, BasePrint + FormPrint, 0,
-                  TtaGetMessage (AMAYA, AM_ORIENTATION), 2, bufMenu, NULL, TRUE);
-   if (Orientation == PP_Landscape)
-       TtaSetMenuForm (BasePrint + PaperOrientation, 1);
-   else
-      TtaSetMenuForm (BasePrint + PaperOrientation, 0);
-
-
-   /* Pages per sheet submenu */
-   i = 0;
-   sprintf (&bufMenu[i], "%s%s", "B", TtaGetMessage (LIB, TMSG_1_PAGE_SHEET));
-   i += ustrlen (&bufMenu[i]) + 1;
-   sprintf (&bufMenu[i], "%s%s", "B", TtaGetMessage (LIB, TMSG_2_PAGE_SHEET));
-   i += ustrlen (&bufMenu[i]) + 1;
-   sprintf (&bufMenu[i], "%s%s", "B", TtaGetMessage (LIB, TMSG_4_PAGE_SHEET));
-   TtaNewSubmenu (BasePrint + PPagesPerSheet, BasePrint + FormPrint, 0,
-                  TtaGetMessage (LIB, TMSG_REDUCTION), 3, bufMenu, NULL, TRUE);
-   if (PagePerSheet == 1)
-       TtaSetMenuForm (BasePrint + PPagesPerSheet, 0);
-   else if (PagePerSheet == 2)
-      TtaSetMenuForm (BasePrint + PPagesPerSheet, 1);
-   else
-      TtaSetMenuForm (BasePrint + PPagesPerSheet, 2);
+  /* Paper format submenu */
+  i = 0;
+  sprintf (&bufMenu[i], "%s%s", "B", TtaGetMessage (LIB, TMSG_A4));
+  i += strlen (&bufMenu[i]) + 1;
+  sprintf (&bufMenu[i], "%s%s", "B", TtaGetMessage (LIB, TMSG_US));
+  TtaNewSubmenu (BasePrint + PaperFormat, BasePrint + FormPrint, 0,
+		 TtaGetMessage (LIB, TMSG_PAPER_SIZE), 2, bufMenu, NULL, TRUE);
+  if (PageSize == PP_US)
+    TtaSetMenuForm (BasePrint + PaperFormat, 1);
+  else
+    TtaSetMenuForm (BasePrint + PaperFormat, 0);
+  
+  /* Orientation submenu */
+  i = 0;
+  sprintf (&bufMenu[i], "%s%s", "B", TtaGetMessage (AMAYA, AM_PORTRAIT));
+  i += strlen (&bufMenu[i]) + 1;
+  sprintf (&bufMenu[i], "%s%s", "B", TtaGetMessage (AMAYA, AM_LANDSCAPE));
+  TtaNewSubmenu (BasePrint + PaperOrientation, BasePrint + FormPrint, 0,
+		 TtaGetMessage (AMAYA, AM_ORIENTATION), 2, bufMenu, NULL, TRUE);
+  if (Orientation == PP_Landscape)
+    TtaSetMenuForm (BasePrint + PaperOrientation, 1);
+  else
+    TtaSetMenuForm (BasePrint + PaperOrientation, 0);
+  /* Pages per sheet submenu */
+  i = 0;
+  sprintf (&bufMenu[i], "%s%s", "B", TtaGetMessage (LIB, TMSG_1_PAGE_SHEET));
+  i += strlen (&bufMenu[i]) + 1;
+  sprintf (&bufMenu[i], "%s%s", "B", TtaGetMessage (LIB, TMSG_2_PAGE_SHEET));
+  i += strlen (&bufMenu[i]) + 1;
+  sprintf (&bufMenu[i], "%s%s", "B", TtaGetMessage (LIB, TMSG_4_PAGE_SHEET));
+  TtaNewSubmenu (BasePrint + PPagesPerSheet, BasePrint + FormPrint, 0,
+		 TtaGetMessage (LIB, TMSG_REDUCTION), 3, bufMenu, NULL, TRUE);
+  if (PagePerSheet == 1)
+    TtaSetMenuForm (BasePrint + PPagesPerSheet, 0);
+  else if (PagePerSheet == 2)
+    TtaSetMenuForm (BasePrint + PPagesPerSheet, 1);
+  else
+    TtaSetMenuForm (BasePrint + PPagesPerSheet, 2);
     
-   /* Print to paper/ Print to file submenu */
-   i = 0;
-   sprintf (&bufMenu[i], "%s%s", "B", TtaGetMessage (LIB, TMSG_PRINTER));
-   i += ustrlen (&bufMenu[i]) + 1;
-   sprintf (&bufMenu[i], "%s%s", "B", TtaGetMessage (LIB, TMSG_PS_FILE));
-   TtaNewSubmenu (BasePrint + PrintSupport, BasePrint + FormPrint, 0,
-                  TtaGetMessage (LIB, TMSG_OUTPUT), 2, bufMenu, NULL, TRUE);
+  /* Print to paper/ Print to file submenu */
+  i = 0;
+  sprintf (&bufMenu[i], "%s%s", "B", TtaGetMessage (LIB, TMSG_PRINTER));
+  i += strlen (&bufMenu[i]) + 1;
+  sprintf (&bufMenu[i], "%s%s", "B", TtaGetMessage (LIB, TMSG_PS_FILE));
+  TtaNewSubmenu (BasePrint + PrintSupport, BasePrint + FormPrint, 0,
+		 TtaGetMessage (LIB, TMSG_OUTPUT), 2, bufMenu, NULL, TRUE);
 
-   /* PaperPrint selector */
-   TtaNewTextForm (BasePrint + PPrinterName, BasePrint + FormPrint, NULL, 30, 1, FALSE);
-   if (PaperPrint == PP_PRINTER)
-     {
-	TtaSetMenuForm (BasePrint + PrintSupport, 0);
-	TtaSetTextForm (BasePrint + PPrinterName, PPrinter);
-     }
-   else
-     {
-	TtaSetMenuForm (BasePrint + PrintSupport, 1);
-	TtaSetTextForm (BasePrint + PPrinterName, PSdir);
-     }
+  /* PaperPrint selector */
+  TtaNewTextForm (BasePrint + PPrinterName, BasePrint + FormPrint, NULL, 30, 1, TRUE);
+  if (PaperPrint == PP_PRINTER)
+    {
+      TtaSetMenuForm (BasePrint + PrintSupport, 0);
+      TtaSetTextForm (BasePrint + PPrinterName, PPrinter);
+    }
+  else
+    {
+      TtaSetMenuForm (BasePrint + PrintSupport, 1);
+      TtaSetTextForm (BasePrint + PPrinterName, PSfile);
+    }
 
-   /* The toggle */
-   i = 0;
-   sprintf (&bufMenu[i], "%s%s", "T", TtaGetMessage (LIB, TMSG_MANUAL_FEED));
-   i += ustrlen (&bufMenu[i]) + 1;
-   sprintf (&bufMenu[i], "%s%s", "T", TtaGetMessage (AMAYA, AM_PRINT_TOC));
-   i += ustrlen (&bufMenu[i]) + 1;
-   sprintf (&bufMenu[i], "%s%s", "T", TtaGetMessage (AMAYA, AM_NUMBERED_LINKS));
-   i += ustrlen (&bufMenu[i]) + 1;
-   sprintf (&bufMenu[i], "%s%s", "T", TtaGetMessage (AMAYA, AM_PRINT_URL));
-   i += ustrlen (&bufMenu[i]) + 1;
-   sprintf (&bufMenu[i], "%s%s", "T", TtaGetMessage (AMAYA, AM_WITH_CSS));
-   TtaNewToggleMenu (BasePrint + PrintOptions, BasePrint + FormPrint,
-		TtaGetMessage (LIB, TMSG_OPTIONS), 5, bufMenu, NULL, FALSE);
-   if (ManualFeed == PP_ON)
-     TtaSetToggleMenu (BasePrint + PrintOptions, 0, TRUE);
-   else
-     TtaSetToggleMenu (BasePrint + PrintOptions, 0, FALSE);
-   TtaSetToggleMenu (BasePrint + PrintOptions, 1, WithToC);
-   TtaSetToggleMenu (BasePrint + PrintOptions, 2, NumberLinks);
-   TtaSetToggleMenu (BasePrint + PrintOptions, 3, PrintURL);
-   TtaSetToggleMenu (BasePrint + PrintOptions, 4, IgnoreCSS);
-
-   /* activates the Print form */
-    TtaShowDialogue (BasePrint+FormPrint, FALSE);
-    if (textFile)
-      {
-	/* invalid dialogue entries */
-	TtaRedrawMenuEntry (BasePrint + PrintOptions, 1, NULL, -1, FALSE);
-	TtaRedrawMenuEntry (BasePrint + PrintOptions, 2, NULL, -1, FALSE);
-      }
+  /* The toggle */
+  i = 0;
+  sprintf (&bufMenu[i], "%s%s", "T", TtaGetMessage (LIB, TMSG_MANUAL_FEED));
+  i += strlen (&bufMenu[i]) + 1;
+  sprintf (&bufMenu[i], "%s%s", "T", TtaGetMessage (AMAYA, AM_PRINT_TOC));
+  i += strlen (&bufMenu[i]) + 1;
+  sprintf (&bufMenu[i], "%s%s", "T", TtaGetMessage (AMAYA, AM_NUMBERED_LINKS));
+  i += strlen (&bufMenu[i]) + 1;
+  sprintf (&bufMenu[i], "%s%s", "T", TtaGetMessage (AMAYA, AM_PRINT_URL));
+  i += strlen (&bufMenu[i]) + 1;
+  sprintf (&bufMenu[i], "%s%s", "T", TtaGetMessage (AMAYA, AM_WITH_CSS));
+  TtaNewToggleMenu (BasePrint + PrintOptions, BasePrint + FormPrint,
+		    TtaGetMessage (LIB, TMSG_OPTIONS), 5, bufMenu, NULL, FALSE);
+  if (ManualFeed == PP_ON)
+    TtaSetToggleMenu (BasePrint + PrintOptions, 0, TRUE);
+  else
+    TtaSetToggleMenu (BasePrint + PrintOptions, 0, FALSE);
+  TtaSetToggleMenu (BasePrint + PrintOptions, 1, WithToC);
+  TtaSetToggleMenu (BasePrint + PrintOptions, 2, NumberLinks);
+  TtaSetToggleMenu (BasePrint + PrintOptions, 3, PrintURL);
+  TtaSetToggleMenu (BasePrint + PrintOptions, 4, IgnoreCSS);
+  
+  /* activates the Print form */
+  TtaShowDialogue (BasePrint+FormPrint, FALSE);
+  if (textFile)
+    {
+      /* invalid dialogue entries */
+      TtaRedrawMenuEntry (BasePrint + PrintOptions, 1, NULL, -1, FALSE);
+      TtaRedrawMenuEntry (BasePrint + PrintOptions, 2, NULL, -1, FALSE);
+    }
 #else  /* _WINDOWS */
-    CreatePrintDlgWindow (TtaGetViewFrame (doc, view), PSdir);
+  CreatePrintDlgWindow (TtaGetViewFrame (doc, view), PSfile);
 #endif /* _WINDOWS */
 }
 
@@ -855,13 +801,7 @@ View                view;
   SectionNumbering
   Execute the "Section Numbering" command
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 void                SectionNumbering (Document doc, View view)
-#else
-void                SectionNumbering (doc, view)
-Document            doc;
-View                view;
-#endif
 {
    ChangeAttrOnRoot (doc, HTML_ATTR_SectionNumbering);
 }
@@ -875,21 +815,39 @@ View                view;
   Transform the HREF and SRC attribute to make them independent from their
   former base.
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 static void         UpdateURLsInSubtree (NotifyElement *event, Element el)
-#else
-static void         UpdateURLsInSubtree (event, el)
-NotifyElement      *event;
-Element             el;
-#endif
 {
-Element             nextEl;
+  Element             nextEl, child;
+  ElementType         elType;
+  SSchema             HTMLschema;
 
   nextEl = TtaGetFirstChild (el);
+  HTMLschema = TtaGetSSchema ("HTML", event->document);
+  elType.ElSSchema = HTMLschema;
   while (nextEl != NULL)
     {
       event->element = nextEl;
       ElementPasted (event);
+
+      /* manage included links and anchors */
+      elType.ElTypeNum = HTML_EL_Anchor;
+      child = TtaSearchTypedElement (elType, SearchInTree, nextEl);
+      while (child)
+	{
+	  event->element = child;
+	  ElementPasted (event);
+	  child = TtaSearchTypedElementInTree (elType, SearchForward, nextEl, child);
+	}
+
+      /* manage included links and anchors */
+      elType.ElTypeNum = HTML_EL_PICTURE_UNIT;
+      child = TtaSearchTypedElement (elType, SearchInTree, nextEl);
+      while (child)
+	{
+	  event->element = child;
+	  ElementPasted (event);
+	  child = TtaSearchTypedElementInTree (elType, SearchForward, nextEl, child);
+	}
       TtaNextSibling (&nextEl);
     }
 }
@@ -904,17 +862,9 @@ Element             nextEl;
   document.
   Return the root element that delimits the new inserted part (a div).
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-static Element MoveDocumentBody (Element el, Document destDoc, Document sourceDoc, STRING target, STRING url, ThotBool deleteTree)
-#else
-static Element MoveDocumentBody (el, destDoc, sourceDoc, target, url, deleteTree)
-Element        el;
-Document       destDoc;
-Document       sourceDoc;
-STRING         target;
-STRING         url;
-ThotBool       deleteTree;
-#endif
+static Element MoveDocumentBody (Element el, Document destDoc,
+				 Document sourceDoc, char *target,
+				 char *url, ThotBool deleteTree)
 {
   Element	   root, ancestor, elem, firstInserted, div;
   Element          lastInserted, srce, copy, old, parent, sibling;
@@ -929,7 +879,8 @@ ThotBool       deleteTree;
       /* locate the target element within the source document */
       root = SearchNAMEattribute (sourceDoc, target, NULL);
       elType = TtaGetElementType (root);
-      isID = (elType.ElTypeNum != HTML_EL_Anchor && elType.ElTypeNum != HTML_EL_MAP);
+      isID = (elType.ElTypeNum != HTML_EL_Anchor &&
+	      elType.ElTypeNum != HTML_EL_MAP);
     }
   else
     {
@@ -1040,13 +991,7 @@ ThotBool       deleteTree;
 /*----------------------------------------------------------------------
   CloseMakeBook
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 static void CloseMakeBook (Document document)
-#else
-static void CloseMakeBook (document)
-Document    document;
-#endif /* __STDC__ */
-
 {
   ResetStop (document);
   /* update internal links */
@@ -1064,27 +1009,15 @@ Document    document;
 /*----------------------------------------------------------------------
   GetIncludedDocuments_callback finishes the GetIncludedDocuments procedure
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 void   GetIncludedDocuments_callback (int newdoc, int status, 
-				      STRING urlName,
-				      STRING outputfile, 
+				      char *urlName,
+				      char *outputfile, 
 				      AHTHeaders *http_headers,
 				      void * context)
-#else  /* __STDC__ */
-void   GetIncludedDocuments_callback (newdoc, status, urlName,
-				      outputfile, http_headers,
-				      context)
-int    newdoc;
-int    status;
-STRING urlName;
-STRING outputfile;
-AHTHeaders *http_headers;
-void  *context;
-#endif /* __STDC__ */
 {
   Element		link, div;
   IncludeCtxt          *ctx, *prev;
-  STRING		url, ptr;
+  char		       *url, *ptr;
   ThotBool              found = FALSE;
 
   /* restore GetIncludedDocuments's context */
@@ -1142,28 +1075,21 @@ void  *context;
   that link by the contents of the target document.
   Return TRUE if one inclusion is launched.
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-static ThotBool  GetIncludedDocuments (Element el, Element link, Document document, IncludeCtxt *prev)
-#else
-static ThotBool  GetIncludedDocuments (el, link, document, prev)
-Element	     el;
-Element	     link;
-Document     document;
-IncludeCtxt *prev;
-#endif
+static ThotBool  GetIncludedDocuments (Element el, Element link,
+				       Document document, IncludeCtxt *prev)
 {
   ElementType           elType;
   Attribute		attr;
   AttributeType	        attrType;
   Document		newdoc;
   IncludeCtxt          *ctx = NULL;
-  STRING		text, ptr, url = NULL;
+  char		       *text, *ptr, *url = NULL;
   int			length;
   ThotBool              found = FALSE;
 
   /* look for anchors with the attribute rel within the element  el */
   attr = NULL;
-  attrType.AttrSSchema = TtaGetSSchema (TEXT("HTML"), document);
+  attrType.AttrSSchema = TtaGetSSchema ("HTML", document);
   elType.ElSSchema = attrType.AttrSSchema;
   elType.ElTypeNum = HTML_EL_Anchor;
 
@@ -1179,11 +1105,11 @@ IncludeCtxt *prev;
       if (attr)
 	{
 	  length = TtaGetTextAttributeLength (attr);
-	  text = TtaAllocString (length + 1);
+	  text = TtaGetMemory (length + 1);
 	  TtaGiveTextAttributeValue (attr, text, &length);
 	  /* Valid rel values are rel="chapter" or rel="subdocument" */
-	  if (ustrcasecmp (text, TEXT("chapter")) &&
-	      ustrcasecmp (text, TEXT("subdocument")))
+	  if (strcasecmp (text, "chapter") &&
+	      strcasecmp (text, "subdocument"))
 	    attr = NULL;
 	  TtaFreeMemory (text);
 	}
@@ -1198,9 +1124,9 @@ IncludeCtxt *prev;
 	/* this link has an attribute HREF */
 	{
 	  length = TtaGetTextAttributeLength (attr);
-	  text = TtaAllocString (length + 1);
+	  text = TtaGetMemory (length + 1);
 	  TtaGiveTextAttributeValue (attr, text, &length);
-	  ptr = ustrrchr (text, '#');
+	  ptr = strrchr (text, '#');
 	  url = text;
 	  if (ptr != NULL)
 	    {
@@ -1215,7 +1141,7 @@ IncludeCtxt *prev;
 	    /* this link designates an external document */
 	    {
 	      /* create a new document and loads the target document */
-	      IncludedDocument = TtaNewDocument (TEXT("HTML"), TEXT("tmp"));
+	      IncludedDocument = TtaNewDocument ("HTML", "tmp");
 	      if (IncludedDocument != 0)
 		{
 		  TtaSetStatus (document, 1, TtaGetMessage (AMAYA, AM_FETCHING), url);
@@ -1247,13 +1173,7 @@ IncludeCtxt *prev;
   Replace all links in a document which have an attribute REL="chapter"
   or REL="subdocument" by the corresponding target document.
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 void                MakeBook (Document document, View view)
-#else
-void                MakeBook (document, view)
-Document            document;
-View                view;
-#endif
 {
   Element	    root, body;
   ElementType	    elType;
