@@ -1,6 +1,6 @@
 /*
  *
- *  (c) COPYRIGHT MIT and INRIA, 1996-2000
+ *  (c) COPYRIGHT MIT and INRIA, 1996-2001
  *  Please first read the full copyright statement in file COPYRIGHT.
  *
  */
@@ -28,6 +28,7 @@
 #include "html2thot_f.h"
 #include "styleparser_f.h"
 #include "undo.h"
+#include "XHTMLbuilder_f.h"
 
 /*----------------------------------------------------------------------
  MakeASpan
@@ -35,14 +36,7 @@
  Span element, create a span element that contains that text string
  and return TRUE; span contains then the created Span element.
  -----------------------------------------------------------------------*/
-#ifdef __STDC__
 ThotBool MakeASpan (Element elem, Element *span, Document doc)
-#else /* __STDC__*/
-ThotBool MakeASpan (elem, span, doc)
-     Element elem;
-     Element *span;
-     Document doc;
-#endif /* __STDC__*/
 {
   ElementType	elType;
   Element	parent, sibling;
@@ -51,10 +45,11 @@ ThotBool MakeASpan (elem, span, doc)
   ret = FALSE;
   *span = NULL;
   elType = TtaGetElementType (elem);
-  if (!ustrcmp(TtaGetSSchemaName (elType.ElSSchema), TEXT("HTML")) ||
-      !ustrcmp(TtaGetSSchemaName (elType.ElSSchema), TEXT("GraphML")))
+  if (!strcmp(TtaGetSSchemaName (elType.ElSSchema), "HTML") ||
+      !strcmp(TtaGetSSchemaName (elType.ElSSchema), "GraphML"))
     /* it's an HTML or GraphML element */
-    if (elType.ElTypeNum == HTML_EL_TEXT_UNIT)
+    if (elType.ElTypeNum == HTML_EL_TEXT_UNIT ||
+	elType.ElTypeNum == HTML_EL_Basic_Elem)
       /* it's a text leaf */
       {
       parent = TtaGetParent (elem);
@@ -63,9 +58,9 @@ ThotBool MakeASpan (elem, span, doc)
 	doit = TRUE;
 	elType = TtaGetElementType (parent);
 	if ((elType.ElTypeNum == HTML_EL_Span &&
-	     !ustrcmp(TtaGetSSchemaName (elType.ElSSchema), TEXT("HTML"))) ||
+	     !strcmp(TtaGetSSchemaName (elType.ElSSchema), "HTML")) ||
 	    (elType.ElTypeNum == GraphML_EL_tspan &&
-	     !ustrcmp(TtaGetSSchemaName (elType.ElSSchema), TEXT("GraphML"))))
+	     !strcmp(TtaGetSSchemaName (elType.ElSSchema), "GraphML")))
 	   /* element parent is a span element */
 	   {
 	   sibling = elem;
@@ -87,7 +82,7 @@ ThotBool MakeASpan (elem, span, doc)
 	if (doit)
 	   /* enclose the text leaf within a span element */
 	   {
-	   if (!ustrcmp(TtaGetSSchemaName (elType.ElSSchema), TEXT("HTML")))
+	   if (!strcmp(TtaGetSSchemaName (elType.ElSSchema), "HTML"))
 	      elType.ElTypeNum = HTML_EL_Span;
 	   else
 	      elType.ElTypeNum = GraphML_EL_tspan;
@@ -112,15 +107,8 @@ ThotBool MakeASpan (elem, span, doc)
  last child of the former SPAN element.
  Otherwise, firstChild and lastChild are NULL.
  -----------------------------------------------------------------------*/
-#ifdef __STDC__
-void DeleteSpanIfNoAttr (Element el, Document doc, Element *firstChild, Element *lastChild)
-#else /* __STDC__*/
-void DeleteSpanIfNoAttr (el, doc, firstChild, lastChild)
-     Element el;
-     Document doc;
-     Element *firstChild;
-     Element *lastChild;
-#endif /* __STDC__*/
+void DeleteSpanIfNoAttr (Element el, Document doc, Element *firstChild,
+			 Element *lastChild)
 {
   ElementType	elType;
   Element	span, child, next;
@@ -132,7 +120,7 @@ void DeleteSpanIfNoAttr (el, doc, firstChild, lastChild)
   *lastChild = NULL;
   elType = TtaGetElementType (el);
   if (elType.ElTypeNum == HTML_EL_Span &&
-      ustrcmp(TtaGetSSchemaName (elType.ElSSchema), TEXT("HTML")) == 0)
+      strcmp(TtaGetSSchemaName (elType.ElSSchema), "HTML") == 0)
      {
      span = el;
      attr = NULL;
@@ -167,14 +155,7 @@ void DeleteSpanIfNoAttr (el, doc, firstChild, lastChild)
   If attribute attr is on a text string (elem), create a SPAN element
   enclosing this text string and move the attribute to that SPAN element.
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 void  AttrToSpan (Element elem, Attribute attr, Document doc)
-#else /* __STDC__*/
-void  AttrToSpan (elem, attr, doc)
-     Element elem;
-     Attribute attr;
-     Document doc;
-#endif /* __STDC__*/
 {
   Element	span, parent;
   Attribute	newAttr;
@@ -182,15 +163,16 @@ void  AttrToSpan (elem, attr, doc)
   ElementType   elType;
   int		kind, len;
 #define ATTRLEN 64
-  STRING	oldValue; /* [ATTRLEN]; */
+  char	       *oldValue; /* [ATTRLEN]; */
 
   elType = TtaGetElementType (elem);
-  if (elType.ElTypeNum == HTML_EL_TEXT_UNIT)
+  if (elType.ElTypeNum == HTML_EL_TEXT_UNIT ||
+      elType.ElTypeNum == HTML_EL_Basic_Elem)
     /* it's a character string */
     {
       parent = TtaGetParent (elem);
       elType = TtaGetElementType (parent);
-      if (ustrcmp(TtaGetSSchemaName (elType.ElSSchema), TEXT("HTML")) == 0)
+      if (strcmp(TtaGetSSchemaName (elType.ElSSchema), "HTML") == 0)
         /* the parent element is an HTML element */
 	/* Create a Span element and move to attribute to this Span element */
         MakeASpan (elem, &span, doc);
@@ -199,7 +181,7 @@ void  AttrToSpan (elem, attr, doc)
 	span = parent;
       if (span != NULL)
         {
-          oldValue = TtaAllocString (ATTRLEN);
+          oldValue = TtaGetMemory (ATTRLEN);
           TtaGiveAttributeType (attr, &attrType, &kind);
 	  newAttr = TtaGetAttribute (span, attrType);
 	  if (newAttr == NULL)
@@ -224,13 +206,7 @@ void  AttrToSpan (elem, attr, doc)
 /*----------------------------------------------------------------------
   GlobalAttrCreated: the user has created a global attribute
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 void                GlobalAttrCreated (NotifyAttribute * event)
-#else
-void                GlobalAttrCreated (event)
-NotifyAttribute    *event;
- 
-#endif
 {
    /* if the attribute is on a text string, create a SPAN element that encloses
       this text string and move the attribute to that SPAN element */
@@ -240,13 +216,7 @@ NotifyAttribute    *event;
 /*----------------------------------------------------------------------
   GlobalAttrDeleted: the user has removed a global attribute
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 void                GlobalAttrDeleted (NotifyAttribute * event)
-#else
-void                GlobalAttrDeleted (event)
-NotifyAttribute    *event;
- 
-#endif
 {
    Element	firstChild, lastChild;
 
@@ -259,13 +229,7 @@ NotifyAttribute    *event;
   AttrClassChanged: the user has created removed or modified a Class
   attribute
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 void                AttrClassChanged (NotifyAttribute * event)
-#else
-void                AttrClassChanged (event)
-NotifyAttribute    *event;
- 
-#endif
 {
    Element	firstChild, lastChild;
 
@@ -288,16 +252,8 @@ NotifyAttribute    *event;
   of that rule with element toEl, for the main view.
   showBoxAllowed is TRUE if the ShowBox rule could be generated
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-void MovePRule (PRule presRule, Element fromEl, Element toEl, Document doc, ThotBool showBoxAllowed)
-#else  /* __STDC__ */
-void MovePRule (presRule, fromEl, toEl, doc, showBoxAllowed)
-PRule       presRule;
-Element     fromEl;
-Element     toEl;
-Document    doc;
-ThotBool    showBoxAllowed;
-#endif /* __STDC__ */
+void MovePRule (PRule presRule, Element fromEl, Element toEl, Document doc,
+		ThotBool showBoxAllowed)
 {
    int         presRuleType;
    PRule       newPRule, oldPRule;
@@ -336,49 +292,43 @@ ThotBool    showBoxAllowed;
 /*----------------------------------------------------------------------
   SetStyleAttribute.
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 void                SetStyleAttribute (Document doc, Element elem)
-#else  /* __STDC__ */
-void                SetStyleAttribute (doc, elem)
-Document            doc;
-Element             elem;
-#endif /* __STDC__ */
 {
    AttributeType       attrType;
    Attribute           styleAttr;
    ElementType         elType;
    Element	       firstChild, lastChild;
-   STRING              schName;
-   STRING              style;
+   char               *schName;
+   char               *style;
    int                 len;
 #define STYLELEN 1000
 
    /* does the element have a Style_ attribute ? */
    elType = TtaGetElementType (elem);
    schName = TtaGetSSchemaName (elType.ElSSchema);
-   if (ustrcmp (schName, TEXT("MathML")) == 0)
+   if (strcmp (schName, "MathML") == 0)
      {
        attrType.AttrSSchema = elType.ElSSchema;
        attrType.AttrTypeNum = MathML_ATTR_style_;
      }
    else
 #ifdef GRAPHML
-   if (ustrcmp (schName, TEXT("GraphML")) == 0)
+   if (strcmp (schName, "GraphML") == 0)
      {
        attrType.AttrSSchema = elType.ElSSchema;
        attrType.AttrTypeNum = GraphML_ATTR_style_;
      }
    else
-#endif
+#endif /* GRAPHML */
       {
-	attrType.AttrSSchema = TtaGetSSchema (TEXT("HTML"), doc);
+	attrType.AttrSSchema = TtaGetSSchema ("HTML", doc);
 	attrType.AttrTypeNum = HTML_ATTR_Style_;
       }
    styleAttr = TtaGetAttribute (elem, attrType);
 
    /* keep the new style string */
    len = STYLELEN;
-   style = TtaAllocString (STYLELEN);
+   style = TtaGetMemory (STYLELEN);
    GetHTMLStyleString (elem, doc, style, &len);
    if (len == 0)
      {
@@ -416,13 +366,7 @@ Element             elem;
   A specific PRule will be created or modified by the user for
   a given element. (pre-event)
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 ThotBool            ChangePRule (NotifyPresentation * event)
-#else  /* __STDC__ */
-ThotBool            ChangePRule (event)
-NotifyPresentation *event;
-
-#endif /* __STDC__ */
 {
   ElementType	     elType, parentType;
   Element	     el, span, body, root, parent;
@@ -432,7 +376,7 @@ NotifyPresentation *event;
   AttributeType      attrType;
   Attribute          attr;
 #define STYLELEN 1000
-  CHAR_T               buffer[15];
+  char               buffer[15];
   int                presType;
   int                w, h, unit, value, i;
   ThotBool           ret;
@@ -443,12 +387,13 @@ NotifyPresentation *event;
   presRule = event->pRule;
   elType = TtaGetElementType (el);
   ret = FALSE;
-  HTMLschema = TtaGetSSchema (TEXT("HTML"), doc);
+  HTMLschema = TtaGetSSchema ("HTML", doc);
 
   /* if it's a background rule on element BODY, move it to element HTML */
   /* if it's a rule on element HTML and it's not a background rule, move
      it to element BODY */
   if (event->event != TtePRuleDelete)
+    {
     if (elType.ElSSchema != HTMLschema)
       /* it's not an HTML element */
       {
@@ -469,8 +414,10 @@ NotifyPresentation *event;
 	  {
 	    root = TtaGetParent (el);
 	    if (presType == PRBackground)
-	      MovePRule (presRule, el, root, doc, TRUE);
-	    ret = TRUE; /* don't let Thot perform normal operation */      
+	      {
+		MovePRule (presRule, el, root, doc, TRUE);
+		ret = TRUE; /* don't let Thot perform normal operation */  
+	      }   
 	  }
 	else if (elType.ElTypeNum == HTML_EL_HTML)
 	  {
@@ -561,9 +508,9 @@ NotifyPresentation *event;
 		    TtaGiveBoxSize (el, doc, 1, unit, &value, &i);
 		    value = TtaGetPRuleValue (presRule);
 		    if (unit == UnPercent)
-		      usprintf (buffer, TEXT("%d%%"), value);
+		      sprintf (buffer, "%d%%", value);
 		    else
-		      usprintf (buffer, TEXT("%d"), value);
+		      sprintf (buffer, "%d", value);
 
 		    attrType.AttrTypeNum = HTML_ATTR_Width__;
 		    attr = TtaGetAttribute (el, attrType);
@@ -604,12 +551,11 @@ NotifyPresentation *event;
 		    if (elType.ElTypeNum == HTML_EL_PICTURE_UNIT)
 		      UpdateImageMap (el, doc, -1, h);
 		  }
-		return (TRUE);
+		return TRUE; /* don't let Thot perform normal operation */
 	      }
 	    else if (IsCharacterLevelElement (el)
 		&& (presType == PRIndent || presType == PRLineSpacing
-		    || presType == PRAdjust || presType == PRJustify
-		    || presType == PRHyphenate))
+		    || presType == PRAdjust || presType == PRHyphenate))
 	      /* if the rule is a Format rule applied to a character-level
 		 element, move it to the first enclosing non character-level
 		 element */
@@ -643,6 +589,7 @@ NotifyPresentation *event;
 	      }
 	  }
       }
+    }
   /* set the Style_ attribute ? */
   SetStyleAttribute (doc, el);
   TtaSetDocumentModified (doc);
@@ -655,12 +602,7 @@ NotifyPresentation *event;
   A specific PRule has been deleted by the user for a given element
   (post-event)
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 void                PRuleDeleted (NotifyPresentation * event)
-#else  /* __STDC__ */
-void                PRuleDeleted (event)
-NotifyPresentation *event;
-#endif /* __STDC__ */
 {
   /* set the Style_ attribute ? */
   SetStyleAttribute (event->document, event->element);
@@ -671,12 +613,7 @@ NotifyPresentation *event;
  AttrLangDeleted
  A Lang attribute has been deleted
  -----------------------------------------------------------------------*/
-#ifdef __STDC__
 void AttrLangDeleted (NotifyAttribute *event)
-#else /* __STDC__*/
-void AttrLangDeleted(event)
-     NotifyAttribute *event;
-#endif /* __STDC__*/
 {
    Element	 firstChild, lastChild;
    AttributeType attrType;
@@ -684,7 +621,7 @@ void AttrLangDeleted(event)
 
   /* if the element is a SPAN without any other attribute, remove the SPAN
      element */
-  DeleteSpanIfNoAttr (event->element, event->document, &firstChild, &lastChild);
+  DeleteSpanIfNoAttr (event->element, event->document, &firstChild,&lastChild);
   /* if it's the root (HTML) element, delete the RealLang attribute */
   if (!TtaGetParent (event->element))
      /* it's the root element */
@@ -702,28 +639,22 @@ void AttrLangDeleted(event)
  MoveAttrLang
  
  -----------------------------------------------------------------------*/
-#ifdef __STDC__
 static void MoveAttrLang (Attribute oldAttr, Element *el, Document doc)
-#else /* __STDC__*/
-static void MoveAttrLang (oldAttr, el, doc)
-     Attribute oldAttr;
-     Element *el;
-     Document doc;
-#endif /* __STDC__*/
 {
   Element	first, parent, sibling, next, firstChild, lastChild;
   Attribute	newAttr, attr;
   AttributeType	attrType;
   int		kind, len;
-  STRING	value    = TtaAllocString (ATTRLEN); 
-  STRING oldValue = TtaAllocString (ATTRLEN);
+  char	       *value    = TtaGetMemory (ATTRLEN); 
+  char         * oldValue = TtaGetMemory (ATTRLEN);
   ThotBool	sameLang;
 
   /* if all siblings have the same LANG attribute, move that attibute to
-     the parent element, unless the parent element has exception Hidden */
+     the parent element, unless the parent element has exception Hidden
+     or the parent element is the document element */
   parent = TtaGetParent (*el);
   if (parent)
-     if (TtaIsHidden (parent))
+     if (TtaIsHidden (parent) || !TtaGetParent (parent))
         parent = NULL;
   if (parent != NULL)
      {
@@ -744,7 +675,7 @@ static void MoveAttrLang (oldAttr, el, doc)
 	      {
 	      len = ATTRLEN - 1;
 	      TtaGiveTextAttributeValue (attr, value, &len);
-	      if (ustrcasecmp(oldValue, value) != 0)
+	      if (strcasecmp(oldValue, value) != 0)
 		 sameLang = FALSE;
 	      }
 	   }
@@ -787,18 +718,14 @@ static void MoveAttrLang (oldAttr, el, doc)
  AttrLangCreated
  A Lang attribute has been created
  -----------------------------------------------------------------------*/
-#ifdef __STDC__
 void AttrLangCreated (NotifyAttribute *event)
-#else /* __STDC__*/
-void AttrLangCreated(event)
-     NotifyAttribute *event;
-#endif /* __STDC__*/
 {
   Element	elem;
   int		len;
+  ElementType   elType;
   AttributeType attrType;
   Attribute	attr;
-  STRING	value    = TtaAllocString (ATTRLEN); 
+  char	       *value = TtaGetMemory (ATTRLEN); 
 
   /* move the LANG attribute to the parent element if all sibling have the
      same attribute with the same value */
@@ -807,22 +734,20 @@ void AttrLangCreated(event)
 
   len = ATTRLEN - 1;
   TtaGiveTextAttributeValue (event->attribute, value, &len);
-  if (ustrcasecmp(value, TEXT("Symbol")) == 0)
-     /* it's a character string in the Symbol character set, it's not really
-	a language */
-    {
+  if (strcasecmp(value, "Symbol") == 0)
+    /* it's a character string in the Symbol character set, it's not really
+       a language */
     TtaRemoveAttribute (elem, event->attribute, event->document);      
-    }
   else
-    {
-      /* if the LANG attribute is on a text string, create a SPAN element that
-	 encloses this text string and move the LANG attribute to that SPAN
-	 element */
-      AttrToSpan (elem, event->attribute, event->document);
-    }
+    /* if the LANG attribute is on a text string, create a SPAN element that
+       encloses this text string and move the LANG attribute to that SPAN
+       element */
+    AttrToSpan (elem, event->attribute, event->document);
   /* if it's the root (HTML) element, create a RealLang attribute too */
-  if (!TtaGetParent (elem))
-     /* it's the root element */
+  elType = TtaGetElementType (elem);
+  if (elType.ElTypeNum == HTML_EL_HTML &&
+      !strcmp(TtaGetSSchemaName (elType.ElSSchema), "HTML"))
+     /* it's the HTML root element */
      {
      attrType.AttrSSchema = event->attributeType.AttrSSchema;
      attrType.AttrTypeNum = HTML_ATTR_RealLang;
@@ -838,12 +763,7 @@ void AttrLangCreated(event)
  AttrLangModified
  A Lang attribute has been modified
  -----------------------------------------------------------------------*/
-#ifdef __STDC__
 void AttrLangModified (NotifyAttribute *event)
-#else /* __STDC__*/
-void AttrLangModified(event)
-     NotifyAttribute *event;
-#endif /* __STDC__*/
 {
   Element	elem;
   AttributeType attrType;
@@ -871,12 +791,7 @@ void AttrLangModified(event)
  AttrLangShouldBeDeleted
  The user wants to remove a Lang attribute
  -----------------------------------------------------------------------*/
-#ifdef __STDC__
 ThotBool AttrLangShouldBeDeleted (NotifyAttribute *event)
-#else /* __STDC__*/
-ThotBool AttrLangShouldBeDeleted(event)
-     NotifyAttribute *event;
-#endif /* __STDC__*/
 {
   Element	elem;
   AttributeType attrType;
