@@ -199,25 +199,56 @@
 #define AM_TMP_DIR		196
 #define AM_COLOR_PALETTE		197
 #define AM_LANNEG_MENU		198
-#define AM_XML_ERROR		199
-#define AM_ANNOT_CONF_MENU		200
-#define AM_ANNOT_USER		201
-#define AM_ANNOT_POST_SERVER		202
-#define AM_ANNOT_SERVERS		203
-#define AM_ANNOT_AUTOLOAD		204
-#define AM_DOC_SEL_COLOR		205
-#define AM_DOC_INS_COLOR		206
-#define AM_ORIENTATION		207
-#define AM_PORTRAIT		208
-#define AM_LANDSCAPE		209
-#define AM_ENABLE_FTP		210
-#define AM_XML_PROFILE		211
-#define AM_XML_WARNING		212
-#define AM_NOT_AVAILABLE		213
-#define AM_UNKNOWN_ENCODING		214
-#define AM_BROWSE		215
-#define AM_FILE_BROWSER		216
-#define AM_SELECTION		217
-#define AM_UNDEFINED_ENCODING		218
-#define AM_ENCODING_WARNING		219
-#define AMAYA_MSG_MAX		220
+#define AM_ANNOT_CONF_MENU		199
+#define AM_ANNOT_USER		200
+#define AM_ANNOT_POST_SERVER		201
+#define AM_ANNOT_SERVERS		202
+#define AM_ANNOT_LAUTOLOAD		203
+#define AM_ANNOT_RAUTOLOAD		204
+#define AM_ANNOT_RAUTOLOAD_RST		205
+#define AM_DOC_SEL_COLOR		206
+#define AM_DOC_INS_COLOR		207
+#define AM_ORIENTATION		208
+#define AM_PORTRAIT		209
+#define AM_LANDSCAPE		210
+#define AM_ENABLE_FTP		211
+#define AM_XML_NOT_WELL_FORMED		212
+#define AM_XML_CHARACTER_ERROR		213
+#define AM_XML_PROFILE		214
+#define AM_XML_ERROR		215
+#define AM_UNKNOWN_ENCODING		216
+#define AM_UNDEFINED_ENCODING		217
+#define AM_UNDEFINED_ENCODING_CONFIRM		218
+#define AM_NOT_AVAILABLE		219
+#define AM_BROWSE		220
+#define AM_FILE_BROWSER		221
+#define AM_SELECTION		222
+#define AM_AFILTER		223
+#define AM_AFILTER_SHOW		224
+#define AM_AFILTER_HIDE		225
+#define AM_AFILTER_SHOW_ALL		226
+#define AM_AFILTER_HIDE_ALL		227
+#define AM_AFILTER_HELP		228
+#define AM_AFILTER_OPTIONS		229
+#define AM_AFILTER_BYAUTHOR		230
+#define AM_AFILTER_BYTYPE		231
+#define AM_AFILTER_BYSERVER		232
+#define AM_ACCESSKEY		233
+#define AM_NONE		234
+#define AM_LOCAL_CSS		235
+#define AM_NO_XPOINTER		236
+#define AM_NO_ANNOT_MOVE		237
+#define AM_NO_ANNOT_MOVE_OTHER		238
+#define AM_SELECT_CHARSET		239
+#define AM_SELECT_MIMETYPE		240
+#define AM_CHANGE_CHARSET		241
+#define AM_CHANGE_MIME_TYPE		242
+#define AM_CHANGE		243
+#define AM_NOCHARSET_SUPPORT		244
+#define AM_NOMIMETYPE_SUPPORT		245
+#define AM_INVALID_MIMETYPE		246
+#define AM_UNKNOWN		247
+#define AM_CSS_ERROR		248
+#define AM_DOUBLE_LOAD		249
+#define AM_UNSAVE		250
+#define AMAYA_MSG_MAX		251
