@@ -1,6 +1,6 @@
 /*
  *
- *  (c) COPYRIGHT MIT and INRIA, 1996.
+ *  (c) COPYRIGHT MIT and INRIA, 1996-2001.
  *  Please first read the full copyright statement in file COPYRIGHT.
  *
  */
@@ -44,152 +44,130 @@ struct _HTError
   AHTProgress 
   displays in the status bar the current state of a request   
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
- BOOL         AHTProgress (HTRequest *request, HTAlertOpcode op, 
-			   int msgnum, const char *dfault,
-			   void *input, HTAlertPar *reply)
-#else  /* __STDC__ */
- BOOL         AHTProgress (request, op, msgnum, dfault, input, reply)
-HTRequest          *request;
-HTAlertOpcode       op;
-int                 msgnum;
-const char         *dfault;
-void               *input;
-HTAlertPar         *reply;
-
-#endif
+BOOL AHTProgress (HTRequest *request, HTAlertOpcode op, 
+		  int msgnum, const char *dfault,
+		  void *input, HTAlertPar *reply)
 {
    AHTReqContext      *me = HTRequest_context (request);
-   CHAR_T              tempbuf[MAX_LENGTH];
+   HTParentAnchor     *anchor;
+   char                text[MAX_LENGTH];
+   char                tempbuf[MAX_LENGTH];
    char                buf[11];
    long                cl, bytes_rw;
    int                 pro;
    int                *raw_rw;
-   HTParentAnchor     *anchor;
-   CHAR_T              text[MAX_LENGTH];
-   CHAR_T              Buff[11];
 
    if (request && HTRequest_internal (request))
-      return NO;
-
+     return NO;
    if (!me)
-      return NO;
-
+     return NO;
    if (input) 
-      iso2wc_strcpy (text, (char*)input);
+     strcpy (text, (char *) input);
    else 
-       text[0] = WC_EOS;
-
+     text[0] = EOS;
    switch (op)
+     {
+     case HT_PROG_TIMEOUT:
+       /*
+	 Message temporarily suppresed as it appears when pressing the Stop button
+	 TtaSetStatus (me->docid, 1, TtaGetMessage (AMAYA, AM_REQUEST_TIMEOUT), NULL);
+       */
+       break;
+     case HT_PROG_DNS:
+       TtaSetStatus (me->docid, 1, TtaGetMessage (AMAYA, AM_LOOKING_HOST), text);
+       break;
+     case HT_PROG_CONNECT:
+       TtaSetStatus (me->docid, 1, TtaGetMessage (AMAYA, AM_CONTACTING_HOST), text);
+       break;
+     case HT_PROG_ACCEPT:
+       TtaSetStatus (me->docid, 1, TtaGetMessage (AMAYA, AM_WAITING_FOR_CONNECTION), NULL);
+       break;
+     case HT_PROG_DONE:
+       /* a message is displayed elsewhere */
+       break;
+     case HT_PROG_READ:
+       if ((me->method != METHOD_PUT) && (me->method != METHOD_POST))
 	 {
-	    case HT_PROG_TIMEOUT:
-	      /* Message temporarily suppresed as it appears when pressing the Stop button */
-	      /*
-		TtaSetStatus (me->docid, 1, TtaGetMessage (AMAYA, AM_REQUEST_TIMEOUT), NULL);
-		*/
-	      break;
-	    case HT_PROG_DNS:
-	       TtaSetStatus (me->docid, 1, TtaGetMessage (AMAYA, AM_LOOKING_HOST), text);
-	       break;
-	    case HT_PROG_CONNECT:
-	       TtaSetStatus (me->docid, 1, TtaGetMessage (AMAYA, AM_CONTACTING_HOST), text);
-	       break;
-	    case HT_PROG_ACCEPT:
-	       TtaSetStatus (me->docid, 1, TtaGetMessage (AMAYA, AM_WAITING_FOR_CONNECTION), NULL);
-	       break;
-	    case HT_PROG_DONE:
-	       /* a message is displayed elsewhere */
-	      break;
-	    case HT_PROG_READ:
-	       if ((me->method != METHOD_PUT) && (me->method != METHOD_POST))
+	   cl = HTAnchor_length (HTRequest_anchor (request));
+	   if (cl > 0)
+	     {
+	       bytes_rw = HTRequest_bodyRead (request);
+	       pro = (int) ((bytes_rw * 100l) / cl);
+	       
+	       if (pro > 100)		/* libwww reports > 100! */
+		 pro = 100;
+	       HTNumToStr ((unsigned long) cl, buf, 10);
+	       sprintf (tempbuf, "%s (%d%% of %s)", me->status_urlName, (int) pro, buf);
+	     }
+	   else 
+	     {
+	       bytes_rw = HTRequest_bytesRead(request);
+	       raw_rw = input ? (int *) input : NULL;
+	       if (bytes_rw > 0)
 		 {
-		   cl = HTAnchor_length (HTRequest_anchor (request));
-		   if (cl > 0)
-		     {
-		       bytes_rw = HTRequest_bodyRead (request);
-		       pro = (int) ((bytes_rw * 100l) / cl);
-		       
-		       if (pro > 100)		/* libwww reports > 100! */
-			 pro = 100;
-		       HTNumToStr ((unsigned long) cl, buf, 10);
-               iso2wc_strcpy (Buff, buf);
-		       usprintf (tempbuf, TEXT("%s (%d%% of %s)\n"), me->status_urlName, (int) pro, Buff);
-		     }
-		   else 
-		     {
-		       bytes_rw = HTRequest_bytesRead(request);
-		       raw_rw = input ? (int *) input : NULL;
-		       if (bytes_rw > 0)
-			 {
-			   HTNumToStr(bytes_rw, buf, 10); 
-               iso2wc_strcpy (Buff, buf);
-			   usprintf (tempbuf, TEXT("%s bytes"), Buff);
-			 } 
-		       else if (raw_rw && *raw_rw>0) 
-			 {
-			   HTNumToStr(*raw_rw, buf, 10);
-               iso2wc_strcpy (Buff, buf);
-			   usprintf (tempbuf, TEXT("%s bytes"), Buff);
-			 } 
-		       else 
-			 buf[0] = EOS;
-		     }
-		   /* update the message on the status bar */
-		   if (buf[0]) 
-		     TtaSetStatus (me->docid, 1, TtaGetMessage (AMAYA, AM_PROG_READ), tempbuf);
-		   else
-		     TtaSetStatus (me->docid, 1, TtaGetMessage (AMAYA, AM_PROG_READ), me->status_urlName);
-		 }
-	       break;
-
-	    case HT_PROG_WRITE:
-	      if ((me->method == METHOD_PUT) || (me->method == METHOD_POST))
-		{
-		  anchor = HTRequest_anchor (HTRequest_source (request));
-		  cl = HTAnchor_length (anchor);
-		  if (cl > 0)
-		    {
-		      bytes_rw = HTRequest_bodyWritten (request);
-			pro = (int) ((bytes_rw * 100l) / cl);
-			HTNumToStr ((unsigned long) cl, buf, 10);
-            iso2wc_strcpy (Buff, buf);
-			usprintf (tempbuf, TEXT("%s: Writing (%d%% of %s)\n"), me->urlName, pro, Buff);
-			TtaSetStatus (me->docid, 1, TtaGetMessage (AMAYA, AM_PROG_WRITE), tempbuf);
-		    }
-		  else  
-		    {
-		      bytes_rw = HTRequest_bytesWritten(request);
-		      raw_rw = input ? (int *) input : NULL;
-		      if (bytes_rw > 0)
-			{
-			  HTNumToStr(bytes_rw, buf, 10);
-              iso2wc_strcpy (Buff, buf);
-			  usprintf (tempbuf, TEXT("%s bytes "), Buff);
-			} 
-		      else if (raw_rw && *raw_rw >0) 
-			{
-			  HTNumToStr(*raw_rw, buf, 10);
-              iso2wc_strcpy (Buff, buf);
-			  usprintf (tempbuf, TEXT("%s bytes "), Buff);
-			} 
-		      else 
-			buf[0] = EOS;
-		    }
-		  /* update the message on the status bar */
-		  /****
-		  if (buf[0]) 
-		    TtaSetStatus (me->docid, 1, TtaGetMessage (AMAYA, AM_PROG_READ), tempbuf);
-		  else
-		  ***/
-		    TtaSetStatus (me->docid, 1, TtaGetMessage (AMAYA, AM_PROG_WRITE), me->status_urlName);
-		}
-	       break;
-		 
-	     default:
-	       TtaSetStatus (me->docid, 1, TtaGetMessage (AMAYA, AM_UNKNOWN_STATUS), NULL);
-	       break;
+		   HTNumToStr(bytes_rw, buf, 10); 
+		   sprintf (tempbuf, "%s bytes", buf);
+		 } 
+	       else if (raw_rw && *raw_rw>0) 
+		 {
+		   HTNumToStr(*raw_rw, buf, 10);
+		   sprintf (tempbuf, "%s bytes", buf);
+		 } 
+	       else 
+		 buf[0] = EOS;
+	     }
+	   /* update the message on the status bar */
+	   if (buf[0]) 
+	     TtaSetStatus (me->docid, 1, TtaGetMessage (AMAYA, AM_PROG_READ), tempbuf);
+	   else
+	     TtaSetStatus (me->docid, 1, TtaGetMessage (AMAYA, AM_PROG_READ), me->status_urlName);
 	 }
-
+       break;
+       
+     case HT_PROG_WRITE:
+       if ((me->method == METHOD_PUT) || (me->method == METHOD_POST))
+	 {
+	   anchor = HTRequest_anchor (HTRequest_source (request));
+	   cl = HTAnchor_length (anchor);
+	   if (cl > 0)
+	     {
+	       bytes_rw = HTRequest_bodyWritten (request);
+	       pro = (int) ((bytes_rw * 100l) / cl);
+	       HTNumToStr ((unsigned long) cl, buf, 10);
+	       sprintf (tempbuf, "%s: Writing (%d%% of %s)", me->urlName, pro, buf);
+	       TtaSetStatus (me->docid, 1, TtaGetMessage (AMAYA, AM_PROG_WRITE), tempbuf);
+	     }
+	   else  
+	     {
+	       bytes_rw = HTRequest_bytesWritten(request);
+	       raw_rw = input ? (int *) input : NULL;
+	       if (bytes_rw > 0)
+		 {
+		   HTNumToStr(bytes_rw, buf, 10);
+		   sprintf (tempbuf, "%s bytes ", buf);
+		 } 
+	       else if (raw_rw && *raw_rw >0) 
+		 {
+		   HTNumToStr(*raw_rw, buf, 10);
+		   sprintf (tempbuf, "%s bytes ", buf);
+		 } 
+	       else 
+		 buf[0] = EOS;
+	     }
+	   /* update the message on the status bar */
+	   /****
+		if (buf[0]) 
+		TtaSetStatus (me->docid, 1, TtaGetMessage (AMAYA, AM_PROG_READ), tempbuf);
+		else
+	   ***/
+	   TtaSetStatus (me->docid, 1, TtaGetMessage (AMAYA, AM_PROG_WRITE), me->status_urlName);
+	 }
+       break;
+       
+     default:
+       TtaSetStatus (me->docid, 1, TtaGetMessage (AMAYA, AM_UNKNOWN_STATUS), NULL);
+       break;
+     }
    return YES;
 }
 
@@ -198,23 +176,12 @@ HTAlertPar         *reply;
   AHTConfirm 
   opens a form to request user confirmation on an action.
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
- BOOL         AHTConfirm (HTRequest * request, HTAlertOpcode op, int msgnum,
-			  const char * dfault,
-			  void *input, HTAlertPar * reply)
-#else  /* __STDC__ */
- BOOL         AHTConfirm (request, op, msgnum, dfault, input, reply)
-HTRequest          *request;
-HTAlertOpcode       op;
-int                 msgnum;
-const char         *dfault;
-void               *input;
-HTAlertPar         *reply;
-
-#endif /* __STDC__ */
+BOOL AHTConfirm (HTRequest * request, HTAlertOpcode op, int msgnum,
+		 const char * dfault,
+		 void *input, HTAlertPar * reply)
 {
   ThotBool         answer;
-  STRING          tmp_buf;
+  char            *tmp_buf;
   AHTReqContext   *me = HTRequest_context (request);
   AHTReqStatus     old_reqStatus;
 
@@ -237,14 +204,14 @@ HTAlertPar         *reply;
       InitConfirm (0, 0, TtaGetMessage (AMAYA, AM_REDIRECTION_CONFIRM));
       break;
     case HT_MSG_FILE_REPLACE:
-      tmp_buf = TtaAllocString (ustrlen (me->urlName) + ustrlen (TtaGetMessage (AMAYA, AM_OVERWRITE_CHECK)) + 10); /*a bit more than enough memory */
-      usprintf (tmp_buf, TtaGetMessage (AMAYA, AM_OVERWRITE_CHECK), me->urlName);
+      tmp_buf = TtaGetMemory (strlen (me->urlName) + strlen (TtaGetMessage (AMAYA, AM_OVERWRITE_CHECK)) + 10); /*a bit more than enough memory */
+      sprintf (tmp_buf, TtaGetMessage (AMAYA, AM_OVERWRITE_CHECK), me->urlName);
       InitConfirm (0, 0, tmp_buf);
       TtaFreeMemory (tmp_buf);
       break;
     case HT_MSG_RULES:
-      tmp_buf = TtaAllocString (ustrlen (me->urlName) + ustrlen (TtaGetMessage (AMAYA, AM_ETAG_CHANGED)) + 10); /*a bit more than enough memory */
-      usprintf (tmp_buf, TtaGetMessage (AMAYA, AM_ETAG_CHANGED), me->urlName);
+      tmp_buf = TtaGetMemory (strlen (me->urlName) + strlen (TtaGetMessage (AMAYA, AM_ETAG_CHANGED)) + 10); /*a bit more than enough memory */
+      sprintf (tmp_buf, TtaGetMessage (AMAYA, AM_ETAG_CHANGED), me->urlName);
       InitConfirm (0, 0, tmp_buf);
       TtaFreeMemory (tmp_buf);
       break;
@@ -267,19 +234,8 @@ HTAlertPar         *reply;
   AHTPrompt
   prompts for a text answer and returns this answer.
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
- BOOL         AHTPrompt (HTRequest * request, HTAlertOpcode op, int msgnum, const char *dfault,
-			       void *input, HTAlertPar * reply)
-#else  /* __STDC__ */
- BOOL         AHTPrompt (request, op, msgnum, dfault, input, reply)
-HTRequest          *request;
-HTAlertOpcode       op;
-int                 msgnum;
-const char         *dfault;
-void               *input;
-HTAlertPar         *reply;
-
-#endif
+BOOL AHTPrompt (HTRequest * request, HTAlertOpcode op, int msgnum, const char *dfault,
+		void *input, HTAlertPar * reply)
 {
   /* JK: removed temporarily this prompt as it should be rewritten for
      use by the FTP module to save a file */
@@ -336,48 +292,29 @@ HTAlertPar         *reply;
   default value.						
   Initial value of *password is completely discarded.	
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
- BOOL         AHTPromptUsernameAndPassword (HTRequest *request, HTAlertOpcode op, int msgnum,
+BOOL AHTPromptUsernameAndPassword (HTRequest *request, HTAlertOpcode op, int msgnum,
 					    const char *dfault, 
 					    void *input, HTAlertPar * reply)
-#else
-BOOL         AHTPromptUsernameAndPassword (request, op, msgnum, dfault, input reply)
-HTRequest          *request;
-HTAlertOpcode       op;
-int                 msgnum;
-const char         *dfault;
-void               *input;
-HTAlertPar         *reply;
-
-#endif /* __STDC */
 {
    AHTReqContext      *me = HTRequest_context (request);
-   const char*               realm = HTRequest_realm (request);
-   CHAR_T*             server;
+   const char         *realm = HTRequest_realm (request);
+   char               *server;
    AHTReqStatus        old_reqStatus;
-#  ifdef _I18N_
-   CHAR_T              RealM[MAX_LENGTH];
-#  else  /* !_I18N_ */
-   const CHAR_T*             RealM = realm;
-#  endif /* !_I18N_ */
 
    if (reply && msgnum >= 0) 
      {
        /* initialise */
-       Answer_name[0] = WC_EOS;
+       Answer_name[0] = EOS;
        Lg_password = 0;
-       Answer_password[0] = WC_EOS;
+       Answer_password[0] = EOS;
 
-#      ifdef _I18N_ 
-       iso2wc_strcpy (RealM, realm);
-#      endif /* _I18N_ */
        /* prepare the authentication realm message */
-       server = AmayaParseUrl (me->urlName, TEXT(""), AMAYA_PARSE_HOST);
+       server = AmayaParseUrl (me->urlName, "", AMAYA_PARSE_HOST);
        /* protection against having a stop kill this thread */
        old_reqStatus = me->reqStatus;
        me->reqStatus = HT_BUSY;
        /* show the popup */
-       InitFormAnswer (me->docid, 1, RealM, server);
+       InitFormAnswer (me->docid, 1, realm, server);
        if (me->reqStatus != HT_ABORT)
 	 me->reqStatus = old_reqStatus;
        /* free allocated memory */
@@ -387,13 +324,10 @@ HTAlertPar         *reply;
        /* handle the user's answers back to the library */
        if (UserAnswer)
 	 {
-	   char tmp[MAX_LENGTH];
-	   wc2iso_strcpy (tmp, Answer_name);
 	   /* set the user name */
-	   HTAlert_setReplyMessage (reply, tmp);
+	   HTAlert_setReplyMessage (reply, Answer_name);
 	   /* set the password */
-	   wc2iso_strcpy (tmp, Answer_password);
-	   HTAlert_setReplySecret (reply, tmp);
+	   HTAlert_setReplySecret (reply, Answer_password);
 	   return YES;
 	 }
        else
@@ -407,37 +341,31 @@ HTAlertPar         *reply;
    Returns TRUE if libwww forced a downgrade to 0.9 while fulfilling
    the request. FALSE, otherwise.
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-ThotBool IsHTTP09Error (HTRequest * request)
-#else
-ThotBool IsHTTP09Error (request)
-HTRequest * request;
-#endif
+ThotBool IsHTTP09Error (HTRequest *request)
 {
-   HTList             *cur;
-   HTError            *pres;
-   ThotBool           found = FALSE;
-   int                 index;
+  HTList             *cur;
+  HTError            *pres;
+  ThotBool           found = FALSE;
+  int                 index;
 
-   cur = HTRequest_error (request);
-
-   while ((pres = (HTError *) HTList_nextObject (cur)))
-     {
-       index = HTError_index (pres);
-       if (index == HTERR_HTTP09) 
-	 {
-	   found = TRUE;
-	   if (WWWTRACE)
-	     HTTrace ("IsHTTP09Error..... Detected 0.9 backward compatibility\n");
-	   /* we set up a more explicit message, as I don't know what may be
-	      before this error. */
-	   HTRequest_addError (request, ERR_FATAL, NO, HTERR_BAD_REPLY,
-			       "Error: Server sent an unexpected reply.", 0,
-			       NULL);
-	   break;
-	 }
-     }
-   return (found);
+  cur = HTRequest_error (request);
+  while ((pres = (HTError *) HTList_nextObject (cur)))
+    {
+      index = HTError_index (pres);
+      if (index == HTERR_HTTP09) 
+	{
+	  found = TRUE;
+	  if (WWWTRACE)
+	    HTTrace ("IsHTTP09Error..... Detected 0.9 backward compatibility\n");
+	  /* we set up a more explicit message, as I don't know what may be
+	     before this error. */
+	  HTRequest_addError (request, ERR_FATAL, NO, HTERR_BAD_REPLY,
+			      "Error: Server sent an unexpected reply.", 0,
+			      NULL);
+	  break;
+	}
+    }
+  return (found);
 }
 
 
@@ -449,56 +377,45 @@ HTRequest * request;
    help file that might be put up as a link. This file can then be
    multi-linguistic.                            
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-BOOL                AHTError_print (HTRequest * request, HTAlertOpcode op, int msgnum, const char *dfault, void *input, HTAlertPar * reply)
-#else  /* __STDC__ */
-BOOL                AHTError_print (request, op, msgnum, dfault, input, reply)
-HTRequest          *request;
-HTAlertOpcode       op;
-int                 msgnum;
-const char         *dfault;
-void               *input;
-HTAlertPar         *reply;
-
-#endif /* __STDC__ */
+BOOL AHTError_print (HTRequest *request, HTAlertOpcode op, int msgnum,
+		     const char *dfault, void *input, HTAlertPar *reply)
 {
-   HTList             *cur = (HTList *) input;
-   HTError            *pres;
-   AHTReqContext      *me = (AHTReqContext *) HTRequest_context (request);
-   int                 index;
+  HTList             *cur = (HTList *) input;
+  HTError            *pres;
+  AHTReqContext      *me = (AHTReqContext *) HTRequest_context (request);
+  int                 index;
 
-   if (WWWTRACE)
-      HTTrace ("HTError..... Generating message\n");
-   if (!request || !cur)
-      return NO;
-   while ((pres = (HTError *) HTList_nextObject (cur)))
-     {
-       index = HTError_index (pres);
-       switch (index)
-	 {
-	 case HTERR_UNAUTHORIZED:
-	   TtaSetStatus (me->docid, 1,
-			 TtaGetMessage (AMAYA, AM_AUTHENTICATION_FAILURE), me->urlName);
-	   break;
-	 case HTERR_FORBIDDEN:
-	   TtaSetStatus (me->docid, 1,
-			 TtaGetMessage (AMAYA, AM_FORBIDDEN_ACCESS), me->urlName);
-	   break;
-	 case HTERR_SYSTEM:
-	   if (!strcmp ("connect",  HTError_location (pres)))
-	     TtaSetStatus (me->docid, 1, TtaGetMessage (AMAYA, AM_CANT_CONNECT_TO_HOST), (STRING) NULL);
-	   else
-	     TtaSetStatus (me->docid, 1, TtaGetMessage (AMAYA, AM_UNKNOWN_SAVE_ERROR), me->urlName);
-	   break;
-	 case HTERR_NO_REMOTE_HOST:
-	   TtaSetStatus (me->docid, 1, TtaGetMessage (AMAYA, AM_CANT_CONNECT_TO_HOST), (STRING) NULL);
-	     break;
-	 default:
-	   break;
-	 }
-     }
-
-   return YES;
+  if (WWWTRACE)
+    HTTrace ("HTError..... Generating message\n");
+  if (!request || !cur)
+    return NO;
+  while ((pres = (HTError *) HTList_nextObject (cur)))
+    {
+      index = HTError_index (pres);
+      switch (index)
+	{
+	case HTERR_UNAUTHORIZED:
+	  TtaSetStatus (me->docid, 1,
+			TtaGetMessage (AMAYA, AM_AUTHENTICATION_FAILURE), me->urlName);
+	  break;
+	case HTERR_FORBIDDEN:
+	  TtaSetStatus (me->docid, 1,
+			TtaGetMessage (AMAYA, AM_FORBIDDEN_ACCESS), me->urlName);
+	  break;
+	case HTERR_SYSTEM:
+	  if (!strcmp ("connect",  HTError_location (pres)))
+	    TtaSetStatus (me->docid, 1, TtaGetMessage (AMAYA, AM_CANT_CONNECT_TO_HOST), NULL);
+	  else
+	    TtaSetStatus (me->docid, 1, TtaGetMessage (AMAYA, AM_UNKNOWN_SAVE_ERROR), me->urlName);
+	  break;
+	case HTERR_NO_REMOTE_HOST:
+	  TtaSetStatus (me->docid, 1, TtaGetMessage (AMAYA, AM_CANT_CONNECT_TO_HOST), NULL);
+	  break;
+	default:
+	  break;
+	}
+    }
+  return YES;
 }
 
 /*----------------------------------------------------------------------
@@ -507,79 +424,66 @@ HTAlertPar         *reply;
    then uses it as the actual server response (useful for displaying
    errors as HTML code). 
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-void                AHTError_MemPrint (HTRequest * request)
-#else  /* __STDC__ */
-void                AHTERROR_MemPrint (request)
-HTRequest          *request;
-
-#endif /* __STDC__ */
+void AHTError_MemPrint (HTRequest *request)
 {
-   HTError            *pres;
-   HTList             *cur = request->error_stack;
-   AHTReqContext      *me = (AHTReqContext *) HTRequest_context (request);
-   int                 index;
-   CHAR_T              buffer[1024];
-   char                isoBuff [1024];
+  HTError            *pres;
+  HTList             *cur = request->error_stack;
+  AHTReqContext      *me = (AHTReqContext *) HTRequest_context (request);
+  int                 index;
+  char                buffer[1024];
 
-
-   if (WWWTRACE)	   
-      HTTrace ("HTError..... Generating message\n");
-   if (!request || !cur)
-      return;
-
-   /* force the error type (we're generating it anyway) */
-   if (!me->http_headers.content_type)
-     me->http_headers.content_type = TtaWCSdup (TEXT("text/html"));
-
-   while ((pres = (HTError *) HTList_nextObject (cur)))
-     {
-	index = HTError_index (pres);
-	{			/* Error number */
-	  switch (index)
-	    {
-	    case HTERR_NO_REMOTE_HOST:
-	    case HTERR_SYSTEM:
-	    case HTERR_INTERNAL:
-	      if (pres->par != NULL)
-		{
-		  if (me->method != METHOD_PUT) 
-		    {
-		      usprintf (buffer, TtaGetMessage (AMAYA, AM_SYS_ERROR_TMPL), me->urlName, me->urlName, (int) pres->element, pres->par);
-              wc2iso_strcpy (isoBuff, buffer);
-		      StrAllocCat (me->error_stream, isoBuff);
-		    }
-		  else
-		    {
-		      usprintf (buffer, TEXT("Error: Server is unavailable or doesn't exist"));
-              wc2iso_strcpy (isoBuff, buffer);
-		      StrAllocCat (me->error_stream, isoBuff);
-		    }
-		}
-	      return;
-	      break;
-	    case HTERR_TIME_OUT:
-	      if (me->method != METHOD_PUT)
-		{
-		  usprintf (buffer, TtaGetMessage (AMAYA, AM_SYS_ERROR_TMPL), me->urlName, me->urlName, (int) pres->element, "connection timeout");
-          wc2iso_strcpy (isoBuff, buffer);
-		  StrAllocCat (me->error_stream, isoBuff);
-		}
-	      else
-		{
-		  usprintf (buffer, TEXT("Error: Server is unavailable or doesn't exist"));
-          wc2iso_strcpy (isoBuff, buffer);
-		  StrAllocCat (me->error_stream, isoBuff);
-		}
-	      break;	   
-	    default:
-	      if (pres->par != NULL)
-		  StrAllocCat (me->error_stream, pres->par);
-	      return;
-	      break;
-	    }
-	}
-     }
+  if (WWWTRACE)	   
+    HTTrace ("HTError..... Generating message\n");
+  if (!request || !cur)
+    return;
+  
+  /* force the error type (we're generating it anyway) */
+  if (!me->http_headers.content_type)
+    me->http_headers.content_type = TtaStrdup ("text/html");
+  while ((pres = (HTError *) HTList_nextObject (cur)))
+    {
+      index = HTError_index (pres);
+      {			/* Error number */
+	switch (index)
+	  {
+	  case HTERR_NO_REMOTE_HOST:
+	  case HTERR_SYSTEM:
+	  case HTERR_INTERNAL:
+	    if (pres->par != NULL)
+	      {
+		if (me->method != METHOD_PUT) 
+		  {
+		    sprintf (buffer, TtaGetMessage (AMAYA, AM_SYS_ERROR_TMPL), me->urlName, me->urlName, (int) pres->element, pres->par);
+		    StrAllocCat (me->error_stream, buffer);
+		  }
+		else
+		  {
+		    sprintf (buffer, "Error: Server is unavailable or doesn't exist");
+		    StrAllocCat (me->error_stream, buffer);
+		  }
+	      }
+	    return;
+	    break;
+	  case HTERR_TIME_OUT:
+	    if (me->method != METHOD_PUT)
+	      {
+		sprintf (buffer, TtaGetMessage (AMAYA, AM_SYS_ERROR_TMPL), me->urlName, me->urlName, (int) pres->element, "connection timeout");
+		StrAllocCat (me->error_stream, buffer);
+	      }
+	    else
+	      {
+		sprintf (buffer, "Error: Server is unavailable or doesn't exist");
+		StrAllocCat (me->error_stream, buffer);
+	      }
+	    break;	   
+	  default:
+	    if (pres->par != NULL)
+	      StrAllocCat (me->error_stream, pres->par);
+	    return;
+	    break;
+	  }
+      }
+    }
 }
 
 /*----------------------------------------------------------------------
@@ -587,19 +491,11 @@ HTRequest          *request;
   displays a message on the status bar that states the number of
   pending requests.
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-void                AHTPrintPendingRequestStatus (Document docid, BOOL last_seconds_of_life)
-#else
-void                AHTPrintPendingRequestStatus (doc, last_seconds_of_life)
-Document            doc;
-BOOL             last_seconds_of_life;
-
-#endif
-
+void AHTPrintPendingRequestStatus (Document docid, BOOL last_seconds_of_life)
 {
    int                 waiting_count = 0;
    AHTDocId_Status    *docid_status;
-   CHAR_T              buffer[120];
+   char              buffer[120];
 
    /* verify if there are any requests at all associated with docid */
 
@@ -613,7 +509,7 @@ BOOL             last_seconds_of_life;
 
    if (waiting_count > 0)
      {
-	usprintf (buffer, TtaGetMessage (AMAYA, AM_WAITING_REQUESTS), waiting_count);
+	sprintf (buffer, TtaGetMessage (AMAYA, AM_WAITING_REQUESTS), waiting_count);
 	TtaSetStatus (docid, 1, buffer, NULL);
 
      }
@@ -624,24 +520,16 @@ BOOL             last_seconds_of_life;
   displays a message on the status bar indicating the result of the
   request.
   ----------------------------------------------------------------------*/
-
-#ifdef __STDC__
 void PrintTerminateStatus (AHTReqContext *me, int status) 
-#else
-void PrintTerminateStatus (me, status)
-AHTReqContext *me;
-int status;
-#endif
-
 {
 
   HTError             *error = (HTError *) NULL;
   HTError             *next_error;
   HTErrorElement      errorElement;
   HTList              *cur;
-  CHAR_T              msg_status[10];
+  char              msg_status[10];
   char                *server_status = NULL;
-  CHAR_T              *wc_tmp;
+  char              *wc_tmp;
   HTResponse          *response;
 
   if (status == 200)
@@ -659,14 +547,14 @@ int status;
   else if (status == 204 && me->method == METHOD_PUT)
     TtaSetStatus (me->docid, 1, 
 		  TtaGetMessage (AMAYA, AM_NO_DATA), 
-		  (STRING) NULL);
+		  NULL);
   else if (status == -400 || status == 505)
     {
       TtaSetStatus (me->docid, 1, 
 		    TtaGetMessage (AMAYA, 
 				   AM_SERVER_DID_NOT_UNDERSTAND_REQ_SYNTAX),
-		    (STRING) NULL);
-      usprintf (AmayaLastHTTPErrorMsg, 
+		    NULL);
+      sprintf (AmayaLastHTTPErrorMsg, 
 	       TtaGetMessage (AMAYA,
 			      AM_SERVER_DID_NOT_UNDERSTAND_REQ_SYNTAX));
     }
@@ -676,7 +564,7 @@ int status;
 		    TtaGetMessage (AMAYA, 
 				   AM_AUTHENTICATION_FAILURE), 
 		    me->status_urlName);
-      usprintf (AmayaLastHTTPErrorMsg, 
+      sprintf (AmayaLastHTTPErrorMsg, 
 	       TtaGetMessage (AMAYA, AM_AUTHENTICATION_FAILURE),
 	       me->status_urlName);
     }
@@ -685,7 +573,7 @@ int status;
       TtaSetStatus (me->docid, 1,
 		    TtaGetMessage (AMAYA, AM_FORBIDDEN_ACCESS),
 		    me->status_urlName);
-      usprintf (AmayaLastHTTPErrorMsg, 
+      sprintf (AmayaLastHTTPErrorMsg, 
 	       TtaGetMessage (AMAYA, AM_FORBIDDEN_ACCESS), 
 	       me->urlName);
     }
@@ -693,15 +581,15 @@ int status;
     {
       TtaSetStatus (me->docid, 1, 
 		    TtaGetMessage (AMAYA, AM_METHOD_NOT_ALLOWED),
-		    (STRING) NULL);
-      usprintf(AmayaLastHTTPErrorMsg, 
+		    NULL);
+      sprintf(AmayaLastHTTPErrorMsg, 
 	      TtaGetMessage (AMAYA, AM_METHOD_NOT_ALLOWED));
     }
   else if (status == -409)
     {
       TtaSetStatus (me->docid, 1,
-		    TEXT("Conflict with the current state of the resource"), NULL);
-      usprintf(AmayaLastHTTPErrorMsg, TEXT("409: Conflict with the current state of the resource"));
+		    "Conflict with the current state of the resource", NULL);
+      sprintf(AmayaLastHTTPErrorMsg, "409: Conflict with the current state of the resource");
     }
   else if (status <0)
     {
@@ -733,11 +621,11 @@ int status;
       if (error == (HTError *) NULL)
 	/* there's no error context */
 	{
-	  usprintf (msg_status, TEXT("%d"), status); 
+	  sprintf (msg_status, "%d", status); 
 	  TtaSetStatus (me->docid, 1, 
 			TtaGetMessage (AMAYA, AM_UNKNOWN_XXX_STATUS), 
 			msg_status);
-	  usprintf (AmayaLastHTTPErrorMsg, 
+	  sprintf (AmayaLastHTTPErrorMsg, 
 		   TtaGetMessage (AMAYA, AM_UNKNOWN_XXX_STATUS),
 		   msg_status);
 	  return;
@@ -748,38 +636,38 @@ int status;
       if (errorElement == HTERR_INTERRUPTED)
 	{
 	  TtaSetStatus (me->docid, 1,
-			TEXT("Transfer interrupted by user"), (STRING) NULL);
-	  usprintf (AmayaLastHTTPErrorMsg, TEXT("%s"), TEXT("Transfer interrupted by user"));
+			"Transfer interrupted by user", NULL);
+	  sprintf (AmayaLastHTTPErrorMsg, "%s", "Transfer interrupted by user");
 	}
       else if (errorElement == HTERR_PRECON_FAILED) 
 	{
 	  TtaSetStatus (me->docid, 1,
-			TEXT("Document has changed (412)"), (STRING) NULL);
-	  usprintf (AmayaLastHTTPErrorMsg, TEXT("%s"), TEXT("Document has changed (412)"));
+			"Document has changed (412)", NULL);
+	  sprintf (AmayaLastHTTPErrorMsg, "%s", "Document has changed (412)");
 	  status = -412;
 	}
       else if (errorElement == HTERR_TIME_OUT || errorElement == HTERR_TIMEOUT)
 	{
 	  TtaSetStatus (me->docid, 1,
-			TEXT("Connection Timeout"), (STRING) NULL);
-	  usprintf (AmayaLastHTTPErrorMsg,
-		    TEXT("Connection Timeout"));
+			"Connection Timeout", NULL);
+	  sprintf (AmayaLastHTTPErrorMsg,
+		    "Connection Timeout");
 	}
       else if (errorElement == HTERR_NOT_IMPLEMENTED)
 	{
 	  TtaSetStatus (me->docid, 1,
 			TtaGetMessage (AMAYA, AM_SERVER_NOT_IMPLEMENTED_501_ERROR), 
-			(STRING) NULL);
-	  usprintf (AmayaLastHTTPErrorMsg, 
+			NULL);
+	  sprintf (AmayaLastHTTPErrorMsg, 
 		    TtaGetMessage (AMAYA, AM_SERVER_NOT_IMPLEMENTED_501_ERROR));
 	  status = -501;
 	}
       else if (errorElement == HTERR_NO_REMOTE_HOST)
 	{
 	  TtaSetStatus (me->docid, 1,
-			TEXT("Host %s doesn't exist"), (char *) error->par);
-	  usprintf (AmayaLastHTTPErrorMsg, 
-		    TEXT("Host %s doesn't exist"), (char *) error->par);
+			"Host %s doesn't exist", (char *) error->par);
+	  sprintf (AmayaLastHTTPErrorMsg, 
+		    "Host %s doesn't exist", (char *) error->par);
 	}
       else if (errorElement == HTERR_INTERNAL)
 	{
@@ -789,7 +677,7 @@ int status;
 	      TtaSetStatus (me->docid, 1, 
 			    TtaGetMessage (AMAYA, AM_SERVER_INTERNAL_ERROR_500_CAUSE), 
 			    error->par);
-	      usprintf (AmayaLastHTTPErrorMsg, 
+	      sprintf (AmayaLastHTTPErrorMsg, 
 			TtaGetMessage (AMAYA, AM_SERVER_INTERNAL_ERROR_500_CAUSE), 
 			error->par);
 	    }
@@ -797,8 +685,8 @@ int status;
 	    {
 	      TtaSetStatus (me->docid, 1, 
 			    TtaGetMessage (AMAYA, AM_SERVER_INTERNAL_ERROR_500_NO_CAUSE), 
-			    (STRING) NULL);
-	      usprintf (AmayaLastHTTPErrorMsg, 
+			    NULL);
+	      sprintf (AmayaLastHTTPErrorMsg, 
 			TtaGetMessage (AMAYA, AM_SERVER_INTERNAL_ERROR_500_NO_CAUSE));
 	    }
 	  status = -500; 
@@ -808,26 +696,26 @@ int status;
       else if (errorElement == HTERR_HTTP09)
 	{
 	  TtaSetStatus (me->docid, 1,
-			TEXT("Server or network forced libwww to downgrade to HTTP/0.9."),
-			(STRING) NULL);
-	  usprintf (AmayaLastHTTPErrorMsg,
-		    TEXT("Server or network forced libwww to downgrade to HTTP/0.9 for this host. Please quit."));
+			"Server or network forced libwww to downgrade to HTTP/0.9.",
+			NULL);
+	  sprintf (AmayaLastHTTPErrorMsg,
+		    "Server or network forced libwww to downgrade to HTTP/0.9 for this host. Please quit.");
 	}
 #endif
       else if (server_status)
 	{
-	  wc_tmp = TtaISO2WCdup (server_status);
+	  wc_tmp = TtaStrdup (server_status);
 	  /* let's output whatever the server or libwww reports as an error */
-	  TtaSetStatus (me->docid, 1, wc_tmp, (STRING) NULL);
-	  ustrcpy (AmayaLastHTTPErrorMsg, wc_tmp);
+	  TtaSetStatus (me->docid, 1, wc_tmp, NULL);
+	  strcpy (AmayaLastHTTPErrorMsg, wc_tmp);
 	  TtaFreeMemory (wc_tmp);
 	}
       else
 	{
 	  /* we don't have anything else, except for the status code */
-	  usprintf (msg_status, TEXT("%d"), status); 
+	  sprintf (msg_status, "%d", status); 
 	  TtaSetStatus (me->docid, 1, TtaGetMessage (AMAYA, AM_UNKNOWN_XXX_STATUS), msg_status);
-	  usprintf (AmayaLastHTTPErrorMsg, 
+	  sprintf (AmayaLastHTTPErrorMsg, 
 		    TtaGetMessage (AMAYA, AM_UNKNOWN_XXX_STATUS), msg_status);
 	}
     }
@@ -840,8 +728,8 @@ int status;
 	  server_status = HTResponse_reason (response);
 	  if (server_status && *server_status)
 	    {
-	      wc_tmp = TtaISO2WCdup (server_status);
-	      usprintf (AmayaLastHTTPErrorMsgR, TEXT("Server reason: %s"), 
+	      wc_tmp = TtaStrdup (server_status);
+	      sprintf (AmayaLastHTTPErrorMsgR, "Server reason: %s", 
 			wc_tmp);
 	      TtaFreeMemory (wc_tmp);
 	    }
