@@ -248,9 +248,19 @@
 #define ANNOTFILTERMENU                 544
 #define MAKEIDMENU                      545
 #define SAVEASDIALOG1                   546
+#define DOCINFOMENU                     547
+#define IDD_DIALOG1                     548
+#define IDD_DIALOG2                     549
+#define IDD_DIALOG4                     550
+#define IDC_CURSOR1                     551
+#define MIMETYPEDIALOG                  552
+#define CHARSETDIALOG                   553
+#define SAVEASDIALOG2                   554
 #define ID_CONFIRM                      1000
 #define ID_DONE                         1001
 #define IDC_URLEDIT                     1002
+#define ID_CHANGEMIMETYPE               1002
+#define ID_CHANGECHARSET                1003
 #define ID_PRINT                        1011
 #define IDC_OPTIONS                     1012
 #define IDC_TABOFCONTENTS               1014
@@ -276,6 +286,7 @@
 #define IDC_URLMESSAGE                  1057
 #define ID_APPLY                        1058
 #define IDC_GETALT                      1058
+#define IDC_CLEAR                       1058
 #define IDC_TIMES                       1060
 #define IDC_HELVETICA                   1061
 #define IDC_COURIER                     1062
@@ -288,7 +299,7 @@
 #define IDC_NORMAL                      1073
 #define IDC_UNDERLINE                   1074
 #define IDC_CROSSOUT                    1075
-#define IDC_DEFAULTUNDERLINE            1076
+#define IDC_OVERLINE                    1076
 #define IDC_06PT                        1079
 #define IDC_10PT                        1090
 #define IDC_08PT                        1091
@@ -304,21 +315,20 @@
 #define IDC_LEFT                        1100
 #define IDC_RIGHT                       1101
 #define IDC_CENTER                      1102
-#define IDC_DEFAULTALIGN                1103
+#define IDC_JUSTIFY                     1103
 #define IDC_BLEFT                       1104
 #define IDC_BCENTER                     1106
 #define IDC_BRIGHT                      1107
 #define IDC_INDENTPT                    1108
 #define IDC_INDENTPTVALUE               1109
-#define IDC_INDENTPTEDIT                1110
+#define IDC_DEFAULTALIGN                1110
+#define IDC_INDENTPTEDIT                1111
 #define IDC_INDENT1                     1113
 #define IDC_INDENT2                     1114
 #define IDC_INDENTDEFAULT               1115
 #define IDC_BINDENT1                    1116
 #define IDC_BINDENT2                    1118
-#define IDC_JUSTIFYES                   1120
-#define IDC_JUSTIFNO                    1121
-#define IDC_JUSTIFDEFAULT               1122
+#define IDC_BJUSTIFY                    1120
 #define IDC_LINESPACINGPT               1123
 #define IDC_LINESPACINGPTVALUE          1124
 #define IDC_LINESPACINGEDIT             1125
@@ -557,7 +567,7 @@
 #define IDC_IGNORE_CSS                  1412
 #define IDC_GPOLYLINE                   1413
 #define IDC_NUMROWS                     1413
-#define IDC_OVERLINE                    1413
+#define IDC_DEFAULTUNDERLINE            1413
 #define IDC_GALPHA2                     1414
 #define IDC_BORDER                      1414
 #define IDC_GGROUP                      1415
@@ -652,7 +662,10 @@
 #define IDC_ANNOTPOSTSERVER             1516
 #define IDC_TANNOTAUTOLOAD              1518
 #define IDC_ANNOTAUTOLOAD               1519
+#define IDC_ANNOTLAUTOLOAD              1519
+#define IDC_ANNOTRAUTOLOAD              1520
 #define ID_ANNOTSHOW                    1521
+#define IDC_ANNOTRAUTOLOADRST           1521
 #define ID_ANNOTHIDE                    1522
 #define ID_ANNOTSHOWALL                 1523
 #define ID_ANNOTHIDEALL                 1524
@@ -660,6 +673,7 @@
 #define IDC_FILTERBYTYPE                1526
 #define IDC_TFILTEROPTIONS              1528
 #define IDC_TFILTERHIDDEN               1529
+#define IDC_TFILTERHELP                 1529
 #define IDC_FILTERSEL                   1531
 #define ID_CREATEID                     1533
 #define ID_REMOVEID                     1534
@@ -673,6 +687,27 @@
 #define IDC_TAUTHINFO                   1544
 #define IDC_TPASSWDEDIT                 1545
 #define IDC_TNAMEEDIT                   1546
+#define IDC_AALT                        1547
+#define IDC_ACTRL                       1548
+#define IDC_ANONE                       1549
+#define IDC_ACCESSKEY                   1550
+#define IDC_DIURL                       1551
+#define IDC_DICONTENTTYPE               1552
+#define IDC_DICHARSET                   1553
+#define IDC_DICONTENTLEN                1554
+#define IDC_DICONTENTTYPE_VAL           1556
+#define IDC_DICHARSET_VAL               1557
+#define IDC_DICONTENTLEN_VAL            1558
+#define IDC_DIURL_VAL                   1559
+#define IDC_PAGENO                      1560
+#define IDC_CHARSET                     1561
+#define IDC_MIMETYPE                    1562
+#define IDC_MTEDIT                      1564
+#define IDC_STATUS                      1566
+#define IDC_USASCII                     1567
+#define IDC_UTF8                        1568
+#define IDC_ISOL1                       1569
+#define IDC_ISOL2                       1570
 #define ID_BUTTON40017                  40017
 #define ID_BUTTON40018                  40018
 #define ID_BUTTON40019                  40019
@@ -717,9 +752,9 @@
 // 
 #ifdef APSTUDIO_INVOKED
 #ifndef APSTUDIO_READONLY_SYMBOLS
-#define _APS_NEXT_RESOURCE_VALUE        546
+#define _APS_NEXT_RESOURCE_VALUE        554
 #define _APS_NEXT_COMMAND_VALUE         40052
-#define _APS_NEXT_CONTROL_VALUE         1547
+#define _APS_NEXT_CONTROL_VALUE         1570
 #define _APS_NEXT_SYMED_VALUE           101
 #endif
 #endif
