@@ -14,9 +14,20 @@
  *                  for the byzance collaborative work application
  */
 
+/* annotlib includes */
 #include "annotlib.h"
+#include "ANNOTfiles_f.h"
+#include "ANNOTschemas_f.h"
+#include "ANNOTevent_f.h"
+#include "ANNOTtools_f.h"
+
+/* Amaya includes */
+#include "init_f.h"
 #include "AHTURLTools_f.h"
 
+/* schema includes */
+#include "Annot.h"
+
 /*-----------------------------------------------------------------------
    Procedure ANNOT_SetPath (document)
   -----------------------------------------------------------------------
@@ -31,7 +42,7 @@ void ANNOT_SetPath (document)
      Document document;
 #endif /* __STDC__*/
 {
-  CHAR_T  *dirList = TtaGetMemory (2000);
+  char  *dirList = TtaGetMemory (2000);
 
   TtaGetDocumentPath (dirList, 2000);
   strcat (dirList, ":");
@@ -44,19 +55,14 @@ void ANNOT_SetPath (document)
   Creates an annotation file for the current document. Returns the number
   of the created document or 0 in case of failure
   -----------------------------------------------------------------------*/
-
-#ifdef __STDC__
-Document ANNOT_NewDocument (Document doc)
-#else /* __STDC__*/
-Document ANNOT_NewDocument (doc)
-     Document doc;
-#endif /* __STDC__*/
+Document ANNOT_NewDocument (Document doc, AnnotMode mode)
 {
   Document annotDoc;
   char     *annot_dir;
   char     *fname;
   char     *docname;
   char     *tmpname;
+  char     *tmp;
 
   /* Create a new annotation document */
   annot_dir = GetAnnotDir ();
@@ -67,7 +73,12 @@ Document ANNOT_NewDocument (doc)
   TtaFreeMemory (tmpname);
 
   /* "annot is the title of the window */
-  annotDoc = InitDocView (0, "annotation", docAnnot, 0, FALSE);
+  if (mode & ANNOT_isReplyTo)
+    tmp = "reply to annotation";
+  else
+    tmp = "annotation";
+
+  annotDoc = InitDocView (0, tmp, docAnnot, 0, FALSE);
 
   if (annotDoc == 0) 
     {
@@ -76,18 +87,11 @@ Document ANNOT_NewDocument (doc)
     }
   else
     {
-#if 0
-      TtaSetDocumentName (annotDoc, TEXT("Annotation");
-      TtaSetDocumentDirectory (annotDoc, annot_dir);
-#endif
-
       /* intialize the (amaya) metadata related to a document */
       if (DocumentURLs[annotDoc])
 	TtaFreeMemory (DocumentURLs[annotDoc]);
       DocumentURLs[annotDoc] = fname;
-      DocumentMeta[annotDoc] = (DocumentMetaDataElement *) TtaGetMemory (sizeof (DocumentMetaDataElement));
-      DocumentMeta[annotDoc]->form_data = NULL;
-      DocumentMeta[annotDoc]->initial_url = NULL;
+      DocumentMeta[annotDoc] = DocumentMetaDataAlloc ();
       DocumentMeta[annotDoc]->method = CE_ABSOLUTE;
       DocumentSource[annotDoc] = 0;
 
@@ -97,49 +101,66 @@ Document ANNOT_NewDocument (doc)
 }
 
 /*-----------------------------------------------------------------------
-   GetMetaData
+  GetMetaData
+  returns the annotation object that corresponds to the annotation
+  doc_annot of document doc.
   -----------------------------------------------------------------------*/
-#ifdef __STDC__
 AnnotMeta *GetMetaData (Document doc, Document doc_annot)
-#else
-AnnotMeta *GetMetaData (doc, doc_annot)
-Document doc;
- Document doc_annot;
-#endif /* __STDC__ */
 {
   List *ptr;
   AnnotMeta *annot = NULL;
 
   /* get a pointer to the annot list */
   ptr = AnnotMetaData[doc].annotations;
-  if (!ptr)
-    return (NULL);
-
   while (ptr)
     {
       annot = (AnnotMeta *) ptr->object;
       /* @@ maybe we could add calls to NormalizeFile here */
       if ((annot->annot_url 
-	   && (!ustrcasecmp (DocumentURLs[doc_annot], annot->annot_url)
-	       || !ustrcasecmp (DocumentURLs[doc_annot], annot->annot_url + 7)))
+	   && (!strcasecmp (DocumentURLs[doc_annot], annot->annot_url)
+	       || !strcasecmp (DocumentURLs[doc_annot], annot->annot_url + 7)))
 	  /* RRS: newly created local annotations have only a body URI */
 	  || (annot->body_url
-	      &&  (!ustrcasecmp (DocumentURLs[doc_annot], annot->body_url) 
-		   || !ustrcasecmp (DocumentURLs[doc_annot], annot->body_url + 7))))
+	      &&  (!strcasecmp (DocumentURLs[doc_annot], annot->body_url) 
+		   || !strcasecmp (DocumentURLs[doc_annot], annot->body_url + 7))))
 	break;
       ptr = ptr->next;
     }
-
+  
   if (ptr)
     return annot;
+
+#ifdef ANNOT_ON_ANNOT
+  if (AnnotMetaData[doc].thread)
+    ptr = AnnotMetaData[doc].thread->annotations;
   else
-    return NULL;
+    ptr = NULL;
+  while (ptr)
+    {
+      annot = (AnnotMeta *) ptr->object;
+      /* @@ maybe we could add calls to NormalizeFile here */
+      if ((annot->annot_url 
+	   && (!strcasecmp (DocumentURLs[doc_annot], annot->annot_url)
+	       || !strcasecmp (DocumentURLs[doc_annot], annot->annot_url + 7)))
+	  /* RRS: newly created local annotations have only a body URI */
+	  || (annot->body_url
+	      &&  (!strcasecmp (DocumentURLs[doc_annot], annot->body_url) 
+		   || !strcasecmp (DocumentURLs[doc_annot], annot->body_url + 7))))
+	break;
+      ptr = ptr->next;
+    }
+  if (ptr)
+    return annot;
+#endif /* ANNOT_ON_ANNOT */
+
+  return NULL;
 }
 
 /*-----------------------------------------------------------------------
   ANNOT_LoadAnnotation
-  Initializes an annotation document by adding a BODY part
-  and adding META elements for title, author, date, and type
+  If an annotation has already been loaded, we open a window and show
+  its body.
+  (@@ JK: weird function!)
   -----------------------------------------------------------------------*/
 #ifdef __STDC__
 void ANNOT_LoadAnnotation (Document doc, Document docAnnot)
@@ -155,7 +176,7 @@ void ANNOT_LoadAnnotation (doc, annotDoc)
      we copy it from the existing metadata */
   annot = GetMetaData (doc, docAnnot);
   if (annot)
-    ANNOT_InitDocumentStructure (doc, docAnnot, annot, FALSE);
+    ANNOT_InitDocumentStructure (doc, docAnnot, annot, ANNOT_initNone);
 }
 
 /*-----------------------------------------------------------------------
@@ -168,7 +189,7 @@ void ANNOT_ReloadAnnotMeta (annotDoc)
      Document annotDoc;
 #endif /* __STDC__*/
 {
-  Document source_doc;
+  Document source_doc; 
   AnnotMeta *annot;
 
   source_doc = DocumentMeta[annotDoc]->source_doc;
@@ -178,7 +199,7 @@ void ANNOT_ReloadAnnotMeta (annotDoc)
   if (!annot)
     return;
   /* initialize the meta data */
-  ANNOT_InitDocumentStructure (source_doc, annotDoc, annot, FALSE);
+  ANNOT_InitDocumentStructure (source_doc, annotDoc, annot, ANNOT_initNone);
 }
 
 /*-----------------------------------------------------------------------
@@ -186,26 +207,18 @@ void ANNOT_ReloadAnnotMeta (annotDoc)
   Initializes an annotation document by adding a BODY part
   and adding META elements for title, author, date, and type
   -----------------------------------------------------------------------*/
-#ifdef __STDC__
-void  ANNOT_InitDocumentMeta (Document doc, Document docAnnot, AnnotMeta *annot, CHAR_T *title)
-#else /* __STDC__*/
-void  ANNOT_InitDocumentMeta (doc, docAnnot, annot, title)
-     Document   doc;
-     Document   docAnnot;
-     AnnotMeta *annot;
-     CHAR_T    *title;
-#endif /* __STDC__*/
+void  ANNOT_InitDocumentMeta (Document doc, Document docAnnot, AnnotMeta *annot, char *source_doc_title)
 {
-  ElementType elType;
-  Element     root, head, el;
-  Attribute           attr;
-  AttributeType       attrType;
-  STRING      user;
-  STRING      doc_anchor;
-  STRING      source_url;
-  CHAR_T     *cdate;
-  CHAR_T     *mdate;
-  CHAR_T     *type;
+  ElementType    elType;
+  Element        root, head, el;
+  Attribute      attr;
+  AttributeType  attrType;
+  STRING         user;
+  STRING         doc_anchor;
+  STRING         source_url;
+  char          *cdate;
+  char          *mdate;
+  char          *type;
 
   user = annot->author;
   source_url = annot->source_url;
@@ -215,7 +228,7 @@ void  ANNOT_InitDocumentMeta (doc, docAnnot, annot, title)
   if (annot->type)
       type = ANNOT_GetLabel(&annot_schema_list, annot->type);
   else
-      type = TEXT(""); /* All local annotations should have a type, but
+      type = ""; /* All local annotations should have a type, but
 			  a service may forget to give us a type. */
 
   /* save the docid of the annotated document */
@@ -226,7 +239,7 @@ void  ANNOT_InitDocumentMeta (doc, docAnnot, annot, title)
   */
 
   /* point to the first node */
-  root = TtaGetMainRoot (docAnnot);
+  root = TtaGetRootElement (docAnnot);
   elType = TtaGetElementType (root);
 
   /* point to the metadata structure */
@@ -249,7 +262,7 @@ void  ANNOT_InitDocumentMeta (doc, docAnnot, annot, title)
 	  elType.ElTypeNum = Annot_EL_CreatorGivenName;
 	  el = TtaSearchTypedElement (elType, SearchInTree, head);
 	  el = TtaGetFirstChild (el);
-	  TtaSetTextContent (el, (CHAR_T *) s->object->name,
+	  TtaSetTextContent (el, (char *) s->object->name,
 			     TtaGetDefaultLanguage (),
 			     docAnnot);
 	}
@@ -260,7 +273,7 @@ void  ANNOT_InitDocumentMeta (doc, docAnnot, annot, title)
 	  elType.ElTypeNum = Annot_EL_CreatorFamilyName;
 	  el = TtaSearchTypedElement (elType, SearchInTree, head);
 	  el = TtaGetFirstChild (el);
-	  TtaSetTextContent (el, (CHAR_T *) s->object->name,
+	  TtaSetTextContent (el, (char *) s->object->name,
 			     TtaGetDefaultLanguage (),
 			     docAnnot);
 	}
@@ -271,12 +284,22 @@ void  ANNOT_InitDocumentMeta (doc, docAnnot, annot, title)
 	  elType.ElTypeNum = Annot_EL_CreatorEmail;
 	  el = TtaSearchTypedElement (elType, SearchInTree, head);
 	  el = TtaGetFirstChild (el);
-	  TtaSetTextContent (el, (CHAR_T *) s->object->name,
+	  TtaSetTextContent (el, (char *) s->object->name,
 			     TtaGetDefaultLanguage (),
 			     docAnnot);
 	}
     }
 
+  /* title metadata */
+  if (annot->title)
+    {
+      elType.ElTypeNum = Annot_EL_ATitle;
+      el = TtaSearchTypedElement (elType, SearchInTree, head);
+      el = TtaGetFirstChild (el);
+      TtaSetTextContent (el, annot->title, TtaGetDefaultLanguage (), 
+			 docAnnot); 
+    }
+  
   /* Creation Date metadata */
   elType.ElTypeNum = Annot_EL_AnnotCDate;
   el = TtaSearchTypedElement (elType, SearchInTree, head);
@@ -299,24 +322,25 @@ void  ANNOT_InitDocumentMeta (doc, docAnnot, annot, title)
   TtaAttachAttribute (el, attr, docAnnot);
 #if 0
     {
-      doc_anchor = TtaGetMemory (ustrlen (DocumentURLs[doc])
-				 + ustrlen (user)
-				 + ustrlen (DocumentURLs[docAnnot])
+      doc_anchor = TtaGetMemory (strlen (DocumentURLs[doc])
+				 + strlen (user)
+				 + strlen (DocumentURLs[docAnnot])
 				 + 20);
       sprintf (doc_anchor, "%s#%s_%s_%s", DocumentURLs[doc],
 	       ANNOT_ANAME, user, DocumentURLs[docAnnot]);
       annot->name = doc_anchor;
     }
 #endif
-  doc_anchor = TtaGetMemory (ustrlen (DocumentURLs[doc])
-			     + ustrlen (annot->name) 
+  doc_anchor = TtaGetMemory (strlen (DocumentURLs[doc])
+			     + strlen (annot->name) 
 			     + 20);
   sprintf (doc_anchor, "%s#%s", DocumentURLs[doc], annot->name);
   TtaSetAttributeText (attr, doc_anchor, el, docAnnot);
   TtaFreeMemory (doc_anchor);
-  /* use the title parameter as the value of the source document field */
+  /* use the source_doc_title parameter as the value of the source
+     document field */
   el = TtaGetFirstChild (el);
-  TtaSetTextContent (el, title,
+  TtaSetTextContent (el, source_doc_title,
 		     TtaGetDefaultLanguage (), docAnnot);
   /* RDF type metadata */
   elType.ElTypeNum = Annot_EL_RDFtype;
@@ -331,24 +355,18 @@ void  ANNOT_InitDocumentMeta (doc, docAnnot, annot, title)
   Initializes an annotation document by adding a BODY part
   and adding META elements for title, author, date, and type
   -----------------------------------------------------------------------*/
-#ifdef __STDC__
-void  ANNOT_InitDocumentBody (Document docAnnot, CHAR_T *title)
-#else /* __STDC__*/
-void  ANNOT_InitDocumentBody (docAnnot, title)
-Document docAnnot;
-CHAR_T *title;
-#endif /* __STDC__*/
+void  ANNOT_InitDocumentBody (Document docAnnot, char *source_doc_title)
 {
   ElementType elType;
   Element     root, head, body, el, child;
-  CHAR_T     *tmp;
+  char     *tmp;
 
   /*
   ** HTML initialization
   */
 
   /* we find the the HTML nature */
-  root = TtaGetMainRoot (docAnnot);
+  root = TtaGetRootElement (docAnnot);
   elType = TtaGetElementType (root);
   head = TtaSearchTypedElement (elType, SearchInTree, root);
   elType.ElTypeNum = Annot_EL_Body;
@@ -369,8 +387,9 @@ CHAR_T *title;
   el = TtaSearchTypedElement (elType, SearchInTree, root);
   el = TtaGetFirstChild (el);
   /* @@ maybe parse the URL here */
-  tmp = TtaGetMemory (ustrlen (title) + sizeof ("Annotation about ") + 1);
-  sprintf (tmp, "Annotation of %s", title);
+  tmp = TtaGetMemory (strlen (source_doc_title)
+		      + sizeof ("Annotation of ") + 1);
+  sprintf (tmp, "Annotation of %s", source_doc_title);
   TtaSetTextContent (el, tmp,
 		     TtaGetDefaultLanguage (), docAnnot);
   TtaFreeMemory (tmp);
@@ -391,13 +410,13 @@ CHAR_T *title;
   attrType.AttrTypeNum = HTML_ATTR_meta_name;
   attr = TtaNewAttribute (attrType);
   TtaAttachAttribute (meta, attr, docAnnot);
-  TtaSetAttributeText (attr, TEXT("GENERATOR"), meta, docAnnot);
+  TtaSetAttributeText (attr, "GENERATOR", meta, docAnnot);
   attrType.AttrTypeNum = HTML_ATTR_meta_content;
   attr = TtaNewAttribute (attrType);
   TtaAttachAttribute (meta, attr, docAnnot);
-  ustrcpy (tempfile, HTAppName);
-  ustrcat (tempfile, TEXT(" "));
-  ustrcat (tempfile, HTAppVersion);
+  strcpy (tempfile, HTAppName);
+  strcat (tempfile, " ");
+  strcat (tempfile, HTAppVersion);
   TtaSetAttributeText (attr, tempfile, meta, docAnnot);
   TtaInsertSibling (meta, child, FALSE, docAnnot);
 #endif
@@ -412,47 +431,431 @@ CHAR_T *title;
     }
 }
 
+/*-----------------------------------------------------------------------
+  ANNOT_ThreadItem_new
+  -----------------------------------------------------------------------*/
+static Element ANNOT_ThreadItem_new (Document doc)
+{
+  Element thread_item;
+  ElementType elType;
+  
+  /* create the new item */
+  elType.ElSSchema =  TtaGetSSchema ("Annot", doc);
+  elType.ElTypeNum = Annot_EL_Thread_item;
+  thread_item =  TtaNewTree (doc, elType, "");
+
+  /* return the element we just created */
+  return thread_item;
+}
+
+/*-----------------------------------------------------------------------
+  ANNOT_ThreadItem_init
+  Inits a thread item default fields.
+  -----------------------------------------------------------------------*/
+static void ANNOT_ThreadItem_init (Element thread_item, Document doc, AnnotMeta *annot_doc, ThotBool useSource)
+{
+  Element             el;
+  ElementType         elType;
+  Attribute           attr;
+  AttributeType       attrType;
+  char               *href;
+  char               *tmp;
+  AnnotMeta          *annot;
+
+  attrType.AttrSSchema = elType.ElSSchema = TtaGetSSchema ("Annot", doc);
+
+  /*
+  **  initialize the reverse link 
+  */
+  attrType.AttrTypeNum = Annot_ATTR_HREF_;
+  /* remove the previous reverse link if it exists already */
+  attr = TtaGetAttribute (thread_item, attrType);
+  if (attr)
+    TtaRemoveAttribute (thread_item, attr, doc);
+  attr = TtaNewAttribute (attrType);
+  TtaAttachAttribute (thread_item, attr, doc);
+  tmp = (useSource) ? annot_doc->source_url : annot_doc->body_url,
+  href = TtaGetMemory (strlen (tmp) + 20);
+  sprintf (href, "%s", tmp);
+  TtaSetAttributeText (attr, href, thread_item, doc);
+  TtaFreeMemory (href);
+
+  if (useSource)
+    annot = GetMetaData (DocumentMeta[doc]->source_doc, doc);
+  else
+    annot = annot_doc;
+
+  if (!annot)
+    tmp = NULL;
+
+  /* put the type of the annotation */
+  elType.ElTypeNum = Annot_EL_TI_Type;
+  el = TtaSearchTypedElement (elType, SearchInTree, thread_item);
+  if (el)
+    {
+      if (annot && annot->type)
+	{
+	  el = TtaGetFirstChild (el);
+      	  tmp =  ANNOT_GetLabel(&annot_schema_list, annot->type);
+	  TtaSetTextContent (el, tmp, TtaGetDefaultLanguage (), doc);
+	}
+    }
+
+  /* put the title of the annotation */
+  elType.ElTypeNum = Annot_EL_TI_Title;
+  el = TtaSearchTypedElement (elType, SearchInTree, thread_item);
+  if (el)
+    {
+      el = TtaGetFirstChild (el);
+      if (annot)
+	tmp = annot->title;
+      TtaSetTextContent (el, (tmp) ? tmp :  "no title", 
+			 TtaGetDefaultLanguage (), doc);
+    }
+
+  /* put the author of the annotation */
+  elType.ElTypeNum = Annot_EL_TI_Author;
+  el = TtaSearchTypedElement (elType, SearchInTree, thread_item);
+  if (el)
+    {
+      el = TtaGetFirstChild (el);
+      if (annot)
+	tmp = annot->author;
+      if (tmp)
+	TtaSetTextContent (el, tmp, TtaGetDefaultLanguage (), doc);
+    }
+
+  /* put the date of the annotation */
+  elType.ElTypeNum = Annot_EL_TI_Date;
+  el = TtaSearchTypedElement (elType, SearchInTree, thread_item);
+  if (el)
+    {
+      el = TtaGetFirstChild (el);
+      if (annot)
+	tmp = annot->mdate;
+      if (tmp)
+	TtaSetTextContent (el, tmp, TtaGetDefaultLanguage (), doc);
+    }
+}
+
+/*-----------------------------------------------------------------------
+  ANNOT_AddThreadItem
+  Experiment the S/P threads.
+
+  root = element to which we want to attach the item.
+  AsSibling = insert it as a sibling of root.
+
+  If root == NULL, we find the thread element. If this one doesn't
+  exist we create it and consider this item as the first one in the list.
+  If the thread element exists, we will use the last child of the thread 
+  as root.
+  -----------------------------------------------------------------------*/
+Element ANNOT_AddThreadItem (Document doc, AnnotMeta *annot)
+{
+#ifdef ANNOT_ON_ANNOT
+  ElementType    elType;
+  Element        root, thread_item, el;
+  Attribute      attr;
+  AttributeType  attrType;
+  char          *url;
+  int            i;
+
+  /* we find the the Thread element and make it our root */
+  root = TtaGetRootElement (doc);
+  elType = TtaGetElementType (root);
+  elType.ElTypeNum = Annot_EL_Thread;
+  el = TtaSearchTypedElement (elType, SearchInTree, root);
+
+  if (el)
+    root = el;
+  else
+    {
+      /* create the thread element */
+      elType.ElTypeNum = Annot_EL_Body;
+      el = TtaSearchTypedElement (elType, SearchInTree, root);
+      if (!el)
+	return NULL; /* couldn't find a body! */
+      elType.ElTypeNum = Annot_EL_Thread;
+      root =  TtaNewTree (doc, elType, "");
+      /* insert the thread */
+      TtaInsertSibling (root, el, FALSE, doc);
+      /* and initialize the root of the thread */
+      el = TtaGetFirstChild (root);
+      ANNOT_ThreadItem_init (el, doc,  annot, TRUE);
+    }
+
+  /* try to find where to insert the element */
+  attrType.AttrSSchema = elType.ElSSchema;
+  attrType.AttrTypeNum = Annot_ATTR_HREF_;
+  TtaSearchAttribute (attrType, SearchForward, root, &el, &attr);
+  while (el)
+    {
+      i = TtaGetTextAttributeLength (attr) + 1;
+      url = TtaGetMemory (i);
+      TtaGiveTextAttributeValue (attr, url, &i);
+      if (!strcasecmp (url, annot->source_url))
+	{
+	  TtaFreeMemory (url);
+	  break;
+	}
+      TtaFreeMemory (url);
+      root = el;
+      TtaSearchAttribute (attrType, SearchForward, root, &el, &attr);
+    }
+  root = el;
+  
+  if (!root)
+    /* we can't insert a reply to nothing! */
+    return NULL;
+      
+  /* find the container and insert it */
+  el = TtaGetLastChild (root);
+  elType = TtaGetElementType (el);
+  if (elType.ElTypeNum != Annot_EL_TI_content)
+    {
+      /* there's no container, create it */
+      root = el;
+      elType.ElTypeNum = Annot_EL_TI_content;
+      el = TtaNewElement (doc, elType);
+      TtaInsertSibling (el, root, FALSE, doc);
+    }
+  /* create the thread_item */
+  thread_item = ANNOT_ThreadItem_new (doc);
+  /* and insert it as the last child of the above container */
+  /* JK: @@ we should use sort here the thread item by date too */
+  root = el;
+  el = TtaGetLastChild (root);
+  if (el)
+    TtaInsertSibling (thread_item, el, FALSE, doc);
+  else
+    TtaInsertFirstChild (&thread_item, root, doc);
+
+  /* init the thread item elements */
+  ANNOT_ThreadItem_init (thread_item, doc,  annot, FALSE);
+
+  return (thread_item);
+#else
+  return 0;
+#endif /* ANNOT_ON_ANNOT */
+}
+
+/*-----------------------------------------------------------------------
+  ANNOT_ToggleThread
+  Selects an item in the thread view.
+  -----------------------------------------------------------------------*/
+void ANNOT_ToggleThread (Document thread_doc, Document annot_doc, 
+			 ThotBool turnOn)
+{
+#ifdef ANNOT_ON_ANNOT
+  ElementType    elType;
+  Element        root, el, ti_desc;
+  Attribute      attr;
+  AttributeType  attrType;
+  char          *url;
+  int            i;
+
+  /* we find the the Thread element and make it our root */
+  root = TtaGetRootElement (thread_doc);
+  elType = TtaGetElementType (root);
+  attrType.AttrSSchema = elType.ElSSchema;
+  attrType.AttrTypeNum = Annot_ATTR_HREF_;
+  TtaSearchAttribute (attrType, SearchForward, root, &el, &attr);
+  while (el)
+    {
+      i = TtaGetTextAttributeLength (attr) + 1;
+      url = TtaGetMemory (i);
+      TtaGiveTextAttributeValue (attr, url, &i);
+      /* grr... again a local compare problem! */
+      elType.ElTypeNum = Annot_EL_TI_desc;
+      ti_desc = TtaSearchTypedElement (elType, SearchInTree, el);
+      attrType.AttrTypeNum = Annot_ATTR_Selected_;
+      attr = TtaGetAttribute (ti_desc, attrType);
+      if (!strcasecmp (url, DocumentURLs[annot_doc])
+	  || !strcasecmp (url + sizeof ("file:/"), DocumentURLs[annot_doc]))
+	{
+	  if (turnOn && !attr)
+	    {
+	      /* turn on the selected status */
+	      attr = TtaNewAttribute (attrType);
+	      TtaAttachAttribute (ti_desc, attr, thread_doc);
+	      TtaSetAttributeValue (attr, Annot_ATTR_Selected__VAL_Yes_, ti_desc, thread_doc);
+	    }
+	  if (!turnOn && attr)
+	    /* turn off the selected status */
+	    TtaRemoveAttribute (ti_desc, attr, thread_doc);
+	}
+      else if (strcasecmp (url, DocumentURLs[annot_doc]) && attr)
+	{
+	  /* turn off the selected status */
+	  TtaRemoveAttribute (ti_desc, attr, thread_doc);
+	}
+      TtaFreeMemory (url);
+      root = el;
+      attrType.AttrTypeNum = Annot_ATTR_HREF_;
+      TtaSearchAttribute (attrType, SearchForward, root, &el, &attr);
+    }
+#endif
+}
+
+/*-----------------------------------------------------------------------
+  ANNOT_GetThreadDoc
+  Returns the doc number of the doc that is currently selected in a thread.
+  Returns 0 if no such doc is open.
+  -----------------------------------------------------------------------*/
+Document ANNOT_GetThreadDoc (Document thread_doc)
+{
+#ifdef ANNOT_ON_ANNOT
+  Document       doc_annot;
+  ElementType    elType;
+  Element        root, el;
+  Attribute      attr;
+  AttributeType  attrType;
+  char          *url;
+  int            i;
+
+  doc_annot = 0;
+  /* we find the the Thread element and make it our root */
+  root = TtaGetRootElement (thread_doc);
+  elType = TtaGetElementType (root);
+  attrType.AttrSSchema = elType.ElSSchema;
+  attrType.AttrTypeNum = Annot_ATTR_Selected_;
+  TtaSearchAttribute (attrType, SearchForward, root, &el, &attr);
+  if (el)
+    {
+      el = TtaGetParent (el);
+      attrType.AttrTypeNum = Annot_ATTR_HREF_;
+      attr = TtaGetAttribute (el, attrType);
+      i = TtaGetTextAttributeLength (attr) + 1;
+      url = TtaGetMemory (i);
+      TtaGiveTextAttributeValue (attr, url, &i);
+      for (i = 1 ; i <DocumentTableLength; i++)
+	{
+	  /* find the document */
+	  /* @@ grr! */
+	  if (!DocumentURLs[i])
+	    continue;
+	  else if (!strcasecmp (url, DocumentURLs[i])
+		   || !strcasecmp (url + sizeof ("file:") - 1, DocumentURLs[i])
+		   || !strcasecmp (url + sizeof ("file:/") - 1, DocumentURLs[i])
+		   || !strcasecmp (url + sizeof ("file://") - 1, DocumentURLs[i]))
+	    {
+	      doc_annot = i;
+	      break;
+	    }
+	}
+      TtaFreeMemory (url);
+    }
+  return doc_annot;
+#else
+  return 0;
+#endif
+}
+
+/*-----------------------------------------------------------------------
+  ANNOT_UpdateThread
+  Updates the metadata of a thread item.
+  -----------------------------------------------------------------------*/
+void ANNOT_UpdateThread (Document doc, AnnotMeta *annot)
+{
+#ifdef ANNOT_ON_ANNOT
+  Document       thread_doc;
+  ElementType    elType;
+  Element        root, el;
+  Attribute      attr;
+  AttributeType  attrType;
+  char          *url;
+  int            i;
+
+  if (!annot)
+    return;
+
+  /* find the document where the thread is being shown */
+  if (AnnotMetaData[doc].thread)
+    thread_doc = AnnotThread_searchRoot (AnnotMetaData[doc].thread->rootOfThread);
+  else
+    thread_doc = 0;
+
+  if (thread_doc == 0)
+    return;
+
+  /* we find the the Thread element and make it our root */
+  root = TtaGetRootElement (thread_doc);
+  elType = TtaGetElementType (root);
+  attrType.AttrSSchema = elType.ElSSchema;
+  attrType.AttrTypeNum = Annot_ATTR_HREF_;
+  TtaSearchAttribute (attrType, SearchForward, root, &el, &attr);
+  while (el)
+    {
+      i = TtaGetTextAttributeLength (attr) + 1;
+      url = TtaGetMemory (i);
+      TtaGiveTextAttributeValue (attr, url, &i);
+      if (!strcasecmp (url, annot->body_url))
+	{
+	  TtaFreeMemory (url);
+	  break;
+	}
+      TtaFreeMemory (url);
+      root = el;
+      TtaSearchAttribute (attrType, SearchForward, root, &el, &attr);
+    }
+
+  /* update the element if we found it */
+  if (el)
+    ANNOT_ThreadItem_init (el, thread_doc, annot, FALSE);
+#endif
+}
+
 /*-----------------------------------------------------------------------
    ANNOT_InitDocumentStructure
    Initializes an annotation document by adding a BODY part
    and adding META elements for title, author, date, and type
   -----------------------------------------------------------------------*/
-
-#ifdef __STDC__
-void  ANNOT_InitDocumentStructure (Document doc, Document docAnnot, AnnotMeta *annot, ThotBool initBody)
-#else /* __STDC__*/
-void  ANNOT_InitDocumentStructure (doc, docAnnot, annot, initBody)
-     Document document;
-     Document docAnnot;
-     AnnotMeta *annot;
-     CHAR_T    *title;
-     ThotBool  initBody;
-
-#endif /* __STDC__*/
+void  ANNOT_InitDocumentStructure (Document doc, Document docAnnot, 
+				   AnnotMeta *annot, AnnotMode mode)
 {
-  ThotBool free_title;
-  CHAR_T  *title;
+  char *source_doc_title;
+  char *text;
+#ifdef ANNOT_ON_ANNOT
+  Element el;
+  ElementType elType;
+#endif /* ANNOT_ON_ANNOT */
 
   /* avoid refreshing the document while we're constructing it */
   TtaSetDisplayMode (docAnnot, NoComputedDisplay);
+  
+   /* prepare the title of the annotation */
+  source_doc_title = ANNOT_GetHTMLTitle (doc);
 
-  title = ANNOT_GetHTMLTitle (doc);
-  if (!title || title[0] == WC_EOS)
+  if (mode & ANNOT_initATitle)
     {
-      title = DocumentURLs[doc];
-      free_title = FALSE;
+      annot->title = TtaStrdup (source_doc_title);
+      if (mode & ANNOT_isReplyTo)
+	text = "Reply to ";
+      else
+	text = "Annotation of ";
+      annot->title = TtaGetMemory (strlen (text)
+				   + strlen (source_doc_title) + 1);
+      sprintf (annot->title, "%s%s", text, source_doc_title);
     }
-  else
-    free_title = TRUE;
 
   /* initialize the meta data */
-  ANNOT_InitDocumentMeta (doc, docAnnot, annot, title);
-  /* initialize the html body */
-  if (initBody)
-    ANNOT_InitDocumentBody (docAnnot, title);
+  ANNOT_InitDocumentMeta (doc, docAnnot, annot, source_doc_title);
 
-  if (free_title)
-    TtaFreeMemory (title);
+  /* initialize the html body */
+  if (mode & ANNOT_initBody)
+    ANNOT_InitDocumentBody (docAnnot, source_doc_title);
+
+  TtaFreeMemory (source_doc_title);
+
+#ifdef ANNOT_ON_ANNOT
+  /* erase the thread */
+  el = TtaGetRootElement (docAnnot);
+  elType = TtaGetElementType (el);
+  elType.ElTypeNum = Annot_EL_Thread;
+  el = TtaSearchTypedElement (elType, SearchInTree, el);
+  if (el)
+    TtaRemoveTree (el, docAnnot);
+#endif /* ANNOT_ON_ANNOT */
 
   /* show the document */
   TtaSetDisplayMode (docAnnot, DisplayImmediately);
@@ -482,14 +885,14 @@ void  ANNOT_InitDocumentStructure (docAnnot, document)
   struct tm   *localDate;
   STRING      strDate;
   STRING      doc_anchor;
-  CHAR_T      tempfile[MAX_LENGTH];
+  char      tempfile[MAX_LENGTH];
   char       *annot_user;
 
   annot_user = GetAnnotUser ();
 
   /* avoid refreshing the document while we're constructing it */
   TtaSetDisplayMode (docAnnot, NoComputedDisplay);
-  root = TtaGetMainRoot (docAnnot);
+  root = TtaGetRootElement (docAnnot);
   elType = TtaGetElementType (root);
   elType.ElTypeNum = HTML_EL_HEAD;
   head = TtaSearchTypedElement (elType, SearchInTree, root);
@@ -519,13 +922,13 @@ void  ANNOT_InitDocumentStructure (docAnnot, document)
   attrType.AttrTypeNum = HTML_ATTR_meta_name;
   attr = TtaNewAttribute (attrType);
   TtaAttachAttribute (meta, attr, docAnnot);
-  TtaSetAttributeText (attr, TEXT("GENERATOR"), meta, docAnnot);
+  TtaSetAttributeText (attr, "GENERATOR", meta, docAnnot);
   attrType.AttrTypeNum = HTML_ATTR_meta_content;
   attr = TtaNewAttribute (attrType);
   TtaAttachAttribute (meta, attr, docAnnot);
-  ustrcpy (tempfile, HTAppName);
-  ustrcat (tempfile, TEXT(" "));
-  ustrcat (tempfile, HTAppVersion);
+  strcpy (tempfile, HTAppName);
+  strcat (tempfile, " ");
+  strcat (tempfile, HTAppVersion);
   TtaSetAttributeText (attr, tempfile, meta, docAnnot);
   TtaInsertSibling (meta, child, FALSE, docAnnot);
 #endif
@@ -694,11 +1097,11 @@ void ANNOT_PrepareAnnotView (document)
   Saves the annotation document doc_annot to the local filesystem
   ----------------------------------------------------------------------*/
 #ifdef __STDC__
-ThotBool            ANNOT_LocalSave (Document doc_annot, CHAR_T *html_filename)
+ThotBool            ANNOT_LocalSave (Document doc_annot, char *html_filename)
 #else  /* __STDC__ */
 ThotBool            ANNOT_LocalSave (doc_annot, html_filename)
 Document            doc_annot;
-CHAR_T             *html_filename;
+char             *html_filename;
 
 #endif /* __STDC__ */
 {
@@ -720,7 +1123,7 @@ CHAR_T             *html_filename;
 
   /* and show the new mdate on the document */
   /* point to the root node */
-  el = TtaGetMainRoot (doc_annot);
+  el = TtaGetRootElement (doc_annot);
   elType = TtaGetElementType (el);
 
   /* point to the metadata structure */
@@ -733,7 +1136,7 @@ CHAR_T             *html_filename;
   el = TtaGetFirstChild (el);
   TtaSetTextContent (el, annot->mdate, TtaGetDefaultLanguage (), doc_annot); 
 
-  return TtaExportDocument (doc_annot, html_filename, TEXT("AnnotT"));
+  return TtaExportDocument (doc_annot, html_filename, "AnnotT");
 }
 
 
