@@ -1,6 +1,6 @@
 /*
  *
- *  (c) COPYRIGHT INRIA  1996-2000
+ *  (c) COPYRIGHT INRIA  1996-2001
  *  Please first read the full copyright statement in file COPYRIGHT.
  *
  */
@@ -75,7 +75,7 @@ Name                n;
    i = 0;
    do
       TtaWriteWideChar (outfile, n[i++], ISO_8859_1 /* UTF_8 */);
-   while (n[i - 1] != TEXT('\0'));
+   while (n[i - 1] != '\0');
 }
 
 
@@ -283,9 +283,6 @@ PRuleType           ruleType;
 	    case PtAdjust:
 	       TtaWriteByte (outfile, C_PR_ADJUST);
 	       break;
-	    case PtJustify:
-	       TtaWriteByte (outfile, C_PR_JUSTIFY);
-	       break;
 	    case PtHyphenate:
 	       TtaWriteByte (outfile, C_PR_HYPHENATE);
 	       break;
@@ -313,6 +310,15 @@ PRuleType           ruleType;
 	    case PtVertOverflow:
 	       TtaWriteByte (outfile, C_PR_VERTOVERFLOW);
 	       break;
+	    case PtGather:
+	       TtaWriteByte (outfile, C_PR_GATHER);
+	       break;
+	    case PtPageBreak:
+	       TtaWriteByte (outfile, C_PR_PAGEBREAK);
+	       break;
+	    case PtLineBreak:
+	       TtaWriteByte (outfile, C_PR_LINEBREAK);
+	       break;
 	    default:
 	       fprintf (stderr, "Invalid rule type %X\n", (int)ruleType);
 	       break;
@@ -498,6 +504,9 @@ BAlignment          align;
 	    case AlignLeftDots:
 	       TtaWriteByte (outfile, C_PIV_LEFTDOT);
 	       break;
+	    case AlignJustify:
+	       TtaWriteByte (outfile, C_PIV_JUSTIFY);
+	       break;
 	    default:
 	       fprintf (stderr, "Invalid alignment %X\n", align);
 	       break;
@@ -563,6 +572,9 @@ PresCondition       cond;
 	    case PcEmpty:
 	       TtaWriteByte (outfile, C_COND_EMPTY);
 	       break;
+	    case PcRoot:
+	       TtaWriteByte (outfile, C_COND_ROOT);
+	       break;
 	    case PcEven:
 	       TtaWriteByte (outfile, C_COND_EVEN);
 	       break;
@@ -928,9 +940,6 @@ ContentType         typ;
 	    case ContConst:
 	       TtaWriteByte (outfile, C_CONT_CONST);
 	       break;
-	    case ContElement:
-	       TtaWriteByte (outfile, C_CONT_ELEM);
-	       break;
 	    default:
 	       fprintf (stderr, "Invalid content %X\n", typ);
 	       break;
@@ -1188,13 +1197,17 @@ PtrPRule            pPRule;
 			     case PtAdjust:
 				WriteAlignment (currentRule->PrAdjust);
 				break;
-			     case PtJustify:
 			     case PtHyphenate:
 			     case PtVertOverflow:
 			     case PtHorizOverflow:
-				WriteBoolean (currentRule->PrJustify);
+			     case PtGather:
+			     case PtPageBreak:
+			     case PtLineBreak:
+				WriteBoolean (currentRule->PrBoolValue);
 				break;
 			     case PtPictInfo:
+			     case PtXRadius:
+			     case PtYRadius:
 				break;
 			  }
 
@@ -1280,10 +1293,7 @@ PtrSSchema          pSS;
       WriteBoolean (pPSch->PsColumnView[i]);
    WriteShort (pPSch->PsNPrintedViews);
    for (i = 0; i < pPSch->PsNPrintedViews; i++)
-     {
-	WriteBoolean (pPSch->PsPrintedView[i].VpAssoc);
-	WriteShort (pPSch->PsPrintedView[i].VpNumber);
-     }
+     WriteShort (pPSch->PsPrintedView[i].VpNumber);
    for (i = 0; i < pPSch->PsNViews; i++)
       WriteBoolean (pPSch->PsExportView[i]);
    WriteShort (pPSch->PsNCounters);
@@ -1391,9 +1401,6 @@ PtrSSchema          pSS;
 	pBox = &pPSch->PsPresentBox[i];
 	WriteName (pBox->PbName);
 	WriteRulePtr (pBox->PbFirstPRule);
-	WriteBoolean (pBox->PbAcceptPageBreak);
-	WriteBoolean (pBox->PbAcceptLineBreak);
-	WriteBoolean (pBox->PbBuildAll);
 	WriteBoolean (pBox->PbPageFooter);
 	WriteBoolean (pBox->PbPageHeader);
 	WriteBoolean (pBox->PbPageBox);
@@ -1409,10 +1416,6 @@ PtrSSchema          pSS;
 		 case ContConst:
 		    WriteShort (pBox->PbContConstant);
 		    break;
-		 case ContElement:
-		    WriteShort (pBox->PbContElem);
-		    WriteShort (pBox->PbContRefElem);
-		    break;
 		 default:
 		    break;
 	      }
@@ -1510,20 +1513,6 @@ PtrSSchema          pSS;
    for (i = 0; i < pSS->SsNAttributes; i++)
       WriteShort (pPSch->PsNComparAttrs[i]);
 
-   for (i = 0; i < pSS->SsNRules; i++)
-      WriteBoolean (pPSch->PsAcceptPageBreak[i]);
-
-   for (i = 0; i < pSS->SsNRules; i++)
-      WriteBoolean (pPSch->PsAcceptLineBreak[i]);
-
-   for (i = 0; i < pSS->SsNRules; i++)
-      WriteBoolean (pPSch->PsBuildAll[i]);
-
-   for (i = 0; i < pSS->SsNRules; i++)
-      WriteBoolean (pPSch->PsInPageHeaderOrFooter[i]);
-
-   for (i = 0; i < pSS->SsNRules; i++)
-      WriteBoolean (pPSch->PsAssocPaginated[i]);
    for (i = 0; i < pSS->SsNRules; i++)
       WriteShort (pPSch->PsElemTransmit[i]);
    WriteShort (pPSch->PsNTransmElems);
