@@ -1,6 +1,6 @@
 /*
  *
- *  (c) COPYRIGHT INRIA, 1996.
+ *  (c) COPYRIGHT INRIA, 1996-2001.
  *  Please first read the full copyright statement in file COPYRIGHT.
  *
  */
@@ -31,11 +31,10 @@
 #define MaxDictionaries 15	/* Maximum number of simultaneous dictionaries                */
 
 extern struct Langue_Ctl LangTable[MAX_LANGUAGES];
-extern struct Langue_Ctl TypoLangTable[MAX_LANGUAGES];
 extern int               FreeEntry;
 extern CHARSET           CharEncoding;
 
-static CHAR_T*      dictPath;	/* environment variable DICOPAR */
+static char        *dictPath;	/* environment variable DICOPAR */
 static PtrDict      dictTable[MaxDictionaries];
 
 unsigned            ReverseCode[NbLtr];
@@ -45,7 +44,6 @@ unsigned char       Code[256];	/* Alphabet characters */
 #include "fileaccess_f.h"
 #include "thotmsg_f.h"
 #include "platform_f.h"
-#include "ustring_f.h"
 
 /*----------------------------------------------------------------------
   ----------------------------------------------------------------------*/
@@ -54,17 +52,17 @@ static void           LoadAlphabet ()
   FILE*         falpha;
   PathBuffer    alphaName;
   unsigned char x;
-  int        i;
+  int           i;
   
   if (dictPath != NULL)
-    ustrcpy (alphaName, dictPath);
+    strcpy (alphaName, dictPath);
   else
-    ustrcpy (alphaName, TEXT(""));
+    strcpy (alphaName, "");
 
-  ustrcat (alphaName, WC_DIR_STR);
-  ustrcat (alphaName, TEXT("alphabet"));
+  strcat (alphaName, WC_DIR_STR);
+  strcat (alphaName, "alphabet");
   
-  if ((falpha = ufopen (alphaName, TEXT("r"))) != NULL)
+  if ((falpha = fopen (alphaName, "r")) != NULL)
     {
       for (i = 0; i < 256; i++)
           Code[i] = (unsigned char) 100;
@@ -84,16 +82,11 @@ static void           LoadAlphabet ()
 /*----------------------------------------------------------------------
   Resolves the common characters for two consecutive words 
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 void                TreateDictionary (PtrDict dict)
-#else  /* __STDC__ */
-void                TreateDictionary (dict)
-PtrDict             dict;
-#endif /* __STDC__ */
 {
    int                 word, i;
-   CHAR_T                lastWord[MAX_WORD_LEN];
-   CHAR_T                currentWord[MAX_WORD_LEN];
+   char                lastWord[MAX_WORD_LEN];
+   char                currentWord[MAX_WORD_LEN];
 
    /* An empty dictionary is not considered  (DictNbWords = -1) */
    if (dict->DictNbWords >= 0)
@@ -105,10 +98,10 @@ PtrDict             dict;
 	  {
 	     int                 k = 0;
 
-	     ustrcpy (lastWord, currentWord);
-	     ustrcpy (currentWord, &dict->DictString[dict->DictWords[word]]);
+	     strcpy (lastWord, currentWord);
+	     strcpy (currentWord, &dict->DictString[dict->DictWords[word]]);
 
-	     if (ustrlen (lastWord) != ustrlen (currentWord))
+	     if (strlen (lastWord) != strlen (currentWord))
 	       {
 		  /* changing the size of the word */
 		  /* => no calculation for the common letters */
@@ -133,12 +126,7 @@ PtrDict             dict;
    ReleaseDictionary: Releases dictionaries which descriptor is    
    referenced by pDictionary.                   
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-static void         ReleaseDictionary (PtrDict * pDictionary)
-#else  /* __STDC__ */
-static void         ReleaseDictionary (pDictionary)
-PtrDict            *pDictionary;
-#endif /* __STDC__ */
+static void         ReleaseDictionary (PtrDict *pDictionary)
 {
    int                 d;
    PtrDict             pdict;
@@ -168,13 +156,7 @@ PtrDict            *pDictionary;
    In return, pDictionary referenes the dictionary context or NULL if     
    there is a lack of memory.                                             
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-static void         CreateDictionary (PtrDict * pDictionary, PtrDocument document)
-#else  /* __STDC__ */
-static void         CreateDictionary (pDictionary, document)
-PtrDict            *pDictionary;
-PtrDocument         document;
-#endif /* __STDC__ */
+static void CreateDictionary (PtrDict *pDictionary, PtrDocument document)
 {
   int                 d;
 
@@ -199,11 +181,7 @@ PtrDocument         document;
 	}
       /* Flushing the dictionary FILE  */
       if (d < MaxDictionaries)
-	{
-	  TtaDisplayMessage (INFO, TtaGetMessage (LIB, TMSG_ERR_LOADING_DICO),
-			     dictTable[d]->DictName);
 	  ReleaseDictionary (&dictTable[d]);
-	}
     }
   
   if (d < MaxDictionaries)
@@ -220,14 +198,8 @@ PtrDocument         document;
    SearchDictName: Looks for a dictionary by its name and returns  
    a pointer (pDictionary) referencing its descriptor or NULL    
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-static void         SearchDictName (PtrDict * pDictionary, CHAR_T* dictName, CHAR_T* dictDirectory)
-#else  /* __STDC__ */
-static void         SearchDictName (pDictionary, dictName, dictDirectory)
-PtrDict            *pDictionary;
-STRING              dictName;
-STRING              dictDirectory;
-#endif /* __STDC__ */
+static void SearchDictName (PtrDict *pDictionary, char *dictName,
+			    char *dictDirectory)
 {
    int                 d;
    ThotBool            found;
@@ -236,8 +208,8 @@ STRING              dictDirectory;
    d = 0;
    while (d < MaxDictionaries && (dictTable[d] != NULL) && (!found))
      {
-	found = (ustrcmp (dictTable[d]->DictName, dictName) == 0
-	       && ustrcmp (dictTable[d]->DictDirectory, dictDirectory) == 0);
+	found = (strcmp (dictTable[d]->DictName, dictName) == 0
+	       && strcmp (dictTable[d]->DictDirectory, dictDirectory) == 0);
 	d++;
      }
    if (found)
@@ -253,27 +225,20 @@ STRING              dictDirectory;
    returns  0 if the file .DCT exists (not treated yet)              
    returns  1 if the file .DCT exists (treated)                      
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-static int          TestDictionary (CHAR_T* dictName, CHAR_T* dictDirectory)
-#else  /* __STDC__ */
-static int          TestDictionary (dictName, dictDirectory)
-CHAR_T*             dictName;
-CHAR_T*             dictDirectory;
-
-#endif /* __STDC__ */
+static int TestDictionary (char *dictName, char *dictDirectory)
 {
   int                 ret, i;
-  CHAR_T              tempbuffer[THOT_MAX_CHAR];
+  char                tempbuffer[THOT_MAX_CHAR];
 
-  FindCompleteName (dictName, TEXT("dic"), dictDirectory, tempbuffer, &i);
+  FindCompleteName (dictName, "dic", dictDirectory, tempbuffer, &i);
   if (TtaFileExist (tempbuffer) == 0)	/* Unknown file */
     {
       /* Looks for not pre-treated dictionary */
-      FindCompleteName (dictName, TEXT("DCT"), dictDirectory, tempbuffer, &i);
+      FindCompleteName (dictName, "DCT", dictDirectory, tempbuffer, &i);
       if (TtaFileExist (tempbuffer) == 0)
 	{
 	  /* File .DCT unknown: looks for a dictionary LEX not pre-treated */
-	  FindCompleteName (dictName, TEXT("LEX"), dictDirectory, tempbuffer, &i);
+	  FindCompleteName (dictName, "LEX", dictDirectory, tempbuffer, &i);
 	  if (TtaFileExist (tempbuffer) == 0)
 	    /* unknown file */
 	    ret = -1;
@@ -295,13 +260,7 @@ CHAR_T*             dictDirectory;
 /*----------------------------------------------------------------------
    ReadDictionary reads a dictionary from a pre-treated file.       
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-static void         ReadDictionary (FILE * dictFile, PtrDict dict)
-#else  /* __STDC__ */
-static void         ReadDictionary (dictFile, dict)
-FILE               *dictFile;
-PtrDict             dict;
-#endif /* __STDC__ */
+static void ReadDictionary (FILE *dictFile, PtrDict dict)
 {
   int              i;
 
@@ -311,27 +270,19 @@ PtrDict             dict;
       i = 0;
       while (i < dict->DictNbChars)
 	{
-#     ifdef _I18N_
-      TtaReadWideChar (dictFile, &(dict->DictString[i]), CharEncoding);
-#     else  /* !_I18N_ */
 	  TtaReadByte (dictFile, &(dict->DictString[i]));
-#     endif /* !_I18N_ */
 	  i++;
 	}
-      
       i = 0;
       while (i < dict->DictNbWords)
 	{
 	  TtaReadByte (dictFile, &(dict->DictCommon[i]));
 	  i++;
 	}
-      
       for (i = 0; i < dict->DictNbWords; i++)
 	TtaReadInteger (dictFile, &dict->DictWords[i]);
-      
       for (i = 0; i < MAX_WORD_LEN; i++)
 	TtaReadInteger (dictFile, &dict->DictLengths[i]);
-      
       /* Loaded */
       dict->DictLoaded = TRUE;
     }
@@ -341,17 +292,11 @@ PtrDict             dict;
 /*----------------------------------------------------------------------
    LoadDict returns 1 if a dictionary is loaded else returns 0
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-static int          LoadDict (FILE * dictFile, PtrDict dict)
-#else  /* __STDC__ */
-static int          LoadDict (dictFile, dict)
-FILE               *dictFile;
-PtrDict             dict;
-#endif /* __STDC__ */
+static int LoadDict (FILE *dictFile, PtrDict dict)
 {
-   CHAR_T             wordGotten[MAX_WORD_LEN];
-   CHAR_T             lineGotten[MAXLIGNE];
-   STRING           plineGotten;
+   char             wordGotten[MAX_WORD_LEN];
+   char             lineGotten[MAXLIGNE];
+   char            *plineGotten;
    int              i, k, length, nbGotten, last_word;
    int              MaxWord, maxWord;
    int              currentLength = 0;
@@ -364,12 +309,12 @@ PtrDict             dict;
    plineGotten = &lineGotten[0];
 
    /* Loading the dictionary */
-   while (ufgets (plineGotten, MAXLIGNE, dictFile) != NULL)
+   while (fgets (plineGotten, MAXLIGNE, dictFile) != NULL)
      {
-	nbGotten = usscanf (plineGotten, TEXT("%s"), wordGotten);
+	nbGotten = sscanf (plineGotten, "%s", wordGotten);
 	if ((nbGotten > 0)
 	    && (dict->DictNbWords < maxWord - 1)
-	    && ((length = ustrlen (wordGotten)) < MAX_WORD_LEN)
+	    && ((length = strlen (wordGotten)) < MAX_WORD_LEN)
 	    && (length + nbChar + 1 < MaxWord - 1))
 	  {
 	     dict->DictNbWords++;
@@ -382,7 +327,7 @@ PtrDict             dict;
 		  currentLength = length;
 	       }
 	     for (k = 0; k < length; k++)
-		dict->DictString[nbChar++] = (CHAR_T) Code[(UCHAR_T) wordGotten[k]];
+		dict->DictString[nbChar++] = (char) Code[(unsigned char) wordGotten[k]];
 	     /* End of a word */
 	     dict->DictString[nbChar++] = EOS;
 
@@ -393,7 +338,6 @@ PtrDict             dict;
 	  /* not the end of the dictionary */
 	  {
 	     /* impossible to load the dictionary */
-	     TtaDisplayMessage (INFO, TtaGetMessage (LIB, TMSG_ERR_LOADING_DICO), dict->DictName);
 	     /* Release the dictionary */
 	     ReleaseDictionary (&dict);	/* => dict = nil */
 	     return (0);
@@ -419,53 +363,39 @@ PtrDict             dict;
    Traite le dico si toTreat = TRUE.                                
    retourne dans pDictionary le pointeur sur son descripteur ou NULL        
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-static void         PrepareDictionary (PtrDict * pDictionary, CHAR_T* dictName, PtrDocument document, CHAR_T* dictDirectory, Language lang, ThotBool readonly, ThotBool treated, ThotBool toTreat)
-#else  /* __STDC__ */
-static void         PrepareDictionary (pDictionary, dictName, document, dictDirectory, lang, readonly, treated, toTreat)
-PtrDict            *pDictionary;
-CHAR_T*             dictName;
-PtrDocument         document;
-CHAR_T*             dictDirectory;
-Language            lang;
-ThotBool            readonly;
-ThotBool            treated;
-ThotBool            toTreat;
-#endif /* __STDC__ */
+static void PrepareDictionary (PtrDict *pDictionary, char *dictName,
+			       PtrDocument document, char *dictDirectory,
+			       Language lang, ThotBool readonly,
+			       ThotBool treated, ThotBool toTreat)
 {
-  CHAR_T              tempbuffer[THOT_MAX_CHAR];
+  char                tempbuffer[THOT_MAX_CHAR];
   ThotBool            new = FALSE;
   ThotBool            ret;
-  FILE*               dictFile;
+  FILE               *dictFile;
   PtrDict             pdict;
   int                 i, im, ic;
 
   *pDictionary = NULL;
   /* Opening the file */
   if (treated)
-    FindCompleteName (dictName, TEXT("dic"), dictDirectory, tempbuffer, &i);
+    FindCompleteName (dictName, "dic", dictDirectory, tempbuffer, &i);
   else
     {
       if (toTreat)
-	FindCompleteName (dictName, TEXT("DCT"), dictDirectory, tempbuffer, &i);
+	FindCompleteName (dictName, "DCT", dictDirectory, tempbuffer, &i);
       else
-	FindCompleteName (dictName, TEXT("LEX"), dictDirectory, tempbuffer, &i);
+	FindCompleteName (dictName, "LEX", dictDirectory, tempbuffer, &i);
     }
   if (readonly == FALSE)
     {
       /* Alterable dictionary */
       if (TtaFileExist (tempbuffer) != 0)
-	{
-	  dictFile = ufopen (tempbuffer, TEXT("rw"));
-	  /* updating the dictionary */
-	  TtaDisplayMessage (INFO, TtaGetMessage (LIB, TMSG_DICO), dictName);
-	}
+	  dictFile = fopen (tempbuffer, "rw");
       else
 	{
-	  new = TRUE;
-	  dictFile = ufopen (tempbuffer, TEXT("w+"));
 	  /* new dictionary */
-	  TtaDisplayMessage (INFO, TtaGetMessage (LIB, TMSG_NEW_DICO), dictName);
+	  new = TRUE;
+	  dictFile = fopen (tempbuffer, "w+");
 	}
     }
   else
@@ -474,8 +404,7 @@ ThotBool            toTreat;
       if (treated == TRUE)
 	dictFile = TtaReadOpen (tempbuffer);
       else
-	dictFile = ufopen (tempbuffer, TEXT("r"));
-      TtaDisplayMessage (INFO, TtaGetMessage (LIB, TMSG_DICO), dictName);
+	dictFile = fopen (tempbuffer, "r");
     }
   
   if (dictFile == NULL)
@@ -496,8 +425,8 @@ ThotBool            toTreat;
   pdict = *pDictionary;
   pdict->DictDoc = document;
   pdict->DictLanguage = lang;
-  pdict->DictDirectory = ustrdup (dictDirectory);
-  ustrcpy (pdict->DictName, dictName);
+  pdict->DictDirectory = TtaStrdup (dictDirectory);
+  strcpy (pdict->DictName, dictName);
   pdict->DictReadOnly = readonly;
   
   /* calculation of the memory size needed by the dictionary */
@@ -523,10 +452,10 @@ ThotBool            toTreat;
 	{
 	  /* Get the length of strings required at the begenning of the file. */
 	  tempbuffer[0] = EOS;
-	  ufgets (tempbuffer, 100, dictFile);
+	  fgets (tempbuffer, 100, dictFile);
 	  if (tempbuffer[0] != EOS)
 	    {
-	      if (usscanf (tempbuffer, TEXT("%d%d"), &im, &ic) == 2)
+	      if (sscanf (tempbuffer, "%d%d", &im, &ic) == 2)
 		{
 		  pdict->DictMaxWords = im;
 		  pdict->DictMaxChars = ic;
@@ -537,7 +466,6 @@ ThotBool            toTreat;
 		  /* -> one go to the begenning of the file */
 		  /* fseek(dictFile, 0L, 0); */
 		  /* impossible to load this dictionary */
-		  TtaDisplayMessage (INFO, TtaGetMessage (LIB, TMSG_ERR_LOADING_DICO), dictName);
 		  /* Release the dictionary */
 		  ReleaseDictionary (pDictionary);
 		  *pDictionary = NULL;
@@ -562,7 +490,6 @@ ThotBool            toTreat;
   if (GetStringInDict (pDictionary, readonly) == -1)
     {
       /* Not enough memory to open this dictionary */
-      TtaDisplayMessage (INFO, TtaGetMessage (LIB, TMSG_LIB_NO_LOAD), dictName);
       /* Release the allocated dictionary */
       ReleaseDictionary (pDictionary);
       *pDictionary = NULL;
@@ -594,18 +521,9 @@ ThotBool            toTreat;
   Returns in pDictionary : a pointer to dictionary and creates it if
   toCreate = TRUE
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-int                 LoadTreatedDict (PtrDict * pDictionary, Language lang, PtrDocument document, CHAR_T* dictName, CHAR_T* dictDirectory, ThotBool readonly, ThotBool toCreate)
-#else  /* __STDC__ */
-int                 LoadTreatedDict (pDictionary, lang, document, dictName, dictDirectory, readonly, toCreate)
-PtrDict            *pDictionary;
-Language            lang;
-PtrDocument         document;
-CHAR_T*             dictName;
-CHAR_T*             dictDirectory;
-ThotBool            readonly;
-ThotBool            toCreate;
-#endif /* __STDC__ */
+int LoadTreatedDict (PtrDict *pDictionary, Language lang, PtrDocument document,
+		     char *dictName, char *dictDirectory, ThotBool readonly,
+		     ThotBool toCreate)
 {
    PtrDict             pdict;
    int                 i;
@@ -671,18 +589,13 @@ ThotBool            toCreate;
    ReloadDictionary: reload a dictionary                            
    returns TRUE if the FILE dictionary is found and well loaded       
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-ThotBool            ReloadDictionary (PtrDict * pDictionary)
-#else  /* __STDC__ */
-ThotBool            ReloadDictionary (pDictionary)
-PtrDict            *pDictionary;
-#endif /* __STDC__ */
+ThotBool ReloadDictionary (PtrDict *pDictionary)
 {
    PtrDict             pdict;
    PtrDocument         document;
    int                 d;
-   CHAR_T              dictName[MAX_NAME_LENGTH];
-   CHAR_T              *dictDirectory;
+   char                dictName[MAX_NAME_LENGTH];
+   char                *dictDirectory;
 
    document = NULL;
    if (*pDictionary == NULL)
@@ -699,7 +612,7 @@ PtrDict            *pDictionary;
 	if (dictTable[d] == pdict)
 	  {
 	     /* Getting information about the dictionary */
-	     ustrcpy (dictName, pdict->DictName);
+	     strcpy (dictName, pdict->DictName);
 	     document = pdict->DictDoc;
 	     /* save the dictionary directory */
              dictDirectory = pdict->DictDirectory;
@@ -735,11 +648,6 @@ void                Dict_Init ()
 
    /* Inititializing of environments needed by dictionarires */
    dictPath = TtaGetEnvString ("DICOPAR");
-   if (dictPath == NULL)
-     {
-	/* The environment variable DICOPAR does not exist */
-	TtaDisplayMessage (INFO, TtaGetMessage (LIB, TMSG_MISSING_DICOPAR), "DICOPAR");
-     }
    LoadAlphabet ();
 }
 
@@ -749,21 +657,13 @@ void                Dict_Init ()
 
    Loads the dictionary associated with a language, if it is not loaded yet
    and registers that a dictionary associated with this language has been loaded.
-
    Returns -1 if the mandatory dictionary cann't be loaded.
    0 if no dictionary has been loaded
    1 if the mandatory dictionary is loaded.
-
    Parameters:
    languageId: name of the concerned language.
-
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-ThotBool            TtaLoadLanguageDictionaries (Language languageId)
-#else  /* __STDC__ */
-ThotBool            TtaLoadLanguageDictionaries (languageId)
-Language            languageId;
-#endif /* __STDC__ */
+ThotBool TtaLoadLanguageDictionaries (Language languageId)
 {
    int                 lang;
    PtrDict             dictPtr;
@@ -801,83 +701,14 @@ Language            languageId;
    return (LangTable[lang].LangDict[0] != NULL || LangTable[lang].LangDict[1] != NULL);
 }
 
-
-/*----------------------------------------------------------------------
-   TtaLoadTypoDictionaries
-
-   Loads the dictionary associated with a typolanguage, if it is not loaded yet
-   and registers that a dictionary associated with this language has been loaded.
-
-   Returns -1 if the mandatory dictionary cann't be loaded.
-   0 if no dictionary has been loaded
-   1 if the mandatory dictionary is loaded.
-
-   Parameters:
-   languageId: name of the concerned language.
-
-  ----------------------------------------------------------------------*/
-#ifdef __STDC__
-ThotBool            TtaLoadTypoDictionaries (Language languageId)
-#else  /* __STDC__ */
-ThotBool            TtaLoadTypoDictionaries (languageId)
-Language            languageId;
-#endif /* __STDC__ */
-{
-   int                 lang;
-   PtrDict             dictPtr;
-   int                 ret;
-
-   /* If the variable dictPath is not loaded -> do nothig */
-   if (dictPath == NULL)
-      return FALSE;
-
-   ret = 1;
-   lang = (int) languageId;
-   /* Verifies if the main dictionary is already loaded */
-   if (TypoLangTable[lang].LangDict[0] == NULL)
-     {
-	/* Loading the main dictionary */
-	if (TypoLangTable[lang].LangPrincipal[0] != EOS)
-	  {
-	     ret = LoadTreatedDict (&dictPtr, lang, NULL,
-		  TypoLangTable[lang].LangPrincipal, dictPath, TRUE, FALSE);
-	     if (ret > 0)
-		TypoLangTable[lang].LangDict[0] = (Dictionary) dictPtr;
-	  }
-     }
-
-   /* Verifies if the secondary dictionary is already laded */
-   if (TypoLangTable[lang].LangDict[1] == NULL)
-     {
-	/* Loading the secondary dictionary */
-	if (TypoLangTable[lang].LangSecondary[0] != EOS)
-	  {
-	     ret = LoadTreatedDict (&dictPtr, lang, NULL,
-		  TypoLangTable[lang].LangSecondary, dictPath, TRUE, FALSE);
-	     if (ret > 0)
-		TypoLangTable[lang].LangDict[1] = (Dictionary) dictPtr;
-	  }
-     }
-   return (TypoLangTable[lang].LangDict[0] != NULL
-	   || TypoLangTable[lang].LangDict[1] != NULL);
-}
-
-
 /*----------------------------------------------------------------------
    TtaUnLoadLanguageDictionaries
 
    Unloads dictionaries associated with a given language.
-
    Parameters:
    languageId: identifier of the language.
-
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-void                TtaUnLoadLanguageDictionaries (Language languageId)
-#else  /* __STDC__ */
-void                TtaUnLoadLanguageDictionaries (languageId)
-Language            languageId;
-#endif /* __STDC__ */
+void TtaUnLoadLanguageDictionaries (Language languageId)
 {
    int                 i, j;
 
@@ -891,48 +722,15 @@ Language            languageId;
 }
 
 
-/*----------------------------------------------------------------------
-   TtaUnLoadTypoDictionaries
-
-   Unloads dictionaries associated with a given language.
-
-   Parameters:
-   languageId: identifier of the language.
-  ----------------------------------------------------------------------*/
-#ifdef __STDC__
-void                TtaUnLoadTypoDictionaries (Language languageId)
-#else  /* __STDC__ */
-void                TtaUnLoadTypoDictionaries (languageId)
-Language            languageId;
-#endif /* __STDC__ */
-{
-   int                 i, j;
-
-   i = (int) languageId;
-   j = 0;
-   while (TypoLangTable[i].LangDict[j] != NULL && j < MAX_DICTS)
-     {
-	ReleaseDictionary ((PtrDict *) & TypoLangTable[i].LangDict[j]);
-	TypoLangTable[i].LangDict[j] = NULL;
-     }
-}
-
-
 /*----------------------------------------------------------------------
    TtaGetPrincipalDictionary
 
    Returns a pointer to the principal dictionary associated to a language.
-
    Return value:
    the pointer to that dictionary or NULL if there is no dictionary for
    this language.
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-Dictionary          TtaGetPrincipalDictionary (Language languageId)
-#else  /* __STDC__ */
-Dictionary          TtaGetPrincipalDictionary (languageId)
-Language            languageId;
-#endif /* __STDC__ */
+Dictionary TtaGetPrincipalDictionary (Language languageId)
 {
    int                 i;
 
@@ -950,53 +748,15 @@ Language            languageId;
 }
 
 
-/*----------------------------------------------------------------------
-   TtaGetPrincipalTypoDictionary
-
-   Returns a pointer to the principal dictionary associated to a language.
-
-   Return value:
-   the pointer to that dictionary or NULL if there is no dictionary for
-   this language.
-  ----------------------------------------------------------------------*/
-#ifdef __STDC__
-Dictionary          TtaGetPrincipalTypoDictionary (Language languageId)
-#else  /* __STDC__ */
-Dictionary          TtaGetPrincipalTypoDictionary (languageId)
-Language            languageId;
-#endif /* __STDC__ */
-{
-   int                 i;
-
-   i = (int) languageId;
-   /* Verification of the parameter */
-   if (i >= FreeEntry)
-     {
-	TtaError (ERR_language_not_found);
-	return NULL;
-     }
-
-   /* Loading dictionaries if exist */
-   TtaLoadTypoDictionaries (languageId);
-   return (TypoLangTable[i].LangDict[0]);
-}
-
-
 /*----------------------------------------------------------------------
    TtaGetSecondaryDictionary
 
    Returns a pointer to the secondary dictionary associated to a language.
-
    Return value:
    the pointer to that dictionary or NULL if there is no dictionary for
    this language.
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-Dictionary          TtaGetSecondaryDictionary (Language languageId)
-#else  /* __STDC__ */
-Dictionary          TtaGetSecondaryDictionary (languageId)
-Language            languageId;
-#endif /* __STDC__ */
+Dictionary TtaGetSecondaryDictionary (Language languageId)
 {
    int                 i;
 
@@ -1009,32 +769,3 @@ Language            languageId;
      }
    return (LangTable[i].LangDict[1]);
 }
-
-
-/*----------------------------------------------------------------------
-   TtaGetSecondaryTypoDictionary
-
-   Returns a pointer to the secondary dictionary associated to a language.
-
-   Return value:
-   the pointer to that dictionary or NULL if there is no dictionary for
-   this language.
-  ----------------------------------------------------------------------*/
-#ifdef __STDC__
-Dictionary          TtaGetSecondaryTypoDictionary (Language languageId)
-#else  /* __STDC__ */
-Dictionary          TtaGetSecondaryTypoDictionary (languageId)
-Language            languageId;
-#endif /* __STDC__ */
-{
-   int                 i;
-
-   i = (int) languageId;
-   /* Verification of the parameter */
-   if (i >= FreeEntry)
-     {
-	TtaError (ERR_language_not_found);
-	return NULL;
-     }
-   return (TypoLangTable[i].LangDict[1]);
-}
