@@ -29,7 +29,7 @@ Thanks to Contributers:
 J Satchell, Eric Marttila 
 */
 
-#include "ustring.h"
+#include "string.h"
 #ifndef _WINDOWS
 #include "thot_gui.h"
 #include "thot_sys.h"
@@ -53,7 +53,7 @@ struct liteClue_context_str
 	XcgLiteClueWidget cw;	/* pointer back to the liteClue widget */
 	Position  abs_x, abs_y;
 	Boolean sensitive;	/* if False, liteClue is suppressed */
-	STRING  text;		/* text to display */
+	char *text;		/* text to display */
 	short text_size;	/* its size */
 };
 
@@ -206,7 +206,7 @@ The font_information is derived
 Return XFontSet for passed font_string. 
 return status
 */
-static int string_to_FontSet (XcgLiteClueWidget cw, STRING  font_string, XFontStruct ** out) 
+static int string_to_FontSet (XcgLiteClueWidget cw, char *font_string, XFontStruct ** out) 
 {
 	Boolean sts;
 	XrmValue from;
@@ -214,7 +214,7 @@ static int string_to_FontSet (XcgLiteClueWidget cw, STRING  font_string, XFontSt
 	
 	to.size = sizeof(out);
 	to.addr = (void *) out;
-	from.size = ustrlen(from.addr = font_string );
+	from.size = strlen(from.addr = font_string );
 	sts = XtConvertAndStore((Widget) cw, XtRString, &from, XtRFontStruct, &to);
 	return sts;
 }
@@ -246,7 +246,7 @@ static void compute_font_info(XcgLiteClueWidget cw)
 Return XFontSet for passed font_string. 
 return status
 */
-static int string_to_FontSet (XcgLiteClueWidget cw, STRING  font_string, XFontSet * out) 
+static int string_to_FontSet (XcgLiteClueWidget cw, char *font_string, XFontSet * out) 
 {
 	Boolean sts;
 	XrmValue from;
@@ -254,7 +254,7 @@ static int string_to_FontSet (XcgLiteClueWidget cw, STRING  font_string, XFontSe
 	
 	to.size = sizeof(out);
 	to.addr = (void *) out;
-	from.size = ustrlen(from.addr = font_string );
+	from.size = strlen(from.addr = font_string );
 	sts = XtConvertAndStore((Widget) cw, XtRString, &from, XtRFontSet, &to);
 	return sts;
 }
@@ -310,7 +310,7 @@ static void create_GC(XcgLiteClueWidget cw )
 a core dump for debugging analysis	
 when a public routine is called with the wrong class of widget
 */
-static void wrong_widget(STRING  routine)
+static void wrong_widget(char *routine)
 {
 	int mypid = getpid(); 
 	fprintf(stderr, "Wrong class of widget passed to %s\n", routine);
@@ -481,7 +481,7 @@ static void Enter_event(Widget w, XtPointer client_data, XEvent * xevent, Boolea
 	   help for next watched widget
 	*/
 	if ((event->time -  cw->liteClue.HelpPopDownTime) > 
-			cw->liteClue.cancelWaitPeriod ) 
+			(unsigned) cw->liteClue.cancelWaitPeriod ) 
 		current_waitPeriod = cw->liteClue.waitPeriod,timeout_event;
 	else
 		current_waitPeriod = 0;
@@ -548,7 +548,7 @@ Return:
 
 ;-
 */
-void XcgLiteClueAddWidget(Widget w, Widget watch,  STRING  text, int size, int option )
+void XcgLiteClueAddWidget(Widget w, Widget watch,  char *text, int size, int option )
 {
 #	define ROUTINE "XcgLiteClueAddWidget"
 	XcgLiteClueWidget cw = (XcgLiteClueWidget) w;
@@ -576,7 +576,7 @@ void XcgLiteClueAddWidget(Widget w, Widget watch,  STRING  text, int size, int o
 	if (text && !(obj->text))
 	{
 		if (!size)
-			size = ustrlen(text);
+			size = strlen(text);
 		obj->text = XtMalloc(size+1);
 		memcpy(obj->text, text, size);
 		obj->text[size] = 0;
