@@ -1,6 +1,6 @@
 /*
  *
- *  (c) COPYRIGHT INRIA, 1996.
+ *  (c) COPYRIGHT INRIA, 1996-2001.
  *  Please first read the full copyright statement in file COPYRIGHT.
  *
  */
@@ -10,7 +10,7 @@
  *
  * Authors: I. Vatton (INRIA)
  *          D. Veillard (W3C/INRIA) Multikey + Event rewrite
- *          R. Guetari (W3C/INRIA) - Unicode and Windows version
+ *          R. Guetari (W3C/INRIA) - Windows version
  *
  */
 
@@ -65,7 +65,6 @@
 #include "keyboards_f.h"
 #include "message_f.h"
 #include "thotmsg_f.h"
-#include "ustring_f.h"
 #include "viewapi_f.h"
 #include "views_f.h"
 
@@ -75,7 +74,7 @@ static int           mk_state = 0;
 static int           TtaKeyboardMapInstalled = 0;
 
 #ifdef _WINDOWS
-static CHAR_T        previous_keysym;
+static char          previous_keysym;
 #else  /* !_WINDOWS */
 static KeySym        previous_keysym;
 static KeySym        previous_value = 0;
@@ -126,8 +125,8 @@ XK_uacute, XK_ucircumflex, XK_udiaeresis, XK_yacute, XK_thorn, XK_ydiaeresis,
 typedef struct multi_key
   {
 #ifdef _WINDOWS
-     CHAR_T              c;
-     CHAR_T              m;
+     char                c;
+     char                m;
      int                 r;
 #else  /* !_WINDOWS */
      KeySym              c;
@@ -532,12 +531,8 @@ int                 TtaUseOwnXLookupString = 0;
   than the usual set and still having Motif functionning properly.
   Daniel Veillard 28 March 96 after installing X11R6 rel 1 ...
   ----------------------------------------------------------------------*/
-int               TtaXLookupString (event, buffer, nbytes, keysym, status)
-register ThotKeyEvent *event;
-STRING              buffer;	/* buffer */
-int                 nbytes;	/* space in buffer for characters */
-KeySym             *keysym;
-ThotComposeStatus  *status;	/* not implemented */
+int TtaXLookupString (ThotKeyEvent *event, char *buffer, int nbytes,
+		      KeySym *keysym, ThotComposeStatus *status)
 {
   KeySym              sym = NoSymbol;
   int                 keycode;
@@ -603,25 +598,25 @@ ThotComposeStatus  *status;	/* not implemented */
 	  buffer[0] = __CR__;
 	  return (1);
 	case XK_KP_Equal:
-	  buffer[0] = TEXT('=');
+	  buffer[0] = '=';
 	  return (1);
 	case XK_KP_Multiply:
-	  buffer[0] = TEXT('*');
+	  buffer[0] = '*';
 	  return (1);
 	case XK_KP_Add:
-	  buffer[0] = TEXT('+');
+	  buffer[0] = '+';
 	  return (1);
 	case XK_KP_Separator:
-	  buffer[0] = TEXT(',');
+	  buffer[0] = ',';
 	  return (1);
 	case XK_KP_Subtract:
-	  buffer[0] = TEXT('-');
+	  buffer[0] = '-';
 	  return (1);
 	case XK_KP_Decimal:
-	  buffer[0] = TEXT('.');
+	  buffer[0] = '.';
 	  return (1);
 	case XK_KP_Divide:
-	  buffer[0] = TEXT('/');
+	  buffer[0] = '/';
 	  return (1);
 	case XK_Return:
 	  buffer[0] = EOL;
@@ -651,13 +646,13 @@ ThotComposeStatus  *status;	/* not implemented */
  * default behaviour. The THOTNOMODIFIER environment
  * variable is for debugging purposes only.
  */
-void                TtaInstallMultiKey ()
+void TtaInstallMultiKey ()
 {
-  CHAR_T* ptr;
+  char   *ptr;
 
 #ifdef _WINDOWS 
   ptr = TtaGetEnvString ("ENABLE_MULTIKEY");
-  if (ptr != NULL && !ustrcasecmp (ptr, TEXT("yes")))
+  if (ptr != NULL && !strcasecmp (ptr, "yes"))
     Enable_Multikey = TRUE;
   else
     Enable_Multikey = FALSE;
@@ -677,7 +672,7 @@ void                TtaInstallMultiKey ()
   TtaDisplay = dpy;
   /* check whether multi-key is enabled */
   ptr = TtaGetEnvString ("ENABLE_MULTIKEY");
-  if (ptr != NULL && !ustrcasecmp (ptr, "yes"))
+  if (ptr != NULL && !strcasecmp (ptr, "yes"))
     Enable_Multikey = TRUE;
   else
     Enable_Multikey = FALSE;
@@ -808,49 +803,42 @@ void                TtaInstallMultiKey ()
 #ifdef _WINDOWS 
 /*----------------------------------------------------------------------
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-int                 WIN_TtaHandleMultiKeyEvent (UINT msg, WPARAM wParam, LPARAM lParam, int* k)
-#else  /* __STDC__ */
-int                 WIN_TtaHandleMultiKeyEvent (msg, wParam, lParam, k)
-UINT    msg; 
-WPARAM wParam; 
-LPARAM lParam;
-int*   k;
-#endif /* __STDC__ */
+int WIN_TtaHandleMultiKeyEvent (UINT msg, WPARAM wParam, LPARAM lParam, int* k)
 {
-   int          index;
-   CHAR_T         KS;
+  int          index;
+  char         KS = EOS;
 
-   if (!Enable_Multikey) /* no multi-key allowed */
-      return 1;
-
-   if (msg == WM_CHAR)
-      KS = (CHAR_T) wParam;
-   
-   if (mk_state == 1 && msg == WM_CHAR) {
+  if (!Enable_Multikey) /* no multi-key allowed */
+    return 1;
+  if (msg == WM_CHAR)
+    KS = (char) wParam;
+  if (mk_state == 1 && msg == WM_CHAR)
+    {
       /* we have already read the stressed character */ 
       /* We look for the result in the list */
-
       mk_state = 0;
       for (index = 0; index < NB_MK; index++)
-          if ((mk_tab[index].m == previous_keysym) && (mk_tab[index].c == (CHAR_T) wParam)) {
-             /*
-              * The corresponding sequence is found. 
-              * Generation of the corresponding character
-              */
-	         (CHAR_T) *k = mk_tab[index].r;
-             return 1;
-		  }
-
-      return (1);
-   }
-   if (KS == '`' || KS == '\'' || KS == '^' || KS == '~' || KS == '"'|| KS == '*') {
+	  {
+        if (mk_tab[index].m == previous_keysym && mk_tab[index].c == wParam)
+		{
+	    /*
+	     * The corresponding sequence is found. 
+	     * Generation of the corresponding character
+	     */
+	    *k = mk_tab[index].r;
+	    return 1;
+		}
+	  }
+      return 1;
+    }
+  if (KS == '`' || KS == '\'' || KS == '^' || KS == '~' || KS == '"'|| KS == '*')
+    {
       /* start of a compose sequence */
        mk_state = 1;
        previous_keysym = KS;
-       return (0);
-   }
-   return (1);
+       return 0;
+    }
+  return 1;
 }
 #else /* _WINDOWS */
 
@@ -859,13 +847,7 @@ int*   k;
 
    Modify the ThotEvent given as the argument to reference a given KeySym.
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-static int          TtaGetIsoKeysym (ThotKeyEvent *ev, KeySym keysym)
-#else  /* __STDC__ */
-static int          TtaGetIsoKeysym (ev, keysym)
-  ThotKeyEvent     *ev;
-KeySym              keysym;
-#endif /* __STDC__ */
+static int TtaGetIsoKeysym (ThotKeyEvent *ev, KeySym keysym)
 {
   KeyCode             keycode;
   int                 codeline;
@@ -920,25 +902,17 @@ KeySym              keysym;
    handle multi-key input to provide Iso-Latin-1 in a consistent manner
    for the whole application.
    It uses an automata, and KeyPressed events can change its state.
-
    Initial = 0 -> 1      -> 2       -> 0 
    Compose     Key       Key
-
    -> 3       -> 5      -> 0
    Num        Num       Num
-
    If the whole sequence correspond to a valid MultiKey sequence, the
    event corresponding to a KeyPress for the result character is generated
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-static int          TtaHandleMultiKeyEvent ( ThotKeyEvent *event)
-#else  /* __STDC__ */
-static int          TtaHandleMultiKeyEvent (event)
-ThotKeyEvent       *event;
-#endif /* __STDC__ */
+static int TtaHandleMultiKeyEvent (ThotKeyEvent *event)
 {
    KeySym              KS, first, last;
-   CHAR_T              buf[2];
+   char                buf[2];
    ThotComposeStatus   status;
    unsigned int        state;
    int                 keycode;
@@ -1182,15 +1156,31 @@ fprintf (stderr, "      Multikey : <Alt>%c %c\n", previous_keysym, KS);
 
    retrieve one X-Windows Event from the queue, this is a blocking call.
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-void                TtaFetchOneEvent (ThotEvent *ev)
-#else  /* __STDC__ */
-void                TtaFetchOneEvent (ev)
-ThotEvent             *ev;
-#endif /* __STDC__ */
+void TtaFetchOneEvent (ThotEvent *ev)
 {
 #ifndef _WINDOWS
+#ifndef _GTK
   XtAppNextEvent (app_cont, ev);
+#else /* _GTK */
+  /* do nothing in gtk because we do not need to know event 
+     on the queue */
+
+
+  /*
+  while (!gtk_events_pending());
+  ev = gtk_get_current_event ();
+  */
+
+#if 0
+  /* free the precedent event */
+  if (ev) gdk_event_free (ev);
+  /* wait until one event is coming */
+  while ( !gdk_events_pending () );
+  /* get the waiting event */
+  ev = gdk_event_get ();
+#endif
+
+#endif /* !_GTK */
 #endif /* ! _WINDOWS */
 }
 
@@ -1209,12 +1199,7 @@ static void *TimerCallback (XtPointer cdata, XtIntervalId *id)
    retrieve one X-Windows Event from the queue if one is immediately
    available.
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-void                TtaFetchOrWaitEvent (ThotEvent *ev)
-#else  /* __STDC__ */
-void                TtaFetchOrWaitEvent (ev)
-ThotEvent          *ev;
-#endif /* __STDC__ */
+void TtaFetchOrWaitEvent (ThotEvent *ev)
 {
 #ifndef _GTK
 #ifndef _WINDOWS
@@ -1230,7 +1215,9 @@ ThotEvent          *ev;
        XtAppNextEvent (app_cont, ev);
      }
 #endif /* ! _WINDOWS */
-#endif /* _GTK */
+#else /* _GTK */
+
+#endif /* !_GTK */
 }
 
 /*----------------------------------------------------------------------
@@ -1239,12 +1226,7 @@ ThotEvent          *ev;
    retrieve one X-Windows Event from the queue if one is immediately
    available.
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-ThotBool            TtaFetchOneAvailableEvent (ThotEvent *ev)
-#else  /* __STDC__ */
-ThotBool            TtaFetchOneAvailableEvent (ev)
-ThotEvent             *ev;
-#endif /* __STDC__ */
+ThotBool TtaFetchOneAvailableEvent (ThotEvent *ev)
 {
 #ifndef _GTK
 #ifndef _WINDOWS
@@ -1259,7 +1241,15 @@ ThotEvent             *ev;
    else if (status != 0)
      XtAppProcessEvent (app_cont, XtIMAll);
 #endif /* ! _WINDOWS */
-#endif /* _GTK */
+#else /* _GTK */
+   if (gtk_events_pending())
+     {
+       ev = gtk_get_current_event ();
+       return TRUE;
+     }
+   else
+     return FALSE;
+#endif /* !_GTK */
    return (FALSE);
 }
 
@@ -1269,13 +1259,9 @@ ThotEvent             *ev;
 
    Processes one given event in the application.
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-void                TtaHandleOneEvent (ThotEvent *ev)
-#else  /* __STDC__ */
-void                TtaHandleOneEvent (ev)
-ThotEvent             *ev;
-#endif /* __STDC__ */
+void TtaHandleOneEvent (ThotEvent *ev)
 {
+#ifndef _GTK
 #ifdef _WINDOWS
   if (ev->message != WM_QUIT)
     {
@@ -1283,13 +1269,11 @@ ThotEvent             *ev;
       DispatchMessage (ev);
     }
 #else /* _WINDOWS */
-#ifndef _GTK
   PtrDocument         pDoc;
   ThotWindow          w;
-  STRING              s;
+  char               *s;
   int                 frame;
   int                 view, i;
-  ThotBool            assoc;
 
   /* Keep client messages */
   if (ev->type == ClientMessage)
@@ -1297,26 +1281,29 @@ ThotEvent             *ev;
       s = XGetAtomName (ev->xany.display, ((XClientMessageEvent *) ev)->message_type);
       if (s == NULL)
 	return;
-      if (!ustrcmp (s, "WM_PROTOCOLS"))
+      if (!strcmp (s, "WM_PROTOCOLS"))
 	{
 	  /* The client message comes from the Window Manager */
 	  w = ev->xany.window;
+	  XFree (s);
 	  s = XGetAtomName (ev->xany.display, ((XClientMessageEvent *) ev)->data.l[0]);
-	  if (!ustrcmp (s, "WM_DELETE_WINDOW"))
+	  if (!strcmp (s, "WM_DELETE_WINDOW"))
 	    {
-	      if (FrRef[0] != 0 && XtWindowOfObject (XtParent (FrameTable[0].WdFrame)) == w)
+	      if (FrRef[0] != 0 &&
+		  XtWindowOfObject (XtParent (FrameTable[0].WdFrame)) == w)
 		TtcQuit (0, 0);
 	      else
 		{
 		  for (frame = 1; frame <= MAX_FRAME; frame++)
 		    {
-		      if (FrRef[frame] != 0 && XtWindowOfObject (XtParent (XtParent (XtParent (FrameTable[frame].WdFrame)))) == w)
+		      if (FrRef[frame] != 0 &&
+			  XtWindowOfObject (XtParent (XtParent (XtParent (FrameTable[frame].WdFrame)))) == w)
 			break;
 		    }
 		  if (frame <= MAX_FRAME)
 		    {
-		      GetDocAndView (frame, &pDoc, &view, &assoc);
-		      CloseView (pDoc, view, assoc);
+		      GetDocAndView (frame, &pDoc, &view);
+		      CloseView (pDoc, view);
 		    }
 		  for (frame = 0; frame <= MAX_FRAME; frame++)
 		    if (FrRef[frame] != 0)
@@ -1324,14 +1311,17 @@ ThotEvent             *ev;
 		      return;
 		  TtaQuit();
 		}
+	      XFree (s);
 	    }
 	}
-      else if (!ustrcmp (s, "THOT_MESSAGES"))
+      else if (!strcmp (s, "THOT_MESSAGES"))
 	{
+	  XFree (s);
 	  /* The client message comes from print */
 	  s = XGetAtomName (ev->xany.display, ((XClientMessageEvent *) ev)->data.l[0]);
 	  i = ((XClientMessageEvent *) ev)->data.l[1];
 	  TtaDisplayMessage (CONFIRM, TtaGetMessage (LIB, i), s);
+	  XFree (s);
 	}
     }
   else if (ev->type == KeyPress)
@@ -1347,8 +1337,8 @@ ThotEvent             *ev;
       /* Manage selection events */
       SelectionEvents ((XSelectionEvent *) ev);
     }
-  
   XtDispatchEvent (ev);
+		      
   /* Manage document events */
   frame = GetWindowFrame (ev->xany.window);
   /* the event does not concern a document */
@@ -1362,36 +1352,47 @@ ThotEvent             *ev;
 	    FrameCallback (frame, ev);
 	}
     }
-#endif /* _GTK */
 #endif /* !_WINDOWS */
+#else /* _GTK */
+  gtk_main_iteration_do (TRUE);
+			 /*if (ev) gtk_main_do_event (ev);*/
+  /* a main loop iteration , not blocking */
+  /*  gtk_main_iteration_do (FALSE);*/
+#endif /* !_GTK */
 }
 
 /*----------------------------------------------------------------------
   TtaHandlePendingEvents
   Processes all pending events in an application.
   ----------------------------------------------------------------------*/
-void                TtaHandlePendingEvents ()
+void TtaHandlePendingEvents ()
 {
 #ifndef _WINDOWS
+#ifndef _GTK
    ThotEvent              ev;
 
    while (TtaFetchOneAvailableEvent(&ev))
      TtaHandleOneEvent (&ev);
+#else /* _GTK */
+     while (gtk_events_pending ())
+       gtk_main_iteration ();
+#endif /* !_GTK */
 #endif /* _WINDOWS */
 }
 
 /*----------------------------------------------------------------------
    TtaMainLoop
-
    Starts the main loop for processing all events in an application. This
    function must be called after all initializations have been made.
-
   ----------------------------------------------------------------------*/
 void TtaMainLoop ()
 {
   NotifyEvent         notifyEvt;
+#ifndef _GTK
   ThotEvent           ev;
-
+#else /* _GTK */
+  ThotEvent           ev=NULL;
+#endif /* !_GTK */
 #ifndef _GTK
   TtaInstallMultiKey ();
 #endif /* _GTK */
@@ -1400,14 +1401,18 @@ void TtaMainLoop ()
   /* Sends the message Init.Pre */
   notifyEvt.event = TteInit;
   if (CallEventType (&notifyEvt, TRUE))
+    {
+#ifdef _GTK
+      gtk_exit (0);
+#endif /* _GTK */
     /* The application is not able to start the editor => quit */
-    exit (0);
+      exit (0);
+    }
   /* Sends the message Init.Post */
   notifyEvt.event = TteInit;
   CallEventType (&notifyEvt, FALSE);
   
   /* Loop wainting for the events */
-#ifndef _GTK
   while (1)
     {
 #ifdef _WINDOWS
@@ -1417,17 +1422,21 @@ void TtaMainLoop ()
 #endif /* _WINDOWS */
       TtaHandleOneEvent (&ev);
     }
+
+#ifndef _GTK
 #else /* _GTK */
+     while (gtk_events_pending ())
+       gtk_main_iteration ();
+  /* gdk_set_show_events(TRUE);*/
   gtk_main ();
-#endif /* _GTK */
+#endif /* !_GTK */
 }
 
 /*----------------------------------------------------------------------
    TtaGetMenuColor
-
    Returns the color used for the background of dialogue windows.
   ----------------------------------------------------------------------*/
-Pixel               TtaGetMenuColor ()
+Pixel TtaGetMenuColor ()
 {
    UserErrorCode = 0;
    return (Pixel) BgMenu_Color;
@@ -1437,7 +1446,7 @@ Pixel               TtaGetMenuColor ()
 /*----------------------------------------------------------------------
    DisplayEmptyBoxLoadResources: displays the empty boxes.            
   ----------------------------------------------------------------------*/
-void                DisplayEmptyBoxLoadResources ()
+void DisplayEmptyBoxLoadResources ()
 {
    if (ThotLocalActions[T_emptybox] == NULL)
       TteConnectAction (T_emptybox, (Proc) DisplayEmptyBox);
@@ -1448,11 +1457,9 @@ void                DisplayEmptyBoxLoadResources ()
 #ifndef _WINDOWS
 /*----------------------------------------------------------------------
    TtaGetCurrentDisplay
-
    Returns the current display descriptor.
-
   ----------------------------------------------------------------------*/
-Display            *TtaGetCurrentDisplay ()
+Display *TtaGetCurrentDisplay ()
 {
    UserErrorCode = 0;
    return TtDisplay;
@@ -1462,11 +1469,9 @@ Display            *TtaGetCurrentDisplay ()
 
 /*----------------------------------------------------------------------
    TtaGetScreenDepth
-
    Returns the current screen depth.
-
   ----------------------------------------------------------------------*/
-int                 TtaGetScreenDepth ()
+int TtaGetScreenDepth ()
 {
    UserErrorCode = 0;
    return TtWDepth;
@@ -1474,25 +1479,14 @@ int                 TtaGetScreenDepth ()
 
 /*----------------------------------------------------------------------
    TtaClickElement
-
    Returns document and element clicked.
-
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-void                TtaClickElement (Document * document, Element * element)
-#else  /* __STDC__ */
-void                TtaClickElement (document, element)
-Document           *document;
-Element            *element;
-
-#endif /* __STDC__ */
-
+void TtaClickElement (Document * document, Element * element)
 {
    int                 frame;
    PtrAbstractBox      absBox;
    PtrDocument         pDoc;
    int                 view;
-   ThotBool            Assoc;
 
    UserErrorCode = 0;
    if (element == NULL || document == NULL)
@@ -1508,7 +1502,7 @@ Element            *element;
 	else
 	  {
 	     *element = (Element) absBox->AbElement;
-	     GetDocAndView (frame, &pDoc, &view, &Assoc);
+	     GetDocAndView (frame, &pDoc, &view);
 	     *document = (Document) IdentDocument (pDoc);
 	  }
      }
@@ -1519,18 +1513,8 @@ Element            *element;
    TtaGiveSelectPosition: returns the mouse position for the last click 
    with respect to the element (position in pixel)            
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-void                TtaGiveSelectPosition (Document document, Element element, View view, int *X, int *Y)
-#else  /* __STDC__ */
-void                TtaGiveSelectPosition (document, element, view, X, Y)
-Document            document;
-Element             element;
-View                view;
-int                *X;
-int                *Y;
-
-#endif /* __STDC__ */
-
+void TtaGiveSelectPosition (Document document, Element element, View view,
+			    int *X, int *Y)
 {
    int                 frame;
    PtrAbstractBox      pAb;
@@ -1567,19 +1551,11 @@ int                *Y;
 
 /*----------------------------------------------------------------------
    TtaSetMultiKey
-
    Enables or disables the multikey support
-
    Parameters:
    value : TRUE/FALSE
-
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 void TtaSetMultikey (ThotBool value)
-#else
-void TtaSetMultikey (value)
-ThotBool value;
-#endif /*__STDC__*/
 {
   Enable_Multikey = value;
   mk_state = 0;
@@ -1593,3 +1569,11 @@ ThotBool value;
 
 
 
+
+
+
+
+
+
+
+
