@@ -1,19 +1,10 @@
 /*
  *
- *  (c) COPYRIGHT INRIA, 1996.
+ *  (c) COPYRIGHT INRIA, 1996-2001
  *  Please first read the full copyright statement in file COPYRIGHT.
  *
  */
 
-/*
- * Warning:
- * This module is part of the Thot library, which was originally
- * developed in French. That's why some comments are still in
- * French, but their translation is in progress and the full module
- * will be available in English in the next release.
- * 
- */
- 
 /*
    Ce module charge un schema de traduction depuis un fichier .TRA
  */
@@ -40,14 +31,9 @@ static ThotBool     error = FALSE;
 /*----------------------------------------------------------------------
    TSchemaError positionne error dans le cas d'une erreur de lecture
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-void                TSchemaError (int err)
-#else  /* __STDC__ */
-void                TSchemaError (err)
-int                 err;
-#endif /* __STDC__ */
+void TSchemaError (int err)
 {
-   TtaDisplayMessage (INFO, TEXT("Error %d in translation schema\n"), err);
+   TtaDisplayMessage (INFO, "Error %d in translation schema\n", err);
    error = TRUE;
 }
 
@@ -56,12 +42,7 @@ int                 err;
    ReadTransCondition lit un type de condition d'application de	
    regle de traduction.					
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 static TransCondition ReadTransCondition (BinFile file)
-#else  /* __STDC__ */
-static TransCondition ReadTransCondition (file)
-BinFile             file;
-#endif /* __STDC__ */
 {
    char                c;
    TransCondition      cond;
@@ -78,9 +59,6 @@ BinFile             file;
 	       case C_TR_LAST:
 		  cond = TcondLast;
 		  break;
-	       case C_TR_DEFINED:
-		  cond = TcondDefined;
-		  break;
 	       case C_TR_REFERRED:
 		  cond = TcondReferred;
 		  break;
@@ -105,9 +83,6 @@ BinFile             file;
 	       case C_TR_PRULE:
 		  cond = TcondPRule;
 		  break;
-	       case C_TR_COMMENT:
-		  cond = TcondComment;
-		  break;
 	       case C_TR_ALPHABET:
 		  cond = TcondAlphabet;
 		  break;
@@ -153,12 +128,7 @@ BinFile             file;
 /*----------------------------------------------------------------------
    ReadTRuleType lit un type de regle de traduction.             
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 static TRuleType    ReadTRuleType (BinFile file)
-#else  /* __STDC__ */
-static TRuleType    ReadTRuleType (file)
-BinFile             file;
-#endif /* __STDC__ */
 {
    char                c;
    TRuleType           ruleType;
@@ -181,6 +151,9 @@ BinFile             file;
 	       case C_TR_REMOVE:
 		  ruleType = TRemove;
 		  break;
+	       case C_TR_IGNORE:
+		  ruleType = TIgnore;
+		  break;
 	       case C_TR_WRITE:
 		  ruleType = TWrite;
 		  break;
@@ -227,12 +200,7 @@ BinFile             file;
 /*----------------------------------------------------------------------
    ReadRelatNAscend                                                
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 static RelatNAscend ReadRelatNAscend (BinFile file)
-#else  /* __STDC__ */
-static RelatNAscend ReadRelatNAscend (file)
-BinFile             file;
-#endif /* __STDC__ */
 {
    char                c;
    RelatNAscend        relat;
@@ -261,12 +229,7 @@ BinFile             file;
    ReadTOrder lit la position ou` il faut creer les chaines	
    produites par le traducteur.                            
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 static TOrder       ReadTOrder (BinFile file)
-#else  /* __STDC__ */
-static TOrder       ReadTOrder (file)
-BinFile             file;
-#endif /* __STDC__ */
 {
    char                c;
    TOrder              order;
@@ -297,12 +260,7 @@ BinFile             file;
    ReadCreatedObject lit le type de chose a` creer dans le fichier 
    de sortie.                                  		
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 static CreatedObject ReadCreatedObject (BinFile file)
-#else  /* __STDC__ */
-static CreatedObject ReadCreatedObject (file)
-BinFile             file;
-#endif /* __STDC__ */
 {
    char                c;
    CreatedObject       obj;
@@ -328,9 +286,6 @@ BinFile             file;
 	       case C_OB_CONTENT:
 		  obj = ToContent;
 		  break;
-	       case C_OB_COMMENT:
-		  obj = ToComment;
-		  break;
 	       case C_OB_ATTRIBUTES:
 		  obj = ToAllAttr;
 		  break;
@@ -389,16 +344,7 @@ BinFile             file;
 /*----------------------------------------------------------------------
    ReadTRelatPosition lit la position relative d'un element a` prendre 
   ----------------------------------------------------------------------*/
-
-#ifdef __STDC__
 static TRelatPosition ReadTRelatPosition (BinFile file)
-
-#else  /* __STDC__ */
-static TRelatPosition ReadTRelatPosition (file)
-BinFile             file;
-
-#endif /* __STDC__ */
-
 {
    char                c;
    TRelatPosition      position;
@@ -418,9 +364,6 @@ BinFile             file;
 	       case C_TR_REFERRED_EL:
 		  position = RpReferred;
 		  break;
-	       case C_TR_ASSOC:
-		  position = RpAssoc;
-		  break;
 	       default:
 		  TSchemaError (10);
 		  position = RpSibling;
@@ -433,16 +376,7 @@ BinFile             file;
 /*----------------------------------------------------------------------
    ReadIndentType	lit un type de regle d'indentation
   ----------------------------------------------------------------------*/
-
-#ifdef __STDC__
 static TIndentType ReadIndentType (BinFile file)
-
-#else  /* __STDC__ */
-static TIndentType ReadIndentType (file)
-BinFile             file;
-
-#endif /* __STDC__ */
-
 {
    char                c;
    TIndentType		 typ;
@@ -476,13 +410,7 @@ BinFile             file;
 /*----------------------------------------------------------------------
    ReadTCounterOp lit le type< d'une operation sur un compteur.    
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 static TCounterOp   ReadTCounterOp (BinFile file)
-#else  /* __STDC__ */
-static TCounterOp   ReadTCounterOp (file)
-BinFile             file;
-#endif /* __STDC__ */
-
 {
    char                c;
    TCounterOp          op;
@@ -518,12 +446,7 @@ BinFile             file;
    ReadTranslVarType lit le type des elements de variables de      
    traduction.                                             
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 static TranslVarType ReadTranslVarType (BinFile file)
-#else  /* __STDC__ */
-static TranslVarType ReadTranslVarType (file)
-BinFile             file;
-#endif /* __STDC__ */
 {
    char                c;
    TranslVarType       varType;
@@ -575,12 +498,7 @@ BinFile             file;
    ReadCounterStyle  lit un style de compteur dans le fichier et   
    retourne sa valeur.                                     
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 static CounterStyle ReadCounterStyle (BinFile file)
-#else  /* __STDC__ */
-static CounterStyle ReadCounterStyle (file)
-BinFile             file;
-#endif /* __STDC__ */
 {
    char                c;
    CounterStyle        style;
@@ -620,13 +538,7 @@ BinFile             file;
    ReadPtrTRule retourne un pointeur sur la regle suivante ou NULL   
    s'il n'y a pas de regle suivante.                       
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-static PtrTRule     ReadPtrTRule (BinFile file, PtrTRule * pNextTRule)
-#else  /* __STDC__ */
-static PtrTRule     ReadPtrTRule (file, pNextTRule)
-BinFile             file;
-PtrTRule           *pNextTRule;
-#endif /* __STDC__ */
+static PtrTRule ReadPtrTRule (BinFile file, PtrTRule *pNextTRule)
 {
    char                c;
    PtrTRule            pTRule;
@@ -645,14 +557,7 @@ PtrTRule           *pNextTRule;
    ReadTRules ecrit une suite de regles chainees et fait pointer	
    pFirstTRule sur la premiere regle de la suite de regles lues.   
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-static void         ReadTRules (BinFile file, PtrTRule * pFirstTRule, PtrTRule * pNextTRule)
-#else  /* __STDC__ */
-static void         ReadTRules (file, pFirstTRule, pNextTRule)
-BinFile             file;
-PtrTRule           *pFirstTRule;
-PtrTRule           *pNextTRule;
-#endif /* __STDC__ */
+static void ReadTRules (BinFile file, PtrTRule *pFirstTRule, PtrTRule *pNextTRule)
 {
    PtrTRule            pTRule;
 
@@ -691,7 +596,8 @@ PtrTRule           *pNextTRule;
 			  TtaReadName (file, pTRule->TrNature);
 			  TtaReadName (file, pTRule->TrTranslSchemaName);
 			  break;
-		       case TRemove: 
+		       case TRemove:
+		       case TIgnore:
 		       case TNoTranslation:
 		       case TNoLineBreak:
 
@@ -732,13 +638,7 @@ PtrTRule           *pNextTRule;
    ReadPtrTRuleBlock retourne un pointeur sur le bloc de regles	
    	suivant ou NULL s'il n'y a pas de bloc suivant.                 
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-static PtrTRuleBlock ReadPtrTRuleBlock (BinFile file, PtrTRuleBlock * pNextBlock)
-#else  /* __STDC__ */
-static PtrTRuleBlock ReadPtrTRuleBlock (file, pNextBlock)
-BinFile             file;
-PtrTRuleBlock      *pNextBlock;
-#endif /* __STDC__ */
+static PtrTRuleBlock ReadPtrTRuleBlock (BinFile file, PtrTRuleBlock *pNextBlock)
 {
    char c;
 
@@ -753,18 +653,8 @@ PtrTRuleBlock      *pNextBlock;
 /*----------------------------------------------------------------------
    ReadBlocks lit une suite de blocs de regles.                    
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-static void         ReadBlocks (BinFile file, PtrTRuleBlock * pBlock, PtrTRule * pNextTRule, PtrSSchema * pSS, PtrTRuleBlock * pNextBlock)
-#else  /* __STDC__ */
-static void         ReadBlocks (file, pBlock, pNextTRule, pSS, pNextBlock)
-BinFile             file;
-PtrTRuleBlock      *pBlock;
-PtrTRule           *pNextTRule;
-PtrSSchema         *pSS;
-PtrTRuleBlock      *pNextBlock;
-
-#endif /* __STDC__ */
-
+static void ReadBlocks (BinFile file, PtrTRuleBlock *pBlock, PtrTRule *pNextTRule,
+			PtrSSchema *pSS, PtrTRuleBlock *pNextBlock)
 {
    PtrTRuleBlock       pBl;
    TranslCondition    *pCond;
@@ -832,6 +722,7 @@ PtrTRuleBlock      *pNextBlock;
 			   case TcondPRule:
 			      TtaReadShort (file, &pCond->TcAttr);
 			      if (!error)
+				{
 				 if (pCond->TcAttr == PtSize ||
 				     pCond->TcAttr == PtIndent ||
 				     pCond->TcAttr == PtLineSpacing ||
@@ -839,12 +730,13 @@ PtrTRuleBlock      *pNextBlock;
 				     pCond->TcAttr == PtFillPattern ||
 				     pCond->TcAttr == PtBackground ||
 				     pCond->TcAttr == PtForeground)
-				   {
+				     {
 				      TtaReadSignedShort (file, &pCond->TcLowerBound);
 				      TtaReadSignedShort (file, &pCond->TcUpperBound);
-				   }
+				     }
 				 else
 				    TtaReadByte (file, &pCond->TcPresValue);
+				}
 			      break;
 			   case TcondElementType:
 			      TtaReadShort (file, &pCond->TcAttr);
@@ -867,12 +759,7 @@ PtrTRuleBlock      *pNextBlock;
    FreeBlocks     libere une suite de blocs de regles ainsi que    
    les regles attachees.                                   
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-static void         FreeBlocks (PtrTRuleBlock pBlock)
-#else  /* __STDC__ */
-static void         FreeBlocks (pBlock)
-PtrTRuleBlock       pBlock;
-#endif /* __STDC__ */
+static void FreeBlocks (PtrTRuleBlock pBlock)
 {
    PtrTRuleBlock       pNextBlock;
    PtrTRule            pTRule, nextRule;
@@ -898,17 +785,9 @@ PtrTRuleBlock       pBlock;
    ReadAttrTRules lit les regles de traduction de l'attribut de    
    numero att appartenant au schema de structure pSS.      
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-static void         ReadAttrTRules (BinFile file, int att, PtrTRuleBlock * pNextBlock, PtrTRule * pNextTRule, PtrSSchema * pSS, PtrTSchema * pTSch)
-#else  /* __STDC__ */
-static void         ReadAttrTRules (file, att, pNextBlock, pNextTRule, pSS, pTSch)
-BinFile             file;
-int                 att;
-PtrTRuleBlock      *pNextBlock;
-PtrTRule           *pNextTRule;
-PtrSSchema         *pSS;
-PtrTSchema         *pTSch;
-#endif /* __STDC__ */
+static void ReadAttrTRules (BinFile file, int att, PtrTRuleBlock *pNextBlock,
+			    PtrTRule *pNextTRule, PtrSSchema *pSS,
+			    PtrTSchema *pTSch)
 {
    AttributeTransl    *pAttrT;
    TranslNumAttrCase  *pCase;
@@ -955,13 +834,7 @@ PtrTSchema         *pTSch;
 /*----------------------------------------------------------------------
    FreeTRulesAttr libere les regles de traduction d'un attribut.   
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-static void         FreeTRulesAttr (AttributeTransl * pAttrT, TtAttribute * pAttr)
-#else  /* __STDC__ */
-static void         FreeTRulesAttr (pAttrT, pAttr)
-AttributeTransl    *pAttrT;
-TtAttribute        *pAttr;
-#endif /* __STDC__ */
+static void FreeTRulesAttr (AttributeTransl *pAttrT, TtAttribute *pAttr)
 {
    int                 i;
 
@@ -990,17 +863,9 @@ TtAttribute        *pAttr;
    ReadPresTRules lit les regles de traduction de la presentation  
    de numero pres appartenant au schema de structure pSS.  
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-static void         ReadPresTRules (BinFile file, int pres, PtrTRuleBlock * pNextBlock, PtrTRule * pNextTRule, PtrSSchema * pSS, PtrTSchema * pTSch)
-#else  /* __STDC__ */
-static void         ReadPresTRules (file, pres, pNextBlock, pNextTRule, pSS, pTSch)
-BinFile             file;
-int                 pres;
-PtrTRuleBlock      *pNextBlock;
-PtrTRule           *pNextTRule;
-PtrSSchema         *pSS;
-PtrTSchema         *pTSch;
-#endif /* __STDC__ */
+static void ReadPresTRules (BinFile file, int pres, PtrTRuleBlock *pNextBlock,
+			    PtrTRule *pNextTRule, PtrSSchema *pSS,
+			    PtrTSchema *pTSch)
 {
    PRuleTransl        *pPruleTr;
    TranslNumAttrCase  *pCase;
@@ -1010,6 +875,7 @@ PtrTSchema         *pTSch;
      {
 	pPruleTr = &(*pTSch)->TsPresTRule[pres];
 	if (pPruleTr->RtExist)
+	  {
 	   if (pres == PtSize || pres == PtIndent ||
 	       pres == PtLineSpacing || pres == PtLineWeight ||
 	       pres == PtFillPattern || pres == PtBackground ||
@@ -1034,6 +900,7 @@ PtrTSchema         *pTSch;
 		   ReadBlocks (file, &pPruleTr->RtPRuleValueBlock[i],
 			       pNextTRule, pSS, pNextBlock);
 		}
+	  }
      }
 }
 
@@ -1042,17 +909,12 @@ PtrTSchema         *pTSch;
    FreeTRulesPres libere les regles de traduction d'une regle de	
    presentation                                            
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-static void         FreeTRulesPres (int pres, PRuleTransl * pPruleTr)
-#else  /* __STDC__ */
-static void         FreeTRulesPres (pres, pPruleTr)
-int                 pres;
-PRuleTransl        *pPruleTr;
-#endif /* __STDC__ */
+static void FreeTRulesPres (int pres, PRuleTransl *pPruleTr)
 {
    int                 i;
 
    if (pPruleTr->RtExist)
+     {
       if (pres == PtSize + 1 || pres == PtIndent + 1 ||
 	  pres == PtLineSpacing + 1 || pres == PtLineWeight + 1 ||
 	  pres == PtFillPattern + 1 || pres == PtBackground + 1 ||
@@ -1063,6 +925,7 @@ PRuleTransl        *pPruleTr;
       else
 	 for (i = 0; i <= MAX_TRANSL_PRES_VAL; i++)
 	    FreeBlocks (pPruleTr->RtPRuleValueBlock[i]);
+     }
 }
 
 
@@ -1075,13 +938,7 @@ PRuleTransl        *pPruleTr;
    - fileName: nom du fichier a lire, sans le suffixe .TRA 
    - pSS: schema de structure correspondant, deja rempli.  
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-PtrTSchema          ReadTranslationSchema (Name fileName, PtrSSchema pSS)
-#else  /* __STDC__ */
-PtrTSchema          ReadTranslationSchema (fileName, pSS)
-Name                fileName;
-PtrSSchema          pSS;
-#endif /* __STDC__ */
+PtrTSchema ReadTranslationSchema (Name fileName, PtrSSchema pSS)
 {
    BinFile             file;
    PtrTRule            pNextTRule;
@@ -1095,22 +952,22 @@ PtrSSchema          pSS;
    StringTransl       *pStringTr;
    PRuleTransl        *pPRuleTr;
    PathBuffer          dirBuffer;
-   CHAR_T              buf[MAX_TXT_LEN];
+   char                buf[MAX_TXT_LEN];
    int                 InitialNElems, i, j;
 
    error = FALSE;
    pTSch = NULL;
    /* compose le nom du fichier a ouvrir */
-   ustrncpy (dirBuffer, SchemaPath, MAX_PATH);
-   MakeCompleteName (fileName, TEXT("TRA"), dirBuffer, buf, &i);
+   strncpy (dirBuffer, SchemaPath, MAX_PATH);
+   MakeCompleteName (fileName, "TRA", dirBuffer, buf, &i);
 
    /* ouvre le fichier */
    file = TtaReadOpen (buf);
    if (file == 0)
      {
-	ustrncpy (buf, fileName, MAX_PATH);
-	ustrcat (buf, TEXT(".TRA"));
-	TtaDisplayMessage (INFO, TtaGetMessage (LIB, TMSG_LIB_MISSING_FILE), buf);
+	strncpy (buf, fileName, MAX_PATH);
+	strcat (buf, ".TRA");
+	TtaDisplayMessage (INFO, TtaGetMessage (LIB, TMSG_TRA_FILE_INCORRECT), buf);
      }
    else
      {
@@ -1239,6 +1096,7 @@ PtrSSchema          pSS;
 		   pPRuleTr = &pTSch->TsPresTRule[i];
 		   TtaReadBool (file, &pPRuleTr->RtExist);
 		   if (pPRuleTr->RtExist)
+		     {
 		      if (i == PtSize || i == PtIndent || i == PtLineSpacing ||
 			  i == PtLineWeight || i == PtFillPattern ||
 			  i == PtBackground || i == PtForeground)
@@ -1254,6 +1112,7 @@ PtrSSchema          pSS;
 			 for (j = 0; j <= MAX_TRANSL_PRES_VAL; j++)
 			    pPRuleTr->RtPRuleValueBlock[j] =
 			       ReadPtrTRuleBlock (file, &pNextBlock);
+		     }
 		}
 	TtaReadShort (file, &pTSch->TsNTranslAlphabets);
 	if (!error)
@@ -1277,13 +1136,13 @@ PtrSSchema          pSS;
 		/* lit la chaine source */
 		j = 0;
 		do
-		   TtaReadWideChar (file, &pStringTr->StSource[j++], ISO_8859_1);
-		while (pStringTr->StSource[j - 1] != WC_EOS);
+		   TtaReadByte (file, &pStringTr->StSource[j++]);
+		while (pStringTr->StSource[j - 1] != EOS);
 		/* lit la chaine cible */
 		j = 0;
 		do
-		   TtaReadWideChar (file, &pStringTr->StTarget[j++], ISO_8859_1);
-		while (pStringTr->StTarget[j - 1] != WC_EOS);
+		   TtaReadByte (file, &pStringTr->StTarget[j++]);
+		while (pStringTr->StTarget[j - 1] != EOS);
 	     }
 	if (!error)
 	   /* lit les constantes */
@@ -1291,8 +1150,8 @@ PtrSSchema          pSS;
 	     {
 		j = pTSch->TsConstBegin[i] - 1;
 		do
-		   TtaReadWideChar (file, &pTSch->TsConstant[j++], ISO_8859_1);
-		while (pTSch->TsConstant[j - 1] != WC_EOS);
+		   TtaReadByte (file, &pTSch->TsConstant[j++]);
+		while (pTSch->TsConstant[j - 1] != EOS);
 	     }
 	/* lit les blocs de regles des elements */
 	if (!error)
@@ -1330,16 +1189,7 @@ PtrSSchema          pSS;
    FreeTranslationSchema   libere le schema de traduction pTSch    
    correspondant au schema de structure pSS.               
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-void                FreeTranslationSchema (PtrTSchema pTSch, PtrSSchema pSS)
-
-#else  /* __STDC__ */
-void                FreeTranslationSchema (pTSch, pSS)
-PtrTSchema          pTSch;
-PtrSSchema          pSS;
-
-#endif /* __STDC__ */
-
+void FreeTranslationSchema (PtrTSchema pTSch, PtrSSchema pSS)
 {
    int                 InitialNElems;
    int                 i;
