@@ -1,19 +1,10 @@
 /*
  *
- *  (c) COPYRIGHT INRIA, 1996.
+ *  (c) COPYRIGHT INRIA, 1996-2001
  *  Please first read the full copyright statement in file COPYRIGHT.
  *
  */
 
-/*
- * Warning:
- * This module is part of the Thot library, which was originally
- * developed in French. That's why some comments are still in
- * French, but their translation is in progress and the full module
- * will be available in English in the next release.
- * 
- */
- 
 /*
  * This module handles structure modifications.
  *
@@ -98,14 +89,7 @@ void                InitSave ()
    IsASavedElement   retourne vrai si l'element pointe par pEl se  
    trouve dans le buffer de Couper-Copier-Coller.                  
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 ThotBool            IsASavedElement (PtrElement pEl)
-#else  /* __STDC__ */
-ThotBool            IsASavedElement (pEl)
-PtrElement          pEl;
-
-#endif /* __STDC__ */
-
 {
    PtrElement          pE;
    PtrPasteElem        pPasteD;
@@ -133,15 +117,7 @@ PtrElement          pEl;
 /*----------------------------------------------------------------------
    CopyLeaf                                                  
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-static void         CopyLeaf (PtrCopyDescr pCopyD, ThotBool redisplay)
-#else  /* __STDC__ */
-static void         CopyLeaf (pCopyD, redisplay)
-PtrCopyDescr        pCopyD;
-ThotBool            redisplay;
-
-#endif /* __STDC__ */
-
+static void CopyLeaf (PtrCopyDescr pCopyD, ThotBool redisplay)
 {
    PtrTextBuffer       pBuf, pBufS;
    PtrDocument         pDocPav;
@@ -168,10 +144,7 @@ ThotBool            redisplay;
 	     ApplyCopy (pDocPav, pCopyD->CdCopyRule, pCopyD->CdCopiedAb, FALSE);
 	     pCopyD->CdCopiedAb->AbChange = TRUE;
 	     /* reaffiche le pave' mis a jour */
-	     if (AssocView (pCopyD->CdCopiedAb->AbElement))
-		frame = pDocPav->DocAssocFrame[pCopyD->CdCopiedAb->AbElement->ElAssocNum - 1];
-	     else
-		frame = pDocPav->DocViewFrame[pCopyD->CdCopiedAb->AbDocView - 1];
+	     frame = pDocPav->DocViewFrame[pCopyD->CdCopiedAb->AbDocView - 1];
 	     /* on ne s'occupe pas de la hauteur de page */
 	     pageHeight = 0;
 	     ChangeConcreteImage (frame, &pageHeight, pCopyD->CdCopiedAb);
@@ -198,16 +171,7 @@ ThotBool            redisplay;
    l'element. pDoc designe le document auquel appartient		
    l'element pointe' par pEl.                                      
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-void                RedisplayCopies (PtrElement pEl, PtrDocument pDoc, ThotBool redisplay)
-#else  /* __STDC__ */
-void                RedisplayCopies (pEl, pDoc, redisplay)
-PtrElement          pEl;
-PtrDocument         pDoc;
-ThotBool            redisplay;
-
-#endif /* __STDC__ */
-
+void RedisplayCopies (PtrElement pEl, PtrDocument pDoc, ThotBool redisplay)
 {
    PtrReference        pRef;
    PtrPSchema          pSchP;
@@ -236,7 +200,8 @@ ThotBool            redisplay;
 		pExtDoc = NULL;
 		do
 		  {
-		     pRef = NextReferenceToEl (pEl, pDoc, FALSE, pRef, &pRefDoc, &pExtDoc, TRUE);
+		     pRef = NextReferenceToEl (pEl, pDoc, FALSE, pRef,
+					       &pRefDoc, &pExtDoc, TRUE);
 		     if (pRef != NULL)
 			/* on a trouve' une reference */
 			if (pRef->RdTypeRef == RefInclusion)
@@ -250,14 +215,15 @@ ThotBool            redisplay;
 	     }
 	   /* traite les regles Transmit de ce type d'element */
 	   /* cherche d'abord le schema de presentation pour l'element */
-	   SearchPresSchema (pEl, &pSchP, &rule, &pSchS);
+	   SearchPresSchema (pEl, &pSchP, &rule, &pSchS, pDoc);
 	   if (pSchP != NULL)
 	      if (pSchP->PsElemTransmit[rule - 1] > 0)
 		 /* il y a une regle Transmit pour ce type d'element */
 		{
 		   /* applique la regle Transmit */
 		   pTrans = &(pSchP->PsTransmElem[pSchP->PsElemTransmit[rule - 1] - 1]);
-		   TransmitElementContent (pEl, pDoc, pTrans->TeTargetAttr, pTrans->TeTargetDoc, pSchS);
+		   TransmitElementContent (pEl, pDoc, pTrans->TeTargetAttr,
+					   pTrans->TeTargetDoc, pSchS);
 		}
 	   /* passe a l'element ascendant */
 	   pEl = pEl->ElParent;
@@ -269,21 +235,15 @@ ThotBool            redisplay;
    IsANewElement   retourne vrai si l'element pointe' par pEl est  
    l'un des nouveaux elements crees                                
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 ThotBool            IsANewElement (PtrElement pEl)
-#else  /* __STDC__ */
-ThotBool            IsANewElement (pEl)
-PtrElement          pEl;
-
-#endif /* __STDC__ */
 {
    int                 i;
    ThotBool            ret;
 
    ret = FALSE;
-   for (i = 0; i < NCreatedElements && !ret; i++) ;
-   if (CreatedElement[i] == pEl)
-      ret = TRUE;
+   for (i = 0; i < NCreatedElements && !ret; i++)
+     if (CreatedElement[i] == pEl)
+       ret = TRUE;
    return ret;
 }
 
@@ -291,13 +251,7 @@ PtrElement          pEl;
    IsWithinANewElement    retourne vrai si l'element pEl est   	
    dans l'un des sous-arbres qu'on vient de creer                  
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 ThotBool            IsWithinANewElement (PtrElement pEl)
-#else  /* __STDC__ */
-ThotBool            IsWithinANewElement (pEl)
-PtrElement          pEl;
-
-#endif /* __STDC__ */
 {
    ThotBool            ret;
 
@@ -317,16 +271,7 @@ PtrElement          pEl;
    element qui est reference', fait recalculer la presentation     
    des attributs-reference qui pointent sur lui.			
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-void                UpdateRefAttributes (PtrElement pRoot, PtrDocument pDoc)
-
-#else  /* __STDC__ */
-void                UpdateRefAttributes (pRoot, pDoc)
-PtrElement          pRoot;
-PtrDocument         pDoc;
-
-#endif /* __STDC__ */
-
+void UpdateRefAttributes (PtrElement pRoot, PtrDocument pDoc)
 {
    PtrReference        pRef;
    PtrElement          pChild;
@@ -369,15 +314,7 @@ PtrDocument         pDoc;
    Parcourt tout le sous-arbre de racine pRoot et, pour chaque     
    element de paire recalcule l'identificateur unique de la paire. 
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-void                AssignPairIdentifiers (PtrElement pRoot, PtrDocument pDoc)
-#else  /* __STDC__ */
-void                AssignPairIdentifiers (pRoot, pDoc)
-PtrElement          pRoot;
-PtrDocument         pDoc;
-
-#endif /* __STDC__ */
-
+void AssignPairIdentifiers (PtrElement pRoot, PtrDocument pDoc)
 {
    PtrElement          pPairEl, pChild;
 
@@ -417,16 +354,8 @@ PtrDocument         pDoc;
    	references qui pointent sur cet element ou un element de son	
    	sous-arbre.							
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-void                RedisplayEmptyReferences (PtrElement pEl, PtrDocument * pDoc, ThotBool redisplay)
-#else  /* __STDC__ */
-void                RedisplayEmptyReferences (pEl, pDoc, redisplay)
-PtrElement          pEl;
-PtrDocument        *pDoc;
-ThotBool            redisplay;
-
-#endif /* __STDC__ */
-
+void RedisplayEmptyReferences (PtrElement pEl, PtrDocument *pDoc,
+			       ThotBool redisplay)
 {
    PtrReference        pRef;
    PtrElement          pElRef, pChild;
@@ -442,13 +371,15 @@ ThotBool            redisplay;
      {
        pRef = NULL;
        pExtDoc = NULL;
-       pRef = NextReferenceToEl (pEl, *pDoc, FALSE, pRef, &pRefDoc, &pExtDoc, TRUE);
+       pRef = NextReferenceToEl (pEl, *pDoc, FALSE, pRef, &pRefDoc, &pExtDoc,
+				 TRUE);
        /* parcourt la chaine des elements qui le referencent */
        while (pRef != NULL)
 	 {
 	   pElRef = pRef->RdElement;
 	   /* un element qui reference */
 	   if (pElRef != NULL && pRefDoc == DocumentOfElement (pElRef))
+	     {
 	     if (pRef->RdAttribute != NULL)
 	       /* reference par attribut */
 	       /* retire la presentation de cet attribut et reaffiche */
@@ -473,10 +404,12 @@ ThotBool            redisplay;
 		 while (!stop);
 		 /* retire provisoirement l'attribut de l'element */
 		 if (pAttr != NULL)
+		   {
 		   if (pPrevAttr == NULL)
 		     pElRef->ElFirstAttr = pAttr->AeNext;
 		   else
 		     pPrevAttr->AeNext = pAttr->AeNext;
+		   }
 		 /* recalcule la presentation de l'element sans l'attribut */
 		 UpdatePresAttr (pElRef, pRef->RdAttribute, pElRef, *pDoc,
 				 TRUE, FALSE, NULL);
@@ -485,10 +418,12 @@ ThotBool            redisplay;
 		   RedisplayDocViews (*pDoc);
 		 /* remet l'attribut a l'element */
 		 if (pAttr != NULL)
+		   {
 		   if (pPrevAttr == NULL)
 		     pElRef->ElFirstAttr = pAttr;
 		   else
 		     pPrevAttr->AeNext = pAttr;
+		   }
 	       }
 	     else if (pElRef->ElTerminal && pElRef->ElLeafType == LtReference)
 	       /* si c'est une inclusion, on ne fait rien */
@@ -503,30 +438,29 @@ ThotBool            redisplay;
 		       if (pAb->AbLeafType == LtText)
 				/* change le contenu du pave reference */
 			 {
-			   pAb->AbText->BuContent[0] = TEXT('[');
-			   pAb->AbText->BuContent[1] = TEXT('?');
-			   pAb->AbText->BuContent[2] = TEXT(']');
+			   pAb->AbText->BuContent[0] = '[';
+			   pAb->AbText->BuContent[1] = '?';
+			   pAb->AbText->BuContent[2] = ']';
 			   pAb->AbText->BuContent[3] = EOS;
 			   pAb->AbText->BuLength = 3;
 			   pAb->AbVolume = 3;
 			   /* reaffiche le pave */
 			   pAb->AbChange = TRUE;
-			   if (AssocView (pElRef))
-			     frame =
-			       pRefDoc->DocAssocFrame[pElRef->ElAssocNum - 1];
-			   else
-			     frame = pRefDoc->DocViewFrame[view];
+			   frame = pRefDoc->DocViewFrame[view];
 			   h = 0;
 			   /* on ignore la hauteur de page */
-			   ChangeConcreteImage (frame, &h, pElRef->ElAbstractBox[view]);
+			   ChangeConcreteImage (frame, &h,
+						pElRef->ElAbstractBox[view]);
 			   if (redisplay)
 			     DisplayFrame (frame);
 			 }
 		     }
 		 RedisplayCopies (pElRef, pRefDoc, redisplay);
 	       }
+	     }
 	   /* reference suivante */
-	   pRef = NextReferenceToEl (pEl, *pDoc, FALSE, pRef, &pRefDoc, &pExtDoc, TRUE);
+	   pRef = NextReferenceToEl (pEl, *pDoc, FALSE, pRef, &pRefDoc,
+				     &pExtDoc, TRUE);
 	 }
      }
    /* traite les fils de l'element */
@@ -544,14 +478,7 @@ ThotBool            redisplay;
 /*----------------------------------------------------------------------
    TtcHolophrast   holophraste les elements selectionnes           
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-void                TtcHolophrast (Document document, View view)
-#else  /* __STDC__ */
-void                TtcHolophrast (document, view)
-Document            document;
-View                view;
-
-#endif /* __STDC__ */
+void TtcHolophrast (Document document, View view)
 {
    PtrElement          firstSel, lastSel, pEl;
    PtrDocument         pDoc;
@@ -560,7 +487,7 @@ View                view;
 
    /* y-a-t'il une selection courante ? */
    if (!GetCurrentSelection (&pDoc, &firstSel, &lastSel, &firstChar, &lastChar))
-      TtaDisplaySimpleMessage (INFO, LIB, TMSG_SEL_EL);
+      return;
    else
      {
 	/* eteint la selection */
@@ -619,24 +546,13 @@ View                view;
 	   (*ThotLocalActions[T_chselect]) (pDoc);
 	if (ThotLocalActions[T_chattr] != NULL)
 	   (*ThotLocalActions[T_chattr]) (pDoc);
-	if (!done)
-	   TtaDisplaySimpleMessage (INFO, LIB, TMSG_HOLOPHRAST_IMP);
      }
 }
 
 /*----------------------------------------------------------------------
    DeHolophrast   deholophraste l'element pEl du document pDoc.    
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-void                DeHolophrast (PtrElement pEl, PtrDocument pDoc)
-
-#else  /* __STDC__ */
-void                DeHolophrast (pEl, pDoc)
-PtrElement          pEl;
-PtrDocument         pDoc;
-
-#endif /* __STDC__ */
-
+void DeHolophrast (PtrElement pEl, PtrDocument pDoc)
 {
    /* detruit les paves de l'element */
    DestroyAbsBoxes (pEl, pDoc, TRUE);
@@ -657,18 +573,8 @@ PtrDocument         pDoc;
    position indiquee (qui doit etre un atome texte), cree l'attribut
    langue sur cet atome si setLangAttr est vrai.
   ----------------------------------------------------------------------*/
-
-#ifdef __STDC__
-void                NewTextLanguage (PtrAbstractBox pAb, int charIndex, Language lang, ThotBool setLangAttr)
-
-#else  /* __STDC__ */
-void                NewTextLanguage (pAb, charIndex, lang, setLangAttr)
-PtrAbstractBox      pAb;
-int                 charIndex;
-Language            lang;
-ThotBool		    setLangAttr;
-#endif /* __STDC__ */
-
+void NewTextLanguage (PtrAbstractBox pAb, int charIndex, Language lang,
+		      ThotBool setLangAttr)
 {
    PtrElement          pEl, pNextEl, pSecond, pNext;
    PtrDocument         pDoc;
@@ -730,14 +636,7 @@ ThotBool		    setLangAttr;
    Retourne TRUE si au moins un element a ete cree', FALSE 
    si rien n'a ete cree'.                                  
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-ThotBool            CompleteElement (PtrElement pEl, PtrDocument pDoc)
-#else  /* __STDC__ */
-ThotBool            CompleteElement (pEl, pDoc)
-PtrElement          pEl;
-PtrDocument         pDoc;
-
-#endif /* __STDC__ */
+ThotBool CompleteElement (PtrElement pEl, PtrDocument pDoc)
 {
    PtrElement          pComponent, pNewEl, pLastEl, pPrev, pClose;
    PtrElement          pSibling, pPage;
@@ -874,7 +773,6 @@ PtrDocument         pDoc;
 			  cree avec sa descendance */
 		       pNewEl = NewSubtree (pSRule->SrComponent[comp],
 					    pEl->ElStructSchema, pDoc,
-					    pEl->ElAssocNum,
 					    TRUE, TRUE, TRUE, TRUE);
 		     if (pNewEl != NULL)
 		       /* on met l'element cee' dans l'arbre */
@@ -996,8 +894,7 @@ PtrDocument         pDoc;
 			l'element */
 		     pComponent = NewSubtree (pSRule->SrListItem,
 					      pEl->ElStructSchema, pDoc,
-					      pEl->ElAssocNum, TRUE, TRUE,
-					      TRUE, TRUE);
+					      TRUE, TRUE, TRUE, TRUE);
 		   if (pComponent != NULL)
 		     /* on insere le nouvel element dans l'arbre */
 		     {
@@ -1060,343 +957,347 @@ PtrDocument         pDoc;
    Retourne TRUE en cas de succes.
    select: select the new element
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-ThotBool            BreakElement (PtrElement pElReplicate, PtrElement pSplitEl, int splitIndex, ThotBool block, ThotBool select)
-#else  /* __STDC__ */
-ThotBool            BreakElement (pElReplicate, pSplitEl, splitIndex, block, select)
-PtrElement          pElReplicate;
-PtrElement          pSplitEl;
-int                 splitIndex;
-ThotBool            block;
-ThotBool		    select;
-#endif /* __STDC__ */
-
+ThotBool BreakElement (PtrElement pElReplicate, PtrElement pSplitEl,
+		       int splitIndex, ThotBool block, ThotBool select)
 {
-   PtrElement          firstSel, lastSel, pAncest, pE, pNextEl, pPrevEl,
-                       pPrev, pNext, pChild, pEl2, pEl, pCompleteElem,
-                       pSibling, pClose;
-   PtrElement         *list;
-   PtrDocument         pDoc;
-   NotifyElement       notifyEl;
-   int                 firstChar, lastChar, NSiblings, nextChar, view;
-   int                 nbEl, i, j;
-   ThotBool            ret, ok;
+  PtrElement      firstSel, lastSel, pAncest, pE, pNextEl, pPrevEl, pPrev,
+                  pNext, pChild, pEl2, pEl, pCompleteElem, pSibling, pClose;
+  PtrElement      *list;
+  PtrDocument     pDoc;
+  NotifyElement   notifyEl;
+  int             firstChar, lastChar, NSiblings, nextChar, view;
+  int             nbEl, i, j;
+  ThotBool        ret, ok;
 
-   ret = FALSE;
-   NSiblings = 0;
-   CloseInsertion ();
-   /* y-a-t'il une selection courante ? */
-   if (!GetCurrentSelection (&pDoc, &firstSel, &lastSel, &firstChar, &lastChar))
-      TtaDisplaySimpleMessage (INFO, LIB, TMSG_SEL_EL);
-   else if (!pDoc->DocReadOnly)
-     {
-	if (pSplitEl != NULL)
-	  {
-	     firstSel = pSplitEl;
-	     firstChar = splitIndex;
-	  }
-	if (pElReplicate != NULL)
-	  {
-	     ok = TRUE;
-	     pAncest = pElReplicate->ElParent;
-	     pEl = firstSel;
-	     if (firstChar <= 1 || !pEl->ElTerminal || pEl->ElLeafType != LtText)
+  ret = FALSE;
+  NSiblings = 0;
+  CloseInsertion ();
+  pAncest = NULL;
+  /* y-a-t'il une selection courante ? */
+  if (!GetCurrentSelection (&pDoc, &firstSel, &lastSel, &firstChar, &lastChar))
+    return ret;
+  else if (!pDoc->DocReadOnly)
+    {
+      if (pSplitEl != NULL)
+	{
+	  firstSel = pSplitEl;
+	  firstChar = splitIndex;
+	}
+      if (pElReplicate != NULL)
+	{
+	  if (pElReplicate->ElTypeNumber == pElReplicate->ElStructSchema->SsRootElem)
+	    /* that's the root element. Don't duplicate it */
+	    ok = FALSE;
+	  else
+	    {
+	      ok = TRUE;
+	      pAncest = pElReplicate->ElParent;
+	      pEl = firstSel;
+	      if (firstChar <= 1 || !pEl->ElTerminal ||
+		  pEl->ElLeafType != LtText)
 		/* la selection est en debut d'element */
-	       {
-		  /* tant qu'il n'y a pas de frere precedent, on remonte au pere */
+		{
+		  /* tant qu'il n'y a pas de frere precedent, on remonte au
+		     pere */
 		  while (pEl->ElParent != NULL && pEl->ElPrevious == NULL)
-		     pEl = pEl->ElParent;
+		    pEl = pEl->ElParent;
 		  if (pEl->ElPrevious == NULL)
-		     /* il n'y a pas de frere precedent, on ne peut pas diviser */
-		     ok = FALSE;
-	       }
-	  }
-	else
-	   ok = CanSplitElement (firstSel, firstChar, block, &pAncest, &pEl,
-				 &pElReplicate);
-	if (ok)
-	  {
-	     /* demande a l'application si on peut creer ce type d'element */
-	     notifyEl.event = TteElemNew;
-	     notifyEl.document = (Document) IdentDocument (pDoc);
-	     notifyEl.element = (Element) (pElReplicate->ElParent);
-	     notifyEl.elementType.ElTypeNum = pElReplicate->ElTypeNumber;
-	     notifyEl.elementType.ElSSchema = (SSchema) pElReplicate->ElStructSchema;
-	     pSibling = pElReplicate;
-	     NSiblings = 1;
-	     while (pSibling->ElPrevious != NULL)
-	       {
-		  NSiblings++;
-		  pSibling = pSibling->ElPrevious;
-	       }
-	     notifyEl.position = NSiblings;
-	     if (CallEventType ((NotifyEvent *) (&notifyEl), TRUE))
-		/* l'application refuse */
-		pAncest = NULL;
-	  }
-	if (pAncest != NULL)
-	  {
-	     pPrev = pEl->ElPrevious;
-	     TtaClearViewSelections ();	/* annule d'abord la selection */
-	     pNext = pEl;
-	     nextChar = firstChar;
-
-	     /* Coupure eventuelle de l'atome TEXTE */
-	     if (pEl->ElTerminal)
-		if (pEl->ElLeafType == LtText && firstChar > 1)
-		  {
-		     if (firstChar > pEl->ElTextLength && pEl->ElNext != NULL)
-		       {
-			  pPrev = pEl;
-			  pNext = pEl->ElNext;
-			  if (pNext->ElTerminal && pNext->ElLeafType == LtText)
-			     nextChar = 1;
-			  else
-			     nextChar = 0;
-		       }
-		     else
-		       {
-			  SplitTextElement (pEl, firstChar, pDoc, TRUE,
-					    &pNext, TRUE);
-			  if (pEl == NULL || pEl->ElStructSchema == NULL)
-			     /* pEl has been deleted by the application.
-				we are lost! */
-			     return ret;
-			  else
-			    /* modifie le volume des paves contenant la 1ere
-			       partie du texte */
-			    for (view = 0; view < MAX_VIEW_DOC; view++)
-			       if (pNext->ElTextLength > 0)
-				  UpdateAbsBoxVolume (pEl, view, pDoc);
-			  pPrev = pEl;
-			  nextChar = 1;
-		       }
-		  }
-		else if (pEl->ElLeafType == LtPicture && firstChar > 0 &&
-			 pEl->ElNext != NULL )
-		  {
-		    pPrev = pEl;
-		    pNext = pEl->ElNext;
-		    if (pNext->ElTerminal && pNext->ElLeafType == LtText)
+		    /* il n'y a pas de frere precedent,on ne peut pas diviser*/
+		    ok = FALSE;
+		}
+	    }
+	}
+      else
+	ok = CanSplitElement (firstSel, firstChar, block, &pAncest, &pEl,
+			      &pElReplicate);
+      if (ok)
+	{
+	  /* demande a l'application si on peut creer ce type d'element */
+	  notifyEl.event = TteElemNew;
+	  notifyEl.document = (Document) IdentDocument (pDoc);
+	  notifyEl.element = (Element) (pElReplicate->ElParent);
+	  notifyEl.elementType.ElTypeNum = pElReplicate->ElTypeNumber;
+	  notifyEl.elementType.ElSSchema = (SSchema) pElReplicate->ElStructSchema;
+	  pSibling = pElReplicate;
+	  NSiblings = 1;
+	  while (pSibling->ElPrevious != NULL)
+	    {
+	      NSiblings++;
+	      pSibling = pSibling->ElPrevious;
+	    }
+	  notifyEl.position = NSiblings;
+	  if (CallEventType ((NotifyEvent *) (&notifyEl), TRUE))
+	    /* l'application refuse */
+	    pAncest = NULL;
+	}
+      if (pAncest != NULL)
+	{
+	  pPrev = pEl->ElPrevious;
+	  TtaClearViewSelections ();	/* annule d'abord la selection */
+	  pNext = pEl;
+	  nextChar = firstChar;
+	  
+	  /* Coupure eventuelle de l'atome TEXTE */
+	  if (pEl->ElTerminal)
+	    {
+	      if (pEl->ElLeafType == LtText && firstChar > 1)
+		{
+		  if (firstChar > pEl->ElTextLength && pEl->ElNext != NULL)
+		    {
+		      pPrev = pEl;
+		      pNext = pEl->ElNext;
+		      if (pNext->ElTerminal && pNext->ElLeafType == LtText)
 			nextChar = 1;
-		     else
+		      else
 			nextChar = 0;
-		  }
-	     pClose = pPrev->ElNext;
-	     /* enregistre les elements preexistants */
-	     pE = pPrev->ElNext;
-	     nbEl = 0;
-	     while (pE != NULL)
-	       {
-		  nbEl++;
-		  pE = pE->ElNext;
-	       }
-	     list = (PtrElement *) TtaGetMemory (nbEl * sizeof (PtrElement));
-	     pE = pPrev->ElNext;
-	     nbEl = 0;
-	     while (pE != NULL)
-	       {
-		  list[nbEl++] = pE;
-		  pE = pE->ElNext;
-	       }
-	     
-	     /* detruit les paves des elements qui vont etre deplaces au */
-	     /* niveau le plus bas. La notification n'est faite que sur  */
-	     /* les elements preexistants */
-	     pE = pPrev->ElNext;
-	     pPrevEl = NULL;
-	     i = 0;
-	     while (pE != NULL)
-	       {
-		  DestroyAbsBoxes (pE, pDoc, TRUE);
-		  pNextEl = pE->ElNext;
-		  /* signale a l'application qu'on va retirer l'element */
-		  j = i;
-		  while (j < nbEl && list[j] != pE)
-		    j++;
+		    }
+		  else
+		    {
+		      SplitTextElement (pEl, firstChar, pDoc, TRUE,
+					&pNext, TRUE);
+		      if (pEl == NULL || pEl->ElStructSchema == NULL)
+			/* pEl has been deleted by the application.
+			   we are lost! */
+			return ret;
+		      else
+			/* modifie le volume des paves contenant la 1ere
+			   partie du texte */
+			for (view = 0; view < MAX_VIEW_DOC; view++)
+			  if (pNext->ElTextLength > 0)
+			    UpdateAbsBoxVolume (pEl, view, pDoc);
+		      pPrev = pEl;
+		      nextChar = 1;
+		    }
+		}
+	      else if (pEl->ElLeafType == LtPicture && firstChar > 0 &&
+		       pEl->ElNext != NULL )
+		{
+		  pPrev = pEl;
+		  pNext = pEl->ElNext;
+		  if (pNext->ElTerminal && pNext->ElLeafType == LtText)
+		    nextChar = 1;
+		  else
+		    nextChar = 0;
+		}
+	    }
+	  pClose = pPrev->ElNext;
+	  /* enregistre les elements preexistants */
+	  pE = pPrev->ElNext;
+	  nbEl = 0;
+	  while (pE != NULL)
+	    {
+	      nbEl++;
+	      pE = pE->ElNext;
+	    }
+	  list = (PtrElement *) TtaGetMemory (nbEl * sizeof (PtrElement));
+	  pE = pPrev->ElNext;
+	  nbEl = 0;
+	  while (pE != NULL)
+	    {
+	      list[nbEl++] = pE;
+	      pE = pE->ElNext;
+	    }
+	  
+	  /* detruit les paves des elements qui vont etre deplaces au */
+	  /* niveau le plus bas. La notification n'est faite que sur  */
+	  /* les elements preexistants */
+	  pE = pPrev->ElNext;
+	  pPrevEl = NULL;
+	  i = 0;
+	  while (pE != NULL)
+	    {
+	      DestroyAbsBoxes (pE, pDoc, TRUE);
+	      pNextEl = pE->ElNext;
+	      /* signale a l'application qu'on va retirer l'element */
+	      j = i;
+	      while (j < nbEl && list[j] != pE)
+		j++;
+	      if (j < nbEl)
+		{
+		  notifyEl.event = TteElemDelete;
+		  notifyEl.document = (Document) IdentDocument (pDoc);
+		  notifyEl.element = (Element) pE;
+		  notifyEl.elementType.ElTypeNum = pE->ElTypeNumber;
+		  notifyEl.elementType.ElSSchema = (SSchema)pE->ElStructSchema;
+		  pSibling = pE;
+		  NSiblings = 0;
+		  while (pSibling->ElPrevious != NULL)
+		    {
+		      NSiblings++;
+		      pSibling = pSibling->ElPrevious;
+		    }
+		  notifyEl.position = TTE_TOOLKIT_DELETE;
+		  notifyEl.info = 0;
+		  if (CallEventType ((NotifyEvent *) (&notifyEl), TRUE))
+		    /* l'application refuse de continuer */
+		    return (ret);
+		}
+	      if (pE->ElStructSchema != NULL)
+		{
+		  RemoveElement (pE);
+		  /* signale a l'application qu'on a retire' un element */
 		  if (j < nbEl)
 		    {
-		      notifyEl.event = TteElemDelete;
-		      notifyEl.document = (Document) IdentDocument (pDoc);
-		      notifyEl.element = (Element) pE;
-		      notifyEl.elementType.ElTypeNum = pE->ElTypeNumber;
-		      notifyEl.elementType.ElSSchema = (SSchema) pE->ElStructSchema;
-		      pSibling = pE;
-		      NSiblings = 0;
-		      while (pSibling->ElPrevious != NULL)
-			{
-			  NSiblings++;
-			  pSibling = pSibling->ElPrevious;
-			}
-		      notifyEl.position = TTE_TOOLKIT_DELETE;
+		      notifyEl.element = (Element) pPrev->ElParent;
+		      notifyEl.position = NSiblings;
 		      notifyEl.info = 0;
-		      if (CallEventType ((NotifyEvent *) (&notifyEl), TRUE))
-			/* l'application refuse de continuer */
-			return (ret);
+		      CallEventType ((NotifyEvent *) (&notifyEl), FALSE);
 		    }
-		  if (pE->ElStructSchema != NULL)
+		  if (pPrevEl != NULL)
+		    InsertElementAfter (pPrevEl, pE);
+		  pPrevEl = pE;
+		}
+	      /* previous managed item in the list */
+	      if (j < nbEl)
+		i = j;
+	      pE = pNextEl;
+	    }
+	  TtaFreeMemory (list);
+	  AbstractImageUpdated (pDoc);
+	  if (pClose != NULL)
+	    /* l'element pPrev devient le dernier fils de son pere */
+	    ChangeFirstLast (pPrev, pDoc, FALSE, FALSE);
+	  /* Reconstruction d'une structure parallele */
+	  pE = pPrev->ElParent;
+	  pEl2 = pE;
+	  pChild = pNext;
+	  while ((pE != NULL) && (pE != pAncest))
+	    {
+	      if (pE != pElReplicate)
+		{
+		  /* signale a l'application qu'on va creer un element */
+		  notifyEl.event = TteElemNew;
+		  notifyEl.document = (Document) IdentDocument (pDoc);
+		  notifyEl.element = (Element) (pE->ElParent);
+		  notifyEl.elementType.ElTypeNum = pE->ElTypeNumber;
+		  notifyEl.elementType.ElSSchema = (SSchema)pE->ElStructSchema;
+		  pSibling = pE;
+		  NSiblings = 1;
+		  while (pSibling->ElPrevious != NULL)
 		    {
-		      RemoveElement (pE);
-		      /* signale a l'application qu'on a retire' un element */
-		      if (j < nbEl)
+		      NSiblings++;
+		      pSibling = pSibling->ElPrevious;
+		    }
+		  notifyEl.position = NSiblings;
+		  if (CallEventType ((NotifyEvent *) (&notifyEl), TRUE))
+		    /* l'application refuse de continuer */
+		    return (ret);
+		}
+	      pEl2 = ReplicateElement (pE, pDoc);
+	      InsertFirstChild (pEl2, pChild);
+	      CompleteElement (pEl2, pDoc);
+	      pChild = pEl2;
+	      if (pE != pElReplicate)
+		{
+		  /* les freres suivant l'element duplique' sont transfere's */
+		  /* comme freres suivants du clone */
+		  pClose = pE->ElNext;
+		  if (pClose != NULL)
+		    {
+		      pPrevEl = pEl2;
+		      while (pClose != NULL)
 			{
-			  notifyEl.element = (Element) pPrev->ElParent;
+			  DestroyAbsBoxes (pClose, pDoc, TRUE);
+			  pNextEl = pClose->ElNext;
+			  /* signale a l'appli qu'on va retirer l'element */
+			  notifyEl.event = TteElemDelete;
+			  notifyEl.document = (Document) IdentDocument (pDoc);
+			  notifyEl.element = (Element) pClose;
+			  notifyEl.elementType.ElTypeNum =pClose->ElTypeNumber;
+			  notifyEl.elementType.ElSSchema = (SSchema) pClose->ElStructSchema;
+			  pSibling = pClose;
+			  NSiblings = 0;
+			  while (pSibling->ElPrevious != NULL)
+			    {
+			      NSiblings++;
+			      pSibling = pSibling->ElPrevious;
+			    }
+			  notifyEl.position = TTE_TOOLKIT_DELETE;
+			  notifyEl.info = 0;
+			  if (CallEventType ((NotifyEvent *) (&notifyEl),TRUE))
+			    /* l'application refuse de continuer */
+			    return (ret);
+			  
+			  RemoveElement (pClose);
+			  /* signale a l'application qu'on a retire' un
+			     element */
+			  notifyEl.element = (Element) (pE->ElParent);
 			  notifyEl.position = NSiblings;
 			  notifyEl.info = 0;
 			  CallEventType ((NotifyEvent *) (&notifyEl), FALSE);
+			  InsertElementAfter (pPrevEl, pClose);
+			  pPrevEl = pClose;
+			  pClose = pNextEl;
 			}
-		      if (pPrevEl != NULL)
-			InsertElementAfter (pPrevEl, pE);
-		      pPrevEl = pE;
+		      AbstractImageUpdated (pDoc);
+		      /* l'element pE devient le dernier fils de son pere */
+		      ChangeFirstLast (pE, pDoc, FALSE, FALSE);
 		    }
-		  /* previous managed item in the list */
-		  if (j < nbEl)
-		    i = j;
-		  pE = pNextEl;
-	       }
-	     TtaFreeMemory (list);
-	     AbstractImageUpdated (pDoc);
-	     if (pClose != NULL)
-		/* l'element pPrev devient le dernier fils de son pere */
-		ChangeFirstLast (pPrev, pDoc, FALSE, FALSE);
-	     /* Reconstruction d'une structure parallele */
-	     pE = pPrev->ElParent;
-	     pEl2 = pE;
-	     pChild = pNext;
-	     while ((pE != NULL) && (pE != pAncest))
-	       {
-		  if (pE != pElReplicate)
-		    {
-		       /* signale a l'application qu'on va creer un element */
-		       notifyEl.event = TteElemNew;
-		       notifyEl.document = (Document) IdentDocument (pDoc);
-		       notifyEl.element = (Element) (pE->ElParent);
-		       notifyEl.elementType.ElTypeNum = pE->ElTypeNumber;
-		       notifyEl.elementType.ElSSchema = (SSchema) pE->ElStructSchema;
-		       pSibling = pE;
-		       NSiblings = 1;
-		       while (pSibling->ElPrevious != NULL)
-			 {
-			    NSiblings++;
-			    pSibling = pSibling->ElPrevious;
-			 }
-		       notifyEl.position = NSiblings;
-		       if (CallEventType ((NotifyEvent *) (&notifyEl), TRUE))
-			  /* l'application refuse de continuer */
-			  return (ret);
-		    }
-		  pEl2 = ReplicateElement (pE, pDoc);
-		  InsertFirstChild (pEl2, pChild);
-		  CompleteElement (pEl2, pDoc);
-		  pChild = pEl2;
-		  if (pE != pElReplicate)
-		    {
-		       /* les freres suivant l'element duplique' sont transfere's */
-		       /* comme freres suivants du clone */
-		       pClose = pE->ElNext;
-		       if (pClose != NULL)
-			 {
-			    pPrevEl = pEl2;
-			    while (pClose != NULL)
-			      {
-				 DestroyAbsBoxes (pClose, pDoc, TRUE);
-				 pNextEl = pClose->ElNext;
-				 /* signale a l'application qu'on va retirer l'element */
-				 notifyEl.event = TteElemDelete;
-				 notifyEl.document = (Document) IdentDocument (pDoc);
-				 notifyEl.element = (Element) pClose;
-				 notifyEl.elementType.ElTypeNum = pClose->ElTypeNumber;
-				 notifyEl.elementType.ElSSchema = (SSchema) pClose->ElStructSchema;
-				 pSibling = pClose;
-				 NSiblings = 0;
-				 while (pSibling->ElPrevious != NULL)
-				   {
-				      NSiblings++;
-				      pSibling = pSibling->ElPrevious;
-				   }
-				 notifyEl.position = TTE_TOOLKIT_DELETE;
-				 notifyEl.info = 0;
-				 if (CallEventType ((NotifyEvent *) (&notifyEl), TRUE))
-				    /* l'application refuse de continuer */
-				    return (ret);
-
-				 RemoveElement (pClose);
-				 /* signale a l'application qu'on a retire' un element */
-				 notifyEl.element = (Element) (pE->ElParent);
-				 notifyEl.position = NSiblings;
-				 notifyEl.info = 0;
-				 CallEventType ((NotifyEvent *) (&notifyEl), FALSE);
-				 InsertElementAfter (pPrevEl, pClose);
-				 pPrevEl = pClose;
-				 pClose = pNextEl;
-			      }
-			    AbstractImageUpdated (pDoc);
-			    /* l'element pE devient le dernier fils de son pere */
-			    ChangeFirstLast (pE, pDoc, FALSE, FALSE);
-			 }
-		    }
-		  pEl2 = pE;
+		}
+	      pEl2 = pE;
+	      pE = pE->ElParent;
+	    }
+	  pClose = pEl2->ElNext;
+	  FwdSkipPageBreak (&pClose);
+	  InsertElementAfter (pEl2, pChild);
+	  if (pClose == NULL)
+	    /* l'element pEl2 n'est plus le dernier fils de son pere */
+	    ChangeFirstLast (pEl2, pDoc, FALSE, TRUE);
+	  /* traite les exclusions des elements crees */
+	  RemoveExcludedElem (&pChild, pDoc);
+	  /* traite les attributs requis des elements crees */
+	  AttachMandatoryAttributes (pChild, pDoc);
+	  if (pDoc->DocSSchema == NULL)
+	    /* le document a ete ferme' entre temps */
+	    ret = FALSE;
+	  else
+	    {
+	      /* traitement des exceptions des nouveaux elements cree's */
+	      CreationExceptions (pChild, pDoc);
+	      /* complete l'element qui a ete coupe' en deux */
+	      pCompleteElem = NULL;
+	      pE = pPrev->ElParent;
+	      while ((pE != NULL) && (pE != pAncest))
+		{
+		  if (CompleteElement (pE, pDoc))
+		    pCompleteElem = pE;
 		  pE = pE->ElParent;
-	       }
-	     pClose = pEl2->ElNext;
-	     FwdSkipPageBreak (&pClose);
-	     InsertElementAfter (pEl2, pChild);
-	     if (pClose == NULL)
-		/* l'element pEl2 n'est plus le dernier fils de son pere */
-		ChangeFirstLast (pEl2, pDoc, FALSE, TRUE);
-	     /* traite les exclusions des elements crees */
-	     RemoveExcludedElem (&pChild, pDoc);
-	     /* traite les attributs requis des elements crees */
-	     AttachMandatoryAttributes (pChild, pDoc);
-	     if (pDoc->DocSSchema == NULL)
-		/* le document a ete ferme' entre temps */
-		ret = FALSE;
-	     else
-	       {
-		  /* traitement des exceptions des nouveaux elements cree's */
-		  CreationExceptions (pChild, pDoc);
-		  /* complete l'element qui a ete coupe' en deux */
-		  pCompleteElem = NULL;
-		  pE = pPrev->ElParent;
-		  while ((pE != NULL) && (pE != pAncest))
-		    {
-		       if (CompleteElement (pE, pDoc))
-			  pCompleteElem = pE;
-		       pE = pE->ElParent;
-		    }
-		  /* traitement des exceptions de l'element qui a ete coupe' */
-		  CreationExceptions (pElReplicate, pDoc);
-		  /* envoie un evenement ElemPaste.Post a l'application */
-		  NotifySubTree (TteElemPaste, pDoc, pChild, -1);
-		  /* reconstruit les paves des elements qui ont ete complete's */
-		  /* cree les paves du nouvel element */
-		  CreateAllAbsBoxesOfEl (pChild, pDoc);
-		  CreateAllAbsBoxesOfEl (pElReplicate, pDoc);
-		  if (pCompleteElem != NULL)
-		     CreateAllAbsBoxesOfEl (pCompleteElem, pDoc);
-		  AbstractImageUpdated (pDoc);
-		  RedisplayDocViews (pDoc);
-		  /* si on est dans un element copie' par inclusion,   */
-		  /* on met a jour les copies de cet element.          */
-		  RedisplayCopies (pEl2, pDoc, TRUE);
-		  RedisplayCopies (pElReplicate, pDoc, TRUE);
-		  UpdateNumbers (NextElement (pChild), pEl2, pDoc, TRUE);
-		  /* indiquer que le document est modifie' */
-		  SetDocumentModified (pDoc, TRUE, 30);
-		  if (select && pNext != NULL)
-		     if (nextChar == 0)
-			SelectElementWithEvent (pDoc, pNext, TRUE, TRUE);
-		     else
-			SelectPositionWithEvent (pDoc, pNext, nextChar);
-		  ret = TRUE;
-	       }
-	     for (view = 0; view < MAX_VIEW_DOC; view++)
-		if (pEl->ElAbstractBox[view] != NULL)
-		   RedisplayCopies (pEl->ElAbstractBox[view]->AbElement, pDoc,
-				    TRUE);
-	  }
-     }
-   return ret;
+		}
+	      /* traitement des exceptions de l'element qui a ete coupe' */
+	      CreationExceptions (pElReplicate, pDoc);
+	      /* envoie un evenement ElemPaste.Post a l'application */
+	      NotifySubTree (TteElemPaste, pDoc, pChild, -1);
+	      /* reconstruit les paves des elements qui ont ete complete's */
+	      /* cree les paves du nouvel element */
+	      CreateAllAbsBoxesOfEl (pChild, pDoc);
+	      CreateAllAbsBoxesOfEl (pElReplicate, pDoc);
+	      if (pCompleteElem != NULL)
+		CreateAllAbsBoxesOfEl (pCompleteElem, pDoc);
+	      AbstractImageUpdated (pDoc);
+	      RedisplayDocViews (pDoc);
+	      /* si on est dans un element copie' par inclusion,   */
+	      /* on met a jour les copies de cet element.          */
+	      RedisplayCopies (pEl2, pDoc, TRUE);
+	      RedisplayCopies (pElReplicate, pDoc, TRUE);
+	      UpdateNumbers (NextElement (pChild), pEl2, pDoc, TRUE);
+	      /* indiquer que le document est modifie' */
+	      SetDocumentModified (pDoc, TRUE, 30);
+	      if (select && pNext != NULL)
+		{
+		  if (nextChar == 0)
+		    SelectElementWithEvent (pDoc, pNext, TRUE, TRUE);
+		  else
+		    SelectPositionWithEvent (pDoc, pNext, nextChar);
+		}
+	      ret = TRUE;
+	    }
+	  for (view = 0; view < MAX_VIEW_DOC; view++)
+	    if (pEl->ElAbstractBox[view] != NULL)
+	      RedisplayCopies (pEl->ElAbstractBox[view]->AbElement, pDoc,
+			       TRUE);
+	}
+    }
+  return ret;
 }
 
 
@@ -1405,16 +1306,8 @@ ThotBool		    select;
    sous-arbre de racine pEl avec leurs voisins, s'ils ont les      
    memes attributs et les memes regles de presentation specifique. 
   ----------------------------------------------------------------------*/
-
-#ifdef __STDC__
-static void         MergeTextLeaves (PtrElement * pEl, PtrElement * pFirstFree, PtrDocument * pDoc)
-#else  /* __STDC__ */
-static void         MergeTextLeaves (pEl, pFirstFree, pDoc)
-PtrElement         *pEl;
-PtrElement         *pFirstFree;
-PtrDocument        *pDoc;
-#endif /* __STDC__ */
-
+static void MergeTextLeaves (PtrElement *pEl, PtrElement *pFirstFree,
+			     PtrDocument *pDoc)
 {
    PtrElement          pPrev, pFree, pChild;
 
@@ -1453,19 +1346,8 @@ PtrDocument        *pDoc;
    Select all elements between firstSel and lastSel in document pDoc
    Redisplay all views.
   ----------------------------------------------------------------------*/
-
-#ifdef __STDC__
-void                SelectRange (PtrDocument pDoc, PtrElement firstSel, PtrElement lastSel, int firstChar, int lastChar)
-
-#else  /* __STDC__ */
-void                SelectRange (pDoc, firstSel, lastSel, firstChar, lastChar)
-PtrDocument         pDoc;
-PtrElement          firstSel;
-PtrElement          lastSel;
-int                 firstChar;
-int                 lastChar;
-#endif /* __STDC__ */
-
+void SelectRange (PtrDocument pDoc, PtrElement firstSel, PtrElement lastSel,
+		  int firstChar, int lastChar)
 {
    PtrElement          pEl, SelectedEl[MAX_SEL_ELEM];
    /* pointeurs sur les elements selectionnes si SelContinue est faux */
@@ -1530,11 +1412,14 @@ int                 lastChar;
       SelectString (pDoc, firstSel, 1, lastChar - 1);
 
    if (lastSel != firstSel)
+     {
       if (discreteSelection)
 	 for (index = 1; index <= NSelectedEls; index++)
-	    AddInSelection (SelectedEl[index - 1], (ThotBool)(index == NSelectedEls));
+	    AddInSelection (SelectedEl[index - 1],
+			    (ThotBool)(index == NSelectedEls));
       else if (lastChar == 0)
 	 ExtendSelection (lastSel, lastChar, TRUE, FALSE, FALSE);
       else
 	 ExtendSelection (lastSel, lastChar - 1, TRUE, FALSE, FALSE);
+     }
 }
