@@ -1,21 +1,12 @@
 /*
  *
- *  (c) COPYRIGHT INRIA, 1996.
+ *  (c) COPYRIGHT INRIA, 1996-2001
  *  Please first read the full copyright statement in file COPYRIGHT.
  *
  */
 
 /*
- * Warning:
- * This module is part of the Thot library, which was originally
- * developed in French. That's why some comments are still in
- * French, but their translation is in progress and the full module
- * will be available in English in the next release.
- * 
- */
- 
-/*
- * Module dedicated to manage text commands.
+ * This module implements text commands.
  *
  * Authors: I. Vatton (INRIA)
  *          R. Guetari (W3C/INRIA) - Unicode and Windows version
@@ -43,47 +34,51 @@
 #include "select_tv.h"
 #include "appdialogue_tv.h"
 
-static ThotBool RightExtended;
-static ThotBool LeftExtended;
-static ThotBool Retry = FALSE;
-static ThotBool Moving = FALSE;
+static ThotBool      RightExtended;
+static ThotBool      LeftExtended;
+static ThotBool      Retry = FALSE;
+static ThotBool      Moving = FALSE;
+static SearchContext WordSearchContext = {
+  NULL, 0, NULL, 0, NULL, 0, TRUE, TRUE
+};
 
+/* cursor movement callback procedures for Math */
+static Func     MathMoveForwardCursorFunction = NULL;
+static Func     MathMoveBackwardCursorFunction = NULL;
+
+#include "abspictures_f.h"
 #include "applicationapi_f.h"
 #include "appli_f.h"
-#include "tree_f.h"
-#include "textcommands_f.h"
-#include "editcommands_f.h"
-#include "structcreation_f.h"
-#include "scroll_f.h"
-#include "boxmoves_f.h"
 #include "boxlocate_f.h"
-#include "views_f.h"
-#include "callback_f.h"
-#include "windowdisplay_f.h"
-#include "font_f.h"
-#include "geom_f.h"
-#include "buildboxes_f.h"
-#include "picture_f.h"
-#include "abspictures_f.h"
-#include "buildlines_f.h"
-#include "memory_f.h"
-#include "structmodif_f.h"
+#include "boxmoves_f.h"
 #include "boxparams_f.h"
 #include "boxselection_f.h"
-#include "structselect_f.h"
+#include "buildboxes_f.h"
+#include "buildlines_f.h"
+#include "callback_f.h"
 #include "content_f.h"
+#include "editcommands_f.h"
+#include "font_f.h"
+#include "geom_f.h"
+#include "hyphen_f.h"
+#include "memory_f.h"
+#include "picture_f.h"
+#include "scroll_f.h"
+#include "structmodif_f.h"
+#include "structcreation_f.h"
+#include "structselect_f.h"
+#include "textcommands_f.h"
+#include "tree_f.h"
 #include "viewapi_f.h"
+#include "views_f.h"
+#include "windowdisplay_f.h"
+#include "word_f.h"
+
 
 /*----------------------------------------------------------------------
    IsTextLeaf teste si un pave est un pave de texte modifiable.     
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 static ThotBool     IsTextLeaf (PtrAbstractBox pave)
-#else  /* __STDC__ */
-static ThotBool     IsTextLeaf (pave)
-PtrAbstractBox      pave;
-
-#endif /* __STDC__ */
 {
    ThotBool            result;
 
@@ -96,18 +91,11 @@ PtrAbstractBox      pave;
 
 
 /*----------------------------------------------------------------------
-   MoveInLine deplace la selection textuelle.                      
-   - frame designe la fenetre de travail.                  
-   - toend indique que l'on va a la fin de la ligne.       
+  MoveInLine moves the text selection.
+  The parameter frame gives the concerned frame.
+  The parameter toend is TRUE when moving to the end of the line.
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 static void         MoveInLine (int frame, ThotBool toend)
-#else  /* __STDC__ */
-static void         MoveInLine (frame, toend)
-int                 frame;
-ThotBool            toend;
-
-#endif /* __STDC__ */
 {
    PtrLine             pLine;
    PtrAbstractBox      pAb;
@@ -123,7 +111,7 @@ ThotBool            toend;
       return;
    else if (toend)
      {
-	/* Prend la derniere boite de la ligne */
+	/* get the last box in the line */
 	if (pLine->LiLastPiece != NULL)
 	   pBox = pLine->LiLastPiece;
 	else
@@ -144,29 +132,18 @@ ThotBool            toend;
 	if (IsTextLeaf (pAb))
 	   nChars = pBox->BxIndChar + 1;
      }
-   /* Reinitialise la selection */
+   /* update the selection */
    ChangeSelection (frame, pAb, nChars, FALSE, TRUE, FALSE, FALSE);
 }
 
 
 /*----------------------------------------------------------------------
-   LocateLeafBox get the box located at the position x+xDelta, y+yDelta.
+   LocateLeafBox gets the box located at the position x+xDelta, y+yDelta.
    if the box is still the same (pFrom) the position is shifted by
    xDelta and yDelta.                     
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-static void         LocateLeafBox (int frame, View view, int x, int y, int xDelta, int yDelta, PtrBox pFrom, ThotBool extendSel)
-#else  /* __STDC__ */
-static void         LocateLeafBox (frame, view, x, y, xDelta, yDelta, pFrom, extendSel)
-int                 frame;
-View                view;
-int                 x;
-int                 y;
-int                 xDelta;
-int                 yDelta;
-PtrBox              pFrom;
-ThotBool            extendSel;
-#endif /* __STDC__ */
+static void LocateLeafBox (int frame, View view, int x, int y, int xDelta,
+			   int yDelta, PtrBox pFrom, ThotBool extendSel)
 {
    ViewFrame          *pFrame;
    PtrBox              pBox, pLastBox;
@@ -226,7 +203,7 @@ ThotBool            extendSel;
        /* try to select down to the bottom of the current displayed frame */
        do
 	 {
-	   /* scroll as long as the bootom of the view is not reached */
+	   /* scroll as long as the bottom of the view is not reached */
 	   org = pLastBox->BxYOrg;
 	   TtcLineDown (doc, view);
 	   /* update the new position */
@@ -251,7 +228,7 @@ ThotBool            extendSel;
 	     if (IsTextLeaf (pAb))
 	       {
 		  x -= pBox->BxXOrg;
-		  LocateClickedChar (pBox, &pBuffer, &x, &index, &nChars, &nbbl);
+		  LocateClickedChar (pBox, extendSel, &pBuffer, &x, &index, &nChars, &nbbl);
 		  if (extendSel && LeftExtended && nChars == pBox->BxNChars)
 		    /* add the last char in the left selection */
 		    nChars = pBox->BxIndChar + nChars;
@@ -267,33 +244,47 @@ ThotBool            extendSel;
      }
 }
 
+/*----------------------------------------------------------------------
+   TtaSetMoveForwardCallback permet de connecter une fonction de
+   l'application a la touche de deplacement du curseur vers l'avant
+  ----------------------------------------------------------------------*/
+void  TtaSetMoveForwardCallback (Func callbackFunc)
+{
+   MathMoveForwardCursorFunction = callbackFunc;
+}
+
+/*----------------------------------------------------------------------
+   TtaSetMoveBackwardCallback permet de connecter une fonction de
+   l'application a la touche de deplacement du curseur vers l'arriere
+  ----------------------------------------------------------------------*/
+void  TtaSetMoveBackwardCallback (Func callbackFunc)
+{
+   MathMoveBackwardCursorFunction = callbackFunc;
+}
+
 /*----------------------------------------------------------------------
    Commandes de deplacement                                           
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-static void         MovingCommands (int code, Document document, View view, ThotBool extendSel)
-#else  /* __STDC__ */
-static void         MovingCommands (code, document, view, extendSel)
-int                 code;
-Document            document;
-View                view;
-ThotBool            extendSel;
-#endif /* __STDC__ */
+static void MovingCommands (int code, Document doc, View view, ThotBool extendSel)
 {
    PtrBox              pBox, pBoxBegin, pBoxEnd;
+   PtrElement          pEl = NULL;
+   PtrLine             pLine;
    ViewFrame          *pFrame;
    ViewSelection      *pViewSel;
    ViewSelection      *pViewSelEnd;
+   CHAR_T              word[MAX_WORD_LEN];
    int                 frame, x, y, i;
    int                 xDelta, yDelta;
-   int                 h, w, doc;
+   int                 h, w;
    int                 indpos, xpos;
-   ThotBool            top = TRUE;
+   int                 first, last;
+   ThotBool            done, top = TRUE;
 
    indpos = 0;
    xpos = 0;
    CloseInsertion ();
-   frame = GetWindowNumber (document, view);
+   frame = GetWindowNumber (doc, view);
    if (frame > 0)
      {
        pFrame = &ViewFrameTable[frame - 1];
@@ -334,7 +325,7 @@ ThotBool            extendSel;
 	     }
 	 }
 
-       /* Check if boxed are visible */
+       /* Check if boxes are visible */
        GetSizesFrame (frame, &w, &h);
        if (!RightExtended && !LeftExtended)
 	 {
@@ -395,25 +386,39 @@ ThotBool            extendSel;
 	     }
 	   else if (!RightExtended && !LeftExtended)
 	     {
-	       if (FirstSelectedElement == FixedElement && FirstSelectedChar == FixedChar)
-		 {
-		   RightExtended = FALSE;
-		   LeftExtended = TRUE;
-		 }
-	       else
+	       if (FirstSelectedElement == FixedElement &&
+		   FirstSelectedChar == FixedChar)
 		 {
 		   RightExtended = TRUE;
 		   LeftExtended = FALSE;
 		 }
+	       else
+		 {
+		   RightExtended = FALSE;
+		   LeftExtended = TRUE;
+		 }
 	     }
 	 }
 
        /* doesn't change the current Shrink value in other cases */
        switch (code)
 	 {
-	 case 1:	/* Backward one character (^B) */
+	 case 1:	/* Backward one character (<-) */
 	   if (pBox != NULL)
 	     {
+	     done = FALSE;
+	     pEl = pBox->BxAbstractBox->AbElement;
+	     if (!strcmp(pEl->ElStructSchema->SsName, "MathML") &&
+		 MathMoveBackwardCursorFunction != NULL)
+	       done = MathMoveBackwardCursorFunction ();
+	     else if (!strcmp (pEl->ElStructSchema->SsName, "GraphML") &&
+		      (!pEl->ElTerminal || pEl->ElLeafType != LtText))
+	       {
+		 TtcPreviousElement (doc, view);
+		 done = TRUE;
+	       }
+	     if (!done)
+	       {
 	       if (extendSel && RightExtended)
 		 {
 		   /* move the right extremity */
@@ -433,7 +438,7 @@ ThotBool            extendSel;
 			   FirstSelectedElement == LastSelectedElement)
 			 {
 			   /* a single insert point */
-			   ChangeSelection (frame, pBox->BxAbstractBox, x, FALSE, TRUE, FALSE, FALSE);
+			   ChangeSelection (frame, pBox->BxAbstractBox, FixedChar, FALSE, TRUE, FALSE, FALSE);
 			   RightExtended = FALSE;
 			 }
 		       else if (SelPosition &&
@@ -452,7 +457,6 @@ ThotBool            extendSel;
 		     /* the x is equal to FirstSelectedChar - 1 */
 		     ChangeSelection (frame, pBox->BxAbstractBox, x, FALSE, TRUE, FALSE, FALSE);
 		   /* show the beginning of the selection */
-		   doc = FrameTable[frame].FrDoc;
 		   if (pBoxBegin->BxXOrg + pViewSel->VsXPos + 4 < pFrame->FrXOrg)
 		     {
 		       if (pFrame->FrXOrg > 0)
@@ -464,26 +468,57 @@ ThotBool            extendSel;
 	       else
 		 {
 		   /* a new box will be selected */
-		   x = pBox->BxXOrg + xpos;
-		   y = pBox->BxYOrg + (pBox->BxHeight / 2);
+		   /* check if the box is within a line */
+		   GetLine (&pLine);
+		   if (pLine)
+		     {
+		       y = pBox->BxYOrg + (pBox->BxHeight / 2);
+		       x = pBox->BxXOrg + xpos;
+		     }
+		   else
+		     {
+		       /* moving outside a block of lines */
+		       y = pBox->BxYOrg - 2;
+		       x = pBox->BxXOrg + pBox->BxWidth;
+		     }
 		   xDelta = -2;
 		   LocateLeafBox (frame, view, x, y, xDelta, 0, pBox, extendSel);
 		 }
+	       }
 	     }
 	   /* Get the last X position */
 	   ClickX = pBoxBegin->BxXOrg + pViewSel->VsXPos - pFrame->FrXOrg;
 	   break;
 	   
-	 case 2:	/* Forward one character (^F) */
-	   if (pBox != NULL)
+	 case 2:	/* Forward one character (->) */
+	   if (pBox)
 	     {
+	     done = FALSE;
+	     pEl = pBox->BxAbstractBox->AbElement;
+	     if (!strcmp(pEl->ElStructSchema->SsName, "MathML") &&
+		 MathMoveForwardCursorFunction != NULL)
+	       done = MathMoveForwardCursorFunction ();
+	     else if (!strcmp (pEl->ElStructSchema->SsName, "GraphML") &&
+		      (!pEl->ElTerminal || pEl->ElLeafType != LtText))
+	       {
+		 TtcNextElement (doc, view);
+		 done = TRUE;
+	       }
+	     if (!done)
+	       {
 	       if (!extendSel || !LeftExtended)
 		 {
 		   /* move the right extremity */
 		   pBox = pBoxEnd;
+		   pEl = pBox->BxAbstractBox->AbElement;
 		   if (!extendSel && pViewSelEnd->VsBox &&
 		       pViewSelEnd->VsBox->BxType == BoGhost)
 		     x = pBox->BxNChars;
+		   else if ( pBox->BxAbstractBox &&
+			     pBox->BxAbstractBox->AbLeafType == LtCompound)
+		     x = pBox->BxNChars;
+		   else if (pEl->ElStructSchema->SsRule[pEl->ElTypeNumber - 1].SrConstruct == CsConstant)
+		     x =  pBox->BxNChars;
 		   else
 		     x = pViewSelEnd->VsIndBox + pBox->BxIndChar;
 		 }
@@ -499,7 +534,7 @@ ThotBool            extendSel;
 			   FirstSelectedElement == LastSelectedElement)
 			 {
 			   /* a single insert point */
-			   ChangeSelection (frame, pBox->BxAbstractBox, x + 1, FALSE, TRUE, FALSE, FALSE);
+			   ChangeSelection (frame, pBox->BxAbstractBox, FixedChar, FALSE, TRUE, FALSE, FALSE);
 			   LeftExtended = FALSE;
 			 }
 		       else if (SelPosition &&
@@ -517,7 +552,6 @@ ThotBool            extendSel;
 		   else
 		     ChangeSelection (frame, pBox->BxAbstractBox, x + 2, FALSE, TRUE, FALSE, FALSE);
 		   /* show the beginning of the selection */
-		   doc = FrameTable[frame].FrDoc;
 		   if (pBoxEnd->BxXOrg + pViewSelEnd->VsXPos > pFrame->FrXOrg + w)
 		     {
 		       if (FrameTable[frame].FrScrollOrg + FrameTable[frame].FrScrollWidth > pFrame->FrXOrg + w)
@@ -528,33 +562,56 @@ ThotBool            extendSel;
 		 }
 	       else
 		 {
-		   x = pBox->BxXOrg + pBox->BxWidth;
-		   y = pBox->BxYOrg + (pBox->BxHeight / 2);
+		   /* check if the box is within a line */
+		   GetLine (&pLine);
+		   if (pLine)
+		     {
+		       y = pBox->BxYOrg + (pBox->BxHeight / 2);
+		       x = pBox->BxXOrg + pBox->BxWidth;
+		     }
+		   else
+		     {
+		       /* moving ouside a block of lines */
+		       y = pBox->BxYOrg + pBox->BxHeight + 2;
+		       x = pBox->BxXOrg;
+		     }
 		   xDelta = 2;
 		   LocateLeafBox (frame, view, x, y, xDelta, 0, pBox, extendSel);
 		 }
+	       }
 	     }
 	   /* Get the last X position */
 	   ClickX = pBoxBegin->BxXOrg + pViewSel->VsXPos - pFrame->FrXOrg;
 	   break;
 	   
 	 case 3:	/* End of line (^E) */
-	   if (pBox != NULL)
+	   if (pBox)
 	     MoveInLine (frame, TRUE);
+	   if (pViewSel->VsBox)
+	     /* Get the last X position */
+	     ClickX = pViewSel->VsBox->BxXOrg + pViewSel->VsXPos - pFrame->FrXOrg;
 	   break;
 	   
 	 case 4:	/* Beginning of line (^A) */
-	   if (pBox != NULL)
+	   if (pBox)
 	     MoveInLine (frame, FALSE);
+	   if (pViewSel->VsBox)
+	     /* Get the last X position */
+	     ClickX = pViewSel->VsBox->BxXOrg + pViewSel->VsXPos - pFrame->FrXOrg;
 	   break;
 	   
 	 case 7:	/* Next line (^N) */
-	   if (pBox != NULL)
+	   if (pBox)
+         pEl = pBox->BxAbstractBox->AbElement;
+	   if (pEl && !strcmp (pEl->ElStructSchema->SsName, "GraphML") &&
+	       (!pEl->ElTerminal || pEl->ElLeafType != LtText))
+	     TtcNextElement (doc, view);
+	   else if (pBox)
 	     {
 	       pBox = pBoxEnd;
 	       x = pViewSelEnd->VsXPos + pBox->BxXOrg;
 	       if (pViewSelEnd->VsBuffer && pViewSelEnd->VsIndBuf < pViewSelEnd->VsBuffer->BuLength)
-		 x = x - CharacterWidth (pViewSelEnd->VsBuffer->BuContent[pViewSelEnd->VsIndBuf], pBox->BxFont);
+		 x -= CharacterWidth (pViewSelEnd->VsBuffer->BuContent[pViewSelEnd->VsIndBuf], pBox->BxFont);
 	       y = pBox->BxYOrg + pBox->BxHeight;
 	       yDelta = 10;
 	       /* store the end position of the selection as the new reference */
@@ -595,7 +652,12 @@ ThotBool            extendSel;
 	   break;
 	   
 	 case 8:	/* Previous line (^P) */
-	   if (pBox != NULL)
+	   if (pBox)
+	     pEl = pBox->BxAbstractBox->AbElement;
+	   if (pEl && !strcmp (pEl->ElStructSchema->SsName, "GraphML") &&
+	       (!pEl->ElTerminal || pEl->ElLeafType != LtText))
+	     TtcPreviousElement (doc, view);
+	   else if (pBox)
 	     {
 	       y = pBoxBegin->BxYOrg;
 	       x = ClickX + pFrame->FrXOrg;
@@ -623,6 +685,94 @@ ThotBool            extendSel;
 	       LocateLeafBox (frame, view, x, y, 0, yDelta, pBox, extendSel);
 	     }
 	   break;
+	   
+	 case 9:	/* Previous word (^<-) */
+	   WordSearchContext.SDocument = LoadedDocument[doc - 1];
+	   WordSearchContext.SStartToEnd = FALSE;
+	   if (RightExtended)
+	     {
+	       /* shrink the current selection */
+	       first = LastSelectedChar;
+	       pEl = LastSelectedElement;
+	     }
+	   else
+	     {
+	       /* extend the current selection */
+	       first = FirstSelectedChar - 1;
+	       pEl = FirstSelectedElement;
+	     }
+	   done = SearchPreviousWord (&pEl, &first, &last, word, &WordSearchContext);
+	   if ((RightExtended && last >= LastSelectedChar) ||
+	       (LeftExtended && first == FirstSelectedChar - 1))
+	     /* It was not the beginning of the next word */
+	     done = SearchPreviousWord (&pEl, &first, &last, word, &WordSearchContext);
+	   if (extendSel)
+	     {
+	       if (RightExtended && FirstSelectedElement == FixedElement &&
+		   last <= FixedChar)
+		 {
+		 /* change the extension direction */
+		   RightExtended = FALSE;
+		   LeftExtended = TRUE;
+		 }
+	       if (LeftExtended)
+		 i = first + 1;
+	       else
+		 i = last;
+	       if (pEl->ElAbstractBox[view - 1])
+		 ChangeSelection (frame, pEl->ElAbstractBox[view - 1], i, TRUE, TRUE, FALSE, FALSE);
+	     }
+	   else
+	     {
+	       SelectString (LoadedDocument[doc - 1], pEl, first + 1, first);
+	       /* remove the extension direction */
+	       LeftExtended = FALSE;
+	     }
+	   break;
+	   
+	 case 10:	/* Next word (^->) */
+	   WordSearchContext.SDocument =  LoadedDocument[doc - 1];
+	   WordSearchContext.SStartToEnd = TRUE;
+	   if (LeftExtended)
+	     {
+	       /* shrink the current selection */
+	       last = FirstSelectedChar;
+	       pEl = FirstSelectedElement;
+	     }
+	   else
+	     {
+	       /* extend the current selection */
+	       last = LastSelectedChar;
+	       pEl = LastSelectedElement;
+	     }
+	   done = SearchNextWord (&pEl, &first, &last, word, &WordSearchContext);
+	   if ((!LeftExtended && first == LastSelectedChar) ||
+	       (LeftExtended && first >= FirstSelectedChar))
+	     /* It was not the beginning of the next word */
+	     done = SearchNextWord (&pEl, &first, &last, word, &WordSearchContext);
+	   if (extendSel)
+	     {
+	       if (LeftExtended && FirstSelectedElement == FixedElement &&
+		   first >= FixedChar)
+		 {
+		 /* change the extension direction */
+		   RightExtended = TRUE;
+		   LeftExtended = FALSE;
+		 }
+	       if (LeftExtended)
+		 i = first + 1;
+	       else
+		 i = last;
+	       if (pEl->ElAbstractBox[view - 1])
+		 ChangeSelection (frame, pEl->ElAbstractBox[view - 1], i, TRUE, TRUE, FALSE, FALSE);
+	     }
+	   else
+	     {
+	       SelectString (LoadedDocument[doc - 1], pEl, first + 1, first);
+	       /* remove the extension direction */
+	       LeftExtended = FALSE;
+	     }
+	   break;
 	 }
        Moving = FALSE;
      }
@@ -630,155 +780,107 @@ ThotBool            extendSel;
 
 /*----------------------------------------------------------------------
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 void                TtcPreviousChar (Document document, View view)
-#else  /* __STDC__ */
-void                TtcPreviousChar (document, view)
-Document            document;
-View                view;
-
-#endif /* __STDC__ */
 {
    MovingCommands (1, document, view, FALSE);
 }
 
 /*----------------------------------------------------------------------
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 void                TtcNextChar (Document document, View view)
-#else  /* __STDC__ */
-void                TtcNextChar (document, view)
-Document            document;
-View                view;
-
-#endif /* __STDC__ */
 {
    MovingCommands (2, document, view, FALSE);
 }
 
 /*----------------------------------------------------------------------
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 void                TtcPreviousLine (Document document, View view)
-#else  /* __STDC__ */
-void                TtcPreviousLine (document, view)
-Document            document;
-View                view;
-
-#endif /* __STDC__ */
 {
    MovingCommands (8, document, view, FALSE);
 }
 
 /*----------------------------------------------------------------------
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 void                TtcNextLine (Document document, View view)
-#else  /* __STDC__ */
-void                TtcNextLine (document, view)
-Document            document;
-View                view;
-
-#endif /* __STDC__ */
 {
    MovingCommands (7, document, view, FALSE);
 }
 
 /*----------------------------------------------------------------------
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 void                TtcStartOfLine (Document document, View view)
-#else  /* __STDC__ */
-void                TtcStartOfLine (document, view)
-Document            document;
-View                view;
-
-#endif /* __STDC__ */
 {
    MovingCommands (4, document, view, FALSE);
 }
 
 /*----------------------------------------------------------------------
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 void                TtcEndOfLine (Document document, View view)
-#else  /* __STDC__ */
-void                TtcEndOfLine (document, view)
-Document            document;
-View                view;
-
-#endif /* __STDC__ */
 {
    MovingCommands (3, document, view, FALSE);
 }
 
 /*----------------------------------------------------------------------
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 void                TtcPreviousSelChar (Document document, View view)
-#else  /* __STDC__ */
-void                TtcPreviousSelChar (document, view)
-Document            document;
-View                view;
-
-#endif /* __STDC__ */
 {
    MovingCommands (1, document, view, TRUE);
 }
 
 /*----------------------------------------------------------------------
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 void                TtcNextSelChar (Document document, View view)
-#else  /* __STDC__ */
-void                TtcNextSelChar (document, view)
-Document            document;
-View                view;
-
-#endif /* __STDC__ */
 {
    MovingCommands (2, document, view, TRUE);
 }
 
 /*----------------------------------------------------------------------
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 void                TtcPreviousSelLine (Document document, View view)
-#else  /* __STDC__ */
-void                TtcPreviousSelLine (document, view)
-Document            document;
-View                view;
-
-#endif /* __STDC__ */
 {
    MovingCommands (8, document, view, TRUE);
 }
 
 /*----------------------------------------------------------------------
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 void                TtcNextSelLine (Document document, View view)
-#else  /* __STDC__ */
-void                TtcNextSelLine (document, view)
-Document            document;
-View                view;
-
-#endif /* __STDC__ */
 {
    MovingCommands (7, document, view, TRUE);
 }
 
+/*----------------------------------------------------------------------
+  ----------------------------------------------------------------------*/
+void                TtcPreviousWord (Document document, View view)
+{
+   MovingCommands (9, document, view, FALSE);
+}
+
+/*----------------------------------------------------------------------
+  ----------------------------------------------------------------------*/
+void                TtcNextWord (Document document, View view)
+{
+   MovingCommands (10, document, view, FALSE);
+}
+
+/*----------------------------------------------------------------------
+  ----------------------------------------------------------------------*/
+void                TtcPreviousSelWord (Document document, View view)
+{
+   MovingCommands (9, document, view, TRUE);
+}
+
+/*----------------------------------------------------------------------
+  ----------------------------------------------------------------------*/
+void                TtcNextSelWord (Document document, View view)
+{
+   MovingCommands (10, document, view, TRUE);
+}
+
 /*----------------------------------------------------------------------
    CopyXClipboard insere le contenu de la selection courante dans   
    le Xbuffer pour transmettre la selection X.             
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-static int          CopyXClipboard (USTRING* buffer, View view)
-#else  /* __STDC__ */
-static int          CopyXClipboard (buffer, view)
-USTRING*            buffer;
-View                view;
-#endif /* __STDC__ */
+static int          CopyXClipboard (USTRING *buffer, View view)
 {
    PtrTextBuffer       clipboard;
    PtrDocument         pDoc;
@@ -790,8 +892,10 @@ View                view;
    int                 k, lg, maxLength;
    int                 firstChar, lastChar;
    int                 v;
+   ThotBool            inAttr;
 
    j = 0;
+   inAttr = FALSE;
    /* Recupere la selection courante */
    if (!GetCurrentSelection (&pDoc, &pFirstEl, &pLastEl, &firstChar, &lastChar))
       /* Rien a copier */
@@ -804,7 +908,8 @@ View                view;
 
    /* Calcule la longueur du Xbuffer a produire */
    if (pFirstEl == pLastEl)
-      maxLength = lastChar - firstChar;		/* un seul element */
+     /* only one element */
+      maxLength = lastChar - firstChar;
    else
      {
 	maxLength = pFirstEl->ElVolume - firstChar;	/* volume 1er element */
@@ -830,34 +935,44 @@ View                view;
 	  }
      }
 
-   if (maxLength == 0)
-      /* Rien a recopier */
-      return 0;
+   if (pDoc == DocSelectedAttr)
+     {
+       /* Selection is within an attribute */
+       firstChar = FirstSelectedCharInAttr;
+       lastChar = LastSelectedCharInAttr;
+       maxLength = LastSelectedCharInAttr - FirstSelectedCharInAttr;
+       inAttr = TRUE;
+       clipboard = AbsBoxSelectedAttr->AbText;
+     }
+   else if (maxLength == 0)
+     /* nothing selected */
+     return 0;
+   else if (pFirstEl->ElTerminal && pFirstEl->ElLeafType == LtText)
+     clipboard = pFirstEl->ElText;
+   else
+     clipboard = NULL;
 
-   /* On reserve un volant de 100 caracteres pour ajouter des CR */
+   /* Adding 100 characters for extra CR */
    max = maxLength + lg;
-   /* Alloue un Xbuffer de la longueur voulue */
+   /* Allocate the Xbuffer with the right length */
    Xbuffer = TtaAllocString (max);
 
    if (*buffer)
      TtaFreeMemory (*buffer);
    *buffer = Xbuffer;
-   /* Recopie le texte dans le Xbuffer */
+   /* Copy the text into the Xbuffer */
    i = 0;
    lg = 0;
 
-   /* note la vue concernee */
+   /* get the current view */
    if (view > 100)
      v = 0;
    else
      v = view - 1;
 
-   pEl = pFirstEl;
    /* Teste si le premier element est de type texte */
-   if (pEl->ElTerminal && pEl->ElLeafType == LtText)
+   if (clipboard)
      {
-	clipboard = pEl->ElText;
-
 	/* On saute les firstChar premiers caracteres */
 	k = 0;
 	j = clipboard->BuLength;
@@ -900,6 +1015,7 @@ View                view;
 
    /* Recopie le texte des elements suivants */
    pOldBlock = NULL;
+   pEl = pFirstEl;
    while (pEl != NULL)
      {
 	pEl = FwdSearchTypedElem (pEl, CharString + 1, NULL);
@@ -918,7 +1034,7 @@ View                view;
                   pBlock = SearchEnclosingType (pEl->ElAbstractBox[v], BoBlock);
 		  if (i != 0 && pBlock != pOldBlock && pOldBlock != NULL)
 		     /* Ajoute un \n en fin d'element */
-		     ustrcpy (&Xbuffer[i++], TEXT("\n\n"));
+		     ustrcpy (&Xbuffer[i++], "\n\n");
 
 		  /* Recopie le texte de l'element */
 		  pOldBlock = pBlock;
@@ -943,29 +1059,21 @@ View                view;
 }
 
 /*----------------------------------------------------------------------
-   TtcCopyToClipboard                                              
+   TtcCopyToClipboard
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-void                TtcCopyToClipboard (Document document, View view)
-#else  /* __STDC__ */
-void                TtcCopyToClipboard (document, view)
-Document            document;
-View                view;
-#endif
+void TtcCopyToClipboard (Document doc, View view)
 {
-#  ifdef _WINDOWS
-   ClipboardLength = CopyXClipboard (&Xbuffer, view);
-#  else /* _WINDOWS */
-   int                 frame;
-
-   ThotWindow          w, wind;
+#ifndef _WINDOWS
+#ifndef _GTK
+   int                  frame;
+   ThotWindow           w, wind;
    XSelectionClearEvent clear;
 
    /* Signale que l'on prend la selection */
-   if (document == 0)
+   if (doc == 0)
       frame = (int)FrRef[0];
    else
-      frame = GetWindowNumber (document, view);
+      frame = GetWindowNumber (doc, view);
 
    /* Signale que l'on prend la selection */
    w = XGetSelectionOwner (TtDisplay, XA_PRIMARY);
@@ -983,13 +1091,134 @@ View                view;
      {
 	XSetSelectionOwner (TtDisplay, XA_PRIMARY, wind, CurrentTime);
 	w = XGetSelectionOwner (TtDisplay, XA_PRIMARY);
-	if (w != wind)
-	   TtaDisplaySimpleMessage (INFO, LIB, TMSG_X_BUF_UNMODIFIED);
      }
 
+#endif /* !_GTK */
+#endif /* _WINDOWS */
    /* Recopie la selection courante */
    ClipboardLength = CopyXClipboard (&Xbuffer, view);
+#ifndef _WINDOWS
+#ifndef _GTK
    /* Annule le cutbuffer courant */
    XStoreBuffer (TtDisplay, Xbuffer, ClipboardLength, 0);
-#  endif /* _WINDOWS */
+#else /* _GTK */
+   /* dont exist in GTK1.2*/
+   /*gtk_clipboard_set_text (gtk_clipboard_get (GDK_NONE), Xbuffer, ClipboardLength);*/
+   /*   printf("le clipboard vaut: %s\n",Xbuffer);*/
+   /* Il faut placer ici la commande de copie du cliboard ans le cliboard XWindows */
+
+#endif /* !_GTK */
+#endif /* _WINDOWS */
 }
+
+
+/*----------------------------------------------------------------------
+  SelectCurrentWord
+  selects the word at the current position.
+  The current position is given by the current box, the current buffer
+  and the index in the buffer.
+  ----------------------------------------------------------------------*/
+void SelectCurrentWord (int frame, PtrBox pBox, int pos, int index,
+			PtrTextBuffer pBuffer, ThotBool inClipboard)
+{
+  PtrTextBuffer       buffer;
+  PtrDocument         pDoc;
+  PtrAbstractBox      pAb;
+  UCHAR_T              c;
+  int                 first, last;
+  int                 doc, i;
+  ThotBool            isSep;
+
+  doc = FrameTable[frame].FrDoc;
+  pAb = pBox->BxAbstractBox;
+  if (frame >= 1 && doc > 0 && index > 0)
+    {
+      /* check if a leaf box is selected */
+      index--;
+      c = pBuffer->BuContent[index];
+      if (c != WC_SPACE && c != WC_EOS)
+	{
+	  /* look for the beginning of the word */
+	  buffer = pBuffer;
+	  first = pos;
+	  i = index;
+	  c = PreviousCharacter (&buffer, &i);
+	  isSep = IsSeparatorChar (c);
+	  while (first > 1 && !isSep && c != WC_EOS)
+	    {
+	      first--;
+	      c = PreviousCharacter (&buffer, &i);
+	      isSep = IsSeparatorChar (c);
+	    }
+	  /* look for the beginning of the word */
+	  buffer = pBuffer;
+	  last = pos;
+	  i = index - 1;
+	  c = NextCharacter (&buffer, &i);
+	  isSep = IsSeparatorChar (c);
+	  while (!isSep && c != WC_EOS)
+	    {
+	      last++;
+	      c = NextCharacter (&buffer, &i);
+	      isSep = IsSeparatorChar (c);
+	    }
+	  if (isSep)
+	    last--;
+	  pDoc = LoadedDocument[doc - 1];
+	  SelectString (pDoc, pAb->AbElement, first, last);
+	  if (inClipboard)
+	    ClipboardLength = CopyXClipboard (&Xbuffer, pAb->AbDocView);
+	}
+    }
+}
+
+/*----------------------------------------------------------------------
+  TtaSelectWord selects the word around the current point in an element
+  ----------------------------------------------------------------------*/
+void TtaSelectWord (Element element, int pos, Document doc, View view)
+{
+  PtrElement       pEl = (PtrElement)element;
+  PtrAbstractBox   pAb;
+  PtrBox           pBox;
+  PtrTextBuffer    pBuffer;
+  int              v, index;
+  int              frame, i;
+
+  if (pEl->ElTerminal && pEl->ElLeafType == LtText)
+    {
+      /* get the abstract box of the element */
+      if (view > 100)
+	v = 0;
+      else
+	v = view - 1;
+      pAb = pEl->ElAbstractBox[v];
+      if (pAb && pAb->AbBox)
+	{
+	  /* look for the box, the buffer and the index in the buffer */
+	  pBox = pAb->AbBox;
+	  i = pos;
+	  if (pBox->BxType == BoSplit)
+	    {
+	      pBox = pBox->BxNexChild;
+	      while (pBox && pBox->BxNChars < i && pBox->BxNexChild)
+		{
+		  i = i - pBox->BxNChars;
+		  /* remove the delta between two boxes */
+		  i = i - pBox->BxNexChild->BxIndChar + pBox->BxNChars + pBox->BxIndChar;
+		  pBox = pBox->BxNexChild;
+		}
+	    }
+	  pBuffer = pBox->BxBuffer;
+	  index =  pBox->BxFirstChar;
+	  while (i > pBuffer->BuLength - index + 1)
+	    {
+	      i = i - pBuffer->BuLength + index - 1;
+	      index = 1;
+	      pBuffer = pBuffer->BuNext;
+	    }
+	  frame = GetWindowNumber (doc, view);
+	  SelectCurrentWord (frame, pBox, pos, i, pBuffer, FALSE);
+	}
+    }
+}
+
