@@ -1,6 +1,6 @@
 /*
  *
- *  (c) COPYRIGHT INRIA, 1996.
+ *  (c) COPYRIGHT INRIA, 1996-2001
  *  Please first read the full copyright statement in file COPYRIGHT.
  *
  */
@@ -14,10 +14,7 @@
  */
 
 #define C_PIV_ATTR 1		/* attribute mark */
-#define C_PIV_ASSOC 2		/* associated element mark */
-#define C_PIV_OLD_COMMENT 3	/* old comment mark */	
 #define C_PIV_BEGIN 4		/* contents beginning mark */
-#define C_PIV_COMMENT 5		/* comment mark */
 #define C_PIV_END 6		/* contents ending mark */	
 #define C_PIV_PRESENT 7		/* presentation rule mark */
 #define C_PIV_LANG 8		/* language mark */
@@ -28,7 +25,6 @@
 #define C_PIV_LONG_LABEL 13	/* long (4-byte) numerical label mark */
 #define C_PIV_NATURE 14		/* nature mark */
 #define C_PIV_DOCNAME 15	/* document name mark */
-#define C_PIV_PARAM 16		/* parameter mark */
 #define C_PIV_REFERRED 17	/* referenced element mark */
 #define C_PIV_REFERENCE 18	/* reference mark */
 #define C_PIV_STRUCTURE 19	/* element mark */
@@ -36,6 +32,7 @@
 #define C_PIV_VERSION 22	/* version mark */
 #define C_PIV_HOLOPHRAST 23	/* holophrasted element mark */
 #define C_PIV_POLYLINE 24	/* polyline mark */
+#define C_PIV_PATH 25		/* graphics path mark */
 #define C_PIV_DOC_END 26	/* document ending mark */
 
 /* specific presentation rule type codes */
@@ -48,7 +45,6 @@
 #define C_PR_FONT 'F'
 #define C_PR_HEIGHT 'H'
 #define C_PR_LINESPACING 'I'
-#define C_PR_JUSTIFY 'J'
 #define C_PR_WIDTH 'L'
 #define C_PR_XRADIUS 'M'
 #define C_PR_YRADIUS 'N'
@@ -101,6 +97,7 @@
 #define C_PIV_RIGHT 'D'
 #define C_PIV_LEFT 'G'
 #define C_PIV_LEFTDOT 'P'
+#define C_PIV_JUSTIFY 'J'
 
 /* dimension types codes */
 #define C_PIV_ABSOLUTE 'A'
