@@ -1,6 +1,6 @@
 /*
  *
- *  (c) COPYRIGHT INRIA, 1996.
+ *  (c) COPYRIGHT INRIA, 1996-2001.
  *  Please first read the full copyright statement in file COPYRIGHT.
  *
  */
@@ -74,29 +74,32 @@
 #define ExcReturnCreateWithin 38
 
 /* Draw exceptions */
+#define ExcSelectParent 310
 #define ExcHighlightChildren 311
 #define ExcExtendedSelection 312
-#define ExcIsDraw 313
-#define ExcMoveResize 314
-#define ExcNoShowBox 315
+#define ExcClickableSurface 313
+#define ExcIsDraw 314
+#define ExcMoveResize 315
+#define ExcNoShowBox 316
 
 /* Table exceptions */
-#define ExcIsTable 316
-#define ExcIsRow 317
-#define ExcIsColHead 318
-#define ExcIsCell 319
-#define ExcNewPercentWidth 320
-#define ExcColRef 321
-#define ExcColSpan 322
-#define ExcRowSpan 323
-#define ExcShadow 324
-#define ExcEventAttr 325
+#define ExcIsTable 320
+#define ExcIsRow 321
+#define ExcIsColHead 322
+#define ExcIsCell 323
+#define ExcNewPercentWidth 324
+#define ExcColRef 325
+#define ExcColSpan 326
+#define ExcRowSpan 327
+#define ExcShadow 328
+#define ExcEventAttr 329
 
 /* CSS exceptions */
 #define ExcCssBackground 340
 #define ExcCssClass 341
 #define ExcCssId 342
 #define ExcCssPseudoClass 343
+
 /* SpellCheck exception */
 #define ExcNoSpellCheck 400
 
@@ -123,6 +126,9 @@
 #define C_NATURE_CONSTR 'X'
 #define C_PAIR_CONSTR 'P'
 #define C_EXTENS_CONSTR 'E'
+#define C_DOCUMENT_CONSTR 'D'
+#define C_ANY_CONSTR 'a'
+#define C_EMPTY_CONSTR 'e'
 
 /* base type coding */
 #define C_CHAR_STRING 'C'
@@ -134,3 +140,5 @@
 #define C_UNUSED 'U'
 
 #endif /* __CONST_STR_H__ */
+
+
