@@ -1,19 +1,10 @@
 /*
  *
- *  (c) COPYRIGHT INRIA, 1996.
+ *  (c) COPYRIGHT INRIA, 1996-2001
  *  Please first read the full copyright statement in file COPYRIGHT.
  *
  */
 
-/*
- * Warning:
- * This module is part of the Thot library, which was originally
- * developed in French. That's why some comments are still in
- * French, but their translation is in progress and the full module
- * will be available in English in the next release.
- * 
- */
- 
 /*
  * Manage box selections
  *
@@ -46,6 +37,7 @@
 #include "buildboxes_f.h"
 #include "displayselect_f.h"
 #include "editcommands_f.h"
+#include "exceptions_f.h"
 #include "font_f.h"
 #include "frame_f.h"
 #include "memory_f.h"
@@ -58,13 +50,7 @@
    ClearAbstractBoxSelection parcours l'arborescence pour annuler  
    toutes ls selections de pave.                           
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 static void         ClearAbstractBoxSelection (PtrAbstractBox pAb)
-#else  /* __STDC__ */
-static void         ClearAbstractBoxSelection (pAb)
-PtrAbstractBox      pAb;
-
-#endif /* __STDC__ */
 {
    PtrAbstractBox      pChildAb;
    PtrAbstractBox      pAbbox1;
@@ -91,13 +77,7 @@ PtrAbstractBox      pAb;
 /*----------------------------------------------------------------------
    ClearViewSelMarks annule la selection courante dans la fenetre.   
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 void                ClearViewSelMarks (int frame)
-#else  /* __STDC__ */
-void                ClearViewSelMarks (frame)
-int                 frame;
-
-#endif /* __STDC__ */
 {
    ViewFrame          *pFrame;
 
@@ -116,13 +96,7 @@ int                 frame;
    ClearViewSelection bascule et annule la mise en evidence de la   
    selection dans la fenetre.                              
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 void                ClearViewSelection (int frame)
-#else  /* __STDC__ */
-void                ClearViewSelection (frame)
-int                 frame;
-
-#endif /* __STDC__ */
 {
    ViewFrame          *pFrame;
    PtrBox              pBox, pBox1, pBox2;
@@ -145,135 +119,139 @@ int                 frame;
 	    pFrame->FrSelectionBegin.VsBox = NULL;
 	    pFrame->FrSelectionEnd.VsBox = NULL;
 
-	    if ( pFrame->FrClipXBegin == 0 && pFrame->FrClipXEnd == 0)
+	    /* ready to un/display the current selection */
+	    if (pBox1 == pBox2)
 	      {
-		/* ready to un/display the current selection */
-		if (pBox1 == pBox2)
-		  {
-		    /* only one box is selected */
-		    if (pBox1->BxType == BoGhost)
-		      /* the highlight is transmitted to children */
-		      DrawBoxSelection (frame, pBox1);
-		    else
-		      {
-			if (pFrame->FrSelectionBegin.VsIndBox == 0 ||
-			    pAb1->AbLeafType == LtPolyLine)
-			  {
-			    /* the whole box is selected */
-			    x1 = pBox1->BxXOrg;
-			    x2 = pBox1->BxXOrg + pBox1->BxWidth;
-			  }
-			else
-			  {
-			    x1 = pBox1->BxXOrg + pFrame->FrSelectionBegin.VsXPos;
-			    x2 = pBox1->BxXOrg + pFrame->FrSelectionEnd.VsXPos;
-			  }
-			if (x1 == x2)
-			  /* removing the caret at the end of a text */
-			  x2 = x1 + 2;
-			DefClip (frame, x1, pBox1->BxYOrg, x2, pBox1->BxYOrg + pBox1->BxHeight);
-			/* undisplay the current selection */
-			if (pAb1->AbLeafType == LtGraphics || pAb1->AbLeafType == LtPolyLine)
-			  /* need to redraw more than one box */
-			  RedrawFrameBottom (frame, 0, NULL);
-			else
-			  RedrawFrameBottom (frame, 0, pAb1);
-		      }
-		  }
-		else if (pAb1 == pAb2)
-		  {
-		    /* several pieces of a split box are selected */
-		    /* the first one */
-		    x1 = pBox1->BxXOrg + pFrame->FrSelectionBegin.VsXPos;
-		    x2 = pBox1->BxXOrg + pBox1->BxWidth;
-		    DefClip (frame, x1, pBox1->BxYOrg, x2, pBox1->BxYOrg + pBox1->BxHeight);
-		    RedrawFrameBottom (frame, 0, pAb1);
-		    /* intermediate boxes */
-		    pBox1 = pBox1->BxNexChild;
-		    while (pBox1 != pBox2)
-		      {
-			DefClip (frame, pBox1->BxXOrg, pBox1->BxYOrg, pBox1->BxXOrg + pBox1->BxWidth, pBox1->BxYOrg + pBox1->BxHeight);
-			RedrawFrameBottom (frame, 0, pAb1);
-			pBox1 = pBox1->BxNexChild;
-		      }
-		    /* the last one */
-		    x1 = pBox2->BxXOrg;
-		    x2 = pBox2->BxXOrg + pFrame->FrSelectionEnd.VsXPos;
-		    DefClip (frame, x1, pBox2->BxYOrg, x2, pBox2->BxYOrg + pBox2->BxHeight);
-		    /* undisplay the current selection */
-		    RedrawFrameBottom (frame, 0, pAb1);
-		  }
+		/* only one box is selected */
+		if (pBox1->BxType == BoGhost ||
+		    (pAb1 != NULL && pAb1->AbElement != NULL &&
+		     FrameTable[frame].FrView == 1 &&
+		     TypeHasException (ExcHighlightChildren,
+				       pAb1->AbElement->ElTypeNumber,
+				       pAb1->AbElement->ElStructSchema)))
+		  /* the highlight is transmitted to children */
+		  DrawBoxSelection (frame, pBox1);
 		else
 		  {
-		    /* undisplay the beginning of the selection */
-		    if (pBox1->BxType == BoGhost)
-		      /* the highlight is transmitted to children */
-		      DrawBoxSelection (frame, pBox1);
+		    if (pFrame->FrSelectionBegin.VsIndBox == 0 ||
+			pAb1->AbLeafType == LtPolyLine ||
+			pAb1->AbLeafType == LtPath)
+		      {
+			/* the whole box is selected */
+			x1 = pBox1->BxXOrg;
+			x2 = pBox1->BxXOrg + pBox1->BxWidth;
+		      }
 		    else
 		      {
-			if (pFrame->FrSelectionBegin.VsIndBox == 0)
+			x1 = pBox1->BxXOrg + pFrame->FrSelectionBegin.VsXPos;
+			x2 = pBox1->BxXOrg + pFrame->FrSelectionEnd.VsXPos;
+		      }
+		    if (x1 == x2)
+		      /* removing the caret at the end of a text */
+		      x2 = x1 + 2;
+		    DefClip (frame, x1, pBox1->BxYOrg, x2,
+			     pBox1->BxYOrg + pBox1->BxHeight);
+		  }
+	      }
+	    else if (pAb1 == pAb2)
+	      {
+		/* several pieces of a split box are selected */
+		/* the first one */
+		x1 = pBox1->BxXOrg + pFrame->FrSelectionBegin.VsXPos;
+		x2 = pBox1->BxXOrg + pBox1->BxWidth;
+		DefClip (frame, x1, pBox1->BxYOrg, x2,
+			 pBox1->BxYOrg + pBox1->BxHeight);
+		/* intermediate boxes */
+		pBox1 = pBox1->BxNexChild;
+		while (pBox1 != pBox2)
+		  {
+		    DefClip (frame, pBox1->BxXOrg, pBox1->BxYOrg,
+			     pBox1->BxXOrg + pBox1->BxWidth,
+			     pBox1->BxYOrg + pBox1->BxHeight);
+		    pBox1 = pBox1->BxNexChild;
+		  }
+		/* the last one */
+		x1 = pBox2->BxXOrg;
+		x2 = pBox2->BxXOrg + pFrame->FrSelectionEnd.VsXPos;
+		DefClip (frame, x1, pBox2->BxYOrg, x2,
+			 pBox2->BxYOrg + pBox2->BxHeight);
+	      }
+	    else
+	      {
+		/* undisplay the beginning of the selection */
+		if (pBox1->BxType == BoGhost ||
+		    (pAb1 != NULL &&
+		     FrameTable[frame].FrView == 1 &&
+		     TypeHasException (ExcHighlightChildren,
+				       pAb1->AbElement->ElTypeNumber,
+				       pAb1->AbElement->ElStructSchema)))
+		  /* the highlight is transmitted to children */
+		  DrawBoxSelection (frame, pBox1);
+		else
+		  {
+		    if (pFrame->FrSelectionBegin.VsIndBox == 0)
+		      {
+			/* the whole box is selected */
+			x1 = pBox1->BxXOrg;
+			x2 = pBox1->BxXOrg + pBox1->BxWidth;
+		      }
+		    else
+		      {
+			x1 = pBox1->BxXOrg + pFrame->FrSelectionBegin.VsXPos;
+			x2 = pBox1->BxXOrg + pBox1->BxWidth;
+		      }
+		    DefClip (frame, x1, pBox1->BxYOrg, x2,
+			     pBox1->BxYOrg + pBox1->BxHeight);
+		    if (pBox1->BxType == BoPiece ||
+			pBox1->BxType == BoDotted)
+		      {
+			/* unselect the end of the split text */
+			pBox = pBox1->BxNexChild;
+			while (pBox)
 			  {
-			    /* the whole box is selected */
-			    x1 = pBox1->BxXOrg;
-			    x2 = pBox1->BxXOrg + pBox1->BxWidth;
-			  }
-			else
-			  {
-			    x1 = pBox1->BxXOrg + pFrame->FrSelectionBegin.VsXPos;
-			    x2 = pBox1->BxXOrg + pBox1->BxWidth;
-			  }
-			DefClip (frame, x1, pBox1->BxYOrg, x2, pBox1->BxYOrg + pBox1->BxHeight);
-			if (pAb1->AbLeafType == LtGraphics || pAb1->AbLeafType == LtPolyLine)
-			  /* need to redraw more thsn one box */
-			  RedrawFrameBottom (frame, 0, NULL);
-			else
-			  RedrawFrameBottom (frame, 0, pAb1);
-			if (pBox1->BxType == BoPiece)
-			  {
-			    /* unselect the end of the split text */
-			    pBox = pBox1->BxNexChild;
-			    while (pBox)
-			      {
-				DefClip (frame, pBox->BxXOrg, pBox->BxYOrg, pBox->BxXOrg + pBox->BxWidth, pBox->BxYOrg + pBox->BxHeight);
-				RedrawFrameBottom (frame, 0, pAb1);
-				pBox = pBox->BxNexChild;
-			      }
+			    DefClip (frame, pBox->BxXOrg, pBox->BxYOrg,
+				     pBox->BxXOrg + pBox->BxWidth,
+				     pBox->BxYOrg + pBox->BxHeight);
+			    pBox = pBox->BxNexChild;
 			  }
 		      }
+		  }
 		
-		    /* undisplay the end of the selection */
-		    if (pBox2->BxType == BoGhost)
-		      /* the highlight is transmitted to children */
-		      DrawBoxSelection (frame, pBox2);
+		/* undisplay the end of the selection */
+		if (pBox2->BxType == BoGhost ||
+		    (pAb2 != NULL &&
+		     FrameTable[frame].FrView == 1 &&
+		     TypeHasException (ExcHighlightChildren,
+				       pAb2->AbElement->ElTypeNumber,
+				       pAb2->AbElement->ElStructSchema)))
+		  /* the highlight is transmitted to children */
+		  DrawBoxSelection (frame, pBox2);
+		else
+		  {
+		    if (pFrame->FrSelectionEnd.VsIndBox == 0)
+		      {
+			/* the whole box is selected */
+			x1 = pBox2->BxXOrg;
+			x2 = pBox2->BxXOrg + pBox2->BxWidth;
+		      }
 		    else
 		      {
-			if (pFrame->FrSelectionEnd.VsIndBox == 0)
+			x1 = pBox2->BxXOrg;
+			x2 = pBox2->BxXOrg + pFrame->FrSelectionEnd.VsXPos;
+		      }
+		    DefClip (frame, x1, pBox2->BxYOrg, x2,
+			     pBox2->BxYOrg + pBox2->BxHeight);
+		    if (pBox2->BxType == BoPiece ||
+			pBox1->BxType == BoDotted)
+		      {
+			/* select the begin of the split text */
+			pBox =  pAb2->AbBox->BxNexChild;
+			while (pBox && pBox != pBox2)
 			  {
-			    /* the whole box is selected */
-			    x1 = pBox2->BxXOrg;
-			    x2 = pBox2->BxXOrg + pBox2->BxWidth;
-			  }
-			else
-			  {
-			    x1 = pBox2->BxXOrg;
-			    x2 = pBox2->BxXOrg + pFrame->FrSelectionEnd.VsXPos;
-			  }
-			DefClip (frame, x1, pBox2->BxYOrg, x2, pBox2->BxYOrg + pBox2->BxHeight);
-			if (pAb2->AbLeafType == LtGraphics || pAb2->AbLeafType == LtPolyLine)
-			  /* need to redraw more than one box */
-			  RedrawFrameBottom (frame, 0, NULL);
-			else
-			  RedrawFrameBottom (frame, 0, pAb2);
-			if (pBox2->BxType == BoPiece)
-			  {
-			    /* select the begin of the split text */
-			    pBox = pAb2->AbBox->BxNexChild;
-			    while (pBox != pBox2)
-			      {
-				DefClip (frame, pBox->BxXOrg, pBox->BxYOrg, pBox->BxXOrg + pBox->BxWidth, pBox->BxYOrg + pBox->BxHeight);
-				RedrawFrameBottom (frame, 0, pAb2);
-				pBox = pBox->BxNexChild;
-			      }
+			    DefClip (frame, pBox->BxXOrg, pBox->BxYOrg,
+				     pBox->BxXOrg + pBox->BxWidth,
+				     pBox->BxYOrg + pBox->BxHeight);
+			    pBox = pBox->BxNexChild;
 			  }
 		      }
 		  }
@@ -291,25 +269,19 @@ void                TtaClearViewSelections ()
    int                 frame;
 
    /* manage all frames */
-   for (frame = 0; frame < MAX_FRAME; frame++)
-      if (ViewFrameTable[frame].FrAbstractBox != NULL)
-	 ClearViewSelection (frame + 1);
+   for (frame = 1; frame <= MAX_FRAME; frame++)
+      if (ViewFrameTable[frame - 1].FrAbstractBox != NULL)
+	{
+	  ClearViewSelection (frame);
+	  DisplayFrame (frame);
+	}
 }
 
 /*----------------------------------------------------------------------
    UpdateViewSelMarks met a jour les marques de selection de frame   
    apres insertion ou destruction de caracteres.           
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-void                UpdateViewSelMarks (int frame, int xDelta, int spaceDelta, int charDelta)
-#else  /* __STDC__ */
-void                UpdateViewSelMarks (frame, xDelta, spaceDelta, charDelta)
-int                 frame;
-int                 xDelta;
-int                 spaceDelta;
-int                 charDelta;
-
-#endif /* __STDC__ */
+void    UpdateViewSelMarks (int frame, int xDelta, int spaceDelta, int charDelta)
 {
    ViewFrame          *pFrame;
    ViewSelection      *pViewSel;
@@ -333,14 +305,7 @@ int                 charDelta;
    Detruit le buffer donne en parametre, met a jour les marques de 
    selection et rend le pointeur sur le buffer precedent.          
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 PtrTextBuffer       DeleteBuffer (PtrTextBuffer pBuffer, int frame)
-#else  /* __STDC__ */
-PtrTextBuffer       DeleteBuffer (pBuffer, frame)
-PtrTextBuffer       pBuffer;
-int                 frame;
-
-#endif /* __STDC__ */
 {
    PtrTextBuffer       pNextBuffer;
    PtrTextBuffer       pPreviousBuffer;
@@ -407,37 +372,30 @@ int                 frame;
    celui qui contient le caractere d'indice global index   
    ainsi que son indice dans ce buffer.                    
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 static void         LocateBuffer (PtrTextBuffer * pBuffer, int *index)
-#else  /* __STDC__ */
-static void         LocateBuffer (pBuffer, index)
-PtrTextBuffer      *pBuffer;
-int                *index;
-
-#endif /* __STDC__ */
 {
    ThotBool            still;
 
    still = (*pBuffer != NULL);
    while (still)
      {
-	/* Est-ce le bon buffer ? */
-	if ((*pBuffer)->BuLength < *index)
-	   /* Non : il faut passer au buffer suivant */
-	   if ((*pBuffer)->BuNext == NULL)
-	     {
-		/* arrive en fin de liste de buffers sans trouver le caractere */
-		*index = (*pBuffer)->BuLength + 1;
-		still = FALSE;
-	     }
-	   else
-	      /* passe au buffer suivant */
-	     {
-		*index -= (*pBuffer)->BuLength;
-		*pBuffer = (*pBuffer)->BuNext;
-	     }
-	else
-	   still = FALSE;
+       /* Est-ce le bon buffer ? */
+       if ((*pBuffer)->BuLength < *index)
+	 /* Non : il faut passer au buffer suivant */
+	 if ((*pBuffer)->BuNext == NULL)
+	   {
+	     /* arrive en fin de liste de buffers sans trouver le caractere */
+	     *index = (*pBuffer)->BuLength + 1;
+	     still = FALSE;
+	   }
+	 else
+	   /* passe au buffer suivant */
+	   {
+	     *index -= (*pBuffer)->BuLength;
+	     *pBuffer = (*pBuffer)->BuNext;
+	   }
+       else
+	 still = FALSE;
      }
 }
 
@@ -449,133 +407,131 @@ int                *index;
    le precedant VsNSpaces, la position dans la boite VsXPos
    et la ligne contenant la boite VsLine.                  
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-void                ComputeViewSelMarks (ViewSelection * selMark)
-#else  /* __STDC__ */
-void                ComputeViewSelMarks (selMark)
-ViewSelection      *selMark;
-
-#endif /* __STDC__ */
+void                ComputeViewSelMarks (ViewSelection *selMark)
 {
-   PtrTextBuffer       pBuffer;
-   PtrTextBuffer       pSelBuffer;
-   PtrBox              pBox;
-   int                 beginInd, x;
-   int                 spaceWidth;
-   int                 max, i;
-   int                 dummy;
-   ThotBool            stop;
+  PtrTextBuffer       pBuffer;
+  PtrTextBuffer       pSelBuffer;
+  PtrBox              pBox;
+  int                 beginInd, x;
+  int                 spaceWidth;
+  int                 max, i;
+  int                 dummy;
+  ThotBool            stop;
 
-   if (selMark->VsBox->BxAbstractBox->AbLeafType == LtText)
-     {
-	/* note l'index et le buffer du caractere precedant la marque */
-	pSelBuffer = selMark->VsBuffer;
-	pBox = selMark->VsBox;
-	if (selMark->VsIndBuf == 1 && pSelBuffer != pBox->BxBuffer)
+  if (selMark->VsBox->BxAbstractBox->AbLeafType == LtText)
+    {
+      /* note l'index et le buffer du caractere precedant la marque */
+      pSelBuffer = selMark->VsBuffer;
+      pBox = selMark->VsBox;
+      if (selMark->VsIndBuf == 1 && pSelBuffer != pBox->BxBuffer)
+	{
+	  if (pSelBuffer->BuPrevious == NULL)
+	    pSelBuffer = pBox->BxBuffer;
+	  else
+	    /* En debut de buffer */
+	    pSelBuffer = pSelBuffer->BuPrevious;
+	  i = pSelBuffer->BuLength;
+	}
+      else
+	/* En fin ou en cours de buffer */
+	i = selMark->VsIndBuf - 1;
+      stop = FALSE;
+
+      /* Est-ce une boite coupee ? */
+      if (pBox->BxType == BoSplit)
+	pBox = pBox->BxNexChild;
+
+      /* Recherche l'index du caractere et la boite de coupure */
+      pBuffer = pBox->BxBuffer;
+      beginInd = 1 - pBox->BxFirstChar;
+      max = pBox->BxNChars;
+      /* Calcule le saut entre cette boite et la suivante pour */
+      /* determiner si on peut selectionner en fin de boite */
+      if (pBox->BxNexChild == NULL)
+	dummy = 0;
+      else
+	dummy = pBox->BxNexChild->BxIndChar - pBox->BxIndChar - pBox->BxNChars;
+
+      /* Boucle tant que le caractere designe se trouve dans */
+      /* le buffer suivant ou dans la boite suivante */
+      while (!stop && (pBuffer != pSelBuffer || max - beginInd + dummy <= i))
+	if (max - beginInd + dummy <= i || pBuffer == NULL)
 	  {
-	     if (pSelBuffer->BuPrevious == NULL)
-		pSelBuffer = pBox->BxBuffer;
-	     else
-		/* En debut de buffer */
-		pSelBuffer = pSelBuffer->BuPrevious;
-	     i = pSelBuffer->BuLength;
-	  }
-	else
-	   /* En fin ou en cours de buffer */
-	   i = selMark->VsIndBuf - 1;
-	stop = FALSE;
+	    /* Box de coupure GetNextBox */
+	    /* Cas particulier des blancs supprimes en fin de boite */
+	    /* Est-ce qu'il y a une boite apres ? */
+	    if (pBox->BxNexChild == NULL)
+	      stop = TRUE;
+	    /* Il existe une boite apres mais c'est une boite fantome */
+	    else if (pBox->BxNexChild->BxNChars == 0 &&
+		     SearchLine (pBox->BxNexChild) == NULL)
+	      stop = TRUE;
+	    else
+	      stop = FALSE;
 
-	/* Est-ce une boite coupee ? */
-	if (pBox->BxType == BoSplit)
-	   pBox = pBox->BxNexChild;
-
-	/* Recherche l'index du caractere et la boite de coupure */
-	pBuffer = pBox->BxBuffer;
-	beginInd = 1 - pBox->BxFirstChar;
-	max = pBox->BxNChars;
-	/* Calcule le saut entre cette boite et la suivante pour */
-	/* determiner si on peut selectionner en fin de boite */
-	if (pBox->BxNexChild == NULL)
-	   dummy = 0;
-	else
-	   dummy = pBox->BxNexChild->BxIndChar - pBox->BxIndChar - pBox->BxNChars;
-
-	/* Boucle tant que le caractere designe se trouve dans */
-	/* le buffer suivant ou dans la boite suivante */
-	while (!stop && (pBuffer != pSelBuffer || max - beginInd + dummy <= i))
-	   if (max - beginInd + dummy <= i || pBuffer == NULL)
-	     {
-		/* Box de coupure GetNextBox */
-		/* Cas particulier des blancs supprimes en fin de boite */
-		/* Est-ce qu'il y a une boite apres ? */
+	    /* Est-ce que la selection est en fin de boite ? */
+	    if (stop)
+	      {
+		dummy = i - max + beginInd;
+		/* Position dans les blancs de fin de ligne */
+		selMark->VsIndBox = pBox->BxNChars + dummy;
+		selMark->VsXPos = pBox->BxLMargin + pBox->BxLBorder + pBox->BxLPadding + pBox->BxW;
+		selMark->VsNSpaces = pBox->BxNSpaces + dummy;
+	      }
+	    /* Sinon on passe a la boite suivante */
+	    else
+	      {
+		pBox = pBox->BxNexChild;
+		beginInd = 1 - pBox->BxFirstChar;
+		max = pBox->BxNChars;
+		pBuffer = pBox->BxBuffer;
+		/* Calcule le saut entre cette boite et la suivante pour */
+		/* determiner si on peut selectionner en fin de boite */
 		if (pBox->BxNexChild == NULL)
-		   stop = TRUE;
-		/* Il existe une boite apres mais c'est une boite fantome */
-		else if (pBox->BxNexChild->BxNChars == 0 && SearchLine (pBox->BxNexChild) == NULL)
-		   stop = TRUE;
+		  dummy = 0;
 		else
-		   stop = FALSE;
-
-		/* Est-ce que la selection est en fin de boite ? */
-		if (stop)
+		  dummy = pBox->BxNexChild->BxIndChar - pBox->BxIndChar - pBox->BxNChars;
+		/* Cas particulier du premier caractere d'une boite coupee */
+		if (pSelBuffer == pBuffer->BuPrevious)
 		  {
-		     dummy = i - max + beginInd;
-		     /* Position dans les blancs de fin de ligne */
-		     selMark->VsIndBox = pBox->BxNChars + dummy;
-		     selMark->VsXPos = pBox->BxWidth;
-		     selMark->VsNSpaces = pBox->BxNSpaces + dummy;
+		    selMark->VsIndBox = 0;
+		    selMark->VsXPos = 0;
+		    selMark->VsNSpaces = 0;
+		    stop = TRUE;
 		  }
-		/* Sinon on passe a la boite suivante */
-		else
-		  {
-		     pBox = pBox->BxNexChild;
-		     beginInd = 1 - pBox->BxFirstChar;
-		     max = pBox->BxNChars;
-		     pBuffer = pBox->BxBuffer;
-		     /* Calcule le saut entre cette boite et la suivante pour */
-		     /* determiner si on peut selectionner en fin de boite */
-		     if (pBox->BxNexChild == NULL)
-			dummy = 0;
-		     else
-			dummy = pBox->BxNexChild->BxIndChar - pBox->BxIndChar - pBox->BxNChars;
-		     /* Cas particulier du premier caractere d'une boite coupee */
-		     if (pSelBuffer == pBuffer->BuPrevious)
-		       {
-			  selMark->VsIndBox = 0;
-			  selMark->VsXPos = 0;
-			  selMark->VsNSpaces = 0;
-			  stop = TRUE;
-		       }
-		  }
-	     }
-	   else
-	     {
-		beginInd += pBuffer->BuLength;
-		pBuffer = pBuffer->BuNext;
-	     }
-
-	/* a trouve la boite de coupure */
-	if (!stop)
-	  {
-	     selMark->VsIndBox = beginInd + i;
-	     /* Reevaluation du decalage dans la boite */
-	     /* 0 si on prend la largeur reelle du blanc */
-	     spaceWidth = pBox->BxSpaceWidth;
-	     /* Index du premier caractere a traiter */
-	     x = pBox->BxFirstChar;
-	     GiveTextParams (pBox->BxBuffer, selMark->VsIndBox, pBox->BxFont, &x, &spaceWidth);
-	     selMark->VsXPos = x;
-	     selMark->VsNSpaces = spaceWidth;
-	     /* ajoute eventuellement les pixels repartis */
-	     if (pBox->BxSpaceWidth != 0)
-		if (selMark->VsNSpaces < pBox->BxNPixels)
-		   selMark->VsXPos += selMark->VsNSpaces;
-		else
-		   selMark->VsXPos += pBox->BxNPixels;
+	      }
 	  }
-	selMark->VsBox = pBox;
-     }
-   selMark->VsLine = SearchLine (selMark->VsBox);
+	else
+	  {
+	    beginInd += pBuffer->BuLength;
+	    pBuffer = pBuffer->BuNext;
+	  }
+
+      /* on a trouve' la boite de coupure */
+      if (!stop)
+	{
+	  selMark->VsIndBox = beginInd + i;
+	  /* Reevaluation du decalage dans la boite */
+	  /* 0 si on prend la largeur reelle du blanc */
+	  spaceWidth = pBox->BxSpaceWidth;
+	  /* Index du premier caractere a traiter */
+	  x = pBox->BxFirstChar;
+	  GiveTextParams (pBox->BxBuffer, selMark->VsIndBox, pBox->BxFont,
+			  &x, &spaceWidth);
+	  selMark->VsXPos = x + pBox->BxLMargin + pBox->BxLBorder + pBox->BxLPadding;
+	  selMark->VsNSpaces = spaceWidth;
+	  /* ajoute eventuellement les pixels repartis */
+	  if (pBox->BxSpaceWidth != 0)
+	    {
+	      if (selMark->VsNSpaces < pBox->BxNPixels)
+		selMark->VsXPos += selMark->VsNSpaces;
+	      else
+		selMark->VsXPos += pBox->BxNPixels;
+	    }
+	}
+      selMark->VsBox = pBox;
+    }
+  selMark->VsLine = SearchLine (selMark->VsBox);
 }
 
 /*----------------------------------------------------------------------
@@ -588,19 +544,9 @@ ViewSelection      *selMark;
   the last selected character.
   The parameter alone is set to TRUE when only one abstract box is selected.
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-void                InsertViewSelMarks (int frame, PtrAbstractBox pAb, int firstChar, int lastChar, ThotBool startSelection, ThotBool endSelection, ThotBool alone)
-#else  /* __STDC__ */
-void                InsertViewSelMarks (frame, pAb, firstChar, lastChar, startSelection, endSelection, alone)
-int                 frame;
-PtrAbstractBox      pAb;
-int                 firstChar;
-int                 lastChar;
-ThotBool            startSelection;
-ThotBool            endSelection;
-ThotBool            alone;
-
-#endif /* __STDC__ */
+void InsertViewSelMarks (int frame, PtrAbstractBox pAb, int firstChar,
+			 int lastChar, ThotBool startSelection,
+			 ThotBool endSelection, ThotBool alone)
 {
   PtrLine             adline;
   PtrTextBuffer       pBuffer;
@@ -622,7 +568,9 @@ ThotBool            alone;
 	  /* eteint la selection */
 	  pBox = pAb->AbBox;
 	  adline = SearchLine (pBox);
-	  graphSel = (pAb->AbLeafType == LtPolyLine || pAb->AbLeafType == LtGraphics);
+	  graphSel = (pAb->AbLeafType == LtPolyLine ||
+		      pAb->AbLeafType == LtPath ||
+		      pAb->AbLeafType == LtGraphics);
 
 	  /* verifie la coherence des indices de caracteres */
 	  if (pAb->AbLeafType == LtText)
@@ -632,9 +580,10 @@ ThotBool            alone;
 		firstChar = 1;
 	      else if (firstChar > 1 && lastChar == 0)
 		lastChar = pAb->AbVolume;
-	      else if (firstChar == 0 && pAb->AbVolume != 0)
+	      else if (startSelection &&firstChar == 0 && pAb->AbVolume != 0)
 		{
-		  firstChar = 1;	/* selection tout le texte du pave */
+		  /* select the whole text */
+		  firstChar = 1;
 		  lastChar = pAb->AbVolume;
 		}
 	    }
@@ -646,8 +595,8 @@ ThotBool            alone;
 	  /* et si elle indique seulement une position */
 	  pFrame->FrSelectOnePosition = SelPosition;
 	  
-	  /* La selection porte sur le pave complet ou un point de controle */
-	  /* de pave polyline */
+	  /* La selection porte sur le pave complet ou un point d'un path */
+	  /* ou d'une polyline */
 	  if (firstChar == 0 || pAb->AbVolume == 0 ||
 	      graphSel || pAb->AbLeafType == LtPicture)
 	    {
@@ -668,7 +617,8 @@ ThotBool            alone;
 		{
 		  pViewSel = &pFrame->FrSelectionBegin;
 		  pViewSel->VsBox = pBox;
-		  if (endSelection && !graphSel && pAb->AbLeafType != LtPicture)
+		  if (endSelection && !graphSel &&
+		      pAb->AbLeafType != LtPicture)
 		    /* tout selectionne */
 		    pViewSel->VsIndBox = 0;
 		  else
@@ -677,7 +627,7 @@ ThotBool            alone;
 		  pViewSel->VsBuffer = pBuffer;
 		  pViewSel->VsLine = adline;
 		  if (pAb->AbLeafType == LtPicture && firstChar > 0)
-		    pViewSel->VsXPos = pBox->BxWidth;
+		    pViewSel->VsXPos = pBox->BxLMargin + pBox->BxLBorder + pBox->BxLPadding + pBox->BxW;
 		  else
 		    pViewSel->VsXPos = 0;
 		  pViewSel->VsNSpaces = 0;
@@ -690,10 +640,9 @@ ThotBool            alone;
 		  pViewSel->VsIndBuf = ind;
 		  pViewSel->VsBuffer = pBuffer;
 		  pViewSel->VsLine = adline;
-		  if (pAb->AbLeafType == LtPicture && firstChar > 0)
-		    pViewSel->VsXPos = pBox->BxWidth;
-		  else if (pAb->AbLeafType == LtSymbol && firstChar == 0)
-		    pViewSel->VsXPos = pBox->BxWidth;
+		  if ((pAb->AbLeafType == LtPicture && firstChar > 0) ||
+		      (pAb->AbLeafType == LtSymbol && firstChar == 0))
+		    pViewSel->VsXPos = pBox->BxLMargin + pBox->BxLBorder + pBox->BxLPadding + pBox->BxW;
 		  else
 		    pViewSel->VsXPos = 0;
 		  pViewSel->VsNSpaces = 0;
@@ -750,7 +699,8 @@ ThotBool            alone;
 		    }
 		  else
 		    {
-		      /* startSelection et endSelection sur deux caracteres differents */
+		      /* startSelection et endSelection sur deux caracteres
+			 differents */
 		      if (startSelection)
 			{
 			  pBuffer = pAb->AbText;
@@ -782,7 +732,7 @@ ThotBool            alone;
 		  /* recherche la position limite du caractere */
 		  pBox = pViewSel->VsBox;
 		  if (pBox->BxNChars == 0 && pBox->BxType == BoComplete)
-		    pViewSel->VsXPos += pBox->BxWidth;
+		    pViewSel->VsXPos += pBox->BxW;
 		  else if (pViewSel->VsIndBox == pBox->BxNChars)
 		    pViewSel->VsXPos += 2;
 		  else
@@ -797,136 +747,145 @@ ThotBool            alone;
 	    }
 
 	  /* pViewSel points to the right selector */
-	  if ( pFrame->FrClipXBegin == 0 && pFrame->FrClipXEnd == 0)
+	  /* ready to display the current selection */
+	  if (startSelection && endSelection)
 	    {
-	      /* ready to display the current selection */
-	      if (startSelection && endSelection)
-		{
-		  /* only one box is selected */
-		  pBox = pViewSel->VsBox;
-		  if (pBox->BxType == BoGhost)
-		    /* the highlight is transmitted to children */
-		    DrawBoxSelection (frame, pBox);
-		  else
-		    {
-		      if (pBox != pFrame->FrSelectionBegin.VsBox)
-			{
-			  /* several pieces of a split box are selected */
-			  /* the last one */
-			  DefClip (frame, pBox->BxXOrg, pBox->BxYOrg, pBox->BxXOrg + pViewSel->VsXPos, pBox->BxYOrg + pBox->BxHeight);
-			  RedrawFrameBottom (frame, 0, pAb);
-			  /* the first one */
-			  pBox = pFrame->FrSelectionBegin.VsBox;
-			  DefClip (frame, pBox->BxXOrg + pFrame->FrSelectionBegin.VsXPos, pBox->BxYOrg, pBox->BxXOrg + pBox->BxWidth, pBox->BxYOrg + pBox->BxHeight);
-			  RedrawFrameBottom (frame, 0, pAb);
-			  /* intermediate boxes */
-			  pBox = pBox->BxNexChild;
-			  while (pBox != pFrame->FrSelectionEnd.VsBox)
-			    {
-			      DefClip (frame, pBox->BxXOrg, pBox->BxYOrg, pBox->BxXOrg + pBox->BxWidth, pBox->BxYOrg + pBox->BxHeight);
-			      RedrawFrameBottom (frame, 0, pAb);
-			      pBox = pBox->BxNexChild;
-			    }
-			}
-		      else if (pFrame->FrSelectionBegin.VsIndBox == 0 || graphSel)
-			{
-			  /* the whole box is selected */
-			  w =  pBox->BxWidth;
-			  if (w == 0)
-			    w = 2;
-			  DefClip (frame, pBox->BxXOrg, pBox->BxYOrg, pBox->BxXOrg + w, pBox->BxYOrg + pBox->BxHeight);
-			  if (graphSel)
-			    /* need to redraw more than one box */
-			    RedrawFrameBottom (frame, 0, NULL);
-			  else
-			    RedrawFrameBottom (frame, 0, pAb);
-			}
-		      else
-			{
-			  /* a substring or a point of the box is selected */
-			  DefClip (frame, pBox->BxXOrg + pFrame->FrSelectionBegin.VsXPos, pBox->BxYOrg, pBox->BxXOrg + pViewSel->VsXPos, pBox->BxYOrg + pBox->BxHeight);
-			  if (graphSel)
-			    /* need to redraw more than one box */
-			    RedrawFrameBottom (frame, 0, NULL);
-			  else
-			    RedrawFrameBottom (frame, 0, pAb);
-			}
-		    }
-		}
-	      else if (endSelection)
-		{
-		  /* display the end of the selection */
-		  pBox = pViewSel->VsBox;
-		  if (pBox->BxType == BoGhost)
-		    /* the highlight is transmitted to children */
-		    DrawBoxSelection (frame, pBox);
-		  else
-		    {
-		      if (pViewSel->VsIndBox == 0)
-			/* the whole box is selected */
-			DefClip (frame, pBox->BxXOrg, pBox->BxYOrg, pBox->BxXOrg + pBox->BxWidth, pBox->BxYOrg + pBox->BxHeight);
-		      else
-			/* a substring or a point of the box is selected */
-			DefClip (frame, pBox->BxXOrg, pBox->BxYOrg, pBox->BxXOrg + pViewSel->VsXPos, pBox->BxYOrg + pBox->BxHeight);
-		      if (graphSel)
-			/* need to redraw more than one box */
-			RedrawFrameBottom (frame, 0, NULL);
-		      else
-			RedrawFrameBottom (frame, 0, pAb);
-		      if (pBox->BxType == BoPiece)
-			{
-			  /* select the begin of the split text */
-			  pBox = pAb->AbBox->BxNexChild;
-			  while (pBox != pViewSel->VsBox)
-			    {
-			      DefClip (frame, pBox->BxXOrg, pBox->BxYOrg, pBox->BxXOrg + pBox->BxWidth, pBox->BxYOrg + pBox->BxHeight);
-			      RedrawFrameBottom (frame, 0, pAb);
-			      pBox = pBox->BxNexChild;
-			    }
-			}
-		    }
-		}
+	      /* only one box is selected */
+	      pBox = pViewSel->VsBox;
+	      if (pBox->BxType == BoGhost ||
+		  (pAb != NULL &&
+		   FrameTable[frame].FrView == 1 &&
+		   TypeHasException (ExcHighlightChildren,
+				     pAb->AbElement->ElTypeNumber,
+				     pAb->AbElement->ElStructSchema)))
+		/* the highlight is transmitted to children */
+		DrawBoxSelection (frame, pBox);
 	      else
 		{
-		  /* display the beginning of the selection */
-		  pBox = pViewSel->VsBox;
-		  if (pBox->BxType == BoGhost)
-		    /* the highlight is transmitted to children */
-		    DrawBoxSelection (frame, pBox);
+		  if (pBox != pFrame->FrSelectionBegin.VsBox)
+		    {
+		      /* several pieces of a split box are selected */
+		      /* the last one */
+		      DefClip (frame, pBox->BxXOrg, pBox->BxYOrg,
+			       pBox->BxXOrg + pViewSel->VsXPos,
+			       pBox->BxYOrg + pBox->BxHeight);
+		      /* the first one */
+		      pBox = pFrame->FrSelectionBegin.VsBox;
+		      DefClip (frame,
+			       pBox->BxXOrg + pFrame->FrSelectionBegin.VsXPos,
+			       pBox->BxYOrg, pBox->BxXOrg + pBox->BxWidth,
+			       pBox->BxYOrg + pBox->BxHeight);
+		      /* intermediate boxes */
+		      pBox = pBox->BxNexChild;
+		      while (pBox != pFrame->FrSelectionEnd.VsBox)
+			{
+			  DefClip (frame, pBox->BxXOrg, pBox->BxYOrg,
+				   pBox->BxXOrg + pBox->BxWidth,
+				   pBox->BxYOrg + pBox->BxHeight);
+			  pBox = pBox->BxNexChild;
+			}
+		    }
+		  else if (pFrame->FrSelectionBegin.VsIndBox == 0 || graphSel)
+		    {
+		      /* the whole box is selected */
+		      w =  pBox->BxWidth;
+		      if (w == 0)
+			w = 2;
+		      DefClip (frame, pBox->BxXOrg, pBox->BxYOrg,
+			       pBox->BxXOrg + w,
+			       pBox->BxYOrg + pBox->BxHeight);
+		    }
 		  else
 		    {
-		      if (pViewSel->VsIndBox == 0)
-			/* the whole box is selected */
-			DefClip (frame, pBox->BxXOrg, pBox->BxYOrg, pBox->BxXOrg + pBox->BxWidth, pBox->BxYOrg + pBox->BxHeight);
+		      if (pFrame->FrSelectionBegin.VsXPos == pViewSel->VsXPos)
+			w = 2;
 		      else
-			/* a substring or a point of the box is selected */
-			DefClip (frame, pBox->BxXOrg + pViewSel->VsXPos, pBox->BxYOrg, pBox->BxXOrg + pBox->BxWidth, pBox->BxYOrg + pBox->BxHeight);
-		      if (graphSel)
-			/* need to redraw more than one box */
-			RedrawFrameBottom (frame, 0, NULL);
-		      else
-			RedrawFrameBottom (frame, 0, pAb);
-		      
-		      if (pBox->BxType == BoPiece)
+			w = 0;
+		      /* a substring or a point of the box is selected */
+		      DefClip (frame,
+			       pBox->BxXOrg + pFrame->FrSelectionBegin.VsXPos,
+			       pBox->BxYOrg, pBox->BxXOrg + pViewSel->VsXPos + w,
+			       pBox->BxYOrg + pBox->BxHeight);
+		    }
+		}
+	    }
+	  else if (endSelection)
+	    {
+	      /* display the end of the selection */
+	      pBox = pViewSel->VsBox;
+	      if (pBox->BxType == BoGhost ||
+		  (pAb != NULL &&
+		   FrameTable[frame].FrView == 1 &&
+		   TypeHasException (ExcHighlightChildren,
+				     pAb->AbElement->ElTypeNumber,
+				     pAb->AbElement->ElStructSchema)))
+		/* the highlight is transmitted to children */
+		DrawBoxSelection (frame, pBox);
+	      else
+		{
+		  if (pViewSel->VsIndBox == 0)
+		    /* the whole box is selected */
+		    DefClip (frame, pBox->BxXOrg, pBox->BxYOrg,
+			     pBox->BxXOrg + pBox->BxWidth,
+			     pBox->BxYOrg + pBox->BxHeight);
+		  else
+		    /* a substring or a point of the box is selected */
+		    DefClip (frame, pBox->BxXOrg, pBox->BxYOrg,
+			     pBox->BxXOrg + pViewSel->VsXPos,
+			     pBox->BxYOrg + pBox->BxHeight);
+		  if (pBox->BxType == BoPiece ||
+		      pBox->BxType == BoDotted)
+		    {
+		      /* select the begin of the split text */
+		      pBox = pAb->AbBox->BxNexChild;
+		      while (pBox != pViewSel->VsBox)
 			{
-			  /* select the end of the split text */
+			  DefClip (frame, pBox->BxXOrg, pBox->BxYOrg,
+				   pBox->BxXOrg + pBox->BxWidth,
+				   pBox->BxYOrg + pBox->BxHeight);
 			  pBox = pBox->BxNexChild;
-			  while (pBox)
-			    {
-			      DefClip (frame, pBox->BxXOrg, pBox->BxYOrg, pBox->BxXOrg + pBox->BxWidth, pBox->BxYOrg + pBox->BxHeight);
-			      RedrawFrameBottom (frame, 0, pAb);
-			      pBox = pBox->BxNexChild;
-			    }
 			}
 		    }
 		}
 	    }
-	  else if (alone && ind > pAb->AbVolume)
+	  else
 	    {
-	      /* the selection is outside the box */
-	      w = pBox->BxXOrg + pBox->BxWidth;
-	    DefClip (frame, w, pBox->BxYOrg,
-		     w + 2, pBox->BxYOrg + pBox->BxHeight);
+	      /* display the beginning of the selection */
+	      pBox = pViewSel->VsBox;
+	      if (pBox->BxType == BoGhost ||
+		  (pAb != NULL &&
+		   FrameTable[frame].FrView == 1 &&
+		   TypeHasException (ExcHighlightChildren,
+				     pAb->AbElement->ElTypeNumber,
+				     pAb->AbElement->ElStructSchema)))
+		/* the highlight is transmitted to children */
+		DrawBoxSelection (frame, pBox);
+	      else
+		{
+		  if (pViewSel->VsIndBox == 0)
+		    /* the whole box is selected */
+		    DefClip (frame, pBox->BxXOrg, pBox->BxYOrg,
+			     pBox->BxXOrg + pBox->BxWidth,
+			     pBox->BxYOrg + pBox->BxHeight);
+		  else
+		    /* a substring or a point of the box is selected */
+		    DefClip (frame, pBox->BxXOrg + pViewSel->VsXPos,
+			     pBox->BxYOrg, pBox->BxXOrg + pBox->BxWidth,
+			     pBox->BxYOrg + pBox->BxHeight);
+		  if (pBox->BxType == BoPiece ||
+		      pBox->BxType == BoDotted)
+		    {
+		      /* select the end of the split text */
+		      pBox = pBox->BxNexChild;
+		      while (pBox)
+			{
+			  DefClip (frame, pBox->BxXOrg, pBox->BxYOrg,
+				   pBox->BxXOrg + pBox->BxWidth,
+				   pBox->BxYOrg + pBox->BxHeight);
+			  pBox = pBox->BxNexChild;
+			}
+		    }
+		}
 	    }
 	}
     }
@@ -936,14 +895,7 @@ ThotBool            alone;
    IsAbstractBoxDisplayed rend la valeur vrai si le pave est affiche'
    dans le frame.                                          
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 ThotBool            IsAbstractBoxDisplayed (PtrAbstractBox pAb, int frame)
-#else  /* __STDC__ */
-ThotBool            IsAbstractBoxDisplayed (pAb, frame)
-PtrAbstractBox      pAb;
-int                 frame;
-
-#endif /* __STDC__ */
 {
    int                 min, max;
 
@@ -961,7 +913,8 @@ int                 frame;
    GetSizesFrame (frame, &min, &max);
    min = ViewFrameTable[frame - 1].FrYOrg;
    max += min;
-   if (pAb->AbBox->BxYOrg + pAb->AbBox->BxHeight < min || pAb->AbBox->BxYOrg > max)
+   if (pAb->AbBox->BxYOrg + pAb->AbBox->BxHeight < min ||
+       pAb->AbBox->BxYOrg > max)
       return FALSE;
    else
       return TRUE;
