@@ -1,19 +1,10 @@
 /*
  *
- *  (c) COPYRIGHT INRIA, 1996.
+ *  (c) COPYRIGHT INRIA, 1996-2001
  *  Please first read the full copyright statement in file COPYRIGHT.
  *
  */
 
-/*
- * Warning:
- * This module is part of the Thot library, which was originally
- * developed in French. That's why some comments are still in
- * French, but their translation is in progress and the full module
- * will be available in English in the next release.
- * 
- */
- 
 /*
  * This module handles line constructions
  *
@@ -49,13 +40,7 @@
    GetNextBox rend l'adresse de la boite associee au pave vivant qui  
    suit pAb.                                               
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 PtrBox              GetNextBox (PtrAbstractBox pAb)
-#else  /* __STDC__ */
-PtrBox              GetNextBox (pAb)
-PtrAbstractBox      pAb;
-
-#endif /* __STDC__ */
 {
    PtrAbstractBox      pNextAb;
    ThotBool            loop;
@@ -71,7 +56,9 @@ PtrAbstractBox      pAb;
 	while (loop)
 	   if (pNextAb == NULL)
 	      /* Est-ce la derniere boite fille d'une boite eclatee */
-	      if (pAb->AbEnclosing->AbBox->BxType == BoGhost)
+	      if (pAb->AbEnclosing &&
+		  pAb->AbEnclosing->AbBox &&
+		  pAb->AbEnclosing->AbBox->BxType == BoGhost)
 		{
 		   /* remonte la hierarchie */
 		   pAb = pAb->AbEnclosing;
@@ -112,13 +99,7 @@ PtrAbstractBox      pAb;
    GetPreviousBox rend l'adresse de la boite associee au pave vivant 
    qui precede pAb.                                        
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 static PtrBox       GetPreviousBox (PtrAbstractBox pAb)
-#else  /* __STDC__ */
-static PtrBox       GetPreviousBox (pAb)
-PtrAbstractBox      pAb;
-
-#endif /* __STDC__ */
 {
    PtrAbstractBox      pNextAb;
    ThotBool            loop;
@@ -172,17 +153,8 @@ PtrAbstractBox      pAb;
   Adjust computes the space width in the adjusted line.
   Move and update the width of all included boxes.
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-static void         Adjust (PtrBox pParentBox, PtrLine pLine, int frame, ThotBool orgXComplete, ThotBool orgYComplete)
-#else  /* __STDC__ */
-static void         Adjust (pParentBox, pLine, frame, orgXComplete, orgYComplete)
-PtrBox              pParentBox;
-PtrLine             pLine;
-int                 frame;
-ThotBool            orgXComplete;
-ThotBool            orgYComplete;
-
-#endif /* __STDC__ */
+static void Adjust (PtrBox pParentBox, PtrLine pLine, int frame,
+		    ThotBool orgXComplete, ThotBool orgYComplete)
 {
   PtrBox              pBox, pBoxInLine;
   int                 width, baseline;
@@ -247,10 +219,9 @@ ThotBool            orgYComplete;
   /* Update the position, the baseline and the width of each included box */
   width = pLine->LiXOrg;
   if (orgXComplete)
-    width += pParentBox->BxXOrg + pParentBox->BxLMargin + pParentBox->BxLBorder + pParentBox->BxLPadding;
+    width += pParentBox->BxXOrg;
   if (orgYComplete)
-    baseline += pParentBox->BxYOrg + pParentBox->BxTMargin + pParentBox->BxTBorder + pParentBox->BxTPadding;
-
+    baseline += pParentBox->BxYOrg;
   nSpaces = pLine->LiNPixels;
   if (pLine->LiFirstPiece != NULL)
     pBoxInLine = pLine->LiFirstPiece;
@@ -295,13 +266,7 @@ ThotBool            orgYComplete;
 /*----------------------------------------------------------------------
    FloatToInt fait un arrondi float -> int.                        
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 int                 FloatToInt (float e)
-#else  /* __STDC__ */
-int                 FloatToInt (e)
-float               e;
-
-#endif /* __STDC__ */
 {
   int                 value;
 
@@ -317,18 +282,8 @@ float               e;
   Align aligns included boxes in the line.
   Move all included boxes.
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-void                Align (PtrBox pParentBox, PtrLine pLine, int delta, int frame, ThotBool orgXComplete, ThotBool orgYComplete)
-#else  /* __STDC__ */
-void                Align (pParentBox, pLine, delta, frame, orgXComplete, orgYComplete)
-PtrBox              pParentBox;
-PtrLine             pLine;
-int                 delta;
-int                 frame;
-ThotBool            orgXComplete;
-ThotBool            orgYComplete;
-
-#endif /* __STDC__ */
+void Align (PtrBox pParentBox, PtrLine pLine, int delta, int frame,
+	    ThotBool orgXComplete, ThotBool orgYComplete)
 {
   PtrBox              pBox, pBoxInLine;
   int                 baseline, x;
@@ -378,20 +333,9 @@ ThotBool            orgYComplete;
   newIndex = the index the next character after the break in that buffer.
   pRootAb = the root abstract box for updating the chain of leaf boxes.   
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-static void         ManageBreakLine (PtrBox pBox, int width, int breakWidth, int boxLength, int nSpaces, int newIndex, PtrTextBuffer pNewBuff, PtrAbstractBox pRootAb)
-#else  /* __STDC__ */
-static void         ManageBreakLine (pBox, width, breakWidth, boxLength, nSpaces, newIndex, pNewBuff, pRootAb)
-PtrBox              pBox;
-int                 width;
-int                 breakWidth;
-int                 boxLength;
-int                 nSpaces;
-int                 newIndex;
-PtrTextBuffer       pNewBuff;
-PtrAbstractBox      pRootAb;
-
-#endif /* __STDC__ */
+static void ManageBreakLine (PtrBox pBox, int width, int breakWidth,
+			     int boxLength, int nSpaces, int newIndex,
+			     PtrTextBuffer pNewBuff, PtrAbstractBox pRootAb)
 {
   PtrBox              ibox1, ibox2;
   PtrBox              pPreviousBox, pNextBox;
@@ -553,19 +497,9 @@ PtrAbstractBox      pRootAb;
   - newIndex = the index the next character after the break in that buffer.
   - wordWidth = the width of the larger word in the string.
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-static ThotBool     FindBreakLine (PtrBox pBox, int *boxWidth, int *breakWidth, int *boxLength, int *nSpaces, int *newIndex, PtrTextBuffer *pNewBuff, int *wordWidth)
-#else  /* __STDC__ */
-static ThotBool     FindBreakLine (pBox, boxWidth, breakWidth, boxLength, nSpaces, newIndex, pNewBuff, wordWidth)
-PtrBox              pBox;
-int                *boxWidth;
-int                *breakWidth;
-int                *boxLength;
-int                *nSpaces;
-int                *newIndex;
-PtrTextBuffer      *pNewBuff;
-int                *wordWidth;
-#endif /* __STDC__ */
+static ThotBool FindBreakLine (PtrBox pBox, int *boxWidth, int *breakWidth,
+			       int *boxLength, int *nSpaces, int *newIndex,
+			       PtrTextBuffer *pNewBuff, int *wordWidth)
 {
   PtrTextBuffer       pBuffer;
   ptrfont             font;
@@ -685,21 +619,9 @@ int                *wordWidth;
   - pNewBuff = the buffer that contains the next character after the break.
   - newIndex = the index the next character after the break in that buffer.
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-static int          SearchBreak (PtrLine pLine, PtrBox pBox, int max, ptrfont font, int *boxLength, int *boxWidth, int *nSpaces, int *newIndex, PtrTextBuffer *pNewBuff)
-#else  /* __STDC__ */
-static int          SearchBreak (pLine, pBox, max, font, boxLength, boxWidth, nSpaces, newIndex, pNewBuff)
-PtrLine             pLine;
-PtrBox              pBox;
-int                 max;
-ptrfont             font;
-int                *boxLength;
-int                *boxWidth;
-int                *nSpaces;
-int                *newIndex;
-PtrTextBuffer      *pNewBuff;
-
-#endif /* __STDC__ */
+static int SearchBreak (PtrLine pLine, PtrBox pBox, int max, ptrfont font,
+			int *boxLength, int *boxWidth, int *nSpaces,
+			int *newIndex, PtrTextBuffer *pNewBuff)
 {
   PtrLine             pPreviousLine;
   PtrTextBuffer       pBuffer;
@@ -744,7 +666,7 @@ PtrTextBuffer      *pNewBuff;
       /* get the block of lines */
       while (pParentBox->BxType == BoGhost)
 	pParentBox = pParentBox->BxAbstractBox->AbEnclosing->AbBox;
-      if (pParentBox->BxAbstractBox->AbJustify)
+      if (pParentBox->BxAbstractBox->AbAdjust == AlignJustify)
 	/* for a justified line take the minimum space width */
 	spaceAdjust = FloatToInt ((float) (spaceAdjust * 7) / (float) (10));
     }
@@ -1111,16 +1033,8 @@ PtrTextBuffer      *pNewBuff;
   max = the maximum width of the first piece.
   pRootAb = the root abstract box for updating the chain of leaf boxes.   
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-static void         BreakMainBox (PtrLine pLine, PtrBox pBox, int max, PtrAbstractBox pRootAb, ThotBool force)
-#else  /* __STDC__ */
-static void         BreakMainBox (pLine, pBox, max, pRootAb, force)
-PtrLine             pLine;
-PtrBox              pBox;
-int                 max;
-PtrAbstractBox      pRootAb;
-ThotBool            force;
-#endif /* __STDC__ */
+static void BreakMainBox (PtrLine pLine, PtrBox pBox, int max,
+			  PtrAbstractBox pRootAb, ThotBool force)
 {
   PtrBox              ibox1, ibox2;
   PtrBox              pPreviousBox, pNextBox;
@@ -1281,16 +1195,8 @@ ThotBool            force;
   max = the maximum width of the first piece.
   pRootAb = the root abstract box for updating the chain of leaf boxes.   
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-static void         BreakPieceOfBox (PtrLine pLine, PtrBox pBox, int max, PtrAbstractBox pRootAb)
-#else  /* __STDC__ */
-static void         BreakPieceOfBox (pLine, pBox, max, pRootAb)
-PtrLine             pLine;
-PtrBox              pBox;
-int                 max;
-PtrAbstractBox      pRootAb;
-
-#endif /* __STDC__ */
+static void BreakPieceOfBox (PtrLine pLine, PtrBox pBox, int max,
+			     PtrAbstractBox pRootAb)
 {
   PtrBox              ibox2, pNextBox;
   PtrTextBuffer       pNewBuff;
@@ -1418,16 +1324,8 @@ PtrAbstractBox      pRootAb;
 /*----------------------------------------------------------------------
    AddBoxInLine adds a box in a line.
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-static void         AddBoxInLine (PtrBox pBox, int *descent, int *ascent, PtrLine pLine)
-#else  /* __STDC__ */
-static void         AddBoxInLine (pBox, descent, ascent, pLine)
-PtrBox              pBox;
-int                *descent;
-int                *ascent;
-PtrLine             pLine;
-
-#endif /* __STDC__ */
+static void AddBoxInLine (PtrBox pBox, int *descent, int *ascent,
+			  PtrLine pLine)
 {
    pLine->LiRealLength += pBox->BxWidth;
    /* Compute the current line height */
@@ -1449,18 +1347,9 @@ PtrLine             pLine;
   - notComplete = TRUE if all enclosed boxes are not managed yet.
   - breakLine = TRUE if the end of the line correspond to a break element.
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-static int          FillLine (PtrLine pLine, PtrAbstractBox pRootAb, ThotBool notComplete, ThotBool *full, ThotBool *adjust, ThotBool *breakLine, int frame)
-#else  /* __STDC__ */
-static int          FillLine (pLine, pRootAb, notComplete, full, adjust, breakLine, frame)
-PtrLine             pLine;
-PtrAbstractBox      pRootAb;
-ThotBool            notComplete;
-ThotBool           *full;
-ThotBool           *adjust;
-ThotBool           *breakLine
-int                 frame;
-#endif /* __STDC__ */
+static int FillLine (PtrLine pLine, PtrAbstractBox pRootAb,
+		     ThotBool notComplete, ThotBool *full, ThotBool *adjust,
+		     ThotBool *breakLine, int frame)
 {
    PtrTextBuffer       pNewBuff;
    PtrBox              pBox;
@@ -1594,6 +1483,8 @@ int                 frame;
 		       if (pNextBox == pLine->LiFirstBox)
 			 pLine->LiFirstPiece = pBox;
 		     }
+		   else
+			 pBox = pNextBox;
 		 }
 	     }
 	   else if (pNextBox->BxWidth + xi <= maxX)
@@ -1713,6 +1604,8 @@ int                 frame;
 		     /* the first box of the line is a split box now */
 		     if (pNextBox == pLine->LiFirstBox && pLine->LiFirstPiece == NULL)
 		       pLine->LiFirstPiece = pBox;
+			 if (pBox == NULL)
+               pBox = pNextBox;
 		     toCut = FALSE;
 		   }
 	       else if (!toCut)
@@ -1724,6 +1617,8 @@ int                 frame;
 		     {
 		       BreakMainBox (pLine, lastbox, maxLength, pRootAb, TRUE);	/* coupure forcee */
 		       pBox = lastbox->BxNexChild;
+               if (pBox == NULL)
+	             pBox = lastbox;
 		     }
 		   /* Si la boite est seule dans la ligne, laisse deborder */
 		   else if (lastbox == pLine->LiFirstBox)
@@ -1732,6 +1627,8 @@ int                 frame;
 		   else
 		     {
 		       pBox = GetPreviousBox (lastbox->BxAbstractBox);
+               if (pBox == NULL)
+	             pBox = lastbox;
 		       /* Si c'est la premiere boite de la ligne et que celle-ci ets coupee */
 		       if (pBox == pLine->LiFirstBox && pLine->LiFirstPiece != NULL)
 			 pBox = pLine->LiFirstPiece;
@@ -1744,13 +1641,15 @@ int                 frame;
 	 }
      }
 
-
+ 
    /* ajoute toutes les boites de la ligne */
    if (pLine->LiFirstPiece != NULL)
       pNextBox = pLine->LiFirstPiece;
    else
       pNextBox = pLine->LiFirstBox;
 
+   if (pBox->BxType == BoSplit)
+     pBox = pBox->BxNexChild;
    still = TRUE;
    while (still)
      {
@@ -1761,7 +1660,11 @@ int                 frame;
 	if (pNextBox == pBox)
 	   still = FALSE;
 	else
+	{
 	   pNextBox = GetNextBox (pNextBox->BxAbstractBox);
+       if (pNextBox == NULL)
+         still = FALSE;
+	}
      }
 
    /* termine le chainage */
@@ -1778,7 +1681,10 @@ int                 frame;
       *full = FALSE;
 
    /* coupe les blancs en fin de ligne pleine */
-   if ((notComplete || *full) && pBox->BxAbstractBox->AbLeafType == LtText && pBox->BxNSpaces != 0)
+   if ((notComplete || *full) &&
+       pBox->BxAbstractBox->AbLeafType == LtText &&
+       pBox->BxNSpaces != 0)
+     {
       if (pLine->LiLastPiece == NULL)
 	{
 	   maxLength = pBox->BxWidth;
@@ -1799,6 +1705,7 @@ int                 frame;
 	   /* met a jour la largeur de la ligne */
 	   pLine->LiRealLength = pLine->LiRealLength - maxLength + pBox->BxWidth;
 	}
+     }
 
    /* Calcule la hauteur et la base de la ligne */
    pLine->LiHeight = descent + ascent;
@@ -1812,14 +1719,7 @@ int                 frame;
    de la justification. Met a jour les marques de selection
    que la boite soit justifiee ou non.                     
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 static void         RemoveAdjustement (PtrBox pBox, int spaceWidth)
-#else  /* __STDC__ */
-static void         RemoveAdjustement (pBox, spaceWidth)
-PtrBox              pBox;
-int                 spaceWidth;
-
-#endif /* __STDC__ */
 {
    int                 x;
    int                 l;
@@ -1844,174 +1744,164 @@ int                 spaceWidth;
   changeSelectBegin and changeSelectEnd are TRUE when the box
   is concerned by the box selection.
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-static void         RemoveBreaks (PtrBox pBox, int frame, ThotBool *changeSelectBegin, ThotBool *changeSelectEnd)
-#else  /* __STDC__ */
-static void         RemoveBreaks (pBox, frame, changeSelectBegin, changeSelectEnd)
-PtrBox              pBox;
-int                 frame;
-ThotBool           *changeSelectBegin;
-ThotBool           *changeSelectEnd;
-
-#endif /* __STDC__ */
+static void RemoveBreaks (PtrBox pBox, int frame, ThotBool *changeSelectBegin,
+			  ThotBool *changeSelectEnd)
 {
-   PtrBox              ibox1;
-   PtrBox              ibox2;
-   PtrBox              pNextBox;
-   int                 x, width;
-   int                 number;
-   int                 lostPixels;
-   int                 diff;
-   PtrAbstractBox      pAb;
-   ViewFrame          *pFrame;
-   ViewSelection      *pViewSel;
+  PtrBox              ibox1;
+  PtrBox              ibox2;
+  PtrBox              pNextBox;
+  PtrAbstractBox      pAb;
+  ViewFrame          *pFrame;
+  ViewSelection      *pViewSel;
+  int                 x, width;
+  int                 number;
+  int                 lostPixels;
+  int                 diff;
 
-   pFrame = &ViewFrameTable[frame - 1];
-   if (pBox != NULL && pBox->BxAbstractBox != NULL)
-     {
-	pAb = pBox->BxAbstractBox;
-	if (pAb != NULL && pAb->AbLeafType == LtText)
-	  {
-	     x = CharacterWidth (SPACE, pBox->BxFont);
-	     if (pFrame->FrSelectionBegin.VsBox == pBox)
-	       {
-		  /* need to update the current selection */
-		  pFrame->FrSelectionBegin.VsBox = pAb->AbBox;
-		  *changeSelectBegin = TRUE;
-	       }
-	     if (pFrame->FrSelectionEnd.VsBox == pBox)
-	       {
-		  /* need to update the current selection */
-		  pFrame->FrSelectionEnd.VsBox = pAb->AbBox;
-		  *changeSelectEnd = TRUE;
-	       }
-
-	     if (pBox->BxType == BoComplete)
-	        /* not split */
-		RemoveAdjustement (pBox, x);
-	     else
-	       {
-		  /* take the first piece */
-		  ibox2 = pBox->BxNexChild;
-		  pBox->BxNexChild = NULL;
-		  if (pBox->BxType == BoSplit)
-		    {
-		       /* update the main box */
-		       pBox->BxType = BoComplete;
-		       pBox->BxPrevious = ibox2->BxPrevious;
-		       /* transmit the current position */
-		       pBox->BxXOrg = ibox2->BxXOrg;
-		       pBox->BxYOrg = ibox2->BxYOrg;
-		       if (pBox->BxPrevious != NULL)
-			  pBox->BxPrevious->BxNext = pBox;
-		       else
-			  pFrame->FrAbstractBox->AbBox->BxNext = pBox;
-
-		       width = 0;
-		       number = 0;
-		       lostPixels = 0;
-		    }
+  pFrame = &ViewFrameTable[frame - 1];
+  if (pBox != NULL && pBox->BxAbstractBox != NULL)
+    {
+      pAb = pBox->BxAbstractBox;
+      if (pAb != NULL && pAb->AbLeafType == LtText)
+	{
+	  x = CharacterWidth (SPACE, pBox->BxFont);
+	  if (pFrame->FrSelectionBegin.VsBox == pBox)
+	    {
+	      /* need to update the current selection */
+	      pFrame->FrSelectionBegin.VsBox = pAb->AbBox;
+	      *changeSelectBegin = TRUE;
+	    }
+	  if (pFrame->FrSelectionEnd.VsBox == pBox)
+	    {
+	      /* need to update the current selection */
+	      pFrame->FrSelectionEnd.VsBox = pAb->AbBox;
+	      *changeSelectEnd = TRUE;
+	    }
+	  
+	  if (pBox->BxType == BoComplete)
+	    /* not split */
+	    RemoveAdjustement (pBox, x);
+	  else
+	    {
+	      /* take the first piece */
+	      ibox2 = pBox->BxNexChild;
+	      pBox->BxNexChild = NULL;
+	      if (pBox->BxType == BoSplit)
+		{
+		  /* update the main box */
+		  pBox->BxType = BoComplete;
+		  pBox->BxPrevious = ibox2->BxPrevious;
+		  /* transmit the current position */
+		  pBox->BxXOrg = ibox2->BxXOrg;
+		  pBox->BxYOrg = ibox2->BxYOrg;
+		  if (pBox->BxPrevious != NULL)
+		    pBox->BxPrevious->BxNext = pBox;
 		  else
+		    pFrame->FrAbstractBox->AbBox->BxNext = pBox;
+		  width = 0;
+		  number = 0;
+		  lostPixels = 0;
+		}
+	      else
+		{
+		  /* merge one or more pieces */
+		  RemoveAdjustement (pBox, x);
+		  width = pBox->BxW;
+		  if (pBox->BxType == BoDotted)
 		    {
-		       /* merege one or more pieces */
-		       RemoveAdjustement (pBox, x);
-		       width = pBox->BxW;
-		       if (pBox->BxType == BoDotted)
-			 {
-			    /* remove the hyphen width */
-			    width -= CharacterWidth (173, pBox->BxFont);
-			    pBox->BxType = BoPiece;
-			 }
-		       number = pBox->BxNSpaces;
-		       lostPixels = pBox->BxIndChar + pBox->BxNChars;
+		      /* remove the hyphen width */
+		      width -= CharacterWidth (173, pBox->BxFont);
+		      pBox->BxType = BoPiece;
 		    }
-
-		  /* Now free all following pieces */
-		  if (ibox2 != NULL)
+		  number = pBox->BxNSpaces;
+		  lostPixels = pBox->BxIndChar + pBox->BxNChars;
+		}
+	      
+	      /* Now free all following pieces */
+	      if (ibox2 != NULL)
+		{
+		  do
 		    {
-		       do
-			 {
-			    ibox1 = ibox2;
-			    RemoveAdjustement (ibox1, x);
-			    /* lost pixels */
-			    diff = ibox1->BxIndChar - lostPixels;
-			    if (diff > 0)
-			      {
-				 /* add skipped spaces */
-				 width += diff * x;
-				 number += diff;
-			      }
-			    else if (ibox1->BxType == BoDotted)
-			       /* remove the hyphen width */
-			       width -= CharacterWidth (173, ibox1->BxFont);
+		      ibox1 = ibox2;
+		      RemoveAdjustement (ibox1, x);
+		      /* lost pixels */
+		      diff = ibox1->BxIndChar - lostPixels;
+		      if (diff > 0)
+			{
+			  /* add skipped spaces */
+			  width += diff * x;
+			  number += diff;
+			}
+		      else if (ibox1->BxType == BoDotted)
+			/* remove the hyphen width */
+			width -= CharacterWidth (173, ibox1->BxFont);
 
-			    /* if the next box is not empty */
-			    if (ibox1->BxNChars > 0)
-			      {
-				 number += ibox1->BxNSpaces;
-				 width += ibox1->BxW;
-			      }
-			    lostPixels = ibox1->BxIndChar + ibox1->BxNChars;
-			    pNextBox = ibox1->BxNext;
-			    /* transmit the rigth margin, border, and padding of the last box */
-			    if (ibox1->BxNexChild == NULL)
-			      {
-				ibox2->BxRMargin = pBox->BxRMargin;
-				ibox2->BxRBorder = pBox->BxRBorder;
-				ibox2->BxRPadding = pBox->BxRPadding;
-			      }
-			    ibox2 = FreeBox (ibox1);
-
-			    /* Prepare the selection update */
-			    pViewSel = &pFrame->FrSelectionBegin;
-			    if (pViewSel->VsBox == ibox1)
-			      {
-				 pViewSel->VsBox = pAb->AbBox;
-				 *changeSelectBegin = TRUE;
-			      }
-			    pViewSel = &pFrame->FrSelectionEnd;
-			    if (pViewSel->VsBox == ibox1)
-			      {
-				 pViewSel->VsBox = pAb->AbBox;
-				 *changeSelectEnd = TRUE;
-			      }
-			 }
-		       while (ibox2 != NULL);
-
-		       /* Update the first piece of box */
-		       if (pBox->BxType == BoPiece)
-			 {
-			    pBox->BxNChars = pBox->BxAbstractBox->AbBox->BxNChars - pBox->BxIndChar;
-			    /* add skipped spaces at the end */
-			    lostPixels = lostPixels - pBox->BxIndChar - pBox->BxNChars;
-			    if (lostPixels > 0)
-			      {
-				 width += lostPixels * x;
-				 number += lostPixels;
-			      }
-			    pBox->BxW = width;
-			    pBox->BxWidth = width + pBox->BxLMargin + pBox->BxLBorder + pBox->BxLPadding + pBox->BxRMargin + pBox->BxRBorder + pBox->BxRPadding;
-			    pBox->BxNSpaces = number;
-			 }
-
-		       /* Update the chain of leaf boxes */
-		       pBox->BxNext = pNextBox;
-		       if (pNextBox != NULL)
-			  pNextBox->BxPrevious = pBox;
-		       else
-			  pFrame->FrAbstractBox->AbBox->BxPrevious = pBox;
+		      /* if the next box is not empty */
+		      if (ibox1->BxNChars > 0)
+			{
+			  number += ibox1->BxNSpaces;
+			  width += ibox1->BxW;
+			}
+		      lostPixels = ibox1->BxIndChar + ibox1->BxNChars;
+		      pNextBox = ibox1->BxNext;
+		      /* transmit the rigth margin, border, and padding of the last box */
+		      if (ibox1->BxNexChild == NULL)
+			{
+			  ibox2->BxRMargin = pBox->BxRMargin;
+			  ibox2->BxRBorder = pBox->BxRBorder;
+			  ibox2->BxRPadding = pBox->BxRPadding;
+			}
+		      ibox2 = FreeBox (ibox1);
+		      
+		      /* Prepare the selection update */
+		      pViewSel = &pFrame->FrSelectionBegin;
+		      if (pViewSel->VsBox == ibox1)
+			{
+			  pViewSel->VsBox = pAb->AbBox;
+			  *changeSelectBegin = TRUE;
+			}
+		      pViewSel = &pFrame->FrSelectionEnd;
+		      if (pViewSel->VsBox == ibox1)
+			{
+			  pViewSel->VsBox = pAb->AbBox;
+			  *changeSelectEnd = TRUE;
+			}
 		    }
-	       }
-	  }
-	/* Pour les autres natures */
-	else
-	  {
-	     if (pFrame->FrSelectionBegin.VsBox == pBox)
-		*changeSelectBegin = TRUE;
-	     if (pFrame->FrSelectionEnd.VsBox == pBox)
-		*changeSelectEnd = TRUE;
-	  }
-     }
+		  while (ibox2 != NULL);
+		  
+		  /* Update the first piece of box */
+		  if (pBox->BxType == BoPiece)
+		    {
+		      pBox->BxNChars = pBox->BxAbstractBox->AbBox->BxNChars - pBox->BxIndChar;
+		      /* add skipped spaces at the end */
+		      lostPixels = lostPixels - pBox->BxIndChar - pBox->BxNChars;
+		      if (lostPixels > 0)
+			{
+			  width += lostPixels * x;
+			  number += lostPixels;
+			}
+		      pBox->BxW = width;
+		      pBox->BxWidth = width + pBox->BxLMargin + pBox->BxLBorder + pBox->BxLPadding + pBox->BxRMargin + pBox->BxRBorder + pBox->BxRPadding;
+		      pBox->BxNSpaces = number;
+		    }
+		  /* Update the chain of leaf boxes */
+		  pBox->BxNext = pNextBox;
+		  if (pNextBox != NULL)
+		    pNextBox->BxPrevious = pBox;
+		  else
+		    pFrame->FrAbstractBox->AbBox->BxPrevious = pBox;
+		}
+	    }
+	}
+      /* Pour les autres natures */
+      else
+	{
+	  if (pFrame->FrSelectionBegin.VsBox == pBox)
+	    *changeSelectBegin = TRUE;
+	  if (pFrame->FrSelectionEnd.VsBox == pBox)
+	    *changeSelectEnd = TRUE;
+	}
+    }
 }
 
 
@@ -2021,14 +1911,7 @@ ThotBool           *changeSelectEnd;
   building) or relativelly to the root box.
   Returns the box height.
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 void                ComputeLines (PtrBox pBox, int frame, int *height)
-#else  /* __STDC__ */
-void                ComputeLines (pBox, frame, height)
-PtrBox              pBox;
-int                 frame;
-int                *height;
-#endif /* __STDC__ */
 {
   PtrLine             pPreviousLine;
   PtrLine             pLine;
@@ -2281,7 +2164,8 @@ int                *height;
 		}
 
 	      /* Teste le cadrage des lignes */
-	      if (toAdjust && (full || pAb->AbTruncatedTail) && pAb->AbJustify)
+	      if (toAdjust && (full || pAb->AbTruncatedTail) &&
+		  pAb->AbAdjust == AlignJustify)
 		Adjust (pBox, pLine, frame, orgXComplete, orgYComplete);
 	      else
 		{
@@ -2307,11 +2191,13 @@ int                *height;
 	  
 	  /* is there a breaked box */
 	  if (pBoxToBreak != NULL)
+	    {
 	    /* is it empty ? */
 	    if (pBoxToBreak->BxNChars > 0)
 	      pNextBox = pLine->LiLastBox;
 	    else if (pNextBox == NULL)
 	      pNextBox = pLine->LiLastBox;
+	    }
 
 	  /* Est-ce la derniere ligne du bloc de ligne ? */
 	  if (full)
@@ -2374,22 +2260,33 @@ int                *height;
 	{
 	  /* compute minimum and maximum width of the paragraph */
 	  GetLine (&pLine);
-	  /* no limit as an extensible line */
-	  pLine->LiXMax = 3000;
-	  pLine->LiFirstBox = pNextBox;
-	  pLine->LiFirstPiece = NULL;
-	  pLine->LiLastPiece = NULL;
-	  pBox->BxMinWidth = FillLine (pLine, pRootAb, pAb->AbTruncatedTail, &full, &toAdjust, &breakLine, frame);
-	  if (full)
-	    {
-	      /* the last box has been broken */
-	      full = FALSE;
-	      still = FALSE;
-	    RemoveBreaks (pLine->LiLastBox, frame, &full, &still);
+	  do
+	    {	      
+	      /* no limit as an extensible line */
+	      pLine->LiXMax = 3000;
+	      pLine->LiFirstBox = pNextBox;
+	      pLine->LiFirstPiece = NULL;
+	      pLine->LiLastBox = NULL;
+	      pLine->LiLastPiece = NULL;
+	      minWidth = FillLine (pLine, pRootAb, pAb->AbTruncatedTail, &full, &toAdjust, &breakLine, frame);
+	      if (pBox->BxMinWidth < minWidth)
+		pBox->BxMinWidth = minWidth;
+	      if (breakLine)
+		pNextBox = GetNextBox (pLine->LiLastBox->BxAbstractBox);
+	      if (full)
+		{
+		  /* the last box has been broken */
+		  full = FALSE;
+		  still = FALSE;
+		  RemoveBreaks (pLine->LiLastBox, frame, &full, &still);
+		}
+	      if (pBox->BxMaxWidth < pLine->LiRealLength)
+		pBox->BxMaxWidth = pLine->LiRealLength;
+	      if (pLine->LiHeight > *height)
+		*height = pLine->LiHeight;
 	    }
-	  pBox->BxMaxWidth = pLine->LiRealLength;
-	  if (pLine->LiHeight > *height)
-	    *height = pLine->LiHeight;
+	  while (breakLine && pNextBox);
+
 	  FreeLine (pLine);
 	}
     }
@@ -2403,16 +2300,8 @@ int                *height;
 /*----------------------------------------------------------------------
   ShiftLine moves the line contents of x pixels.
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-static void         ShiftLine (PtrLine pLine, PtrAbstractBox pAb, PtrBox pBox, int x, int frame)
-#else  /* __STDC__ */
-static void         ShiftLine (pLine, pAb, pBox, x, frame)
-PtrLine             pLine;
-PtrAbstractBox      pAb;
-PtrBox              pBox;
-int                 x;
-int                 frame;
-#endif /* __STDC__ */
+static void ShiftLine (PtrLine pLine, PtrAbstractBox pAb, PtrBox pBox,
+		       int x, int frame)
 {
    PtrBox              ibox1, pSaveBox;
    PtrBox              pLastBox;
@@ -2436,11 +2325,11 @@ int                 frame;
    yf = yd + pLine->LiHeight;
 
    /* reaffiche la fin de la ligne */
-   if (pAb->AbAdjust == AlignLeft
-       || pAb->AbAdjust == AlignLeftDots
-   /* on force le cadrage a gauche si le bloc de lignes prend la largeur */
-   /* du contenu */
-       || pAb->AbBox->BxContentWidth)
+   if (pAb->AbAdjust == AlignLeft || pAb->AbAdjust == AlignJustify ||
+       pAb->AbAdjust == AlignLeftDots ||
+       /* on force le cadrage a gauche si le bloc de lignes prend la largeur */
+       /* du contenu */
+       pAb->AbBox->BxContentWidth)
      {
 	if (pLine->LiLastPiece == NULL)
 	   pLastBox = pLine->LiLastBox;
@@ -2524,16 +2413,7 @@ int                 frame;
    CompressLine compresse ou e'tend la ligne justifiee suite a`    
    l'ajout d'espaces et un ecart de xDelta pixels.         
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-static void         CompressLine (PtrLine pLine, int xDelta, int frame, int spaceDelta)
-#else  /* __STDC__ */
-static void         CompressLine (pLine, xDelta, frame, spaceDelta)
-PtrLine             pLine;
-int                 xDelta;
-int                 frame;
-int                 spaceDelta;
-
-#endif /* __STDC__ */
+static void CompressLine (PtrLine pLine, int xDelta, int frame, int spaceDelta)
 {
    PtrBox              ibox1, pBox;
    ViewSelection      *pViewSel;
@@ -2657,16 +2537,8 @@ int                 spaceDelta;
    la boite referencee par la marque Debut ou Fin de       
    Selection est liberee.                                  
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-void                RemoveLines (PtrBox pBox, int frame, PtrLine pFirstLine, ThotBool * changeSelectBegin, ThotBool * changeSelectEnd)
-#else  /* __STDC__ */
-void                RemoveLines (pBox, frame, pFirstLine, changeSelectBegin, changeSelectEnd)
-PtrBox              pBox;
-int                 frame;
-PtrLine             pFirstLine;
-ThotBool           *changeSelectBegin;
-ThotBool           *changeSelectEnd;
-#endif /* __STDC__ */
+void RemoveLines (PtrBox pBox, int frame, PtrLine pFirstLine,
+		  ThotBool *changeSelectBegin, ThotBool *changeSelectEnd)
 {
   PtrBox              ibox1;
   PtrLine             pNextLine;
@@ -2738,16 +2610,8 @@ ThotBool           *changeSelectEnd;
   RecomputeLines recomputes a part or the whole block of lines after
   a change in the box ibox.
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-void                RecomputeLines (PtrAbstractBox pAb, PtrLine pFirstLine, PtrBox ibox, int frame)
-#else  /* __STDC__ */
-void                RecomputeLines (pAb, pFirstLine, ibox, frame)
-PtrAbstractBox      pAb;
-PtrLine             pFirstLine;
-PtrBox              ibox;
-int                 frame;
-
-#endif /* __STDC__ */
+void RecomputeLines (PtrAbstractBox pAb, PtrLine pFirstLine, PtrBox ibox,
+		     int frame)
 {
    Propagation         propagateStatus;
    UCHAR_T             charIndex;
@@ -2915,17 +2779,8 @@ int                 frame;
   the included box pBox.
   The parameter xDelta gives the value of the width change.
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-void                UpdateLineBlock (PtrAbstractBox pAb, PtrLine pLine, PtrBox pBox, int xDelta, int spaceDelta, int frame)
-#else  /* __STDC__ */
-void                UpdateLineBlock (pAb, pLine, pBox, xDelta, spaceDelta, frame)
-PtrAbstractBox      pAb;
-PtrLine             pLine;
-PtrBox              pBox;
-int                 xDelta;
-int                 spaceDelta;
-int                 frame;
-#endif /* __STDC__ */
+void UpdateLineBlock (PtrAbstractBox pAb, PtrLine pLine, PtrBox pBox,
+		      int xDelta, int spaceDelta, int frame)
 {
    PtrTextBuffer       pNewBuff;
    PtrBox              ibox1;
@@ -3023,24 +2878,30 @@ int                 frame;
 		       else
 			  ibox1 = pLine->LiFirstBox;
 		       if (ibox1->BxWidth > maxLength)
-			  if (ibox1->BxAbstractBox->AbLeafType == LtText && maxLength > 0)
+			 {
+			  if (ibox1->BxAbstractBox->AbLeafType == LtText &&
+			      maxLength > 0)
 			    {
 			       /* Elimine le cas des lignes sans blanc */
 			       if (pLine->LiNSpaces == 0)
-				  maxLength = 1;	/* force la reevaluation */
+				  maxLength = 1;  /* force la reevaluation */
 			       else
 				 {
 				    length = ibox1->BxNChars;
-				    /* regarde si on peut trouver une coupure */
-				    maxLength = SearchBreak (pLine, ibox1, maxLength, ibox1->BxFont, &length, &width,
-					    &nSpaces, &newIndex, &pNewBuff);
+				    /* regarde si on peut trouver une coupure*/
+				    maxLength = SearchBreak (pLine, ibox1,
+                                                maxLength, ibox1->BxFont,
+                                                &length, &width, &nSpaces,
+						&newIndex, &pNewBuff);
 				 }
 
 			       if (maxLength > 0)
-				  RecomputeLines (pAb, pLine->LiPrevious, NULL, frame);
+				  RecomputeLines (pAb, pLine->LiPrevious, NULL,
+						  frame);
 			    }
 			  else
 			     maxLength = 0;
+			 }
 		    }
 		  else
 		     maxLength = 0;
@@ -3048,48 +2909,54 @@ int                 frame;
 		  /* Peut-on remonter le premier mot de la ligne suivante ? */
 		  if (maxLength == 0)
 		    {
-		       if (pLine->LiNext != NULL)
-			 {
-			    maxLength = pLine->LiXMax - pLine->LiRealLength - xDelta;
-			    pLi2 = pLine->LiNext;
-			    if (pLi2->LiFirstPiece != NULL)
-			       ibox1 = pLi2->LiFirstPiece;
-			    else
-			       ibox1 = pLi2->LiFirstBox;
-
-			    if (ibox1->BxWidth > maxLength)
-			       if (ibox1->BxAbstractBox->AbLeafType == LtText && maxLength > 0)
-				 {
-				    /* Elimine le cas des lignes sans blanc */
-				    if (pLi2->LiNSpaces == 0)
-				       maxLength = 1;	/* force la reevaluation */
-				    else
-				      {
-					 length = ibox1->BxNChars;
-					 /* regarde si on peut trouver une coupure */
-					 maxLength = SearchBreak (pLi2, ibox1, maxLength, ibox1->BxFont,
-								  &length, &width, &nSpaces, &newIndex, &pNewBuff);
-				      }
-				 }
-			       else
-				  maxLength = 0;
-			 }
-
-		       if (maxLength > 0)
-			  RecomputeLines (pAb, pLine, NULL, frame);
-		       else if (pLine->LiSpaceWidth == 0)
-			  ShiftLine (pLine, pAb, pBox, xDelta, frame);
-		       else
-			 {
-			    CompressLine (pLine, xDelta, frame, spaceDelta);
-			    pLine->LiRealLength = realLength;
-			 }
+		      if (pLine->LiNext != NULL)
+			{
+			  maxLength = pLine->LiXMax - pLine->LiRealLength - xDelta;
+			  pLi2 = pLine->LiNext;
+			  if (pLi2->LiFirstPiece != NULL)
+			    ibox1 = pLi2->LiFirstPiece;
+			  else
+			    ibox1 = pLi2->LiFirstBox;
+			  
+			  if (ibox1->BxWidth > maxLength)
+			    {
+			      if (ibox1->BxAbstractBox->AbLeafType == LtText &&
+				  maxLength > 0)
+				{
+				  /* Elimine le cas des lignes sans blanc */
+				  if (pLi2->LiNSpaces == 0)
+				    maxLength = 1; /* force la reevaluation */
+				  else
+				    {
+				      length = ibox1->BxNChars;
+				      /* regarde si on peut trouver une
+					 coupure */
+				      maxLength = SearchBreak (pLi2, ibox1,
+						  maxLength, ibox1->BxFont,
+						  &length, &width, &nSpaces,
+						  &newIndex, &pNewBuff);
+				    }
+				}
+			      else
+				maxLength = 0;
+			    }
+			}
+		      
+		      if (maxLength > 0)
+			RecomputeLines (pAb, pLine, NULL, frame);
+		      else if (pLine->LiSpaceWidth == 0)
+			ShiftLine (pLine, pAb, pBox, xDelta, frame);
+		      else
+			{
+			  CompressLine (pLine, xDelta, frame, spaceDelta);
+			  pLine->LiRealLength = realLength;
+			}
 		    }
 		  else
-		     RecomputeLines (pAb, pLine, NULL, frame);
+		    RecomputeLines (pAb, pLine, NULL, frame);
 	       }
 	     else
-		RecomputeLines (pAb, pLine, NULL, frame);
+	       RecomputeLines (pAb, pLine, NULL, frame);
 	  }
      }
 }
@@ -3100,15 +2967,7 @@ int                 frame;
   current line of pAb.
   Update the block of lines if necessary.
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-void                EncloseInLine (PtrBox pBox, int frame, PtrAbstractBox pAb)
-#else  /* __STDC__ */
-void                EncloseInLine (pBox, frame, pAb)
-PtrBox              pBox;
-int                 frame;
-PtrAbstractBox      pAb;
-
-#endif /* __STDC__ */
+void      EncloseInLine (PtrBox pBox, int frame, PtrAbstractBox pAb)
 {
   PtrBox              ibox1;
   PtrBox              pPieceBox;
