@@ -1,21 +1,12 @@
 /*
  *
- *  (c) COPYRIGHT INRIA, 1996.
+ *  (c) COPYRIGHT INRIA, 1996-2001
  *  Please first read the full copyright statement in file COPYRIGHT.
  *
  */
 
 /*
- * Warning:
- * This module is part of the Thot library, which was originally
- * developed in French. That's why some comments are still in
- * French, but their translation is in progress and the full module
- * will be available in English in the next release.
- * 
- */
- 
-/*
- * visualisation of Selections.
+ * visualization of Selection.
  *
  * Author: I. Vatton (INRIA)
  *
@@ -39,28 +30,21 @@
 #include "font_f.h"
 #include "frame_f.h"
 #include "units_f.h"
-#include "windowdisplay_f.h"
+#include "xwindowdisplay_f.h"
 
 
 /*----------------------------------------------------------------------
-  DisplayPointSelection draw characteristics point of the box.
+  DisplayPointSelection draw control points of the box.
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 void         DisplayPointSelection (int frame, PtrBox pBox, int pointselect)
-#else  /* __STDC__ */
-void         DisplayPointSelection (frame, pBox, pointselect)
-int                 frame;
-PtrBox              pBox;
-int                 pointselect;
-#endif /* __STDC__ */
 {
   ViewFrame          *pFrame;
   PtrAbstractBox      pAb;
   PtrTextBuffer       pBuffer;
-  int                 leftX, rightX;
-  int                 topY, bottomY;
-  int                 minX, thick;
-  int                 middleY;
+  PtrPathSeg          pPa;
+  int                 leftX, middleX, rightX;
+  int                 topY, middleY, bottomY;
+  int                 thick, halfThick;
   int                 i, j, n;
   int                 x, y;
 
@@ -73,41 +57,42 @@ int                 pointselect;
 	thick = pBox->BxWidth;
       if (thick > pBox->BxHeight)
 	thick = pBox->BxHeight;
+      halfThick = thick / 2;
 
       /* selection points */
       leftX = pBox->BxXOrg - pFrame->FrXOrg;
       topY = pBox->BxYOrg - pFrame->FrYOrg;
       bottomY = topY + pBox->BxHeight - thick;
       rightX = leftX + pBox->BxWidth - thick;
-      minX = leftX + (pBox->BxWidth - thick) / 2;
-      middleY = topY + (pBox->BxHeight - thick) / 2;
+      middleX = leftX + (pBox->BxWidth / 2) - halfThick;
+      middleY = topY + (pBox->BxHeight / 2) - halfThick;
       if (pAb->AbLeafType == LtPicture)
 	{
-	  /* 8 characteristic points */
+	  /* 8 control points */
 	  DrawRectangle (frame, 0, 0, leftX, topY, thick, thick,
-			 0, 0, 0, InsertColor, 2);
-	  DrawRectangle (frame, 0, 0, minX, topY, thick, thick,
-			 0, 0, 0, InsertColor, 2);
+			 0, InsertColor, 2);
+	  DrawRectangle (frame, 0, 0, middleX, topY, thick, thick,
+			 0, InsertColor, 2);
 	  DrawRectangle (frame, 0, 0, rightX, topY, thick, thick,
-			 0, 0, 0, InsertColor, 2);
+			 0, InsertColor, 2);
 	  DrawRectangle (frame, 0, 0, leftX, middleY, thick, thick,
-			 0, 0, 0, InsertColor, 2);
+			 0, InsertColor, 2);
 	  DrawRectangle (frame, 0, 0, rightX, middleY, thick, thick,
-			 0, 0, 0, InsertColor, 2);
+			 0, InsertColor, 2);
 	  DrawRectangle (frame, 0, 0, leftX, bottomY, thick, thick,
-			 0, 0, 0, InsertColor, 2);
-	  DrawRectangle (frame, 0, 0, minX, bottomY, thick, thick,
-			 0, 0, 0, InsertColor, 2);
+			 0, InsertColor, 2);
+	  DrawRectangle (frame, 0, 0, middleX, bottomY, thick, thick,
+			 0, InsertColor, 2);
 	  DrawRectangle (frame, 0, 0, rightX, bottomY, thick, thick,
-			 0, 0, 0, InsertColor, 2);
+			 0, InsertColor, 2);
 	}
       else if (pAb->AbLeafType == LtPolyLine && pBox->BxNChars > 1)
 	{
-	  /* Draw characteristic points of the polyline */
-	  /* if there is almost one point in he polyline */
+	  /* Draw control points of the polyline */
+	  /* if there is at least one point in the polyline */
 	  pBuffer = pBox->BxBuffer;
-	  leftX = pBox->BxXOrg - pFrame->FrXOrg;
-	  topY = pBox->BxYOrg - pFrame->FrYOrg;
+	  leftX = pBox->BxXOrg - pFrame->FrXOrg - halfThick;
+	  topY = pBox->BxYOrg - pFrame->FrYOrg - halfThick;
 	  j = 1;
 	  n = pBox->BxNChars;
 	  for (i = 1; i < n; i++)
@@ -124,24 +109,45 @@ int                 pointselect;
 	      if (pointselect == 0 || pointselect == i)
 		{
 		  x = leftX + PixelValue (pBuffer->BuPoints[j].XCoord,
-					  UnPixel, NULL,
-					  ViewFrameTable[frame - 1].FrMagnification);
-		  if (x > rightX)
-		    x =  rightX;
+				   UnPixel, NULL,
+				   ViewFrameTable[frame - 1].FrMagnification);
 		  y = topY + PixelValue (pBuffer->BuPoints[j].YCoord,
-					 UnPixel, NULL,
-					 ViewFrameTable[frame - 1].FrMagnification);
-		  if (y > bottomY)
-		    y =  bottomY;
-		  DrawRectangle (frame, 0, 0,
-				 x, y,
-				 thick, thick,
-				 0, 0, 0, InsertColor, 2);
+				   UnPixel, NULL,
+				   ViewFrameTable[frame - 1].FrMagnification);
+		  DrawRectangle (frame, 0, 0, x, y, thick, thick, 0,
+				 InsertColor, 2);
 		}
 	      
 	      j++;
 	    }
 	}
+      else if (pAb->AbLeafType == LtPath)
+	{
+	  /* Draw control points of the path */
+	  pPa = pAb->AbFirstPathSeg;
+	  leftX = pBox->BxXOrg - pFrame->FrXOrg - halfThick;
+	  topY = pBox->BxYOrg - pFrame->FrYOrg - halfThick;
+	  while (pPa)
+	    {
+	      if (pPa->PaNewSubpath || !pPa->PaPrevious)
+		/* this path segment starts a new subpath */
+		{
+		  x = leftX + PixelValue (pPa->XStart, UnPixel, NULL,
+				   ViewFrameTable[frame - 1].FrMagnification);
+		  y = topY + PixelValue (pPa->YStart, UnPixel, NULL,
+                                   ViewFrameTable[frame - 1].FrMagnification);
+		  DrawRectangle (frame, 0, 0, x, y, thick, thick, 0,
+				 InsertColor, 2);
+		}
+	      x = leftX + PixelValue (pPa->XEnd, UnPixel, NULL,
+				   ViewFrameTable[frame - 1].FrMagnification);
+	      y = topY + PixelValue (pPa->YEnd, UnPixel, NULL,
+				   ViewFrameTable[frame - 1].FrMagnification);
+	      DrawRectangle (frame, 0, 0, x, y, thick, thick, 0,
+			     InsertColor, 2);
+	      pPa = pPa->PaNext;
+	    }
+	}
       else if (pointselect != 0)
 	/* Keep in mind the selected caracteristic point       */
 	/*            1-------------2-------------3            */
@@ -155,70 +161,70 @@ int                 pointselect;
 	  {
 	  case 1:
 	    DrawRectangle (frame, 0, 0, leftX, topY, thick, thick,
-			   0, 0, 0, InsertColor, 2);
+			   0, InsertColor, 2);
 	    break;
 	  case 2:
-	    DrawRectangle (frame, 0, 0, minX, topY, thick, thick,
-			   0, 0, 0, InsertColor, 2);
+	    DrawRectangle (frame, 0, 0, middleX, topY, thick, thick,
+			   0, InsertColor, 2);
 	    break;
 	  case 3:
 	    DrawRectangle (frame, 0, 0, rightX, topY, thick, thick,
-			   0, 0, 0, InsertColor, 2);
+			   0, InsertColor, 2);
 	    break;
 	  case 4:
 	    DrawRectangle (frame, 0, 0, rightX, middleY, thick, thick,
-			   0, 0, 0, InsertColor, 2);
+			   0, InsertColor, 2);
 	    break;
 	  case 5:
 	    DrawRectangle (frame, 0, 0, rightX, bottomY, thick, thick,
-			   0, 0, 0, InsertColor, 2);
+			   0, InsertColor, 2);
 	    break;
 	  case 6:
-	    DrawRectangle (frame, 0, 0, minX, bottomY, thick, thick,
-			   0, 0, 0, InsertColor, 2);
+	    DrawRectangle (frame, 0, 0, middleX, bottomY, thick, thick,
+			   0, InsertColor, 2);
 	    break;
 	  case 7:
 	    DrawRectangle (frame, 0, 0, leftX, bottomY, thick, thick,
-			   0, 0, 0, InsertColor, 2);
+			   0, InsertColor, 2);
 	    break;
 	  case 8:
 	    DrawRectangle (frame, 0, 0, leftX, middleY, thick, thick,
-			   0, 0, 0, InsertColor, 2);
+			   0, InsertColor, 2);
 	    break;
 	  }
       else if (pAb->AbLeafType == LtGraphics && pAb->AbVolume != 0)
 	/* C'est une boite graphique */
-	/* On marque en noir les points caracteristiques de la boite */
+	/* On marque les points caracteristiques de la boite */
 	switch (pAb->AbRealShape)
 	  {
 	  case SPACE:
-	  case TEXT('R'):
-	  case TEXT('0'):
-	  case TEXT('1'):
-	  case TEXT('2'):
-	  case TEXT('3'):
-	  case TEXT('4'):
-	  case TEXT('5'):
-	  case TEXT('6'):
-	  case TEXT('7'):
-	  case TEXT('8'):
-	    /* 8 characteristic points */
+	  case 'R':
+	  case '0':
+	  case '1':
+	  case '2':
+	  case '3':
+	  case '4':
+	  case '5':
+	  case '6':
+	  case '7':
+	  case '8':
+	    /* 8 control points */
 	    DrawRectangle (frame, 0, 0, leftX, topY, thick, thick,
-			   0, 0, 0, InsertColor, 2);
-	    DrawRectangle (frame, 0, 0, minX, topY, thick, thick,
-			   0, 0, 0, InsertColor, 2);
+			   0, InsertColor, 2);
+	    DrawRectangle (frame, 0, 0, middleX, topY, thick, thick,
+			   0, InsertColor, 2);
 	    DrawRectangle (frame, 0, 0, rightX, topY, thick, thick,
-			   0, 0, 0, InsertColor, 2);
+			   0, InsertColor, 2);
 	    DrawRectangle (frame, 0, 0, leftX, middleY, thick, thick,
-			   0, 0, 0, InsertColor, 2);
+			   0, InsertColor, 2);
 	    DrawRectangle (frame, 0, 0, rightX, middleY, thick, thick,
-			   0, 0, 0, InsertColor, 2);
+			   0, InsertColor, 2);
 	    DrawRectangle (frame, 0, 0, leftX, bottomY, thick, thick,
-			   0, 0, 0, InsertColor, 2);
-	    DrawRectangle (frame, 0, 0, minX, bottomY, thick, thick,
-			   0, 0, 0, InsertColor, 2);
+			   0, InsertColor, 2);
+	    DrawRectangle (frame, 0, 0, middleX, bottomY, thick, thick,
+			   0, InsertColor, 2);
 	    DrawRectangle (frame, 0, 0, rightX, bottomY, thick, thick,
-			   0, 0, 0, InsertColor, 2);
+			   0, InsertColor, 2);
 	    break;
 	  case 'C':
 	  case 'L':
@@ -226,146 +232,161 @@ int                 pointselect;
 	  case 'c':
 	  case 'P':
 	  case 'Q':
-	    /* 4 characteristic points */
-	    DrawRectangle (frame, 0, 0, minX, topY, thick, thick,
-			   0, 0, 0, InsertColor, 2);
+	    /* 4 control points */
+	    DrawRectangle (frame, 0, 0, middleX, topY, thick, thick,
+			   0, InsertColor, 2);
 	    DrawRectangle (frame, 0, 0, leftX, middleY, thick, thick,
-			   0, 0, 0, InsertColor, 2);
+			   0, InsertColor, 2);
 	    DrawRectangle (frame, 0, 0, rightX, middleY, thick, thick,
-			   0, 0, 0, InsertColor, 2);
-	    DrawRectangle (frame, 0, 0, minX, bottomY, thick, thick,
-			   0, 0, 0, InsertColor, 2);
+			   0, InsertColor, 2);
+	    DrawRectangle (frame, 0, 0, middleX, bottomY, thick, thick,
+			   0, InsertColor, 2);
+	    if (pAb->AbRealShape == 'C' && pAb->AbRx == 0 && pAb->AbRy == 0)
+	      /* rounded corners are not round. display a control point
+		 for each corner */
+	      {
+		DrawRectangle (frame, 0, 0, leftX, topY, thick, thick,
+			       0, InsertColor, 2);
+		DrawRectangle (frame, 0, 0, rightX, topY, thick, thick,
+			       0, InsertColor, 2);
+		DrawRectangle (frame, 0, 0, leftX, bottomY, thick, thick,
+			       0, InsertColor, 2);
+		DrawRectangle (frame, 0, 0, rightX, bottomY, thick, thick,
+			       0, InsertColor, 2);
+	      }
 	    break;
 	  case 'W':
-	    /* 3 characteristic points */
+	    /* 3 control points */
 	    DrawRectangle (frame, 0, 0, leftX, topY, thick, thick,
-			   0, 0, 0, InsertColor, 2);
+			   0, InsertColor, 2);
 	    DrawRectangle (frame, 0, 0, rightX, topY, thick, thick,
-			   0, 0, 0, InsertColor, 2);
+			   0, InsertColor, 2);
 	    DrawRectangle (frame, 0, 0, rightX, bottomY, thick, thick,
-			   0, 0, 0, InsertColor, 2);
+			   0, InsertColor, 2);
 	    break;
 	  case 'X':
-	    /* 3 characteristic points */
+	    /* 3 control points */
 	    DrawRectangle (frame, 0, 0, rightX, topY, thick, thick,
-			   0, 0, 0, InsertColor, 2);
+			   0, InsertColor, 2);
 	    DrawRectangle (frame, 0, 0, leftX, bottomY, thick, thick,
-			   0, 0, 0, InsertColor, 2);
+			   0, InsertColor, 2);
 	    DrawRectangle (frame, 0, 0, rightX, bottomY, thick, thick,
-			   0, 0, 0, InsertColor, 2);
+			   0, InsertColor, 2);
 	    break;
 	  case 'Y':
-	    /* 3 characteristic points */
+	    /* 3 control points */
 	    DrawRectangle (frame, 0, 0, leftX, topY, thick, thick,
-			   0, 0, 0, InsertColor, 2);
+			   0, InsertColor, 2);
 	    DrawRectangle (frame, 0, 0, leftX, bottomY, thick, thick,
-			   0, 0, 0, InsertColor, 2);
+			   0, InsertColor, 2);
 	    DrawRectangle (frame, 0, 0, rightX, bottomY, thick, thick,
-			   0, 0, 0, InsertColor, 2);
+			   0, InsertColor, 2);
 	    break;
 	  case 'Z':
-	    /* 3 characteristic points */
+	    /* 3 control points */
 	    DrawRectangle (frame, 0, 0, leftX, topY, thick, thick,
-			   0, 0, 0, InsertColor, 2);
+			   0, InsertColor, 2);
 	    DrawRectangle (frame, 0, 0, rightX, topY, thick, thick,
-			   0, 0, 0, InsertColor, 2);
+			   0, InsertColor, 2);
 	    DrawRectangle (frame, 0, 0, rightX, bottomY, thick, thick,
-			   0, 0, 0, InsertColor, 2);
+			   0, InsertColor, 2);
 	    break;
 	    
 	  case 'h':
 	  case '<':
 	  case '>':
-	    /* 2 characteristic points */
+	    /* 2 control points */
 	    DrawRectangle (frame, 0, 0, leftX, middleY, thick, thick,
-			   0, 0, 0, InsertColor, 2);
+			   0, InsertColor, 2);
 	    DrawRectangle (frame, 0, 0, rightX, middleY, thick, thick,
-			   0, 0, 0, InsertColor, 2);
+			   0, InsertColor, 2);
 	    break;
 	  case 't':
-	    /* 3 characteristic points */
+	    /* 3 control points */
 	    DrawRectangle (frame, 0, 0, leftX, topY, thick, thick,
-			   0, 0, 0, InsertColor, 2);
-	    DrawRectangle (frame, 0, 0, minX, topY, thick, thick,
-			   0, 0, 0, InsertColor, 2);
+			   0, InsertColor, 2);
+	    DrawRectangle (frame, 0, 0, middleX, topY, thick, thick,
+			   0, InsertColor, 2);
 	    DrawRectangle (frame, 0, 0, rightX, topY, thick, thick,
-			   0, 0, 0, InsertColor, 2);
+			   0, InsertColor, 2);
 	    break;
 	  case 'b':
-	    /* 3 characteristic points */
+	    /* 3 control points */
 	    DrawRectangle (frame, 0, 0, leftX, bottomY, thick, thick,
-			   0, 0, 0, InsertColor, 2);
-	    DrawRectangle (frame, 0, 0, minX, bottomY, thick, thick,
-			   0, 0, 0, InsertColor, 2);
+			   0, InsertColor, 2);
+	    DrawRectangle (frame, 0, 0, middleX, bottomY, thick, thick,
+			   0, InsertColor, 2);
 	    DrawRectangle (frame, 0, 0, rightX, bottomY, thick, thick,
-			   0, 0, 0, InsertColor, 2);
+			   0, InsertColor, 2);
 	    break;
 	  case 'v':
 	  case '^':
 	  case 'V':
-	    /* 2 characteristic points */
-	    DrawRectangle (frame, 0, 0, minX, topY, thick, thick,
-			   0, 0, 0, InsertColor, 2);
-	    DrawRectangle (frame, 0, 0, minX, bottomY, thick, thick,
-			   0, 0, 0, InsertColor, 2);
+	    /* 2 control points */
+	    DrawRectangle (frame, 0, 0, middleX, topY, thick, thick,
+			   0, InsertColor, 2);
+	    DrawRectangle (frame, 0, 0, middleX, bottomY, thick, thick,
+			   0, InsertColor, 2);
 	    break;
 	  case 'l':
-	    /* 3 characteristic points */
+	    /* 3 control points */
 	    DrawRectangle (frame, 0, 0, leftX, topY, thick, thick,
-			   0, 0, 0, InsertColor, 2);
+			   0, InsertColor, 2);
 	    DrawRectangle (frame, 0, 0, leftX, middleY, thick, thick,
-			   0, 0, 0, InsertColor, 2);
+			   0, InsertColor, 2);
 	    DrawRectangle (frame, 0, 0, leftX, bottomY, thick, thick,
-			   0, 0, 0, InsertColor, 2);
+			   0, InsertColor, 2);
 	    break;
 	  case 'r':
-	    /* 3 characteristic points */
+	    /* 3 control points */
 	    DrawRectangle (frame, 0, 0, rightX, topY, thick, thick,
-			   0, 0, 0, InsertColor, 2);
+			   0, InsertColor, 2);
 	    DrawRectangle (frame, 0, 0, rightX, middleY, thick, thick,
-			   0, 0, 0, InsertColor, 2);
+			   0, InsertColor, 2);
 	    DrawRectangle (frame, 0, 0, rightX, bottomY, thick, thick,
-			   0, 0, 0, InsertColor, 2);
+			   0, InsertColor, 2);
 	    break;
 	  case '\\':
 	  case 'O':
 	  case 'e':
-	    /* 2 characteristic points */
+	    /* 2 control points */
 	    DrawRectangle (frame, 0, 0, leftX, topY, thick, thick,
-			   0, 0, 0, InsertColor, 2);
+			   0, InsertColor, 2);
 	    DrawRectangle (frame, 0, 0, rightX, bottomY, thick, thick,
-			   0, 0, 0, InsertColor, 2);
+			   0, InsertColor, 2);
 	    break;
 	  case '/':
 	  case 'o':
 	  case 'E':
-	    /* 2 characteristic points */
+	    /* 2 control points */
 	    DrawRectangle (frame, 0, 0, rightX, topY, thick, thick,
-			   0, 0, 0, InsertColor, 2);
+			   0, InsertColor, 2);
 	    DrawRectangle (frame, 0, 0, leftX, bottomY, thick, thick,
-			   0, 0, 0, InsertColor, 2);
+			   0, InsertColor, 2);
 	    break;
 	  case 'g':
 	    /* Coords of the line are given by the enclosing box */
 	    pAb = pAb->AbEnclosing;
-	    if ((pAb->AbHorizPos.PosEdge == Left && pAb->AbVertPos.PosEdge == Top) ||
-		(pAb->AbHorizPos.PosEdge == Right && pAb->AbVertPos.PosEdge == Bottom))
+	    if ((pAb->AbHorizPos.PosEdge == Left &&
+		 pAb->AbVertPos.PosEdge == Top) ||
+		(pAb->AbHorizPos.PosEdge == Right &&
+		 pAb->AbVertPos.PosEdge == Bottom))
 	      {
 		/* draw a \ */
-		/* 2 characteristic points */
+		/* 2 control points */
 		DrawRectangle (frame, 0, 0, leftX, topY, thick, thick,
-			       0, 0, 0, InsertColor, 2);
+			       0, InsertColor, 2);
 		DrawRectangle (frame, 0, 0, rightX, bottomY, thick, thick,
-			       0, 0, 0, InsertColor, 2);
+			       0, InsertColor, 2);
 	      }
 	    else
 	      {
 		/* draw a / */
-		/* 2 characteristic points */
+		/* 2 control points */
 		DrawRectangle (frame, 0, 0, rightX, topY, thick, thick,
-			       0, 0, 0, InsertColor, 2);
+			       0, InsertColor, 2);
 		DrawRectangle (frame, 0, 0, leftX, bottomY, thick, thick,
-			       0, 0, 0, InsertColor, 2);
+			       0, InsertColor, 2);
 	      }
 	    break;
 	  default:
@@ -379,13 +400,7 @@ int                 pointselect;
   DisplayBgBoxSelection paints the box background with the selection
   color.
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 void         DisplayBgBoxSelection (int frame, PtrBox pBox)
-#else  /* __STDC__ */
-void         DisplayBgBoxSelection (frame, pBox)
-int          frame;
-PtrBox       pBox;
-#endif /* __STDC__ */
 {
   PtrBox              pChildBox;
   ViewFrame          *pFrame;
@@ -396,27 +411,7 @@ PtrBox       pBox;
     {
       pFrame = &ViewFrameTable[frame - 1];
       pAb = pBox->BxAbstractBox;
-      
-      if (pBox->BxType == BoGhost ||
-	  (pAb != NULL &&
-	   TypeHasException (ExcHighlightChildren, pAb->AbElement->ElTypeNumber, pAb->AbElement->ElStructSchema)))
-	{
-	  /* the box is not displayed, select its children */
-	  if (pAb->AbFirstEnclosed != NULL)
-	    {
-	      pChildBox = pAb->AbFirstEnclosed->AbBox;
-	      while (pChildBox != NULL)
-		{
-		  DisplayBgBoxSelection (frame, pChildBox);
-		  pAb = pChildBox->BxAbstractBox;
-		  if (pAb->AbNext != NULL)
-		    pChildBox = pAb->AbNext->AbBox;
-		  else
-		    pChildBox = NULL;
-		}
-	    }
-	}
-      else if (pBox->BxType == BoSplit)
+      if (pBox->BxType == BoSplit)
 	{
 	  /* display the selection on pieces of the current box */
 	  pChildBox = pBox->BxNexChild;
@@ -428,6 +423,7 @@ PtrBox       pBox;
 	}
       else if (pAb->AbLeafType == LtPicture ||
 	       pAb->AbLeafType == LtGraphics ||
+	       pAb->AbLeafType == LtPath ||
 	       pAb->AbLeafType == LtPolyLine)
 	DisplayPointSelection (frame, pBox, 0);
       else
@@ -438,67 +434,16 @@ PtrBox       pBox;
 	  /* draw the background of the selection */
 	  DrawRectangle (frame, 0, 0, leftX, topY,
 			 pBox->BxWidth, pBox->BxHeight,
-			 0, 0, 0, SelColor, 2);
+			 0, SelColor, 2);
 	}
     }
 }
 
-/*----------------------------------------------------------------------
-  DisplayBgSelection goes through the tree for displaying the background
-  selection.
-  ----------------------------------------------------------------------*/
-#ifdef __STDC__
-void                DisplayBgSelection (int frame, PtrAbstractBox pAb)
-#else  /* __STDC__ */
-void                DisplayBgSelection (frame, pAb)
-int                 frame;
-PtrAbstractBox      pAb;
-#endif /* __STDC__ */
-{
-   PtrAbstractBox      pChildAb;
-   ViewFrame          *pFrame;
-
-   if (pAb != NULL)
-     {
-	/* The abstract box is selected */
-	if (pAb->AbSelected)
-	  {
-	     pFrame = &ViewFrameTable[frame - 1];
-	     if (pFrame->FrSelectionBegin.VsBox == NULL ||
-		 pFrame->FrSelectionEnd.VsBox == NULL ||
-		 pAb->AbLeafType == LtCompound ||
-		 (pAb != pFrame->FrSelectionBegin.VsBox->BxAbstractBox &&
-		  pAb != pFrame->FrSelectionEnd.VsBox->BxAbstractBox))
-	       {
-		 /* it's not a terminal extremity of the selection */
-		 if (pAb->AbVolume > 0)
-		   DisplayBgBoxSelection (frame, pAb->AbBox);
-	       }
-	  }
-	else if (pAb->AbLeafType == LtCompound)
-	   /* Sinon on parcours le sous-arbre */
-	  {
-	     pChildAb = pAb->AbFirstEnclosed;
-	     while (pChildAb != NULL)
-	       {
-		  DisplayBgSelection (frame, pChildAb);
-		  pChildAb = pChildAb->AbNext;
-	       }
-	  }
-     }
-}
-
 
 /*----------------------------------------------------------------------
   DrawBoxSelection paints the box with the selection background.
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 void         DrawBoxSelection (int frame, PtrBox pBox)
-#else  /* __STDC__ */
-void         DrawBoxSelection (frame, pBox)
-int          frame;
-PtrBox       pBox;
-#endif /* __STDC__ */
 {
   PtrBox              pChildBox;
   PtrAbstractBox      pAb;
@@ -506,26 +451,7 @@ PtrBox       pBox;
   if (pBox != NULL)
     {
       pAb = pBox->BxAbstractBox;      
-      if (pBox->BxType == BoGhost
-	  || (pAb != NULL
-	      && TypeHasException (ExcHighlightChildren, pAb->AbElement->ElTypeNumber, pAb->AbElement->ElStructSchema)))
-	{
-	  /* the box is not displayed, select its children */
-	  if (pAb->AbFirstEnclosed != NULL)
-	    {
-	      pChildBox = pAb->AbFirstEnclosed->AbBox;
-	      while (pChildBox != NULL)
-		{
-		  DrawBoxSelection (frame, pChildBox);
-		  pAb = pChildBox->BxAbstractBox;
-		  if (pAb->AbNext != NULL)
-		    pChildBox = pAb->AbNext->AbBox;
-		  else
-		    pChildBox = NULL;
-		}
-	    }
-	}
-      else if (pBox->BxType == BoSplit)
+      if (pBox->BxType == BoSplit)
 	{
 	  /* display the selection on pieces of the current box */
 	  pChildBox = pBox->BxNexChild;
@@ -536,11 +462,10 @@ PtrBox       pBox;
 	    }
 	}
       else
-	{
-	  /* display other elements */
-	  DefClip (frame, pBox->BxXOrg, pBox->BxYOrg, pBox->BxXOrg + pBox->BxWidth, pBox->BxYOrg + pBox->BxHeight);
-	  RedrawFrameBottom (frame, 0, pAb);
-	}
+	/* display other elements */
+	DefClip (frame, pBox->BxXOrg, pBox->BxYOrg,
+		 pBox->BxXOrg + pBox->BxWidth,
+		 pBox->BxYOrg + pBox->BxHeight);
     }
 }
 
@@ -548,64 +473,45 @@ PtrBox       pBox;
   SetNewSelectionStatus goes through the tree for switching the selection
   indicator.
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-void                SetNewSelectionStatus (int frame, PtrAbstractBox pAb, ThotBool status)
-#else  /* __STDC__ */
-void                SetNewSelectionStatus (frame, pAb, status)
-int                 frame;
-PtrAbstractBox      pAb;
-ThotBool            status;
-
-#endif /* __STDC__ */
+void    SetNewSelectionStatus (int frame, PtrAbstractBox pAb, ThotBool status)
 {
-   PtrAbstractBox      pChildAb;
-   ViewFrame          *pFrame;
+  PtrAbstractBox      pChildAb;
+  ViewFrame          *pFrame;
 
-   if (pAb != NULL)
-     {
-	/* Le pave est selectionne */
-	if (pAb->AbSelected)
-	  {
-	     pFrame = &ViewFrameTable[frame - 1];
-	     pAb->AbSelected = status;
-	     if ( pFrame->FrClipXBegin == 0 && pFrame->FrClipXEnd == 0 &&
-		  pAb->AbVolume != 0)
-	       /* ready to un/display the current selection */
-	       /* doesn't display selection limits */
-	       if (pFrame->FrSelectionBegin.VsBox == NULL ||
-		   pFrame->FrSelectionEnd.VsBox == NULL ||
-		   pAb->AbLeafType == LtCompound ||
-		   (pAb != pFrame->FrSelectionBegin.VsBox->BxAbstractBox &&
-		    pAb != pFrame->FrSelectionEnd.VsBox->BxAbstractBox))
-		 if (pAb->AbBox)
-		   DrawBoxSelection (frame, pAb->AbBox);
-	  }
-	else if (pAb->AbLeafType == LtCompound)
-	   /* Sinon on parcours le sous-arbre */
-	  {
-	     pChildAb = pAb->AbFirstEnclosed;
-	     while (pChildAb != NULL)
-	       {
-		  SetNewSelectionStatus (frame, pChildAb, status);
-		  pChildAb = pChildAb->AbNext;
-	       }
-	  }
-     }
+  if (pAb != NULL)
+    {
+      if (pAb->AbSelected)
+	{
+	  /* the abstract box is selected */
+	  pFrame = &ViewFrameTable[frame - 1];
+	  pAb->AbSelected = status;
+	    /* doesn't display selection limits */
+	    if (pFrame->FrSelectionBegin.VsBox == NULL ||
+		pFrame->FrSelectionEnd.VsBox == NULL ||
+		pAb->AbLeafType == LtCompound ||
+		(pAb != pFrame->FrSelectionBegin.VsBox->BxAbstractBox &&
+		 pAb != pFrame->FrSelectionEnd.VsBox->BxAbstractBox))
+	      if (pAb->AbBox)
+		DrawBoxSelection (frame, pAb->AbBox);
+	}
+      else if (pAb->AbLeafType == LtCompound)
+	/* check the subtree */
+	{
+	  pChildAb = pAb->AbFirstEnclosed;
+	  while (pChildAb != NULL)
+	    {
+	      SetNewSelectionStatus (frame, pChildAb, status);
+	      pChildAb = pChildAb->AbNext;
+	    }
+	}
+    }
 }
 
 /*----------------------------------------------------------------------
   DisplayStringSelection the selection on a substring of text
   between leftX and rightX.
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 void         DisplayStringSelection (int frame, int leftX, int rightX, PtrBox pBox)
-#else  /* __STDC__ */
-void         DisplayStringSelection (frame, leftX, rightX, pBox)
-int                 frame;
-int                 leftX;
-int                 rightX;
-PtrBox              pBox;
-#endif /* __STDC__ */
 {
   PtrBox              pParentBox;
   ViewFrame          *pFrame;
@@ -635,7 +541,8 @@ PtrBox              pBox;
       /* clipped by the enclosing box */
       height = pParentBox->BxYOrg + pParentBox->BxHeight - pFrame->FrYOrg;
       /* and the scrolling zone */
-      width = FrameTable[frame].FrScrollOrg + FrameTable[frame].FrScrollWidth - pFrame->FrXOrg;
+      width = FrameTable[frame].FrScrollOrg + FrameTable[frame].FrScrollWidth
+	      - pFrame->FrXOrg;
 
       topY = pBox->BxYOrg - pFrame->FrYOrg;
       h = pBox->BxHeight;
@@ -659,8 +566,6 @@ PtrBox              pBox;
 	col = InsertColor;
       else
 	col = SelColor;
-      DrawRectangle (frame, 0, 0, leftX, topY, width, h,
-		     0, 0, 0, col, 2);
+      DrawRectangle (frame, 0, 0, leftX, topY, width, h, 0, col, 2);
     }
 }
-
